#
# sysmt_fw.pm
# -----------
#
# Design and Implementation by Bjoern Lemke               
#           
# (C)opyright 2011,2012 by Bjoern Lemke
#                                              
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2, or (at your option)
# any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; see the file COPYING.  If not, write to
# the Free Software Foundation, 59 Temple Place - Suite 330,
# Boston, MA 02111-1307, USA.
#

package PerlSpace::SysMtFirewall;


############################
### Server Group methods ###
############################

sub sysmtFWSGMaster
{
    
    my ( $dbh, $user ) = @_;

    my ( $headmsg, $fullname, $sysmsg )  = PerlSpace::SysMtUtil::getHeaderInfo($dbh, $user);
    $$dbdata{'headertext'} = $headmsg;
    $$dbdata{'fullname'} = $fullname;
    $$dbdata{'sysmsg'} = $sysmsg;
    $$dbdata{'content'} = "sysmt_fwsgmaster.html";
    
    $TT ||= Template->new({ INCLUDE_PATH  => $PerlSpace::SysMtExecuter::tmplpath });
    $TT->process('sysmt_frame.html', $dbdata) || die $TT->error(), "\n";

    
    return 0;
    
}


sub sysmtFWSGListByName
{
    
    my ( $dbh, $user, $sgname) = @_;    

    my $stmt = "select sgid, sgname from sysmt_fwsg where sgname like '%" . $sgname . "%'";    
    my $ordering = "order by sgname";
 
    sysmtFWSGSearchExecuteList($dbh, $user, $stmt, $ordering);

    return 0;    

}

sub sysmtFWSGSearchExecuteList
{
    
    my ( $dbh, $user, $stmt, $ordering ) = @_;

    my $sth = $dbh->prepare($stmt . " " . $ordering . ";");

    $sth->execute;
    
    my $dbdata;

    $$dbdata{'stmt'} = $stmt;

    my $sgid;
    my $sgname;
    
    my $i=0;
    while ( ($sgid, $sgname ) = $sth->fetchrow_array) 
    {

	$$dbdata{'sglist'}[$i]{'sgid'} = $sgid;
	$$dbdata{'sglist'}[$i]{'sgname'} = $sgname;

	$i++;
    }
    
    $sth->finish;    


    my ( $headmsg, $fullname, $sysmsg )  = PerlSpace::SysMtUtil::getHeaderInfo($dbh, $user);
    $$dbdata{'headertext'} = $headmsg;
    $$dbdata{'fullname'} = $fullname;
    $$dbdata{'sysmsg'} = $sysmsg;
    $$dbdata{'content'} = "sysmt_fwsglist.html";
    
    $TT ||= Template->new({ INCLUDE_PATH  => $PerlSpace::SysMtExecuter::tmplpath });
    $TT->process('sysmt_frame.html', $dbdata) || die $TT->error(), "\n";

    return 0;
}


sub sysmtFWSG
{    
    my ( $dbh, $user, $sgid ) = @_;
    
    my $dbdata;

    # reached fs tmpl retrievel
    $stmt="select sgname, sgdesc from sysmt_fwsg where sgid = ?;";
    $sth = $dbh->prepare($stmt);
    $sth->bind_param(1, $sgid, DBI::SQL_INTEGER);
    
    $sth->execute;

    ( $sgname, $sgdesc ) = $sth->fetchrow_array;     
    
    $sth->finish;

    $$dbdata{'sgid'} = $sgid;
    $$dbdata{'sgname'} = $sgname;
    $$dbdata{'sgdesc'} = $sgdesc;


    # ip retrievel
    $stmt="select ipval, ipdesc from sysmt_fwsgentry where sgid = ? order by ipval;";

    $sth = $dbh->prepare($stmt);

    $sth->bind_param(1, $sgid, DBI::SQL_INTEGER);

    $sth->execute;
        
    my $ipval;
    my $ipdesc;

    $i=0;
    while ( ($ipval, $ipdesc ) = $sth->fetchrow_array) 
    {
	$$dbdata{'iplist'}[$i]{'ipval'} = $ipval;
	$$dbdata{'iplist'}[$i]{'ipdesc'} = $ipdesc;
	$i++;
    }
    
    $sth->finish;    


    my ( $headmsg, $fullname, $sysmsg )  = PerlSpace::SysMtUtil::getHeaderInfo($dbh, $user);
    $$dbdata{'headertext'} = $headmsg;
    $$dbdata{'fullname'} = $fullname;
    $$dbdata{'sysmsg'} = $sysmsg;
    $$dbdata{'content'} = "sysmt_fwsg.html";
    
    $TT ||= Template->new({ INCLUDE_PATH  => $PerlSpace::SysMtExecuter::tmplpath });
    $TT->process('sysmt_frame.html', $dbdata) || die $TT->error(), "\n";

    return 0;
    
}

sub sysmtFWSGNew
{

    my ( $dbh, $user ) = @_;

    if ( PerlSpace::SysMtUtil::checkFWWrite($dbh, $user) == 0 )
    {
        die "No appropriate right\n";
    }

    my $dbdata;


    my ( $headmsg, $fullname, $sysmsg )  = PerlSpace::SysMtUtil::getHeaderInfo($dbh, $user);
    $$dbdata{'headertext'} = $headmsg;
    $$dbdata{'fullname'} = $fullname;
    $$dbdata{'sysmsg'} = $sysmsg;
    $$dbdata{'content'} = "sysmt_fwsgnew.html";
    
    $TT ||= Template->new({ INCLUDE_PATH  => $PerlSpace::SysMtExecuter::tmplpath });
    $TT->process('sysmt_frame.html', $dbdata) || die $TT->error(), "\n";

    return 0;

}


sub sysmtFWSGCreate
{

    my ( $dbh, $user, $sgname, $sgdesc) = @_;

    my $dbdata;

    my $sgid;

    # trim left and right whitespaces
    $sgname =~ s/^\s+//;
    $sgname =~ s/\s+$//;


    if ( $PerlSpace::SysMtExecuter::db eq "cego" )
    {

	$sth = $dbh->prepare("? = call newFWSG ( ?, ? );");
	
	$sth->bind_param_inout(1, \$sgid, 10);
	$sth->bind_param(2, $sgname, DBI::SQL_VARCHAR);
	$sth->bind_param(3, $sgdesc, DBI::SQL_VARCHAR);
	
	$sth->execute;

    }
    elsif ( $PerlSpace::SysMtExecuter::db eq "mysql" )
    {
	$sth = $dbh->prepare("select newFWSG(?,?);");

	$sth->bind_param(1, $sgname, DBI::SQL_VARCHAR);
	$sth->bind_param(2, $sgdesc, DBI::SQL_VARCHAR);
	
	$sth->execute;
	$sgid = $sth->fetchrow_array;	
    }
    elsif ( $PerlSpace::SysMtExecuter::db eq "db2" )
    {
	$sth = $dbh->prepare(q{call newFWSG(?,?,?)});

	$sth->bind_param(1, $sgname, DBI::SQL_VARCHAR);
	$sth->bind_param(2, $sgdesc, DBI::SQL_VARCHAR);
	$sth->bind_param_inout(3, \$sgid, 100, DBI::SQL_INTEGER);

	$sth->execute;
    }

    $sth->finish;    

    return sysmtFWSG($dbh, $user, $sgid);

}

sub sysmtFWSGUpdate
{

    my ( $dbh, $user, $sgid, $sgname, $sgdesc ) = @_;

    my $dbdata;

    $sth = $dbh->prepare("update sysmt_fwsg set sgname = ?, sgdesc = ? where sgid = ?;");

    $sth->bind_param(1, $sgname, DBI::SQL_VARCHAR);
    $sth->bind_param(2, $sgdesc, DBI::SQL_VARCHAR);
    $sth->bind_param(3, $sgid, DBI::SQL_INTEGER);

    $sth->execute;

    $sth->finish;    

    return sysmtFWSG($dbh, $user, $sgid);

}


sub sysmtFWSGDelete
{

    my ( $dbh, $user, $sgid ) = @_;

    my $dbdata;

    $sth = $dbh->prepare("delete from sysmt_fwsgentry where sgid = ?;");
   
    $sth->bind_param(1, $sgid, DBI::SQL_INTEGER);

    $sth->execute;

    $sth->finish;    

    $sth = $dbh->prepare("delete from sysmt_fwsg where sgid = ?;");
   
    $sth->bind_param(1, $sgid, DBI::SQL_INTEGER);

    $sth->execute;

    $sth->finish;    

    return sysmtFWSGMaster($dbh, $user);

}

sub sysmtFWSGAddEntry
{

    my ( $dbh, $user, $sgid, $ipval, $ipdesc ) = @_;


    $sth = $dbh->prepare("insert into sysmt_fwsgentry ( sgid, ipval, ipdesc ) values (?,?,?);");
    
    $sth->bind_param(1, $sgid, DBI::SQL_INTEGER);
    $sth->bind_param(2, $ipval, DBI::SQL_VARCHAR);
    $sth->bind_param(3, $ipdesc, DBI::SQL_VARCHAR);

    $sth->execute;
    
    $sth->finish;    

    return sysmtFWSG($dbh, $user, $sgid);

}

sub sysmtFWSGUpdateEntry
{

    my ( $dbh, $user, $sgid, $oipval, $ipval, $ipdesc ) = @_;
    
    $sth = $dbh->prepare("update sysmt_fwsgentry set ipval = ?, ipdesc = ? where sgid = ? and ipval = ?;");
    
    $sth->bind_param(1, $ipval, DBI::SQL_VARCHAR);
    $sth->bind_param(2, $ipdesc, DBI::SQL_VARCHAR);
    $sth->bind_param(3, $sgid, DBI::SQL_INTEGER);
    $sth->bind_param(4, $oipval, DBI::SQL_VARCHAR);

    $sth->execute;

    $sth->finish;    

    return sysmtFWSG($dbh, $user, $sgid);

}


sub sysmtFWSGDeleteEntry
{

    my ( $dbh, $user, $sgid, $ipval ) = @_;

    $sth = $dbh->prepare("delete from sysmt_fwsgentry where sgid = ? and ipval = ?;");

    $sth->bind_param(1, $sgid, DBI::SQL_INTEGER);
    $sth->bind_param(2, $ipval, DBI::SQL_VARCHAR);

    $sth->execute;

    $sth->finish;

    return sysmtFWSG($dbh, $user, $sgid);

}

########################
### Port Set methods ###
########################

sub sysmtFWPSMaster
{
    
    my ( $dbh, $user ) = @_;
    
    my ( $headmsg, $fullname, $sysmsg )  = PerlSpace::SysMtUtil::getHeaderInfo($dbh, $user);
    $$dbdata{'headertext'} = $headmsg;
    $$dbdata{'fullname'} = $fullname;
    $$dbdata{'sysmsg'} = $sysmsg;
    $$dbdata{'content'} = "sysmt_fwpsmaster.html";
    
    $TT ||= Template->new({ INCLUDE_PATH  => $PerlSpace::SysMtExecuter::tmplpath });
    $TT->process('sysmt_frame.html', $dbdata) || die $TT->error(), "\n";

    return 0;

    
}

sub sysmtFWPSListByName
{
    
    my ( $dbh, $user, $psname) = @_;    

    my $stmt = "select psid, psname from sysmt_fwps where psname like '%" . $psname . "%'";    
    my $ordering = "order by psname";
 
    sysmtFWPSSearchExecuteList($dbh, $user, $stmt, $ordering);

    return 0;    

}

sub sysmtFWPSSearchExecuteList
{
    
    my ( $dbh, $user, $stmt, $ordering ) = @_;

    my $sth = $dbh->prepare($stmt . " " . $ordering . ";");

    $sth->execute;
    
    my $dbdata;

    $$dbdata{'stmt'} = $stmt;

    my $psid;
    my $psname;
    
    my $i=0;
    while ( ($psid, $psname ) = $sth->fetchrow_array) 
    {

	$$dbdata{'pslist'}[$i]{'psid'} = $psid;
	$$dbdata{'pslist'}[$i]{'psname'} = $psname;

	$i++;
    }
    
    $sth->finish;    
    

    my ( $headmsg, $fullname, $sysmsg )  = PerlSpace::SysMtUtil::getHeaderInfo($dbh, $user);
    $$dbdata{'headertext'} = $headmsg;
    $$dbdata{'fullname'} = $fullname;
    $$dbdata{'sysmsg'} = $sysmsg;
    $$dbdata{'content'} = "sysmt_fwpslist.html";
    
    $TT ||= Template->new({ INCLUDE_PATH  => $PerlSpace::SysMtExecuter::tmplpath });
    $TT->process('sysmt_frame.html', $dbdata) || die $TT->error(), "\n";

    return 0;

}


sub sysmtFWPS
{    
    my ( $dbh, $user, $psid ) = @_;
    
    my $dbdata;

    # reached fs tmpl retrievel
    $stmt="select psname, psdesc from sysmt_fwps where psid = ?;";
    $sth = $dbh->prepare($stmt);
    $sth->bind_param(1, $psid, DBI::SQL_INTEGER);

    $sth->execute;

    ( $psname, $psdesc ) = $sth->fetchrow_array;     
    
    $sth->finish;

    $$dbdata{'psid'} = $psid;
    $$dbdata{'psname'} = $psname;
    $$dbdata{'psdesc'} = $psdesc;


    # port retrievel
    $stmt="select portval, porttype, portdesc from sysmt_fwpsentry where psid = ? order by portval;";

    $sth = $dbh->prepare($stmt);

    $sth->bind_param(1, $psid, DBI::SQL_INTEGER);

    $sth->execute;
        
    my $portval;
    my $porttype;
    my $portdesc;

    $i=0;
    while ( ($portval, $porttype, $portdesc ) = $sth->fetchrow_array) 
    {
	$$dbdata{'portlist'}[$i]{'portval'} = $portval;
	$$dbdata{'portlist'}[$i]{'porttype'} = $porttype;
	$$dbdata{'portlist'}[$i]{'portdesc'} = $portdesc;
	$i++;
    }
    
    $sth->finish;    


    my ( $headmsg, $fullname, $sysmsg )  = PerlSpace::SysMtUtil::getHeaderInfo($dbh, $user);
    $$dbdata{'headertext'} = $headmsg;
    $$dbdata{'fullname'} = $fullname;
    $$dbdata{'sysmsg'} = $sysmsg;
    $$dbdata{'content'} = "sysmt_fwps.html";
    
    $TT ||= Template->new({ INCLUDE_PATH  => $PerlSpace::SysMtExecuter::tmplpath });
    $TT->process('sysmt_frame.html', $dbdata) || die $TT->error(), "\n";

    return 0;

    
}

sub sysmtFWPSNew
{

    my ( $dbh, $user ) = @_;

    if ( PerlSpace::SysMtUtil::checkFWWrite($dbh, $user) == 0 )
    {
        die "No appropriate right\n";
    }

    my $dbdata;


    my ( $headmsg, $fullname, $sysmsg )  = PerlSpace::SysMtUtil::getHeaderInfo($dbh, $user);
    $$dbdata{'headertext'} = $headmsg;
    $$dbdata{'fullname'} = $fullname;
    $$dbdata{'sysmsg'} = $sysmsg;
    $$dbdata{'content'} = "sysmt_fwpsnew.html";
    
    $TT ||= Template->new({ INCLUDE_PATH  => $PerlSpace::SysMtExecuter::tmplpath });
    $TT->process('sysmt_frame.html', $dbdata) || die $TT->error(), "\n";

    return 0;

}


sub sysmtFWPSCreate
{

    my ( $dbh, $user, $psname, $psdesc) = @_;

    my $dbdata;

    my $psid;

    # trim left and right whitespaces
    $psname =~ s/^\s+//;
    $psname =~ s/\s+$//;

    if ( $PerlSpace::SysMtExecuter::db eq "cego" )
    {

	$sth = $dbh->prepare("? = call newFWPS ( ?, ? );");
	
	$sth->bind_param_inout(1, \$psid, 10);
	$sth->bind_param(2, $psname, DBI::SQL_VARCHAR);
	$sth->bind_param(3, $psdesc, DBI::SQL_VARCHAR);
	
        $sth->execute;

    }
    elsif ( $PerlSpace::SysMtExecuter::db eq "mysql" )
    {
	$sth = $dbh->prepare("select newFWPS(?,?);");

	$sth->bind_param(1, $psname, DBI::SQL_VARCHAR);
	$sth->bind_param(2, $psdesc, DBI::SQL_VARCHAR);
	
	$sth->execute;
	$psid = $sth->fetchrow_array;	
    }
    elsif ( $PerlSpace::SysMtExecuter::db eq "db2" )
    {
	$sth = $dbh->prepare(q{call newFWPS(?,?,?)});

	$sth->bind_param(1, $psname, DBI::SQL_VARCHAR);
	$sth->bind_param(2, $psdesc, DBI::SQL_VARCHAR);
	$sth->bind_param_inout(3, \$psid, 100, DBI::SQL_INTEGER);
    
        $sth->execute;

    }
    $sth->finish;    

    return sysmtFWPS($dbh, $user, $psid);

}

sub sysmtFWPSUpdate
{

    my ( $dbh, $user, $psid, $psname, $psdesc ) = @_;

    my $dbdata;

    $sth = $dbh->prepare("update sysmt_fwps set psname = ?, psdesc = ? where psid = ?;");

    $sth->bind_param(1, $psname, DBI::SQL_VARCHAR);
    $sth->bind_param(2, $psdesc, DBI::SQL_VARCHAR);
    $sth->bind_param(3, $psid, DBI::SQL_INTEGER);

    $sth->execute;

    $sth->finish;    

    return sysmtFWPS($dbh, $user, $psid);

}


sub sysmtFWPSDelete
{

    my ( $dbh, $user, $psid ) = @_;

    my $dbdata;

    $sth = $dbh->prepare("delete from sysmt_fwpsentry where psid = ?;");
   
    $sth->bind_param(1, $psid, DBI::SQL_INTEGER);

    $sth->execute;

    $sth->finish;    

    $sth = $dbh->prepare("delete from sysmt_fwps where psid = ?;");
   
    $sth->bind_param(1, $psid, DBI::SQL_INTEGER);

    $sth->execute;

    $sth->finish;    

    return sysmtFWPSMaster($dbh, $user);

}

sub sysmtFWPSAddEntry
{

    my ( $dbh, $user, $psid, $portval, $porttype, $portdesc ) = @_;

    $sth = $dbh->prepare("insert into sysmt_fwpsentry ( psid, portval, porttype, portdesc ) values (?,?,?,?);");
    $sth->bind_param(1, $psid, DBI::SQL_INTEGER);
    $sth->bind_param(2, $portval, DBI::SQL_VARCHAR);
    $sth->bind_param(3, $porttype, DBI::SQL_VARCHAR);
    $sth->bind_param(4, $portdesc, DBI::SQL_VARCHAR);
    
    $sth->execute;
    
    $sth->finish;    

    return sysmtFWPS($dbh, $user, $psid);

}

sub sysmtFWPSUpdateEntry
{

    my ( $dbh, $user, $psid, $oportval, $portval, $porttype, $portdesc ) = @_;
    
    $sth = $dbh->prepare("update sysmt_fwpsentry set portval = ?, porttype = ?, portdesc = ? where psid = ? and portval = ?;");
    
    $sth->bind_param(1, $portval, DBI::SQL_VARCHAR);
    $sth->bind_param(2, $porttype, DBI::SQL_VARCHAR);
    $sth->bind_param(3, $portdesc, DBI::SQL_VARCHAR);
    $sth->bind_param(4, $psid, DBI::SQL_INTEGER);
    $sth->bind_param(5, $oportval, DBI::SQL_VARCHAR);

    $sth->execute;

    $sth->finish;    

    return sysmtFWPS($dbh, $user, $psid);

}


sub sysmtFWPSDeleteEntry
{

    my ( $dbh, $user, $psid, $portval ) = @_;

    $sth = $dbh->prepare("delete from sysmt_fwpsentry where psid = ? and portval = ?;");

    $sth->bind_param(1, $psid, DBI::SQL_INTEGER);
    $sth->bind_param(2, $portval, DBI::SQL_VARCHAR);

    $sth->execute;

    $sth->finish;

    return sysmtFWPS($dbh, $user, $psid );

}

####################
### Rule methods ###
####################

sub sysmtFWRMaster
{
    
    my ( $dbh, $user ) = @_;

    my @sidlist = PerlSpace::SysMtUtil::getMtWriteSidForUser($dbh, $user);
    
    $i=0;
    foreach my $sid ( @sidlist )
    {
	$$dbdata{'sidlist'}[$i] = $sid;
	$i++;
    }

    my ( $headmsg, $fullname, $sysmsg )  = PerlSpace::SysMtUtil::getHeaderInfo($dbh, $user);
    $$dbdata{'headertext'} = $headmsg;
    $$dbdata{'fullname'} = $fullname;
    $$dbdata{'sysmsg'} = $sysmsg;
    $$dbdata{'content'} = "sysmt_fwrmaster.html";
    
    $TT ||= Template->new({ INCLUDE_PATH  => $PerlSpace::SysMtExecuter::tmplpath });
    $TT->process('sysmt_frame.html', $dbdata) || die $TT->error(), "\n";

    
    return 0;
    
}

sub sysmtFWRListBySid
{
    
    my ( $dbh, $sid) = @_;    

    my $stmt = "select fwrid, sid, sgfrom, sgto, portset from sysmt_sysfwview where sid = '" . $sid . "'";    
    my $ordering = "order by sid, sgfrom, sgto, portset";
 
    sysmtFWRSearchExecuteList($dbh, $stmt, $ordering, "yes", $sid);

    return 0;    

}

sub sysmtFWRSearchExecuteList
{
    
    my ( $dbh, $stmt, $ordering, $fwradd, $sid ) = @_;

    my $sth = $dbh->prepare($stmt . " " . $ordering . ";");

    $sth->execute;
    
    my $dbdata;

    $$dbdata{'stmt'} = $stmt;
    $$dbdata{'fwradd'} = $fwradd;
    $$dbdata{'sid'} = $sid;

    my $fwrid;
    my $sid;
    my $sysid;
    my $sgfrom;
    my $sgto;
    my $portset;

    
    my $i=0;
    while ( ($fwrid, $sid, $sgfrom, $sgto, $portset ) = $sth->fetchrow_array) 
    {
	$$dbdata{'rlist'}[$i]{'fwrid'} = $fwrid;
	$$dbdata{'rlist'}[$i]{'sid'} = $sid;
	$$dbdata{'rlist'}[$i]{'sgfrom'} = $sgfrom;
	$$dbdata{'rlist'}[$i]{'sgto'} = $sgto;
	$$dbdata{'rlist'}[$i]{'portset'} = $portset;
	$i++;
    }
    $sth->finish;


    # get server groups
    my @sglist = PerlSpace::SysMtUtil::getFWSGList($dbh);
    
    $i=0;
    foreach my $sg ( @sglist )
    {
	$$dbdata{'sglist'}[$i] = $sg;
	$i++;
    }

    # get port sets
    my @pslist = PerlSpace::SysMtUtil::getFWPSList($dbh);
    
    $i=0;
    foreach my $ps ( @pslist )
    {
	$$dbdata{'pslist'}[$i] = $ps;
	$i++;
    }

    my ( $headmsg, $fullname, $sysmsg )  = PerlSpace::SysMtUtil::getHeaderInfo($dbh, $user);
    $$dbdata{'headertext'} = $headmsg;
    $$dbdata{'fullname'} = $fullname;
    $$dbdata{'sysmsg'} = $sysmsg;
    $$dbdata{'content'} = "sysmt_fwrlist.html";
    
    $TT ||= Template->new({ INCLUDE_PATH  => $PerlSpace::SysMtExecuter::tmplpath });
    $TT->process('sysmt_frame.html', $dbdata) || die $TT->error(), "\n";


    return 0;
}

sub sysmtFWRAddRule
{

    my ( $dbh, $sid, $sgfrom, $sgto, $portset, $fwrdesc ) = @_;

    my $dbdata;
    my $fwrid;
    
    if ( $PerlSpace::SysMtExecuter::db eq "cego" )
    {
	
	$sth = $dbh->prepare("? = call newSysFW (?,?,?,?,?);");
	
	$sth->bind_param_inout(1, \$fwrid, 10);
	$sth->bind_param(2, $sgfrom, DBI::SQL_VARCHAR);
	$sth->bind_param(3, $sgto, DBI::SQL_VARCHAR);
	$sth->bind_param(4, $portset, DBI::SQL_VARCHAR);
	$sth->bind_param(5, $fwrdesc, DBI::SQL_VARCHAR);
	$sth->bind_param(6, $sid, DBI::SQL_VARCHAR);
	
	$sth->execute;

    }
    elsif ( $PerlSpace::SysMtExecuter::db eq "mysql" )
    {
	$sth = $dbh->prepare("select newSysFW(?,?,?,?,?);");

	$sth->bind_param(1, $sgfrom, DBI::SQL_VARCHAR);
	$sth->bind_param(2, $sgto, DBI::SQL_VARCHAR);
	$sth->bind_param(3, $portset, DBI::SQL_VARCHAR);
	$sth->bind_param(4, $fwrdesc, DBI::SQL_VARCHAR);
	$sth->bind_param(5, $sid, DBI::SQL_VARCHAR);
	
	$sth->execute;
	$fwrid = $sth->fetchrow_array;	
    }
    elsif ( $PerlSpace::SysMtExecuter::db eq "db2" )
    {
	$sth = $dbh->prepare(q{call newSysFW(?,?,?,?,?,?)});

	$sth->bind_param(1, $sgfrom, DBI::SQL_VARCHAR);
	$sth->bind_param(2, $sgto, DBI::SQL_VARCHAR);
	$sth->bind_param(3, $portset, DBI::SQL_VARCHAR);
	$sth->bind_param(4, $fwrdesc, DBI::SQL_VARCHAR);
	$sth->bind_param(5, $sid, DBI::SQL_VARCHAR);
	$sth->bind_param_inout(6, \$fwrid, 100, DBI::SQL_INTEGER);

	$sth->execute;

    }
    
    $sth->finish;    

    return PerlSpace::SysMtFirewall::sysmtFWRListBySid($dbh, $sid);

}

1;
