#
# sysmt_grp.pm
# ------------
#
# Design and Implementation by Bjoern Lemke               
#           
# (C)opyright 2010,2011,2012 by Bjoern Lemke
#                                              
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2, or (at your option)
# any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; see the file COPYING.  If not, write to
# the Free Software Foundation, 59 Temple Place - Suite 330,
# Boston, MA 02111-1307, USA.
#

package PerlSpace::SysMtGroup;

sub sysmtGroupMaster
{

    my ( $dbh, $user ) = @_;

    my ( $headmsg, $fullname, $sysmsg )  = PerlSpace::SysMtUtil::getHeaderInfo($dbh, $user);
    $$dbdata{'headertext'} = $headmsg;
    $$dbdata{'fullname'} = $fullname;
    $$dbdata{'sysmsg'} = $sysmsg;
    $$dbdata{'content'} = "sysmt_grpmaster.html";

    $TT ||= Template->new({ INCLUDE_PATH  => $PerlSpace::SysMtExecuter::tmplpath });
    $TT->process('sysmt_frame.html', $dbdata) || die $TT->error(), "\n";

    return 0;

}


sub sysmtGroupList
{
    
    my ( $dbh, $user, $bgname) = @_;    

    my $stmt = "select bgid, bgname from sysmt_bgroup where bgname like '%" . $bgname . "%'";    
    my $ordering = "order by bgname";
 
    sysmtGroupExecuteList($dbh, $user, $stmt, $ordering);

    return 0;    

}

sub sysmtGroupExecuteList
{
    
    my ( $dbh, $user, $stmt, $ordering ) = @_;

    my $sth = $dbh->prepare($stmt . " " . $ordering . ";");

    $sth->execute;
    
    my $dbdata;

    $$dbdata{'ordering'} = $ordering;
    $$dbdata{'stmt'} = $stmt;

    my $bgid;
    my $bgname;
    
    my $i=0;
    while ( ($bgid, $bgname ) = $sth->fetchrow_array) 
    {

	$$dbdata{'bglist'}[$i]{'bgid'} = $bgid;
	$$dbdata{'bglist'}[$i]{'bgname'} = $bgname;

	$i++;
    }
    
    $sth->finish;    

    my ( $headmsg, $fullname, $sysmsg )  = PerlSpace::SysMtUtil::getHeaderInfo($dbh, $user);
    $$dbdata{'headertext'} = $headmsg;
    $$dbdata{'fullname'} = $fullname;
    $$dbdata{'sysmsg'} = $sysmsg;
    $$dbdata{'content'} = "sysmt_grplist.html";

    $TT ||= Template->new({ INCLUDE_PATH  => $PerlSpace::SysMtExecuter::tmplpath });
    $TT->process('sysmt_frame.html', $dbdata) || die $TT->error(), "\n";

    return 0;

}


sub sysmtGroup
{
    
    my ( $dbh, $user, $bgid, $stmt, $ordering ) = @_;
    
    my $dbdata;

    $$dbdata{'stmt'} = $stmt;
    $$dbdata{'ordering'} = $ordering;

    my $sth = $dbh->prepare("select bgid, bgname, bgdesc from sysmt_bgroup where bgid = ?;");
    $sth->bind_param(1, $bgid, DBI::SQL_INTEGER);
    
    $sth->execute;
    

    my $bgid;
    my $bgname;
    my $bgdesc;


    ( $bgid, $bgname, $bgdesc ) = $sth->fetchrow_array; 

    $$dbdata{'bgid'} = $bgid;
    $$dbdata{'bgname'} = $bgname;
    $$dbdata{'bgdesc'} = $bgdesc;
    
    $sth->fetchrow_array; 
    $sth->finish;

    # adding users retrievel
    $stmt="select dbuser from sysmt_user where uid not in ( select uid from sysmt_usr2bgrp where bgid = ?) order by dbuser;";
    $sth = $dbh->prepare($stmt);
    $sth->bind_param(1, $bgid, DBI::SQL_INTEGER);

    $sth->execute;

    $i=0;
    while ( ($bgusr) = $sth->fetchrow_array) 
    {
	$$dbdata{'addusrlist'}[$i] = $bgusr;
	$i++;
    }

    $sth->finish;

    # removing users retrievel
    $stmt="select dbuser from sysmt_user where uid in ( select uid from sysmt_usr2bgrp where bgid = ?) order by dbuser;";
    $sth = $dbh->prepare($stmt);
    $sth->bind_param(1, $bgid, DBI::SQL_INTEGER);
    
    $sth->execute;
        
    my $bgusr = "";
    $$dbdata{'bgusr'} = "";
    $i=0;
    while ( ($bgusr) = $sth->fetchrow_array) 
    {
	$$dbdata{'delusrlist'}[$i] = $bgusr;
	if ( $$dbdata{'bgusr'} eq "" )
	{
	    $$dbdata{'bgusr'} = $bgusr;
	}
	else
	{
	    $$dbdata{'bgusr'} = $$dbdata{'bgusr'} . ", " . $bgusr;
	}
	$i++;
    }

    $sth->finish;


    # adding sets retrievel
    $stmt="select setname from sysmt_systemset where setid not in ( select setid from sysmt_set2bgrp where bgid = ?);";
    $sth = $dbh->prepare($stmt);
    $sth->bind_param(1, $bgid, DBI::SQL_INTEGER);

    $sth->execute;

    $i=0;
    while ( ($bgset) = $sth->fetchrow_array) 
    {
	$$dbdata{'addsetlist'}[$i] = $bgset;
	$i++;
    }
    
    $sth->finish;    

    # removing sets retrievel
    $stmt="select setname from sysmt_systemset where setid in ( select setid from sysmt_set2bgrp where bgid = ?);";
    $sth = $dbh->prepare($stmt);
    $sth->bind_param(1, $bgid, DBI::SQL_INTEGER);

    $sth->execute;
        
    my $bgset = "";
    $$dbdata{'bgset'} = "";
    $i=0;
    while ( ($bgset) = $sth->fetchrow_array) 
    {
	$$dbdata{'delsetlist'}[$i] = $bgset;
	if ( $$dbdata{'bgset'} eq "" )
	{
	    $$dbdata{'bgset'} = $bgset;
	}
	else
	{
	    $$dbdata{'bgset'} = $$dbdata{'bgset'} . ", " . $bgset;
	}
	$i++;
    }
    
    $sth->finish;    


    # adding projects retrievel
    $stmt="select prjname from sysmt_project where pid not in ( select pid from sysmt_prj2bgrp where bgid = ?) order by prjname;";
    $sth = $dbh->prepare($stmt);
    $sth->bind_param(1, $bgid, DBI::SQL_INTEGER);
    
    $sth->execute;

    my $i=0;
    my $prjname;
    while ( ($prjname) = $sth->fetchrow_array) 
    {
	$$dbdata{'addprjlist'}[$i] = $prjname;
	$i++;
    }
    
    $sth->finish;    

    # removing projects retrievel
    $stmt="select prjname from sysmt_project where pid in ( select pid from sysmt_prj2bgrp where bgid = ?) order by prjname;";
    $sth = $dbh->prepare($stmt);
    $sth->bind_param(1, $bgid, DBI::SQL_INTEGER);

    $sth->execute;

    $$dbdata{'bgprj'} = "";
    $i=0;
    while ( ($prjname) = $sth->fetchrow_array) 
    {
	$$dbdata{'delprjlist'}[$i] = $prjname;

	if ( $$dbdata{'bgprj'} eq "" )
	{
	    $$dbdata{'bgprj'} = $prjname;
	}
	else
	{
	    $$dbdata{'bgprj'} = $$dbdata{'bgprj'} . ", " . $prjname;
	}

	$i++;
    }
    
    $sth->finish;    


    my @delrightlist = PerlSpace::SysMtUtil::getBGroupRightList($dbh, $bgid);
    my @addrightlist = PerlSpace::SysMtUtil::getBGroupRightListToAdd($dbh, $bgid);

    $i=0;
    foreach my $r ( @addrightlist )
    {

	$$dbdata{'addrightlist'}[$i] = $r;
	$i++;
    }

    
    $i=0;
    foreach my $r ( @delrightlist )
    {

	$$dbdata{'delrightlist'}[$i] = $r;
	if ( $$dbdata{'bgrights'} eq "" )
	{
	    $$dbdata{'bgrights'} = $r;
	}
	else
	{
	    $$dbdata{'bgrights'} = $$dbdata{'bgrights'} . ", " . $r;
	}
	$i++;
    }

    my ( $headmsg, $fullname, $sysmsg )  = PerlSpace::SysMtUtil::getHeaderInfo($dbh, $user);
    $$dbdata{'headertext'} = $headmsg;
    $$dbdata{'fullname'} = $fullname;
    $$dbdata{'sysmsg'} = $sysmsg;
    $$dbdata{'content'} = "sysmt_grp.html";

    $TT ||= Template->new({ INCLUDE_PATH  => $PerlSpace::SysMtExecuter::tmplpath });
    $TT->process('sysmt_frame.html', $dbdata) || die $TT->error(), "\n";

    return 0;

}


sub sysmtGroupNew
{

    my ( $dbh, $user ) = @_;

    my $dbdata;

    my ( $headmsg, $fullname, $sysmsg )  = PerlSpace::SysMtUtil::getHeaderInfo($dbh, $user);
    $$dbdata{'headertext'} = $headmsg;
    $$dbdata{'fullname'} = $fullname;
    $$dbdata{'sysmsg'} = $sysmsg;
    $$dbdata{'content'} = "sysmt_grpnew.html";

    $TT ||= Template->new({ INCLUDE_PATH  => $PerlSpace::SysMtExecuter::tmplpath });
    $TT->process('sysmt_frame.html', $dbdata) || die $TT->error(), "\n";

    return 0;

}

sub sysmtGroupCreate
{

    my ( $dbh, $user, $bgname, $bgdesc, $stmt, $ordering ) = @_;

    # trim left and right whitespaces
    $bgname =~ s/^\s+//;
    $bgname =~ s/\s+$//;

    my $dbdata;
    my $bgid;

    if ( $PerlSpace::SysMtExecuter::db eq "cego" )
    {

	$sth = $dbh->prepare("? = call newGroup ( ?, ? );");
	
	$sth->bind_param_inout(1, \$bgid, 10);
	$sth->bind_param(2, $bgname, DBI::SQL_VARCHAR);
	$sth->bind_param(3, $bgdesc, DBI::SQL_VARCHAR);
	
	$sth->execute;

    }
    elsif ( $PerlSpace::SysMtExecuter::db eq "mysql" )
    {
	$sth = $dbh->prepare("select newGroup(?,?);");
	
	$sth->bind_param(1, $bgname, DBI::SQL_VARCHAR);
	$sth->bind_param(2, $bgdesc, DBI::SQL_VARCHAR);    
	$sth->execute;
	$bgid = $sth->fetchrow_array;
    }
    elsif ( $PerlSpace::SysMtExecuter::db eq "db2" )
    {

	$sth = $dbh->prepare(q{ call newGroup(?,?,?)});
	
	$sth->bind_param(1, $bgname, DBI::SQL_VARCHAR);
	$sth->bind_param(2, $bgdesc, DBI::SQL_VARCHAR);
	$sth->bind_param_inout(3, \$bgid, 100, DBI::SQL_INTEGER);    

	$sth->execute;
	
    }

    $sth->finish;

    return sysmtGroup($dbh, $user, $bgid, $stmt, $ordering);

}

sub sysmtGroupUpdate
{

    my ( $dbh, $user, $bgid, $bgname, $bgdesc, $stmt, $ordering ) = @_;
        
    $sth = $dbh->prepare("update sysmt_bgroup set bgname = ?, bgdesc = ? where bgid = ?;");
     
    $sth->bind_param(1, $bgname, DBI::SQL_VARCHAR);
    $sth->bind_param(2, $bgdesc, DBI::SQL_VARCHAR);
    $sth->bind_param(3, $bgid, DBI::SQL_INTEGER);

    $sth->execute;

    $sth->finish;    

    return sysmtGroup($dbh, $user, $bgid, $stmt, $ordering);

}

sub sysmtGroupDelete
{

    my ( $dbh, $user, $bgid ) = @_;

    my $dbdata;

    $sth = $dbh->prepare("delete from sysmt_prj2approval where bgid = ?;");    
    $sth->bind_param(1, $bgid, DBI::SQL_INTEGER);

    $sth->execute;

    $sth->finish;    

    $sth = $dbh->prepare("delete from sysmt_usr2bgrp where bgid = ?;");    
    $sth->bind_param(1, $bgid, DBI::SQL_INTEGER);

    $sth->execute;

    $sth->finish;    

    $sth = $dbh->prepare("delete from sysmt_prj2bgrp where bgid = ?;");    
    $sth->bind_param(1, $bgid, DBI::SQL_INTEGER);

    $sth->execute;

    $sth->finish;    

    $sth = $dbh->prepare("delete from sysmt_set2bgrp where bgid = ?;");    
    $sth->bind_param(1, $bgid, DBI::SQL_INTEGER);

    $sth->execute;

    $sth->finish;    

    $sth = $dbh->prepare("delete from sysmt_mtapproval where bgid = ?;");
    $sth->bind_param(1, $bgid, DBI::SQL_INTEGER);

    $sth->execute;

    $sth->finish;    

    $sth = $dbh->prepare("delete from sysmt_bgroup where bgid = ?;");
    $sth->bind_param(1, $bgid, DBI::SQL_INTEGER);

    $sth->execute;

    $sth->finish;    

    return sysmtGroupMaster($dbh, $user);

}

sub sysmtGroupInfo
{
    
    my ( $dbh, $user ) = @_;

    my $sth = $dbh->prepare("select bgname, bgdesc from sysmt_bgroup bg, sysmt_usr2bgrp u2g, sysmt_user u where u.dbuser = ? and u.uid = u2g.uid and u2g.bgid = bg.bgid;");

    $sth->bind_param(1, $user, DBI::SQL_VARCHAR);

    $sth->execute;
    
    my $dbdata;

    my $bgname;
    my $bgdesc;
    
    my $i=0;
    while ( ($bgname, $bgdesc ) = $sth->fetchrow_array) 
    {

	$$dbdata{'bglist'}[$i]{'bgname'} = $bgname;
	$$dbdata{'bglist'}[$i]{'bgdesc'} = $bgdesc;

	$i++;
    }
    
    $sth->finish;    
    
    for ( $j=0; $j<$i; $j++ )
    {

	# num prj
	my $sth = $dbh->prepare("select count(*) from sysmt_bgroup bg, sysmt_prj2bgrp p2g where bg.bgname = ? and bg.bgid = p2g.bgid;");
	
	$sth->bind_param(1, $$dbdata{'bglist'}[$j]{'bgname'}, DBI::SQL_VARCHAR);
	$sth->execute;
	
	my $numprj = $sth->fetchrow_array; 

	$sth->finish;
	
	$$dbdata{'bglist'}[$j]{'numprj'} = $numprj;

	# num sys 
	my $sth = $dbh->prepare("select count(*) from sysmt_bgroup bg, sysmt_prj2bgrp p2g, sysmt_system s where bg.bgname = ? and bg.bgid = p2g.bgid and p2g.pid = s.pid;");
	
	$sth->bind_param(1, $$dbdata{'bglist'}[$j]{'bgname'}, DBI::SQL_VARCHAR);
	$sth->execute;
	
	my $numsys = $sth->fetchrow_array; 

	$sth->finish;
	
	$$dbdata{'bglist'}[$j]{'numsys'} = $numsys;
	
    }

    my ( $headmsg, $fullname, $sysmsg )  = PerlSpace::SysMtUtil::getHeaderInfo($dbh, $user);
    $$dbdata{'headertext'} = $headmsg;
    $$dbdata{'fullname'} = $fullname;
    $$dbdata{'sysmsg'} = $sysmsg;
    $$dbdata{'content'} = "sysmt_grpinfo.html";

    $TT ||= Template->new({ INCLUDE_PATH  => $PerlSpace::SysMtExecuter::tmplpath });
    $TT->process('sysmt_frame.html', $dbdata) || die $TT->error(), "\n";

    return 0;
}


sub sysmtGroupAddRight
{

    my ( $dbh, $user, $bgid, $bgright, $stmt, $ordering ) = @_;

    if ( $bgright )
    {
	$sth = $dbh->prepare("insert into sysmt_bgright values ( ?, ? );");
	
	$sth->bind_param(1, $bgid, DBI::SQL_INTEGER);
	$sth->bind_param(2, $bgright, DBI::SQL_VARCHAR);
	
	$sth->execute;
	
	$sth->finish;    
    }

    return sysmtGroup($dbh, $user, $bgid, $stmt, $ordering);

}

sub sysmtGroupDelRight
{

    my ( $dbh, $user, $bgid, $bgright, $stmt, $ordering ) = @_;

    $sth = $dbh->prepare("delete from sysmt_bgright where bgid = ? and bgright = ?;");
    
    $sth->bind_param(1, $bgid, DBI::SQL_INTEGER);
    $sth->bind_param(2, $bgright, DBI::SQL_VARCHAR);

    $sth->execute;

    $sth->finish;

    return sysmtGroup($dbh, $user, $bgid, $stmt, $ordering);

}


sub sysmtGroupAddProject
{

    my ( $dbh, $user, $bgid, $prjname, $stmt, $ordering ) = @_;

    $sth = $dbh->prepare("insert into sysmt_prj2bgrp ( bgid, pid ) values ( ?, ( select pid from sysmt_project where prjname = ? ));");
    
    $sth->bind_param(1, $bgid, DBI::SQL_INTEGER);
    $sth->bind_param(2, $prjname, DBI::SQL_VARCHAR);

    $sth->execute;

    $sth->finish;    

    return sysmtGroup($dbh, $user, $bgid, $stmt, $ordering);

}

sub sysmtGroupDelProject
{

    my ( $dbh, $user, $bgid, $prjname, $stmt, $ordering ) = @_;


    $sth = $dbh->prepare("delete from sysmt_prj2bgrp where bgid = ? and pid = ( select pid from sysmt_project where prjname = ? );");

    $sth->bind_param(1, $bgid, DBI::SQL_INTEGER);    
    $sth->bind_param(2, $prjname, DBI::SQL_VARCHAR);

    $sth->execute;

    $sth->finish;

    return sysmtGroup($dbh, $user, $bgid, $stmt, $ordering);

}


sub sysmtGroupAddUser
{

    my ( $dbh, $user, $bgid, $usr, $stmt, $ordering ) = @_;

    $sth = $dbh->prepare("insert into sysmt_usr2bgrp ( bgid, uid ) values ( ?, ( select uid from sysmt_user where dbuser = ? ));");
    
    $sth->bind_param(1, $bgid, DBI::SQL_INTEGER);
    $sth->bind_param(2, $usr, DBI::SQL_VARCHAR);

    $sth->execute;

    $sth->finish;    


    return sysmtGroup($dbh, $user, $bgid, $stmt, $ordering);

}

sub sysmtGroupDelUser
{

    my ( $dbh, $user, $bgid, $usr, $stmt, $ordering ) = @_;

    $sth = $dbh->prepare("delete from sysmt_usr2bgrp where bgid = ? and uid = ( select uid from sysmt_user where dbuser = ? );");

    $sth->bind_param(1, $bgid, DBI::SQL_INTEGER);    
    $sth->bind_param(2, $usr, DBI::SQL_VARCHAR);

    $sth->execute;

    $sth->finish;

    return sysmtGroup($dbh, $user, $bgid, $stmt, $ordering);

}

sub sysmtGroupAddSet
{

    my ( $dbh, $user, $bgid, $bgset, $stmt, $ordering ) = @_;

    $sth = $dbh->prepare("insert into sysmt_set2bgrp ( bgid, setid ) values ( ?, ( select setid from sysmt_systemset where setname = ? ));");
    
    $sth->bind_param(1, $bgid, DBI::SQL_INTEGER);
    $sth->bind_param(2, $bgset, DBI::SQL_VARCHAR);

    $sth->execute;

    $sth->finish;    


    return sysmtGroup($dbh, $user, $bgid, $stmt, $ordering);

}

sub sysmtGroupDelSet
{

    my ( $dbh, $user, $bgid, $bgset, $stmt, $ordering ) = @_;

    $sth = $dbh->prepare("delete from sysmt_set2bgrp where bgid = ? and setid = ( select setid from sysmt_systemset where setname = ? );");

    $sth->bind_param(1, $bgid, DBI::SQL_INTEGER);    
    $sth->bind_param(2, $bgset, DBI::SQL_VARCHAR);

    $sth->execute;

    $sth->finish;

    return sysmtGroup($dbh, $user, $bgid, $stmt, $ordering);

}

1;
