#
# sysmt_mt.pm
# -----------
#
# Design and Implementation by Bjoern Lemke               
#           
# (C)opyright 2010,2011,2012 by Bjoern Lemke
#                                              
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2, or (at your option)
# any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; see the file COPYING.  If not, write to
# the Free Software Foundation, 59 Temple Place - Suite 330,
# Boston, MA 02111-1307, USA.
#

use POSIX;

my $scale=4;

package PerlSpace::SysMtMaintain;

my $cego_selection="mid, prjname, sid, shortdesc, mtfrom, mtto, downfrom, downto, status, ticketnr, conflicts, tgname, thrid";
my $mysql_selection="mid, prjname, sid, shortdesc, date_format(mtfrom, '%d.%m.%Y %m:%i:%s'), date_format(mtto, '%d.%m.%Y %m:%i:%s'), date_format(downfrom, '%d.%m.%Y %m:%i:%s'), date_format(downto, '%d.%m.%Y %m:%i:%s'), status, ticketnr, conflicts, tgname, thrid";
my $db2_selection="m.mid, prjname, sid, shortdesc, ts_fmt(mtfrom, 'dd.mm.yyyy hh:mi:ss'), ts_fmt(mtto, 'dd.mm.yyyy hh:mi:ss'), ts_fmt(downfrom, 'dd.mm.yyyy hh:mi:ss'), ts_fmt(downto, 'dd.mm.yyyy hh:mi:ss'), m.status, ticketnr, conflicts, tgname, thrid";

sub sysmtMtMaster
{

    my ( $dbh, $user ) = @_;

    my $stmt;
    my $dbdata;

    $$dbdata{'user'} = $user;
    
    $$dbdata{'statuslist'}[0] = 'Requested';
    $$dbdata{'statuslist'}[1] = 'Approved';
    $$dbdata{'statuslist'}[2] = 'Verified';
    $$dbdata{'statuslist'}[3] = 'Claimed';
    $$dbdata{'statuslist'}[4] = 'Done';
    $$dbdata{'statuslist'}[5] = 'Aborted';
    $$dbdata{'statuslist'}[6] = 'Attention';

    my @rdsidlist = PerlSpace::SysMtUtil::getMtReadSidForUser($dbh, $user);
    
    $i=0;
    foreach my $sid ( @rdsidlist )
    {
	$$dbdata{'rdsidlist'}[$i] = $sid;
	$i++;
    }

    my @rdprjlist = PerlSpace::SysMtUtil::getMtReadProjectForUser($dbh, $user);
    
    $i=0;
    foreach my $prj ( @rdprjlist )
    {
	$$dbdata{'rdprojectlist'}[$i] = $prj;
	$i++;
    }

    my @wrsidlist = PerlSpace::SysMtUtil::getMtWriteSidForUser($dbh, $user);
    
    $i=0;
    foreach my $sid ( @wrsidlist )
    {
	$$dbdata{'wrsidlist'}[$i] = $sid;
	$i++;
    }

    my @wrprjlist = PerlSpace::SysMtUtil::getMtWriteProjectForUser($dbh, $user);
    
    $i=0;
    foreach my $prj ( @wrprjlist )
    {
	$$dbdata{'wrprojectlist'}[$i] = $prj;
	$i++;
    }

    my @setlist;

    @setlist = PerlSpace::SysMtUtil::getMtReadSysSetForUser($dbh, $user);

    $i=0;
    foreach my $set ( @setlist )
    {
	$$dbdata{'setlist'}[$i] = $set;
	$i++;
    }

    @gslist = PerlSpace::SysMtUtil::getGroupSearchForUser($dbh, $user);

    $i=0;
    foreach my $gs ( @gslist )
    {	
	$$dbdata{'gslist'}[$i]{'gsid'} = $$gs{'gsid'};
	$$dbdata{'gslist'}[$i]{'gsname'} = $$gs{'gsname'};
	$$dbdata{'gslist'}[$i]{'gsspec'} = $$gs{'gsspec'};
	$i++;
    }

    @uslist = PerlSpace::SysMtUtil::getUserSearchForUser($dbh, $user);

    $i=0;
    foreach my $us ( @uslist )
    {	
	$$dbdata{'uslist'}[$i]{'usid'} = $$us{'usid'};
	$$dbdata{'uslist'}[$i]{'usname'} = $$us{'usname'};
	$$dbdata{'uslist'}[$i]{'usspec'} = $$us{'usspec'};
	$i++;
    }


    $$dbdata{'curmonth'} = PerlSpace::SysMtUtil::getCurrentMonth();
    $$dbdata{'curyear'} = PerlSpace::SysMtUtil::getCurrentYear();
    
    @yearlist = PerlSpace::SysMtUtil::getYearList();
    @monthlist = PerlSpace::SysMtUtil::getMonthList();

    $i=0;
    foreach my $year ( @yearlist )
    {
	$$dbdata{'yearlist'}[$i] = $year;
	$i++;
    }

    $i=0;
    foreach my $month ( @monthlist )
    {
	$$dbdata{'monthlist'}[$i] = $month;
	$i++;
    }


    my ( $headmsg, $fullname, $sysmsg )  = PerlSpace::SysMtUtil::getHeaderInfo($dbh, $user);
    $$dbdata{'headertext'} = $headmsg;
    $$dbdata{'fullname'} = $fullname;
    $$dbdata{'sysmsg'} = $sysmsg;
    $$dbdata{'content'} = 'sysmt_mtmaster.html';

    $TT ||= Template->new({ INCLUDE_PATH  => $PerlSpace::SysMtExecuter::tmplpath });
    $TT->process('sysmt_frame.html', $dbdata) || die $TT->error(), "\n";

    return 0;

}

sub sysmtMtListBySpec
{
    
    my ( $dbh, $user, $sspec ) = @_;
    my $ordering = "order by mtfrom";

    $sspec =~ s/\$user/$user/g;

    
    my $stmt;

    if ( $PerlSpace::SysMtExecuter::db eq "cego" )
    {
	$stmt = "select " .
	    $cego_selection .
	    " from sysmt_mtview m where " . $sspec . " and m.pid in ( select pid from sysmt_prj2bgrp " .
	    " where bgid in ( select distinct bgid from sysmt_usr2bgrp u2g, sysmt_user u, sysmt_bgright r " .
	    " where ( r.bgright = 'mtread' or r.bgright = 'mtwrite' ) and r.bgid = u2g.bgid and  u2g.uid = u.uid and u.dbuser = '" . $user ."'))";
    }
    elsif ( $PerlSpace::SysMtExecuter::db eq "mysql" )
    {
	$stmt = "select " .
	    $mysql_selection .
	    " from sysmt_mtview m where " . $sspec . " and m.pid in ( select pid from sysmt_prj2bgrp where bgid in " .
	    " ( select distinct bgid from sysmt_usr2bgrp u2g, sysmt_user u, sysmt_bgright r " .
	    " where ( r.bgright = 'mtread' or r.bgright = 'mtwrite' ) and r.bgid = u2g.bgid and  u2g.uid = u.uid and u.dbuser = '" . $user ."'))";
    }
    elsif ( $PerlSpace::SysMtExecuter::db eq "db2" )
    {
	$stmt = "select " .
	    $db2_selection .
	    " from sysmt_mtview m where " . $sspec . " and m.pid in ( select pid from sysmt_prj2bgrp p2g where p2g.bgid in " .
	    " ( select distinct u2g.bgid from sysmt_usr2bgrp u2g, sysmt_user u, sysmt_bgright r " .
	    " where ( r.bgright = 'mtread' or r.bgright = 'mtwrite' ) and r.bgid = u2g.bgid and u2g.uid = u.uid and u.dbuser = '" . $user ."'))";
	
    }

    my $thrid;
    return sysmtMtExecuteList($dbh, $user, $stmt, $ordering, $thrid);

}


sub sysmtMtListByStatus
{
    
    my ( $dbh, $user, $status, $year ) = @_;
    my $ordering = "order by mtfrom";

    my $stmt;

    if ( $PerlSpace::SysMtExecuter::db eq "cego" )
    {
	$stmt = "select " .
	    $cego_selection .
	    " from sysmt_mtview m where m.status = '" . $status . "' and date2str(mtfrom, '%Y') = '" . $year . "' and m.pid in " .
	    " ( select pid from sysmt_prj2bgrp where bgid in " .
	    " ( select distinct bgid from sysmt_usr2bgrp u2g, sysmt_user u, sysmt_bgright r  " .
	    " where ( r.bgright = 'mtread' or r.bgright = 'mtwrite' ) and r.bgid = u2g.bgid and  u2g.uid = u.uid and u.dbuser = '" . $user ."'))";
    }
    elsif ( $PerlSpace::SysMtExecuter::db eq "mysql" )
    {
	$stmt = "select " .
	    $mysql_selection .
	    " from sysmt_mtview m where m.status = '" . $status . "' and year(mtfrom) = " . $year . " and m.pid in " .
	    " ( select pid from sysmt_prj2bgrp where bgid in " .
	    " ( select distinct u2g.bgid from sysmt_usr2bgrp u2g, sysmt_user u, sysmt_bgright r " .
	    " where ( r.bgright = 'mtread' or r.bgright = 'mtwrite' ) and r.bgid = u2g.bgid and  u2g.uid = u.uid and u.dbuser = '" . $user ."'))";
	
    }
    elsif ( $PerlSpace::SysMtExecuter::db eq "db2" )
    {
	$stmt = "select " .
	    $db2_selection .
	    " from sysmt_mtview m where m.status = '" . $status . "' and year(mtfrom) = " . $year . " and m.pid in " .
	    " ( select pid from sysmt_prj2bgrp p2g where p2g.bgid in " .
	    " ( select distinct u2g.bgid from sysmt_usr2bgrp u2g, sysmt_user u, sysmt_bgright r " .
	    " where ( r.bgright = 'mtread' or r.bgright = 'mtwrite' ) and r.bgid = u2g.bgid and  u2g.uid = u.uid and u.dbuser = '" . $user ."'))";
	
    }

    my $thrid;
    return sysmtMtExecuteList($dbh, $user, $stmt, $ordering, $thrid);

}


sub sysmtMtListBySid
{
    
    my ( $dbh, $user, $sid, $year ) = @_;
    my $ordering = "order by mtfrom";

    my $stmt;

    if ( $PerlSpace::SysMtExecuter::db eq "cego" )
    {
	$stmt = "select " .
	    $cego_selection .
	    " from sysmt_mtview where sid = '" . $sid . "' and date2str(mtfrom, '%Y') = '" . $year . "'";
    }
    elsif ( $PerlSpace::SysMtExecuter::db eq "mysql" )
    {
	$stmt = "select " .
	    $mysql_selection .
	    " from sysmt_mtview where sid = '" . $sid . "' and year(mtfrom) = " . $year;
    }
    elsif ( $PerlSpace::SysMtExecuter::db eq "db2" )
    {
	$stmt = "select " .
	    $db2_selection .
	    " from sysmt_mtview m where sid = '" . $sid . "' and year(mtfrom) = " . $year;
    }

    my $thrid;
    return sysmtMtExecuteList($dbh, $user, $stmt, $ordering,$thrid);


}

sub sysmtMtListByApproval
{
    
    my ( $dbh, $user ) = @_;
    my $ordering = "order by mtfrom";

    my $stmt;


    if ( $PerlSpace::SysMtExecuter::db eq "cego" )
    {
	$stmt = "select " .
	    $cego_selection .
	    " from sysmt_mtview m, sysmt_mtapproval ma where m.mid = ma.mid and m.status = 'Requested' and  ma.status = 'Requested' and  ma.bgid in " .
	    " ( select distinct bgid from sysmt_usr2bgrp u2g, sysmt_user u, sysmt_bgright r " .
	    " where ( r.bgright = 'mtread' or r.bgright = 'mtwrite' ) and r.bgid = u2g.bgid and  u2g.uid = u.uid and u.dbuser = '" . $user ."')";

    }
    elsif ( $PerlSpace::SysMtExecuter::db eq "mysql" )
    {
	$stmt = "select " .
	    $mysql_selection .
	    " from sysmt_mtview m, sysmt_mtapproval ma where m.mid = ma.mid and m.status = 'Requested' and  ma.status = 'Requested' and  ma.bgid in " .
	    " ( select distinct bgid from sysmt_usr2bgrp u2g, sysmt_user u, sysmt_bgright r " .
	    " where ( r.bgright = 'mtread' or r.bgright = 'mtwrite' ) and r.bgid = u2g.bgid and  u2g.uid = u.uid and u.dbuser = '" . $user ."')";
    }
    elsif ( $PerlSpace::SysMtExecuter::db eq "db2" )
    {
	$stmt = "select " .
	    $db2_selection .
	    " from sysmt_mtview m, sysmt_mtapproval ma where m.mid = ma.mid and m.status = 'Requested' and  ma.status = 'Requested' and  ma.bgid in " .
	    " ( select distinct u2g.bgid from sysmt_usr2bgrp u2g, sysmt_user u, sysmt_bgright r " .
	    " where ( r.bgright = 'mtread' or r.bgright = 'mtwrite' ) and r.bgid = u2g.bgid and  u2g.uid = u.uid and u.dbuser = '" . $user ."')";
    }

    my $thrid;        
    return sysmtMtExecuteList($dbh, $user, $stmt, $ordering,$thrid);

}

sub sysmtMtListUnplanned
{
    
    my ( $dbh, $user ) = @_;
    my $ordering = "order by mtfrom";

    my $stmt;


    if ( $PerlSpace::SysMtExecuter::db eq "cego" )
    {
	$stmt = "select " .
	    $cego_selection .
	    " from sysmt_mtview m where mtfrom is null and m.pid in ( select pid from sysmt_prj2bgrp where bgid in " .
	    " ( select distinct bgid from sysmt_usr2bgrp u2g, sysmt_user u, sysmt_bgright r " .
	    " where ( r.bgright = 'mtread' or r.bgright = 'mtwrite' ) and r.bgid = u2g.bgid and  u2g.uid = u.uid and u.dbuser = '" . $user ."'))";
    }
    elsif ( $PerlSpace::SysMtExecuter::db eq "mysql" )
    {
	$stmt = "select " .
	    $mysql_selection .
	    " from sysmt_mtview m where mtfrom is null and m.pid in ( select pid from sysmt_prj2bgrp where bgid in " .
	    " ( select distinct bgid from sysmt_usr2bgrp u2g, sysmt_user u, sysmt_bgright r " .
	    " where ( r.bgright = 'mtread' or r.bgright = 'mtwrite' ) and r.bgid = u2g.bgid and  u2g.uid = u.uid and u.dbuser = '" . $user ."'))";
    }
    elsif ( $PerlSpace::SysMtExecuter::db eq "db2" )
    {
	$stmt = "select " .
	    $db2_selection .
	    " from sysmt_mtview m where mtfrom is null and m.pid in ( select pid from sysmt_prj2bgrp p2g where p2g.bgid in " .
	    " ( select distinct u2g.bgid from sysmt_usr2bgrp u2g, sysmt_user u, sysmt_bgright r " .
	    " where ( r.bgright = 'mtread' or r.bgright = 'mtwrite' ) and r.bgid = u2g.bgid and  u2g.uid = u.uid and u.dbuser = '" . $user ."'))";
    }

    my $thrid;    
    return sysmtMtExecuteList($dbh, $user, $stmt, $ordering,$thrid);

}

sub sysmtMtListByProject
{
    
    my ( $dbh, $user, $project, $year ) = @_;
    my $ordering = "order by mtfrom";
    

    my $stmt;

    if ( $PerlSpace::SysMtExecuter::db eq "cego" )
    {
	$stmt = "select " .
	    $cego_selection .
	    " from sysmt_mtview where prjname = '" . $project . "' and date2str(mtfrom, '%Y') = '" . $year . "'";
    }
    elsif ( $PerlSpace::SysMtExecuter::db eq "mysql" )
    {
	$stmt = "select " .
	    $mysql_selection .
	    " from sysmt_mtview where prjname = '" . $project . "' and year(mtfrom) = " . $year;
    }
    elsif ( $PerlSpace::SysMtExecuter::db eq "db2" )
    {
	$stmt = "select " .
	    $db2_selection .
	    " from sysmt_mtview m where prjname = '" . $project . "' and year(mtfrom) = " . $year;
    }

    my $thrid;
    return sysmtMtExecuteList($dbh, $user, $stmt, $ordering,$thrid);

}

sub sysmtMtListBySet
{
    
    my ( $dbh, $user, $sysset, $year ) = @_;
    my $ordering = "order by mtfrom";


    my $stmt;

    if ( $PerlSpace::SysMtExecuter::db eq "cego" )
    {
	$stmt = "select " .
	    $cego_selection .
	    " from sysmt_mtview mtv, sysmt_sys2set s2s, sysmt_systemset ss where date2str(mtfrom, '%Y') = '" . $year . "' and ss.setname = '" . $sysset . "' and ss.setid = s2s.setid and s2s.sysid = mtv.sysid";
    }
    elsif ( $PerlSpace::SysMtExecuter::db eq "mysql" )
    {
	$stmt = "select " .
	    $mysql_selection .
	    " from sysmt_mtview mtv, sysmt_sys2set s2s, sysmt_systemset ss where year(mtfrom) = " . $year . " and ss.setname = '" . $sysset . "' and ss.setid = s2s.setid and s2s.sysid = mtv.sysid";
    }
    elsif ( $PerlSpace::SysMtExecuter::db eq "db2" )
    {
	$stmt = "select " .
	    $db2_selection .
	    " from sysmt_mtview m, sysmt_sys2set s2s, sysmt_systemset ss where year(mtfrom) = " . $year . " and ss.setname = '" . $sysset . "' and ss.setid = s2s.setid and s2s.sysid = m.sysid";
    }

    my $thrid;
    return sysmtMtExecuteList($dbh, $user, $stmt, $ordering,$thrid);

}

sub sysmtMtListByMonth
{
    
    my ( $dbh, $user, $year, $month ) = @_;
    my $ordering = "order by mtfrom";

    my $fmonth=$month;
    my $fyear=$year;
    
    if ( $fmonth eq "01" )
    {
	$fmonth = "02";
    }
    elsif ( $fmonth eq "02" )
    {
	$fmonth = "03";
    }
    elsif ( $fmonth eq "03" )
    {
	$fmonth = "04";
    }
    elsif ( $fmonth eq "04" )
    {
	$fmonth = "05";
    }
    elsif ( $fmonth eq "05" )
    {
	$fmonth = "06";
    }
    elsif ( $fmonth eq "06" )
    {
	$fmonth = "07";
    }
    elsif ( $fmonth eq "07" )
    {
	$fmonth = "08";
    }
    elsif ( $fmonth eq "08" )
    {
	$fmonth = "09";
    }
    elsif ( $fmonth eq "09" )
    {
	$fmonth = "10";
    }
    elsif ( $fmonth eq "10" )
    {
	$fmonth = "11";
    }
    elsif ( $fmonth eq "11" )
    {
	$fmonth = "12";
    }
    elsif ( $fmonth eq "12" )
    {
	$fmonth = "01";
	$fyear = $year + 1;
    }
	
    my $stmt;
    
    if ( $PerlSpace::SysMtExecuter::db eq "cego" )
    {
	$stmt = "select " .
	    $cego_selection . 
	    " from sysmt_mtview m where mtfrom between date('%d.%m.%Y %H:%M:%S', '01." . $month . "." . $year . " 00:00:00') and date('%d.%m.%Y %H:%M:%S', '01." . $fmonth . "." . $fyear . " 00:00:00') and m.pid in " .
	    " ( select pid from sysmt_prj2bgrp where bgid in " .
	    " ( select distinct bgid from sysmt_usr2bgrp u2g, sysmt_user u, sysmt_bgright r " .
	    " where ( r.bgright = 'mtread' or r.bgright = 'mtwrite' ) and r.bgid = u2g.bgid and  u2g.uid = u.uid and u.dbuser = '" . $user ."'))";
    }
    elsif ( $PerlSpace::SysMtExecuter::db eq "mysql" )
    {
	$stmt = "select " .
	    $mysql_selection .
	    " from sysmt_mtview m where month(mtfrom) = " .  $month . " and year(mtfrom) = " . $year . " and m.pid in " .
	    " ( select pid from sysmt_prj2bgrp where bgid in " .
	    " ( select distinct bgid from sysmt_usr2bgrp u2g, sysmt_user u, sysmt_bgright r " .
	    " where ( r.bgright = 'mtread' or r.bgright = 'mtwrite' ) and r.bgid = u2g.bgid and  u2g.uid = u.uid and u.dbuser = '" . $user ."'))";
    }
    elsif ( $PerlSpace::SysMtExecuter::db eq "db2" )
    {
	$stmt = "select " .
	    $db2_selection .
	    " from sysmt_mtview m where month(mtfrom) = " .  $month . " and year(mtfrom) = " . $year . " and m.pid in " .
	    " ( select pid from sysmt_prj2bgrp p2g where p2g.bgid in " .
	    " ( select distinct u2g.bgid from sysmt_usr2bgrp u2g, sysmt_user u, sysmt_bgright r " .
	    " where ( r.bgright = 'mtread' or r.bgright = 'mtwrite' ) and r.bgid = u2g.bgid and  u2g.uid = u.uid and u.dbuser = '" . $user ."'))";
    }

    my $thrid;    
    return sysmtMtExecuteList($dbh, $user, $stmt, $ordering,$thrid);

}

sub sysmtMtListByWeek
{
    
    my ( $dbh, $user, $year, $week ) = @_;
    my $ordering = "order by mtfrom";

    # week number correction for database date function
    # still not clear if this correction is required


    my $stmt;

    if ( $PerlSpace::SysMtExecuter::db eq "cego" )
    {
	$week = substr "0" . $week, -2, 2;
	$stmt = "select " .
	    $cego_selection .
	    " from sysmt_mtview m where date2str(mtfrom, '%W%Y') = '" . $week . $year . "' and m.pid in " .
	    " ( select pid from sysmt_prj2bgrp where bgid in " .
	    " ( select distinct bgid from sysmt_usr2bgrp u2g, sysmt_user u, sysmt_bgright r " .
	    " where ( r.bgright = 'mtread' or r.bgright = 'mtwrite' ) and r.bgid = u2g.bgid and  u2g.uid = u.uid and u.dbuser = '" . $user ."'))";

    }
    elsif ( $PerlSpace::SysMtExecuter::db eq "mysql" )
    {
	$week = substr "0" . $week, -2, 2;
	$stmt = "select " .
	    $mysql_selection .
	    " from sysmt_mtview m where year(mtfrom) = " . $year . " and week(mtfrom) = " . $week . " and m.pid in " .
	    " ( select pid from sysmt_prj2bgrp where bgid in " .
	    " ( select distinct bgid from sysmt_usr2bgrp u2g, sysmt_user u, sysmt_bgright r " .
	    " where ( r.bgright = 'mtread' or r.bgright = 'mtwrite' ) and r.bgid = u2g.bgid and  u2g.uid = u.uid and u.dbuser = '" . $user ."'))";
    }
    elsif ( $PerlSpace::SysMtExecuter::db eq "db2" )
    {
	# $week++;
	$week = substr "0" . $week, -2, 2;
	$stmt = "select " .
	    $db2_selection .
	    " from sysmt_mtview m where year(mtfrom) = " . $year . " and week(mtfrom) = " . $week . " and m.pid in " .
	    " ( select pid from sysmt_prj2bgrp where bgid in " .
	    " ( select distinct u2g.bgid from sysmt_usr2bgrp u2g, sysmt_user u, sysmt_bgright r " .
	    " where ( r.bgright = 'mtread' or r.bgright = 'mtwrite' ) and r.bgid = u2g.bgid and  u2g.uid = u.uid and u.dbuser = '" . $user ."'))";
    }

    my $thrid;
    return sysmtMtExecuteList($dbh, $user, $stmt, $ordering,$thrid);
    
}

sub sysmtMtListByDate
{
    
    my ( $dbh, $user, $fromdate, $todate ) = @_;
    my $ordering = "order by mtfrom";

    # week number correction for database date function
    $week--;

    my $stmt;

    if ( $PerlSpace::SysMtExecuter::db eq "cego" )
    {
	$stmt = "select " .
	    $cego_selection .
	    " from sysmt_mtview m where mtfrom > date('%d.%m.%Y 00:00:00', '" . $fromdate . " 00:00:00') and mtfrom < date('%d.%m.%Y 00:00:00', '" . $todate . " 00:00:00') and m.pid in " .
	    " ( select pid from sysmt_prj2bgrp where bgid in " .
	    " ( select distinct bgid from sysmt_usr2bgrp u2g, sysmt_user u, sysmt_bgright r " .
	    " where ( r.bgright = 'mtread' or r.bgright = 'mtwrite' ) and r.bgid = u2g.bgid and  u2g.uid = u.uid and u.dbuser = '" . $user ."'))";
	
    }
    elsif ( $PerlSpace::SysMtExecuter::db eq "mysql" )
    {
	$stmt = "select " .
	    $mysql_selection .
	    " from sysmt_mtview m where mtfrom > date_format(" . $fromdate . ", '%d.%m.%Y') and mtfrom < date_format(" . $todate . ",'%d.%m.%Y') and m.pid in " .
	    " ( select pid from sysmt_prj2bgrp where bgid in " .
	    " ( select distinct bgid from sysmt_usr2bgrp u2g, sysmt_user u, sysmt_bgright r " .
	    " where ( r.bgright = 'mtread' or r.bgright = 'mtwrite' ) and r.bgid = u2g.bgid and  u2g.uid = u.uid and u.dbuser = '" . $user ."'))";
    }
    elsif ( $PerlSpace::SysMtExecuter::db eq "db2" )
    {

	$db2from = PerlSpace::SysMtUtil::db2DateTime($fromdate . " 00:00:00");
	$db2to = PerlSpace::SysMtUtil::db2DateTime($todate . " 00:00:00");
	
	$stmt = "select " .
	    $db2_selection .
	    " from sysmt_mtview m where mtfrom > '" . $db2from . "' and mtfrom < '" . $db2to . "' and m.pid in " .
	    " ( select pid from sysmt_prj2bgrp p2g where p2g.bgid in " .
	    " ( select distinct u2g.bgid from sysmt_usr2bgrp u2g, sysmt_user u, sysmt_bgright r " .
	    " where ( r.bgright = 'mtread' or r.bgright = 'mtwrite' ) and r.bgid = u2g.bgid and  u2g.uid = u.uid and u.dbuser = '" . $user ."'))";
    }

    my $thrid;
    return sysmtMtExecuteList($dbh, $user, $stmt, $ordering,$thrid);
    
}

sub sysmtMtListByDesc
{
    
    my ( $dbh, $user, $desc ) = @_;
    my $ordering = "order by mtfrom";

    my $stmt;
    
    if ( $PerlSpace::SysMtExecuter::db eq "cego" )
    {
	$stmt = "select " .
	    $cego_selection .
	    " from sysmt_mtview m where shortdesc like '%" . $desc . "%' and m.pid in " .
	    " ( select pid from sysmt_prj2bgrp where bgid in " .
	    " ( select distinct bgid from sysmt_usr2bgrp u2g, sysmt_user u, sysmt_bgright r " .
	    " where ( r.bgright = 'mtread' or r.bgright = 'mtwrite' ) and r.bgid = u2g.bgid and  u2g.uid = u.uid and u.dbuser = '" . $user ."'))";	
    }
    elsif ( $PerlSpace::SysMtExecuter::db eq "mysql" )
    {
	$stmt = "select " .
	    $mysql_selection .
	    " from sysmt_mtview m where shortdesc like '%" . $desc . "%' and m.pid in " .
	    " ( select pid from sysmt_prj2bgrp where bgid in " .
	    " ( select distinct bgid from sysmt_usr2bgrp u2g, sysmt_user u, sysmt_bgright r " .
	    " where ( r.bgright = 'mtread' or r.bgright = 'mtwrite' ) and r.bgid = u2g.bgid and  u2g.uid = u.uid and u.dbuser = '" . $user ."'))";
    }
    elsif ( $PerlSpace::SysMtExecuter::db eq "db2" )
    {
	$stmt = "select " .
	    $db2_selection .
	    " from sysmt_mtview m where shortdesc like '%" . $desc . "%' and m.pid in " .
	    " ( select pid from sysmt_prj2bgrp where bgid in " .
	    " ( select distinct u2g.bgid from sysmt_usr2bgrp u2g, sysmt_user u, sysmt_bgright r " .
	    " where ( r.bgright = 'mtread' or r.bgright = 'mtwrite' ) and r.bgid = u2g.bgid and  u2g.uid = u.uid and u.dbuser = '" . $user ."'))";
    }

    my $thrid;
    return sysmtMtExecuteList($dbh, $user, $stmt, $ordering,$thrid);

}

sub sysmtMtListByMid
{
    
    my ( $dbh, $user, $mid ) = @_;
    my $ordering = "order by mtfrom";

    my $stmt;
    
    if ( $PerlSpace::SysMtExecuter::db eq "cego" )
    {
	$stmt = "select " .
	    $cego_selection .
	    " from sysmt_mtview m where mid = " . $mid . " and m.pid in " .
	    " ( select pid from sysmt_prj2bgrp where bgid in " .
	    " ( select distinct bgid from sysmt_usr2bgrp u2g, sysmt_user u, sysmt_bgright r " .
	    " where ( r.bgright = 'mtread' or r.bgright = 'mtwrite' ) and r.bgid = u2g.bgid and  u2g.uid = u.uid and u.dbuser = '" . $user ."'))";
	
    }
    elsif ( $PerlSpace::SysMtExecuter::db eq "mysql" )
    {
	$stmt = "select " .
	    $mysql_selection .
	    " from sysmt_mtview m where mid = " . $mid . " and m.pid in " .
	    " ( select pid from sysmt_prj2bgrp where bgid in " .
	    " ( select distinct bgid from sysmt_usr2bgrp u2g, sysmt_user u, sysmt_bgright r " .
	    " where ( r.bgright = 'mtread' or r.bgright = 'mtwrite' ) and r.bgid = u2g.bgid and  u2g.uid = u.uid and u.dbuser = '" . $user ."'))";	   
    }
    elsif ( $PerlSpace::SysMtExecuter::db eq "db2" )
    {
	$stmt = "select " .
	    $db2_selection .
	    " from sysmt_mtview m where mid = " . $mid . " and m.pid in " .
	    " ( select pid from sysmt_prj2bgrp where bgid in " .
	    " ( select distinct u2g.bgid from sysmt_usr2bgrp u2g, sysmt_user u, sysmt_bgright r " .
	    " where ( r.bgright = 'mtread' or r.bgright = 'mtwrite' ) and r.bgid = u2g.bgid and  u2g.uid = u.uid and u.dbuser = '" . $user ."'))";	   
    }

    my $thrid;
    return sysmtMtExecuteList($dbh, $user, $stmt, $ordering,$thrid);

}


sub sysmtMtListByThread
{
    
    my ( $dbh, $user, $thrid, $thrstmt, $thrordering ) = @_;
    my $ordering = "order by mtfrom";

    my $stmt;
    
    if ( $PerlSpace::SysMtExecuter::db eq "cego" )
    {
	$stmt = "select " .
	    $cego_selection .
	    " from sysmt_mtview m where thrid = " . $thrid . " and m.pid in " .
	    " ( select pid from sysmt_prj2bgrp where bgid in " .
	    " ( select distinct bgid from sysmt_usr2bgrp u2g, sysmt_user u, sysmt_bgright r " .
	    " where ( r.bgright = 'mtread' or r.bgright = 'mtwrite' ) and r.bgid = u2g.bgid and  u2g.uid = u.uid and u.dbuser = '" . $user ."'))";
	
    }
    elsif ( $PerlSpace::SysMtExecuter::db eq "mysql" )
    {
	$stmt = "select " .
	    $mysql_selection .
	    " from sysmt_mtview m where thrid = " . $thrid . " and m.pid in " .
	    " ( select pid from sysmt_prj2bgrp where bgid in " .
	    " ( select distinct u2g.bgid from sysmt_usr2bgrp u2g, sysmt_user u, sysmt_bgright r " .
	    " where ( r.bgright = 'mtread' or r.bgright = 'mtwrite' ) and r.bgid = u2g.bgid and u2g.uid = u.uid and u.dbuser = '" . $user ."'))";	   
    }
    elsif ( $PerlSpace::SysMtExecuter::db eq "db2" )
    {
	$stmt = "select " .
	    $db2_selection .
	    " from sysmt_mtview m where thrid = " . $thrid . " and m.pid in " .
	    " ( select pid from sysmt_prj2bgrp where bgid in " .
	    " ( select distinct u2g.bgid from sysmt_usr2bgrp u2g, sysmt_user u, sysmt_bgright r " .
	    " where ( r.bgright = 'mtread' or r.bgright = 'mtwrite' ) and r.bgid = u2g.bgid and  u2g.uid = u.uid and u.dbuser = '" . $user ."'))";	   
    }


    return sysmtMtExecuteList($dbh, $user, $stmt, $ordering,$thrid,$thrstmt,$thrordering);

}


sub sysmtMtListByTicket
{
    
    my ( $dbh, $user, $ticket ) = @_;
    my $ordering = "order by mtfrom";

    my $stmt;

    if ( $PerlSpace::SysMtExecuter::db eq "cego" )
    {
	$stmt = "select " .
	    $cego_selection .
	    " from sysmt_mtview m where ticketnr = (bigint)" . $ticket . " and m.pid in " .
	    " ( select pid from sysmt_prj2bgrp where bgid in " .
	    " ( select distinct bgid from sysmt_usr2bgrp u2g, sysmt_user u, sysmt_bgright r " .
	    " where ( r.bgright = 'mtread' or r.bgright = 'mtwrite' ) and r.bgid = u2g.bgid and  u2g.uid = u.uid and u.dbuser = '" . $user ."'))";	
    }
    elsif ( $PerlSpace::SysMtExecuter::db eq "mysql" )
    {
	$stmt = "select " .
	    $mysql_selection .
	    " from sysmt_mtview m where ticketnr = " . $ticket . " and m.pid in " .
	    " ( select pid from sysmt_prj2bgrp where bgid in " .
	    " ( select distinct bgid from sysmt_usr2bgrp u2g, sysmt_user u, sysmt_bgright r " .
	    " where ( r.bgright = 'mtread' or r.bgright = 'mtwrite' ) and r.bgid = u2g.bgid and  u2g.uid = u.uid and u.dbuser = '" . $user ."'))";
    }
    elsif ( $PerlSpace::SysMtExecuter::db eq "db2" )
    {
	$stmt = "select " .
	    $db2_selection .
	    " from sysmt_mtview m where ticketnr = " . $ticket . " and m.pid in " .
	    " ( select pid from sysmt_prj2bgrp where bgid in " .
	    " ( select distinct u2g.bgid from sysmt_usr2bgrp u2g, sysmt_user u, sysmt_bgright r " .
	    " where ( r.bgright = 'mtread' or r.bgright = 'mtwrite' ) and r.bgid = u2g.bgid and  u2g.uid = u.uid and u.dbuser = '" . $user ."'))";
    }

    my $thrid;
    return sysmtMtExecuteList($dbh, $user, $stmt, $ordering,$thrid);

}

sub sysmtMtExecuteList
{
    
    my ( $dbh, $user, $stmt, $ordering, $thrid, $thrstmt, $thrordering ) = @_;

    # my $lastquery = $stmt; 
    my $query = $stmt . " " . $ordering. ";";

    my $sth = $dbh->prepare($query);

    # $ret = $sth->execute;
    # warn "Query is " . $query;

    $sth->execute;
    
    my $dbdata;

    # $$dbdata{'lastquery'} = $lastquery;
    $$dbdata{'ordering'} = $ordering;
    $$dbdata{'user'} = $user;
    $$dbdata{'stmt'} = $stmt;
    $$dbdata{'thrid'} = $thrid;

    $$dbdata{'thrordering'} = $thrordering;
    $$dbdata{'thrstmt'} = $thrstmt;

    my $mid;
    my $prjname;
    my $sid;
    my $shortdesc;    
    my $mtfrom;
    my $mtto;
    my $status;
    my $ticket;
    my $conflicts;
    my $tgname;
    my $thrid;


    my $i=0;
    while ( ($mid, $prjname, $sid, $shortdesc, $mtfrom, $mtto, $downfrom, $downto, $status, $ticket, $conflicts, $tgname, $thrid ) = $sth->fetchrow_array) 
    {

	if ( $mtfrom eq "null" )
	{
	    $mtfrom = "";
	}
	if ( $mtto eq "null" )
	{
	    $mtto = "";
	}

	$$dbdata{'mtlist'}[$i]{'mid'} = $mid;
	$$dbdata{'mtlist'}[$i]{'prjname'} = $prjname;
	$$dbdata{'mtlist'}[$i]{'sid'} = $sid;
	$$dbdata{'mtlist'}[$i]{'shortdesc'} = $shortdesc;
	$$dbdata{'mtlist'}[$i]{'mtfrom'} = $mtfrom;
	$$dbdata{'mtlist'}[$i]{'mtto'} = $mtto;
	$$dbdata{'mtlist'}[$i]{'downfrom'} = $downfrom;
	$$dbdata{'mtlist'}[$i]{'downto'} = $downto;

	$$dbdata{'mtlist'}[$i]{'status'} = $status;
	$$dbdata{'mtlist'}[$i]{'ticket'} = $ticket;
	$$dbdata{'mtlist'}[$i]{'conflicts'} = $conflicts;

	$$dbdata{'mtlist'}[$i]{'tgname'} = $tgname;
	$$dbdata{'mtlist'}[$i]{'thrid'} = $thrid;

	$i++;
    }
    
    $sth->finish;    

    # get approval information

    for ( $j=0; $j<$i; $j++)
    {
	$$dbdata{'mtlist'}[$j]{'approval'} = PerlSpace::SysMtUtil::getApprovalInfo($dbh, $$dbdata{'mtlist'}[$j]{'mid'});
    }

    # get approval information

    for ( $j=0; $j<$i; $j++)
    {
	$$dbdata{'mtlist'}[$j]{'verification'} = PerlSpace::SysMtUtil::getVerificationInfo($dbh, $$dbdata{'mtlist'}[$j]{'mid'});
    }
    
    my ( $headmsg, $fullname, $sysmsg )  = PerlSpace::SysMtUtil::getHeaderInfo($dbh, $user);
    $$dbdata{'headertext'} = $headmsg;
    $$dbdata{'fullname'} = $fullname;
    $$dbdata{'sysmsg'} = $sysmsg;
    $$dbdata{'content'} = 'sysmt_mtlist.html';


    $TT ||= Template->new({
	INCLUDE_PATH  => $PerlSpace::SysMtExecuter::tmplpath  });
    $TT->process('sysmt_frame.html', $dbdata) || die $TT->error(), "\n";

    return 0;
}


sub sysmtMt
{
    
    my ( $dbh, $user, $mid, $stmt, $ordering, $thrstmt, $thrordering ) = @_;
    
    my $dbdata;

    $$dbdata{'stmt'} = $stmt;
    $$dbdata{'ordering'} = $ordering;

    $$dbdata{'thrstmt'} = $thrstmt;
    $$dbdata{'thrordering'} = $thrordering;


    $$dbdata{'user'} = $user;

    my $sth;
    
    if ( $PerlSpace::SysMtExecuter::db eq "cego" )
    {
	$sth = $dbh->prepare("select mid, lockby, prjname, sid, shortdesc, description, mtfrom, mtto, downfrom, downto, status, ticketnr, mttype, conflicts, thrid, tgname, tshortdesc from sysmt_mtview where mid = ?;");
    } 
    elsif ( $PerlSpace::SysMtExecuter::db eq "mysql" )
    {
	$sth = $dbh->prepare("select mid, lockby, prjname, sid, shortdesc, description, date_format(mtfrom, '%d.%m.%Y %m:%i:%s'),date_format(mtto, '%d.%m.%Y %m:%i:%s'),date_format(downfrom, '%d.%m.%Y %m:%i:%s'),date_format(downto, '%d.%m.%Y %m:%i:%s'), status, ticketnr, mttype, conflicts, thrid, tgname, tshortdesc from sysmt_mtview where mid = ?;");
    }
    elsif ( $PerlSpace::SysMtExecuter::db eq "db2" )
    {
	$sth = $dbh->prepare("select mid, lockby, prjname, sid, shortdesc, description, ts_fmt(mtfrom, 'dd.mm.yyyy hh:mi:ss'),ts_fmt(mtto, 'dd.mm.yyyy hh:mi:ss'),ts_fmt(downfrom, 'dd.mm.yyyy hh:mi:ss'),ts_fmt(downto, 'dd.mm.yyyy hh:mi:ss'), status, ticketnr, mttype, conflicts, thrid, tgname, tshortdesc from sysmt_mtview where mid = ?;");
    }

    $sth->bind_param(1, $mid, DBI::SQL_INTEGER);
        
    $sth->execute;
    

    my $mid;
    my $lockby;
    my $project;
    my $sid;
    my $shortdesc;
    my $description;
    my $mtfrom;
    my $mtto;
    my $downfrom;
    my $downto;
    my $status;
    my $type;
    my $conflicts;
    my $thrid;
    my $tgname;


    ( $mid, $lockby, $project, $sid, $shortdesc, $description, $mtfrom, $mtto, $downfrom, $downto,  $status, $ticket, $type, $conflicts, $thrid, $tgname, $tshortdesc ) = $sth->fetchrow_array; 

    if ( lc $mtfrom eq "null" )
    {
	$mtfrom = "";
    }
    if ( lc $mtto eq "null" )
    {
	$mtto = "";
    }
    if ( $lockby eq "" )
    {
	$lockby = "null";
    }
        
    $$dbdata{'mid'} = $mid;
    $$dbdata{'lockby'} = $lockby;
    $$dbdata{'sid'} = $sid;
    $$dbdata{'project'} = $project;
    $$dbdata{'shortdesc'} = $shortdesc;
    $$dbdata{'description'} = $description;
    $$dbdata{'mtfrom'} = $mtfrom;
    $$dbdata{'mtto'} = $mtto;
    $$dbdata{'downfrom'} = $downfrom;
    $$dbdata{'downto'} = $downto;
    $$dbdata{'status'} = $status;
    $$dbdata{'ticket'} = $ticket;
    $$dbdata{'type'} = $type;
    $$dbdata{'conflicts'} = $conflicts;
    $$dbdata{'thrid'} = $thrid;
    $$dbdata{'tgname'} = $tgname;
    $$dbdata{'tshortdesc'} = $tshortdesc;
    
    $sth->fetchrow_array; 
    $sth->finish;

    # sid retrievel
    $stmt="select distinct sid from sysmt_system s, sysmt_project p, sysmt_prj2bgrp p2g, sysmt_usr2bgrp u2g, sysmt_user u where s.pid = p.pid and p.pid = p2g.pid and p.pid = p2g.pid and p2g.bgid = u2g.bgid and u.dbuser = ? and u.uid = u2g.uid order by sid;";

        
    $sth = $dbh->prepare($stmt);
    $sth->bind_param(1, $user, DBI::SQL_VARCHAR);
    
    $sth->execute;

    my $clonesid;	
    $i=0;
    while ( ($clonesid) = $sth->fetchrow_array) 
    {
	$$dbdata{'sidlist'}[$i] = $clonesid;
	$i++;
    }
    
    $sth->finish;    

    # set retrievel
    $stmt="select setname from sysmt_systemset ss, sysmt_sys2set s2s, sysmt_system s where s.sid = ? and s.sysid = s2s.sysid and s2s.setid = ss.setid order by setname;";

    $sth = $dbh->prepare($stmt);
    $sth->bind_param(1, $sid, DBI::SQL_VARCHAR);
    
    $sth->execute;

    my $set;	
    $i=0;
    while ( ($set) = $sth->fetchrow_array) 
    {
	$$dbdata{'setlist'}[$i] = $set;
	$i++;
    }
    
    $sth->finish;

    # verification retrievel

    $stmt="select distinct bgname from sysmt_project p, sysmt_prj2verification p2v, sysmt_bgroup g where  p.prjname = ? and p.pid = p2v.pid and p2v.bgid = g.bgid and g.bgid not in ( select bgid from sysmt_mtverification where mid = ? ) order by bgname;";

    $sth = $dbh->prepare($stmt);
    $sth->bind_param(1, $project, DBI::SQL_VARCHAR);
    $sth->bind_param(2, $mid, DBI::SQL_INTEGER);

    $sth->execute;

    my $set;	
    $i=0;
    while ( ($bgname) = $sth->fetchrow_array) 
    {
	$$dbdata{'addvglist'}[$i] = $bgname;
	$i++;
    }
    
    $sth->finish;


    $stmt="select distinct bgname from sysmt_bgroup g, sysmt_mtverification mtv where mtv.mid = ? and mtv.bgid = g.bgid order by bgname;";

    $sth = $dbh->prepare($stmt);
    $sth->bind_param(1, $mid, DBI::SQL_INTEGER);

    $sth->execute;

    my $set;	
    $i=0;
    while ( ($bgname) = $sth->fetchrow_array) 
    {
	$$dbdata{'delvglist'}[$i] = $bgname;
	$i++;
    }
    
    $sth->finish;


    # approval retrievel
    $stmt="select bgname, status from sysmt_mtapproval ma, sysmt_bgroup g where g.bgid = ma.bgid and ma.mid = ?;";

    $sth = $dbh->prepare($stmt);
    $sth->bind_param(1, $mid, DBI::SQL_INTEGER);

    $sth->execute;

    my $set;	
    $numapp=0;
    while ( ($agroup, $status) = $sth->fetchrow_array) 
    {
	$$dbdata{'approvallist'}[$numapp]{'group'} = $agroup;
	$$dbdata{'approvallist'}[$numapp]{'status'} = $status;
	$$dbdata{'approvallist'}[$numapp]{'auth'} = 'no';
	$numapp++;
    }
    
    $sth->finish;

    # verification retrievel
    $stmt="select bgname, status from sysmt_mtverification ma, sysmt_bgroup g where g.bgid = ma.bgid and ma.mid = ?;";

    $sth = $dbh->prepare($stmt);
    $sth->bind_param(1, $mid, DBI::SQL_INTEGER);

    
    $sth->execute;

    my $set;
    $numver=0;
    while ( ($agroup, $status) = $sth->fetchrow_array) 
    {
	$$dbdata{'verificationlist'}[$numver]{'group'} = $agroup;
	$$dbdata{'verificationlist'}[$numver]{'status'} = $status;
	$$dbdata{'verificationlist'}[$numver]{'auth'} = 'no';
	$numver++;
    }
    
    $sth->finish;

    # thread retrievel

    $stmt="select distinct tgname, thrid, shortdesc from sysmt_threadview where tgname in ( select tgname from sysmt_threadgroup tg, sysmt_tg2bgrp tg2bg, sysmt_prj2bgrp p2g, sysmt_system s where s.sid = ? and s.pid = p2g.pid and p2g.bgid = tg2bg.bgid and tg2bg.tgid = tg.tgid );";

    $sth = $dbh->prepare($stmt);
    $sth->bind_param(1, $sid, DBI::SQL_VARCHAR);
    
    $sth->execute;

    my $set;
    $i=0;
    while ( ($tgname, $thrid, $shortdesc) = $sth->fetchrow_array) 
    {
	$$dbdata{'threadlist'}[$i]{'tgname'} = $tgname;
	$$dbdata{'threadlist'}[$i]{'thrid'} = $thrid;
	$$dbdata{'threadlist'}[$i]{'shortdesc'} = $shortdesc;
	$i++;
    }
    
    $sth->finish;

    my @grouplist;

    @grouplist = PerlSpace::SysMtUtil::getGroupSetForUser($dbh, $user);

    foreach my $group ( @grouplist )
    {
        # warn "Checking group " . $group . "\n";
        for ( $i=0; $i<$numapp; $i++ )
        {
            if ( $$dbdata{'approvallist'}[$i]{'group'} eq $group )
            {   
                # warn "Setting auth to yes\n";
                $$dbdata{'approvallist'}[$i]{'auth'} = 'yes';
            }       
        }

        for ( $i=0; $i<$numver; $i++ )
        {
            if ( $$dbdata{'verificationlist'}[$i]{'group'} eq $group )
            {   
                # warn "Setting auth to yes\n";
                $$dbdata{'verificationlist'}[$i]{'auth'} = 'yes';
            }       
        }

    }


    my ( $headmsg, $fullname, $sysmsg )  = PerlSpace::SysMtUtil::getHeaderInfo($dbh, $user);
    $$dbdata{'headertext'} = $headmsg;
    $$dbdata{'fullname'} = $fullname;
    $$dbdata{'sysmsg'} = $sysmsg;
    $$dbdata{'content'} = 'sysmt_mt.html';

    $TT ||= Template->new({ INCLUDE_PATH  => $PerlSpace::SysMtExecuter::tmplpath });
    $TT->process('sysmt_frame.html', $dbdata) || die $TT->error(), "\n";
    
    return 0;
}

sub sysmtMtNew
{

    my ( $dbh, $user, $project ) = @_;

    my $dbdata;

    $$dbdata{'user'} = $user;

    $$dbdata{'project'} = $project;    

    $sth = $dbh->prepare("select distinct sid from sysmt_systemview where prjname = ?;");

    $sth->bind_param(1, $project, DBI::SQL_VARCHAR);
    
    $sth->execute;
        
    my $sidname;	
    my $i=0;
    while ( ($sidname) = $sth->fetchrow_array) 
    {
	$$dbdata{'sidlist'}[$i]{'name'} = $sidname;
	$i++;
    }
    
    $sth->finish;

    my ( $headmsg, $fullname, $sysmsg )  = PerlSpace::SysMtUtil::getHeaderInfo($dbh, $user);
    $$dbdata{'headertext'} = $headmsg;
    $$dbdata{'fullname'} = $fullname;
    $$dbdata{'sysmsg'} = $sysmsg;
    $$dbdata{'content'} = "sysmt_mtnew.html";

        
    $TT ||= Template->new({ INCLUDE_PATH  => $PerlSpace::SysMtExecuter::tmplpath });
    $TT->process('sysmt_frame.html', $dbdata) || die $TT->error(), "\n";
    
    return 0;
}

sub sysmtMtNewBySid
{

    my ( $dbh, $user, $sid, $thrid ) = @_;

    my $dbdata;

    $$dbdata{'user'} = $user;

    $sth = $dbh->prepare("select prjname from sysmt_systemview where sid = ?;");

    $sth->bind_param(1, $sid, DBI::SQL_VARCHAR);
    
    $sth->execute;
        
    $prjname = $sth->fetchrow_array;

    $sth->finish;

    $$dbdata{'project'} = $prjname;
    $$dbdata{'thrid'} = $thrid;
    $$dbdata{'sidlist'}[0]{'name'} = $sid;

    my ( $headmsg, $fullname, $sysmsg )  = PerlSpace::SysMtUtil::getHeaderInfo($dbh, $user);
    $$dbdata{'headertext'} = $headmsg;
    $$dbdata{'fullname'} = $fullname;
    $$dbdata{'sysmsg'} = $sysmsg;
    $$dbdata{'content'} = "sysmt_mtnew.html";
    
   
    $TT ||= Template->new({ INCLUDE_PATH  => $PerlSpace::SysMtExecuter::tmplpath });
    $TT->process('sysmt_frame.html', $dbdata) || die $TT->error(), "\n";
    
    return 0;
}


sub sysmtMtCreate
{

    my ( $dbh, $user, $sid, $shortdesc, $description, $mtfrom, $mtto, $downfrom, $downto, $ticket, $type, $thrid ) = @_;

    my $dbdata;

    $$dbdata{'user'} = $user;

    my $mid;
    my $status="Requested";

    if ( $type eq "Claimed" )
    {
	$status="Claimed";
    }
    elsif ( $type eq "Attention" )
    {
	$status="Attention";
    }    

    if ( ! $mtfrom )
    {
	$mtfrom = $downfrom;
    }
    if ( ! $mtto )
    {
	$mtto = $downto;
    }

    if ( $mtfrom && $mtto && $downfrom && $downto )
    {
			
	if ( $PerlSpace::SysMtExecuter::db eq "cego" )
	{

	    $sth = $dbh->prepare("? = call newMt ( ?, ?, ?, date('%d.%m.%Y %H:%M:%S', ?), date('%d.%m.%Y %H:%M:%S', ?), date('%d.%m.%Y %H:%M:%S', ?),date('%d.%m.%Y %H:%M:%S', ?), ?, (bigint)?, ?, ? );");

	    $sth->bind_param_inout(1, \$mid, 10);
	    $sth->bind_param(2, $sid, DBI::SQL_VARCHAR);
	    $sth->bind_param(3, $shortdesc, DBI::SQL_VARCHAR);
	    $sth->bind_param(4, $description, DBI::SQL_VARCHAR);
	    $sth->bind_param(5, $mtfrom, DBI::SQL_VARCHAR);
	    $sth->bind_param(6, $mtto, DBI::SQL_VARCHAR);
	    $sth->bind_param(7, $downfrom, DBI::SQL_VARCHAR);
	    $sth->bind_param(8, $downto, DBI::SQL_VARCHAR);
	    $sth->bind_param(9, $status, DBI::SQL_VARCHAR);
	    $sth->bind_param(10, $ticket, DBI::SQL_INTEGER);
	    $sth->bind_param(11, $type, DBI::SQL_VARCHAR);
	    if ( $thrid )
	    {
		$sth->bind_param(12, $thrid, DBI::SQL_INTEGER);    
	    }
	}
	elsif ( $PerlSpace::SysMtExecuter::db eq "mysql" )
	{

	    $sth = $dbh->prepare("select newMt(?,?,?,?,?,?,?,?,?,?,?);");

	    $sth->bind_param(1, $sid, DBI::SQL_VARCHAR);
	    $sth->bind_param(2, $shortdesc, DBI::SQL_VARCHAR);
	    $sth->bind_param(3, $description, DBI::SQL_VARCHAR);
	    $sth->bind_param(4, PerlSpace::SysMtUtil::mysqlDate($mtfrom), DBI::SQL_VARCHAR);
	    $sth->bind_param(5, PerlSpace::SysMtUtil::mysqlDate($mtto), DBI::SQL_VARCHAR);
	    $sth->bind_param(6, PerlSpace::SysMtUtil::mysqlDate($downfrom), DBI::SQL_VARCHAR);
	    $sth->bind_param(7, PerlSpace::SysMtUtil::mysqlDate($downto), DBI::SQL_VARCHAR);
	    $sth->bind_param(8, $status, DBI::SQL_VARCHAR);
	    $sth->bind_param(9, $ticket, DBI::SQL_INTEGER);
	    $sth->bind_param(10, $type, DBI::SQL_VARCHAR);
	    if ( $thrid )
	    {
		$sth->bind_param(11, $thrid, DBI::SQL_INTEGER);    
	    }
	}
	elsif ( $PerlSpace::SysMtExecuter::db eq "db2" )
	{

	    $sth = $dbh->prepare(q{call newMt(?,?,?,?,?,?,?,?,?,?,?,?)});

	    $sth->bind_param(1, $sid, DBI::SQL_VARCHAR);
	    $sth->bind_param(2, $shortdesc, DBI::SQL_VARCHAR);
	    $sth->bind_param(3, $description, DBI::SQL_VARCHAR);
	    $sth->bind_param(4, PerlSpace::SysMtUtil::db2DateTime($mtfrom), DBI::SQL_VARCHAR);
	    $sth->bind_param(5, PerlSpace::SysMtUtil::db2DateTime($mtto), DBI::SQL_VARCHAR);
	    $sth->bind_param(6, PerlSpace::SysMtUtil::db2DateTime($downfrom), DBI::SQL_VARCHAR);
	    $sth->bind_param(7, PerlSpace::SysMtUtil::db2DateTime($downto), DBI::SQL_VARCHAR);
	    $sth->bind_param(8, $status, DBI::SQL_VARCHAR);
	    $sth->bind_param(9, $ticket, DBI::SQL_INTEGER);
	    $sth->bind_param(10, $type, DBI::SQL_VARCHAR);	    
	    $sth->bind_param(11, $thrid, DBI::SQL_INTEGER);
	    $sth->bind_param_inout(12, \$mid, 100, DBI::SQL_INTEGER);
	}

    }
    elsif ( $mtfrom && $mtto )
    {

	if ( $PerlSpace::SysMtExecuter::db eq "cego" )
	{
	    
	    $sth = $dbh->prepare("? = call newMt ( ?, ?, ?, date('%d.%m.%Y %H:%M:%S', ?), date('%d.%m.%Y %H:%M:%S', ?), null, null, ?, (bigint)?, ?, ? );");
	    
	    $sth->bind_param_inout(1, \$mid, 10);
	    $sth->bind_param(2, $sid, DBI::SQL_VARCHAR);
	    $sth->bind_param(3, $shortdesc, DBI::SQL_VARCHAR);
	    $sth->bind_param(4, $description, DBI::SQL_VARCHAR);
	    $sth->bind_param(5, $mtfrom, DBI::SQL_VARCHAR);
	    $sth->bind_param(6, $mtto, DBI::SQL_VARCHAR);
	    $sth->bind_param(7, $status, DBI::SQL_VARCHAR);
	    $sth->bind_param(8, $ticket, DBI::SQL_INTEGER);
	    $sth->bind_param(9, $type, DBI::SQL_VARCHAR);
	    if ( $thrid )
	    {
		$sth->bind_param(10, $thrid, DBI::SQL_INTEGER);
	    }
	}
	elsif ( $PerlSpace::SysMtExecuter::db eq "mysql" )
	{

	    $sth = $dbh->prepare("select newMt(?,?,?,?,?,null,null,?,?,?,?);");

	    $sth->bind_param(1, $sid, DBI::SQL_VARCHAR);
	    $sth->bind_param(2, $shortdesc, DBI::SQL_VARCHAR);
	    $sth->bind_param(3, $description, DBI::SQL_VARCHAR);
	    $sth->bind_param(4, PerlSpace::SysMtUtil::mysqlDate($mtfrom), DBI::SQL_VARCHAR);
	    $sth->bind_param(5, PerlSpace::SysMtUtil::mysqlDate($mtto), DBI::SQL_VARCHAR);
	    $sth->bind_param(6, $status, DBI::SQL_VARCHAR);
	    $sth->bind_param(7, $ticket, DBI::SQL_INTEGER);
	    $sth->bind_param(8, $type, DBI::SQL_VARCHAR);	    
	    if ( $thrid )
	    {
		$sth->bind_param(9, $thrid, DBI::SQL_INTEGER);    
	    }
	}
	elsif ( $PerlSpace::SysMtExecuter::db eq "db2" )
	{

	    $sth = $dbh->prepare(q{call newMt(?, ?, ?, ?, ?, null, null, ?, ?, ?, ?, ?)});

	    $sth->bind_param(1, $sid, DBI::SQL_VARCHAR);
	    $sth->bind_param(2, $shortdesc, DBI::SQL_VARCHAR);
	    $sth->bind_param(3, $description, DBI::SQL_VARCHAR);
	    $sth->bind_param(4, PerlSpace::SysMtUtil::db2DateTime($mtfrom), DBI::SQL_VARCHAR);
	    $sth->bind_param(5, PerlSpace::SysMtUtil::db2DateTime($mtto), DBI::SQL_VARCHAR);
	    $sth->bind_param(6, $status, DBI::SQL_VARCHAR);
	    $sth->bind_param(7, $ticket, DBI::SQL_INTEGER);
	    $sth->bind_param(8, $type, DBI::SQL_VARCHAR);	    
	    $sth->bind_param(9, $thrid, DBI::SQL_INTEGER);
	    $sth->bind_param_inout(10, \$mid, 100, DBI::SQL_INTEGER);
	}
    }
    else
    {
	if ( $PerlSpace::SysMtExecuter::db eq "cego" )
	{
	    $sth = $dbh->prepare("? = call newMt ( ?, ?, ?, null, null, null, null, ?, (bigint)?, ?, ? );");

	    $sth->bind_param_inout(1, \$mid, 10);
	    $sth->bind_param(2, $sid, DBI::SQL_VARCHAR);
	    $sth->bind_param(3, $shortdesc, DBI::SQL_VARCHAR);
	    $sth->bind_param(4, $description, DBI::SQL_VARCHAR);
	    $sth->bind_param(5, $status, DBI::SQL_VARCHAR);
	    $sth->bind_param(6, $ticket, DBI::SQL_INTEGER);
	    $sth->bind_param(7, $type, DBI::SQL_VARCHAR);
	    if ( $thrid )
	    {
		$sth->bind_param(8, $thrid, DBI::SQL_INTEGER);
	    }
	}
	elsif ( $PerlSpace::SysMtExecuter::db eq "mysql" )
	{

	    $sth = $dbh->prepare("select newMt(?,?,?,null,null,null,null,?,?,?,?);");

	    $sth->bind_param(1, $sid, DBI::SQL_VARCHAR);
	    $sth->bind_param(2, $shortdesc, DBI::SQL_VARCHAR);
	    $sth->bind_param(3, $description, DBI::SQL_VARCHAR);
	    $sth->bind_param(4, $status, DBI::SQL_VARCHAR);
	    $sth->bind_param(5, $ticket, DBI::SQL_INTEGER);
	    $sth->bind_param(6, $type, DBI::SQL_VARCHAR);	   
	    if ( $thrid )
	    {
		$sth->bind_param(7, $thrid, DBI::SQL_INTEGER);    
	    }
	}
	elsif ( $PerlSpace::SysMtExecuter::db eq "db2" )
	{

	    $sth = $dbh->prepare(q{call newMt(?, ?, ?, null, null, null, null, ?, ?, ?,?,?)});

	    $sth->bind_param(1, $sid, DBI::SQL_VARCHAR);
	    $sth->bind_param(2, $shortdesc, DBI::SQL_VARCHAR);
	    $sth->bind_param(3, $description, DBI::SQL_VARCHAR);
	    $sth->bind_param(4, $status, DBI::SQL_VARCHAR);
	    $sth->bind_param(5, $ticket, DBI::SQL_INTEGER);
	    $sth->bind_param(6, $type, DBI::SQL_VARCHAR);	   
	    $sth->bind_param(7, $thrid, DBI::SQL_INTEGER);
	    $sth->bind_param_inout(8, \$mid, 100, DBI::SQL_INTEGER);
	}
    }


    if ( $PerlSpace::SysMtExecuter::db eq "cego" )
    {	
	$sth->execute;
    }
    elsif ( $PerlSpace::SysMtExecuter::db eq "mysql" )
    {
	$sth->execute;
	$mid = $sth->fetchrow_array;
    }
    elsif ( $PerlSpace::SysMtExecuter::db eq "db2" )
    {
	$sth->execute;
    }
    
    $sth->finish;

    PerlSpace::SysMtUtil::logMtAction($dbh, $mid, "Created by " . $user);

    return sysmtMt($dbh, $user, $mid);

}

sub sysmtMtMod
{

    my ( $dbh, $user, $mid, $stmt, $ordering, $thrstmt, $thrordering ) = @_;

    if ( PerlSpace::SysMtUtil::checkMtWrite($dbh, $user, $mid) == 0 )
    {
        die "No appropriate right\n";
    }

    # warn "ordering is $ordering";

    $sth = $dbh->prepare("select lockby from sysmt_mt where mid = ?;");
   
    $sth->bind_param(1, $mid, DBI::SQL_INTEGER);

    $sth->execute;

    my $lockuser = $sth->fetchrow_array;

    $sth->finish;

    if ( $lockuser eq $user || $lockuser eq "null" || $lockuser eq "" )
    {
	
	$sth = $dbh->prepare("update sysmt_mt set lockby = ? where mid = ?;");
	$sth->bind_param(1, $user, DBI::SQL_VARCHAR);
	$sth->bind_param(2, $mid, DBI::SQL_INTEGER);
	
	$sth->execute;
	
	$sth->finish;    

	return sysmtMt($dbh, $user, $mid, $stmt, $ordering, $thrstmt, $thrordering);
    }
    else
    {
        die "Entry locked by user\n";
    }

}

sub sysmtMtAbort
{

    my ( $dbh, $user, $mid, $stmt, $ordering, $thrstmt, $thrordering ) = @_;

    if ( PerlSpace::SysMtUtil::checkMtWrite($dbh, $user, $mid) == 0 )
    {
        die "No appropriate right\n";
    }
    
    $sth = $dbh->prepare("select lockby from sysmt_mt where mid = ?;");
   
    $sth->bind_param(1, $mid, DBI::SQL_INTEGER);

    $sth->execute;

    my $lockuser = $sth->fetchrow_array;

    $sth->finish;


    if ( $lockuser ne $user  )
    {      
        die "No valid lock\n";
    }

    $sth = $dbh->prepare("update sysmt_mt set lockby = null where mid = ?;");
    $sth->bind_param(1, $mid, DBI::SQL_INTEGER);

    $sth->execute;
        
    $sth->finish;    
	
    return sysmtMt($dbh, $user, $mid, $stmt, $ordering, $thrstmt, $thrordering);    
}

sub sysmtMtUpdate
{

    my ( $dbh, $user, $mid, $shortdesc, $mtfrom, $mtto, $downfrom, $downto, $type, $stmt, $ordering, $thrstmt, $thrordering ) = @_;

    if ( PerlSpace::SysMtUtil::checkMtWrite($dbh, $user, $mid) == 0 )
    {
        die "No appropriate right\n";
    }
    
    $sth = $dbh->prepare("select lockby from sysmt_mt where mid = ?;");
   
    $sth->bind_param(1, $mid, DBI::SQL_INTEGER);

    $sth->execute;

    my $lockuser = $sth->fetchrow_array;

    $sth->finish;

    if ( $lockuser ne $user  )
    {      
        die "No valid lock\n";
    }

    my $status = "Requested";
    if ( $type eq "Claimed" )
    {
	$status = "Claimed";
    }
    elsif ( $type eq "Attention" )
    {
	$status = "Attention";
    }

    if ( ! $mtfrom )
    {
	$mtfrom = $downfrom;
    }
    if ( ! $mtto )
    {
	$mtto = $downto;
    }
    
    if ( $mtfrom && $mtto && $downfrom && $downto )
    {
	
	if ( $PerlSpace::SysMtExecuter::db eq "cego" )
	{
	    $sth = $dbh->prepare("update sysmt_mt set shortdesc = ?, mtfrom=date('%d.%m.%Y %H:%M:%S', ?), mtto = date('%d.%m.%Y %H:%M:%S', ?), downfrom = date('%d.%m.%Y %H:%M:%S', ?), downto = date('%d.%m.%Y %H:%M:%S', ?), status = ?, mttype = ?  where mid = ?;");

	    $sth->bind_param(1, $shortdesc, DBI::SQL_VARCHAR);
	    $sth->bind_param(2, $mtfrom, DBI::SQL_VARCHAR);
	    $sth->bind_param(3, $mtto, DBI::SQL_VARCHAR);
	    $sth->bind_param(4, $downfrom, DBI::SQL_VARCHAR);
	    $sth->bind_param(5, $downto, DBI::SQL_VARCHAR);
	    $sth->bind_param(6, $status, DBI::SQL_VARCHAR);
	    $sth->bind_param(7, $type, DBI::SQL_VARCHAR);
	    $sth->bind_param(8, $mid, DBI::SQL_INTEGER);

	}
	elsif ( $PerlSpace::SysMtExecuter::db eq "mysql" )
	{
	    $sth = $dbh->prepare("update sysmt_mt set shortdesc = ?, mtfrom= ?, mtto = ?, downfrom = ?, downto = ?, status = ?, mttype = ? where mid = ?;");


	    $sth->bind_param(1, $shortdesc, DBI::SQL_VARCHAR);
	    $sth->bind_param(2, PerlSpace::SysMtUtil::mysqlDate($mtfrom), DBI::SQL_VARCHAR);
	    $sth->bind_param(3, PerlSpace::SysMtUtil::mysqlDate($mtto), DBI::SQL_VARCHAR);
	    $sth->bind_param(4, PerlSpace::SysMtUtil::mysqlDate($downfrom), DBI::SQL_VARCHAR);
	    $sth->bind_param(5, PerlSpace::SysMtUtil::mysqlDate($downto), DBI::SQL_VARCHAR);
	    $sth->bind_param(6, $status, DBI::SQL_VARCHAR);
	    $sth->bind_param(7, $type, DBI::SQL_VARCHAR);
	    $sth->bind_param(8, $mid, DBI::SQL_INTEGER);

	}
	elsif ( $PerlSpace::SysMtExecuter::db eq "db2" )
	{
	    $sth = $dbh->prepare("update sysmt_mt set shortdesc = ?, mtfrom= ?, mtto = ?, downfrom = ?, downto = ?, status = ?, mttype = ? where mid = ?;");


	    $sth->bind_param(1, $shortdesc, DBI::SQL_VARCHAR);
	    $sth->bind_param(2, PerlSpace::SysMtUtil::db2DateTime($mtfrom), DBI::SQL_VARCHAR);
	    $sth->bind_param(3, PerlSpace::SysMtUtil::db2DateTime($mtto), DBI::SQL_VARCHAR);
	    $sth->bind_param(4, PerlSpace::SysMtUtil::db2DateTime($downfrom), DBI::SQL_VARCHAR);
	    $sth->bind_param(5, PerlSpace::SysMtUtil::db2DateTime($downto), DBI::SQL_VARCHAR);
	    $sth->bind_param(6, $status, DBI::SQL_VARCHAR);
	    $sth->bind_param(7, $type, DBI::SQL_VARCHAR);
	    $sth->bind_param(8, $mid, DBI::SQL_INTEGER);

	}
	
    }
    elsif ( $mtfrom && $mtto )
    {
	if ( $PerlSpace::SysMtExecuter::db eq "cego" )
	{
	    $sth = $dbh->prepare("update sysmt_mt set shortdesc = ?, mtfrom = date('%d.%m.%Y %H:%M:%S', ?), mtto = date('%d.%m.%Y %H:%M:%S', ?), downfrom = null, downto = null, status = ?, mttype = ?  where mid = ?;");
	    $sth->bind_param(1, $shortdesc, DBI::SQL_VARCHAR);
	    $sth->bind_param(2, $mtfrom, DBI::SQL_VARCHAR);
	    $sth->bind_param(3, $mtto, DBI::SQL_VARCHAR);
	    $sth->bind_param(4, $status, DBI::SQL_VARCHAR);
	    $sth->bind_param(5, $type, DBI::SQL_VARCHAR);
	    $sth->bind_param(6, $mid, DBI::SQL_INTEGER);

	}
	elsif ( $PerlSpace::SysMtExecuter::db eq "mysql" )
	{
	    $sth = $dbh->prepare("update sysmt_mt set shortdesc = ?, mtfrom = ?, mtto = ?, downfrom = null, downto = null, status = ?, mttype = ? where mid = ?;");
	    $sth->bind_param(1, $shortdesc, DBI::SQL_VARCHAR);
	    $sth->bind_param(2, PerlSpace::SysMtUtil::mysqlDate($mtfrom), DBI::SQL_VARCHAR);
	    $sth->bind_param(3, PerlSpace::SysMtUtil::mysqlDate($mtto), DBI::SQL_VARCHAR);
	    $sth->bind_param(4, $status, DBI::SQL_VARCHAR);
	    $sth->bind_param(5, $type, DBI::SQL_VARCHAR);
	    $sth->bind_param(6, $mid, DBI::SQL_INTEGER);
	}
	elsif ( $PerlSpace::SysMtExecuter::db eq "db2" )
	{
	    $sth = $dbh->prepare("update sysmt_mt set shortdesc = ?, mtfrom= ?, mtto = ?, downfrom = null, downto = null, status = ?, mttype = ? where mid = ?;");

	    $sth->bind_param(1, $shortdesc, DBI::SQL_VARCHAR);
	    $sth->bind_param(2, PerlSpace::SysMtUtil::db2DateTime($mtfrom), DBI::SQL_VARCHAR);
	    $sth->bind_param(3, PerlSpace::SysMtUtil::db2DateTime($mtto), DBI::SQL_VARCHAR);
	    $sth->bind_param(4, $status, DBI::SQL_VARCHAR);
	    $sth->bind_param(5, $type, DBI::SQL_VARCHAR);
	    $sth->bind_param(6, $mid, DBI::SQL_INTEGER);

	}
    }
    else
    {

	if ( $PerlSpace::SysMtExecuter::db eq "cego" )
	{
	    $sth = $dbh->prepare("update sysmt_mt set shortdesc = ?, mtfrom = null, mtto = null, downfrom = null, downto = null, status = ?, mttype = ?  where mid = ?;");
	}
	elsif ( $PerlSpace::SysMtExecuter::db eq "mysql" )
	{
	    $sth = $dbh->prepare("update sysmt_mt set shortdesc = ?, mtfrom= null, mtto = null, downfrom = null, downto = null, status = ?, mttype = ? where mid = ?;");
	}
	elsif ( $PerlSpace::SysMtExecuter::db eq "db2" )
	{
	    $sth = $dbh->prepare("update sysmt_mt set shortdesc = ?, mtfrom= null, mtto = null, downfrom = null, downto = null, status = ?, mttype = ? where mid = ?;");
	}

	$sth->bind_param(1, $shortdesc, DBI::SQL_VARCHAR);
	$sth->bind_param(2, $status, DBI::SQL_VARCHAR);
	$sth->bind_param(3, $type, DBI::SQL_VARCHAR);
	$sth->bind_param(4, $mid, DBI::SQL_INTEGER);
		
    }
     
    $sth->execute;
    
    $sth->finish;    

    PerlSpace::SysMtUtil::logMtAction($dbh, $mid, "Edited by " . $user);
    
    $sth = $dbh->prepare("update sysmt_mt set lockby = null where mid = ?;");
    $sth->bind_param(1, $mid, DBI::SQL_INTEGER);

    $sth->execute;

    $sth->finish;    

    $sth = $dbh->prepare("update sysmt_mtapproval set status = 'Requested' where mid = ?;");
    $sth->bind_param(1, $mid, DBI::SQL_INTEGER);

    $sth->execute;

    $sth->finish;    

    return sysmtMt($dbh, $user, $mid, $stmt, $ordering, $thrstmt, $thrordering);

}


sub sysmtMtSetToStatus
{

    my ( $dbh, $user, $mid, $status, $stmt, $ordering, $thrstmt, $thrordering) = @_;


    if ( PerlSpace::SysMtUtil::checkMtWrite($dbh, $user, $mid) == 0 )
    {
        die "No appropriate right\n";
    }


    $sth = $dbh->prepare("update sysmt_mt set status = ? where mid = ?;");
    $sth->bind_param(1, $status, DBI::SQL_VARCHAR);
    $sth->bind_param(2, $mid, DBI::SQL_INTEGER);

    $sth->execute;

    $sth->finish;    

    PerlSpace::SysMtUtil::logMtAction($dbh, $mid, "Changed to status " . $status . " by " . $user);
	
    return sysmtMt($dbh, $user, $mid, $stmt, $ordering, $thrstmt, $thrordering);    
}


sub sysmtMtSetTicket
{

    my ( $dbh, $user, $mid, $ticketnr, $stmt, $ordering, $thrstmt, $thrordering ) = @_;

    if ( PerlSpace::SysMtUtil::checkMtWrite($dbh, $user, $mid) == 0 )
    {
        die "No appropriate right\n";
    }

    my $dbdata;

    if ( $PerlSpace::SysMtExecuter::db eq "cego" )
    {
	$sth = $dbh->prepare("update sysmt_mt set ticketnr =(bigint)? where mid = ?;");
    }
    elsif ( $PerlSpace::SysMtExecuter::db eq "mysql" )
    {
	$sth = $dbh->prepare("update sysmt_mt set ticketnr = ? where mid = ?;");
    }
    elsif ( $PerlSpace::SysMtExecuter::db eq "db2" )
    {
	$sth = $dbh->prepare("update sysmt_mt set ticketnr = ? where mid = ?;");
    }

    $sth->bind_param(1, $ticketnr, DBI::SQL_INTEGER);
    $sth->bind_param(2, $mid, DBI::SQL_INTEGER);

    $sth->execute;

    $sth->finish;    

    PerlSpace::SysMtUtil::logMtAction($dbh, $mid, "Ticket set to  " . $ticketnr . " by " . $user);

    return sysmtMt($dbh, $user, $mid, $stmt, $ordering, $thrstmt, $thrordering);

}

sub sysmtMtSetDescription
{

    my ( $dbh, $user, $mid, $desc, $stmt, $ordering, $thrstmt, $thrordering) = @_;

    if ( PerlSpace::SysMtUtil::checkMtWrite($dbh, $user, $mid) == 0 )
    {
        die "No appropriate right\n";
    }

    my $dbdata;

    if ( $PerlSpace::SysMtExecuter::db eq "cego" )
    {
	$sth = $dbh->prepare("update sysmt_mt set description =? where mid = ?;");
    }
    elsif ( $PerlSpace::SysMtExecuter::db eq "mysql" )
    {
	$sth = $dbh->prepare("update sysmt_mt set description = ? where mid = ?;");
    }
    elsif ( $PerlSpace::SysMtExecuter::db eq "db2" )
    {
	$sth = $dbh->prepare("update sysmt_mt set description = ? where mid = ?;");
    }

    $sth->bind_param(1, $desc, DBI::SQL_VARCHAR);
    $sth->bind_param(2, $mid, DBI::SQL_INTEGER);

    $sth->execute;

    $sth->finish;    

    PerlSpace::SysMtUtil::logMtAction($dbh, $mid, "Description changed by " . $user);

    return sysmtMt($dbh, $user, $mid, $stmt, $ordering, $thrstmt, $thrordering);

}

sub sysmtMtAddVerification
{

    my ( $dbh, $user, $mid, $bgname, $stmt, $ordering, $thrstmt, $thrordering) = @_;

    if ( PerlSpace::SysMtUtil::checkMtWrite($dbh, $user, $mid) == 0 )
    {
        die "No appropriate right\n";
    }

    my $dbdata;

    my $sth;

    if ( $PerlSpace::SysMtExecuter::db eq "cego" )
    {
	$sth = $dbh->prepare("insert into sysmt_mtverification values ( ?, ( select bgid from sysmt_bgroup where bgname = ? ), 'Requested');");
    }
    elsif ( $PerlSpace::SysMtExecuter::db eq "mysql" )
    {
	$sth = $dbh->prepare("insert into sysmt_mtverification XXXXXX;");
    }
    elsif ( $PerlSpace::SysMtExecuter::db eq "db2" )
    {
	$sth = $dbh->prepare("insert into sysmt_mtverification values ( ?, ( select bgid from sysmt_bgroup where bgname = ? ), 'Requested');");
    }

    $sth->bind_param(1, $mid, DBI::SQL_INTEGER);
    $sth->bind_param(2, $bgname, DBI::SQL_VARCHAR);

    $sth->execute;

    $sth->finish;    


    PerlSpace::SysMtUtil::logMtAction($dbh, $mid, "Verification added by " . $user);

    return sysmtMt($dbh, $user, $mid, $stmt, $ordering, $thrstmt, $thrordering);

}

sub sysmtMtDelVerification
{

    my ( $dbh, $user, $mid, $bgname, $stmt, $ordering, $thrstmt, $thrordering) = @_;

    if ( PerlSpace::SysMtUtil::checkMtWrite($dbh, $user, $mid) == 0 )
    {
        die "No appropriate right\n";
    }

    my $dbdata;

    
    $sth = $dbh->prepare("delete from sysmt_mtverification where mid = ? and bgid = ( select bgid from sysmt_bgroup where bgname =  ? );");

    $sth->bind_param(1, $mid, DBI::SQL_INTEGER);
    $sth->bind_param(2, $bgname, DBI::SQL_VARCHAR);

    $sth->execute;

    $sth->finish;    

    PerlSpace::SysMtUtil::logMtAction($dbh, $mid, "Verification deleted by " . $user);

    return sysmtMt($dbh, $user, $mid, $stmt, $ordering, $thrstmt, $thrordering);

}



sub sysmtMtReqSidClone
{

    my ( $dbh, $user, $mid, $clonesid, $stmt, $ordering, $thrstmt, $thrordering) = @_;

    if ( PerlSpace::SysMtUtil::checkMtWrite($dbh, $user, $mid) == 0 )
    {
        die "No appropriate right\n";
    }

    $$dbdata{'user'} = $user;
    $$dbdata{'mid'} = $mid;    
    $$dbdata{'sid'} = $clonesid;
    $$dbdata{'stmt'} = $stmt;
    $$dbdata{'ordering'} = $ordering;

    $$dbdata{'thrstmt'} = $thrstmt;
    $$dbdata{'thrordering'} = $thrordering;


    $$dbdata{'clonetype'} = "sidclone";

    my ( $headmsg, $fullname, $sysmsg )  = PerlSpace::SysMtUtil::getHeaderInfo($dbh, $user);
    $$dbdata{'headertext'} = $headmsg;
    $$dbdata{'fullname'} = $fullname;
    $$dbdata{'sysmsg'} = $sysmsg;
    $$dbdata{'content'} = "sysmt_mtclone.html";

        
    $TT ||= Template->new({ INCLUDE_PATH  => $PerlSpace::SysMtExecuter::tmplpath });
    $TT->process('sysmt_frame.html', $dbdata) || die $TT->error(), "\n";
    
    return 0;
}
    


sub sysmtMtSidClone
{

    my ( $dbh, $user, $mid, $clonesid, $stmt, $ordering, $thrstmt, $thrordering) = @_;

    if ( PerlSpace::SysMtUtil::checkMtWrite($dbh, $user, $mid) == 0 )
    {
        die "No appropriate right\n";
    }

    my $sth = $dbh->prepare("select mid, prjname, sid, shortdesc, description, mtfrom, mtto, downfrom, downto, status, ticketnr, mttype, thrid from sysmt_mtview where mid = ?;");
    $sth->bind_param(1, $mid, DBI::SQL_INTEGER);
    
    $sth->execute;
    

    my $mid;
    my $sid;
    my $shortdesc;
    my $description;
    my $mtfrom;
    my $mtto;
    my $status;
    my $type;
    my $thrid;


    ( $mid, $project, $sid, $shortdesc, $description, $mtfrom, $mtto, $downfrom, $downto, $status, $ticket, $type, $thrid ) = $sth->fetchrow_array; 

    if ( ! $ticket )
    {
	$ticket = 0;
    }

    $sth->finish;

    $mid = cloneSid($dbh, $project, $clonesid,  $shortdesc, $description, $mtfrom, $mtto, $downfrom, $downto, $status, $ticket, $type, $thrid );
    
    PerlSpace::SysMtUtil::logMtAction($dbh, $mid, "Cloned by " . $user);

    return sysmtMt($dbh, $user, $mid, $stmt, $ordering, $thrstmt, $thrordering);

}


sub sysmtMtReqSetClone
{

    my ( $dbh, $user, $mid, $setname, $stmt, $ordering, $thrstmt, $thrordering) = @_;

    if ( PerlSpace::SysMtUtil::checkMtWrite($dbh, $user, $mid) == 0 )
    {
        die "No appropriate right\n";
    }


    $$dbdata{'user'} = $user;
    $$dbdata{'mid'} = $mid;
    $$dbdata{'setname'} = $setname;
    $$dbdata{'stmt'} = $stmt;
    $$dbdata{'ordering'} = $ordering;

    $$dbdata{'thrstmt'} = $thrstmt;
    $$dbdata{'thrordering'} = $thrordering;

    $$dbdata{'sids'} = PerlSpace::SysMtUtil::getSidsForSet($dbh, $setname);;        
    $$dbdata{'clonetype'} = "setclone";    


    my ( $headmsg, $fullname, $sysmsg )  = PerlSpace::SysMtUtil::getHeaderInfo($dbh, $user);
    $$dbdata{'headertext'} = $headmsg;
    $$dbdata{'fullname'} = $fullname;
    $$dbdata{'sysmsg'} = $sysmsg;
    $$dbdata{'content'} = "sysmt_mtclone.html";

       
    $TT ||= Template->new({ INCLUDE_PATH  => $PerlSpace::SysMtExecuter::tmplpath });
    $TT->process('sysmt_frame.html', $dbdata) || die $TT->error(), "\n";
    
    return 0;
}


sub sysmtMtSetClone
{

    my ( $dbh, $user,  $mid, $setname, $stmt, $ordering, $thrstmt, $thrordering) = @_;

    if ( PerlSpace::SysMtUtil::checkMtWrite($dbh, $user, $mid) == 0 )
    {
        die "No appropriate right\n";
    }


    my $dbdata;

    my $sth = $dbh->prepare("select mid, prjname, sid, shortdesc, description, mtfrom, mtto, downfrom, downto, status, ticketnr, mttype, thrid from sysmt_mtview where mid = ?;");
    $sth->bind_param(1, $mid, DBI::SQL_INTEGER);
    
    $sth->execute;
    
    my $mid;
    my $sid;
    my $shortdesc;
    my $description;
    my $mtfrom;
    my $mtto;
    my $status;
    my $type;
    my $thrid;

    ( $mid, $project, $sid, $shortdesc, $description, $mtfrom, $mtto, $downfrom, $downto, $status, $ticket, $type, $thrid ) = $sth->fetchrow_array;
    $sth->finish;

    if ( ! $ticket  )
    {
	$ticket = 0;
    }

    # sid for set retrievel 
    $stmt="select sid from sysmt_system s, sysmt_sys2set s2s, sysmt_systemset ss where ss.setname = ? and ss.setid = s2s.setid and s2s.sysid = s.sysid;";
    my $sth = $dbh->prepare($stmt);
    $sth->bind_param(1, $setname, DBI::SQL_VARCHAR);
    
    $sth->execute;

    my $sidcount=0;
    my $clonesid;
    while ( ($clonesid) = $sth->fetchrow_array) 
    {
	$sidlist[$sidcount] = $clonesid;
	$sidcount++;
    }
    
    $sth->finish;    

    my $i=0;
    while ( $i < $sidcount )
    {

	my $clonesid = $sidlist[$i];
	
	if ( $clonesid ne $sid )
	{	    
	    $mid = cloneSid($dbh, $project, $clonesid, $shortdesc, $description, $mtfrom, $mtto, $downfrom, $downto, $status, $ticket, $type, $thrid );	    
	    PerlSpace::SysMtUtil::logMtAction($dbh, $mid, "Cloned by " . $user);	    
	}
	
	$i++;
    }
        
    return sysmtMt($dbh, $user, $mid, $stmt, $ordering, $thrstmt, $thrordering);
    
}

sub cloneSid
{
    
    my ( $dbh, $project, $clonesid,  $shortdesc, $description, $mtfrom, $mtto, $downfrom, $downto, $status, $ticket, $type, $thrid ) = @_;

    my $sth;
    my $mid;
   
    $status="Requested";
 
    if ( $PerlSpace::SysMtExecuter::db eq "cego" )
    {
	
	if ( $downfrom && $downto && $mtfrom && $mtto )
	{
	    
	    $sth = $dbh->prepare("? = call newMt ( ?, ?, ?, date('%d.%m.%Y %H:%M:%S', ?), date('%d.%m.%Y %H:%M:%S', ?), date('%d.%m.%Y %H:%M:%S', ?), date('%d.%m.%Y %H:%M:%S', ?), ?, (bigint)?, ?, ? );");
	    
	    
	    $sth->bind_param_inout(1, \$mid, 10);
	    $sth->bind_param(2, $clonesid, DBI::SQL_VARCHAR);
	    $sth->bind_param(3, $shortdesc, DBI::SQL_VARCHAR);
	    $sth->bind_param(4, $description, DBI::SQL_VARCHAR);
	    $sth->bind_param(5, $mtfrom, DBI::SQL_VARCHAR);
	    $sth->bind_param(6, $mtto, DBI::SQL_VARCHAR);
	    $sth->bind_param(7, $downfrom, DBI::SQL_VARCHAR);
	    $sth->bind_param(8, $downto, DBI::SQL_VARCHAR);
	    $sth->bind_param(9, $status, DBI::SQL_VARCHAR);
	    $sth->bind_param(10, $ticket, DBI::SQL_INTEGER);
	    $sth->bind_param(11, $type, DBI::SQL_VARCHAR);
	    if ( $thrid )
	    {
		$sth->bind_param(12, $thrid, DBI::SQL_INTEGER);
	    }

	}
	elsif ( $mtfrom && $mtto )
	{
	    
	    $sth = $dbh->prepare("? = call newMt ( ?, ?, ?, date('%d.%m.%Y %H:%M:%S', ?), date('%d.%m.%Y %H:%M:%S', ?), null, null, ?, (bigint)?, ?, ? );");
	    
	    $sth->bind_param_inout(1, \$mid, 10);
	    $sth->bind_param(2, $clonesid, DBI::SQL_VARCHAR);
	    $sth->bind_param(3, $shortdesc, DBI::SQL_VARCHAR);
	    $sth->bind_param(4, $description, DBI::SQL_VARCHAR);
	    $sth->bind_param(5, $mtfrom, DBI::SQL_VARCHAR);
	    $sth->bind_param(6, $mtto, DBI::SQL_VARCHAR);
	    $sth->bind_param(7, $status, DBI::SQL_VARCHAR);
	    $sth->bind_param(8, $ticket, DBI::SQL_INTEGER);
	    $sth->bind_param(9, $type, DBI::SQL_VARCHAR);
	    if ( $thrid )
	    {
		$sth->bind_param(10, $thrid, DBI::SQL_INTEGER);
	    }	  
	}
	else
	{
	    
	    $sth = $dbh->prepare("? = call newMt ( ?, ?, ?, null, null, null, null, ?, (bigint)?, ? );");
	    
	    $sth->bind_param_inout(1, \$mid, 10);
	    $sth->bind_param(2, $clonesid, DBI::SQL_VARCHAR);
	    $sth->bind_param(3, $shortdesc, DBI::SQL_VARCHAR);
	    $sth->bind_param(4, $description, DBI::SQL_VARCHAR);
	    $sth->bind_param(5, $status, DBI::SQL_VARCHAR);
	    $sth->bind_param(6, $ticket, DBI::SQL_INTEGER);
	    $sth->bind_param(7, $type, DBI::SQL_VARCHAR);
	    if ( $thrid )
	    {
		$sth->bind_param(8, $thrid, DBI::SQL_INTEGER);
	    }
	}

	$sth->execute;

    }
    elsif ( $PerlSpace::SysMtExecuter::db eq "mysql" )
    {

	$sth = $dbh->prepare("select newMt (?,?,?,?,?,?,?,?,?,?,?);");
	
	$sth->bind_param(1, $clonesid, DBI::SQL_VARCHAR);
	$sth->bind_param(2, $shortdesc, DBI::SQL_VARCHAR);
	$sth->bind_param(3, $description, DBI::SQL_VARCHAR);
	$sth->bind_param(4, $mtfrom, DBI::SQL_VARCHAR);
	$sth->bind_param(5, $mtto, DBI::SQL_VARCHAR);
	$sth->bind_param(6, $downfrom, DBI::SQL_VARCHAR);
	$sth->bind_param(7, $downto, DBI::SQL_VARCHAR);
	$sth->bind_param(8, $status, DBI::SQL_VARCHAR);
	$sth->bind_param(9, $ticket, DBI::SQL_INTEGER);

	$sth->bind_param(10, $type, DBI::SQL_VARCHAR);
	if ( $thrid )
	{
	    $sth->bind_param(11, $thrid, DBI::SQL_INTEGER);
	}

	$sth->execute;

	$mid = $sth->fetchrow_array;
			
    }
    elsif ( $PerlSpace::SysMtExecuter::db eq "db2" )
    {
    
	if ( $downfrom && $downto && $mtfrom && $mtto )
	{
	    
	    $sth = $dbh->prepare(q{call newMt (?,?,?,?,?,?,?,?,?,?,?,?)});
	    
	    $sth->bind_param(1, $clonesid, DBI::SQL_VARCHAR);
	    $sth->bind_param(2, $shortdesc, DBI::SQL_VARCHAR);
	    $sth->bind_param(3, $description, DBI::SQL_VARCHAR);
	    $sth->bind_param(4, $mtfrom, DBI::SQL_VARCHAR);
	    $sth->bind_param(5, $mtto, DBI::SQL_VARCHAR);
	    $sth->bind_param(6, $downfrom, DBI::SQL_VARCHAR);
	    $sth->bind_param(7, $downto, DBI::SQL_VARCHAR);
	    $sth->bind_param(8, $status, DBI::SQL_VARCHAR);
	    $sth->bind_param(9, $ticket, DBI::SQL_INTEGER);
	    $sth->bind_param(10, $type, DBI::SQL_VARCHAR);
	    $sth->bind_param(11, $thrid, DBI::SQL_INTEGER);
	    $sth->bind_param_inout(12, \$mid, 100, DBI::SQL_INTEGER);

	}
	elsif ( $mtfrom && $mtto )
	{
	    
	    $sth = $dbh->prepare(q{call newMt (?,?,?,?,?,null,null,?,?,?,?,?)});
	    
	    $sth->bind_param(1, $clonesid, DBI::SQL_VARCHAR);
	    $sth->bind_param(2, $shortdesc, DBI::SQL_VARCHAR);
	    $sth->bind_param(3, $description, DBI::SQL_VARCHAR);
	    $sth->bind_param(4, $mtfrom, DBI::SQL_VARCHAR);
	    $sth->bind_param(5, $mtto, DBI::SQL_VARCHAR);
	    $sth->bind_param(6, $status, DBI::SQL_VARCHAR);
	    $sth->bind_param(7, $ticket, DBI::SQL_INTEGER);
	    $sth->bind_param(8, $type, DBI::SQL_VARCHAR);
	    $sth->bind_param(9, $thrid, DBI::SQL_VARCHAR);
	    $sth->bind_param_inout(10, \$mid, 100, DBI::SQL_INTEGER);
	}
	else
	{
	    
	    $sth = $dbh->prepare(q{call newMt (?,?,?,null,null,null,null,?,?,?,?,?)});
	    
	    $sth->bind_param(1, $clonesid, DBI::SQL_VARCHAR);
	    $sth->bind_param(2, $shortdesc, DBI::SQL_VARCHAR);
	    $sth->bind_param(3, $description, DBI::SQL_VARCHAR);
	    $sth->bind_param(4, $status, DBI::SQL_VARCHAR);
	    $sth->bind_param(5, $ticket, DBI::SQL_INTEGER);
	    $sth->bind_param(6, $type, DBI::SQL_VARCHAR);
	    $sth->bind_param(7, $thrid, DBI::SQL_INTEGER);
	    $sth->bind_param_inout(8, \$mid, 100, DBI::SQL_INTEGER);
	    
	}

	$sth->execute;

    }
    
    $sth->finish;
    
    return $mid;

}

sub sysmtMtLog
{
    
    my ( $dbh, $user, $mid, $stmt, $ordering, $thrstmt, $thrordering ) = @_;

    my $dbdata;

    $$dbdata{'mid'} = $mid;
    $$dbdata{'user'} = $user;
    $$dbdata{'stmt'} = $stmt;
    $$dbdata{'ordering'} = $ordering;

    $$dbdata{'thrstmt'} = $thrstmt;
    $$dbdata{'thrordering'} = $thrordering;


    my $sth = $dbh->prepare("select logts, logentry from sysmt_mtlog where mid = ? order by logts;");
    $sth->bind_param(1, $mid, DBI::SQL_INTEGER);
    
    $sth->execute;
    
    my $logts;
    my $logentry;

    $i=0;
    while ( ( $logts, $logentry ) = $sth->fetchrow_array )
    {
	$$dbdata{'loglist'}[$i]{'logts'} = $logts;
	$$dbdata{'loglist'}[$i]{'logentry'} = $logentry;
	$i++;
    }

    $sth->finish;

    my ( $headmsg, $fullname, $sysmsg )  = PerlSpace::SysMtUtil::getHeaderInfo($dbh, $user);
    $$dbdata{'headertext'} = $headmsg;
    $$dbdata{'fullname'} = $fullname;
    $$dbdata{'sysmsg'} = $sysmsg;
    $$dbdata{'content'} = "sysmt_mtlog.html";

    
    $TT ||= Template->new({ INCLUDE_PATH  => $PerlSpace::SysMtExecuter::tmplpath });
    $TT->process('sysmt_frame.html', $dbdata) || die $TT->error(), "\n";
    
    return 0;
}


sub sysmtMtConflict
{
    
    my ( $dbh, $user, $mid, $stmt, $ordering, $thrstmt, $thrordering ) = @_;

    my $dbdata;

    $$dbdata{'mid'} = $mid;
    $$dbdata{'user'} = $user;
    $$dbdata{'stmt'} = $stmt;
    $$dbdata{'ordering'} = $ordering;

    $$dbdata{'thrstmt'} = $thrstmt;
    $$dbdata{'thrordering'} = $thrordering;


    # my $sth = $dbh->prepare("select mid, shortdesc, mtfrom, mtto from sysmt_mt mt1 where exists ( select mid from sysmt_mt mt2 where mt2.mid = ? and mt2.mid != mt1.mid and mt1.mtfrom > mt2.mtfrom and mt1.mtfrom < mt2.mtto  and  mt1.sysid = mt2.sysid );");

    my $sth = $dbh->prepare("select mid, shortdesc, mtfrom, mtto from sysmt_mt mt1 where exists ( select mid from sysmt_mt mt2 where mt2.mid = ? and mt2.mid != mt1.mid and ( (mt1.mtfrom > mt2.mtfrom and mt1.mtfrom < mt2.mtto) or (mt1.mtfrom < mt2.mtfrom and mt1.mtto> mt2.mtfrom))  and  mt1.sysid = mt2.sysid );");

    $sth->bind_param(1, $mid, DBI::SQL_INTEGER);
    
    $sth->execute;
    

    my $cmid;
    my $shortdesc;
    my $mtfrom;
    my $mtto;

    $i=0;
    while ( ( $cmid, $shortdesc, $mtfrom, $mtto ) = $sth->fetchrow_array )
    {
	$$dbdata{'conflictlist'}[$i]{'mid'} = $cmid;
	$$dbdata{'conflictlist'}[$i]{'shortdesc'} = $shortdesc;
	$$dbdata{'conflictlist'}[$i]{'mtfrom'} = $mtfrom;
	$$dbdata{'conflictlist'}[$i]{'mtto'} = $mtto;
	$i++;
    }

    $sth->finish;


    my ( $headmsg, $fullname, $sysmsg )  = PerlSpace::SysMtUtil::getHeaderInfo($dbh, $user);
    $$dbdata{'headertext'} = $headmsg;
    $$dbdata{'fullname'} = $fullname;
    $$dbdata{'sysmsg'} = $sysmsg;
    $$dbdata{'content'} = "sysmt_mtconflict.html";

    
    $TT ||= Template->new({ INCLUDE_PATH  => $PerlSpace::SysMtExecuter::tmplpath });
    $TT->process('sysmt_frame.html', $dbdata) || die $TT->error(), "\n";
    
    return 0;
}


sub sysmtMtResource
{
    
    my ( $dbh, $user, $mid, $luskid, $luresfrom, $luresto, $stmt, $ordering, $thrstmt, $thrordering ) = @_;

    my $dbdata;

    $$dbdata{'mid'} = $mid;
    $$dbdata{'user'} = $user;
    $$dbdata{'stmt'} = $stmt;
    $$dbdata{'ordering'} = $ordering;

    $$dbdata{'thrstmt'} = $thrstmt;
    $$dbdata{'thrordering'} = $thrordering;


    my $sth = $dbh->prepare("select rpeid, resname, activity, resfrom, resto from sysmt_resplanview where mid = ? order by resfrom;");
    $sth->bind_param(1, $mid, DBI::SQL_INTEGER);
    
    $sth->execute;
    
    $i=0;
    while ( ( my $rpeid, $resname, $activity, $resfrom, $resto ) = $sth->fetchrow_array )
    {
	$$dbdata{'rpelist'}[$i]{'rpeid'} = $rpeid;
	$$dbdata{'rpelist'}[$i]{'resname'} = $resname;
	$$dbdata{'rpelist'}[$i]{'activity'} = $activity;
	$$dbdata{'rpelist'}[$i]{'resfrom'} = $resfrom;
	$$dbdata{'rpelist'}[$i]{'resto'} = $resto;
	$i++;
    }

    $sth->finish;

    # skill retrievel
    $sth = $dbh->prepare("select skid, skname from sysmt_skill;");
    $sth->execute;
        
    $$dbdata{'dolu'} = "no";

    $i=0;
    while ( ( my $skid, $skname ) = $sth->fetchrow_array) 
    {
	$$dbdata{'sklist'}[$i]{'skid'} = $skid;
	$$dbdata{'sklist'}[$i]{'skname'} = $skname;

	if ( $luskid == $skid)
	{
	    $$dbdata{'dolu'} = "yes";
	    $$dbdata{'skid'} = $skid;
	    $$dbdata{'skname'} = $skname;
	}
	$i++;
    }
    $sth->finish;    

    # make resource lookup ?
    if ( $luskid )
    {

	$$dbdata{'resfrom'} = $luresfrom;
	$$dbdata{'resto'} = $luresto;
	
	my @avrlist = PerlSpace::SysMtUtil::getAvailableResources($dbh, $mid, $luskid, $luresfrom, $luresto);
	
	$i=0;
	foreach my $avr ( @avrlist )
	{
	    # warn "Resid=" . $$avr{'resid'};

	    $$dbdata{'avrlist'}[$i]{'resid'} = $$avr{'resid'};
	    $$dbdata{'avrlist'}[$i]{'resname'} = $$avr{'resname'};
	    $i++;
	}
    }


    my ( $headmsg, $fullname, $sysmsg )  = PerlSpace::SysMtUtil::getHeaderInfo($dbh, $user);
    $$dbdata{'headertext'} = $headmsg;
    $$dbdata{'fullname'} = $fullname;
    $$dbdata{'sysmsg'} = $sysmsg;
    $$dbdata{'content'} = "sysmt_mtresplan.html";

    
    $TT ||= Template->new({ INCLUDE_PATH  => $PerlSpace::SysMtExecuter::tmplpath });
    $TT->process('sysmt_frame.html', $dbdata) || die $TT->error(), "\n";
    
    return 0;
}

sub sysmtMtResourceAddEntry
{

    my ( $dbh, $user, $resid, $mid, $resfrom, $resto, $stmt, $ordering, $thrstmt, $thrordering) = @_;


    if ( PerlSpace::SysMtUtil::checkResourceWrite($dbh, $user, $mid) == 0 )
    {
        die "No appropriate right\n";
    }
    
    my $rseid;
    my $activity="not specified";

    if ( $PerlSpace::SysMtExecuter::db eq "cego" )
    {
	$sth = $dbh->prepare("? = call newResourceEntry (?,date('%d.%m.%Y %H:%M:%S',?),date('%d.%m.%Y %H:%M:%S',?),?,?);");
	
	$sth->bind_param_inout(1, \$rseid, 10);
	$sth->bind_param(2, $activity, DBI::SQL_VARCHAR);
	$sth->bind_param(3, $resfrom, DBI::SQL_VARCHAR);    
	$sth->bind_param(4, $resto, DBI::SQL_VARCHAR);
	$sth->bind_param(5, $resid, DBI::SQL_INTEGER);
	$sth->bind_param(6, $mid, DBI::SQL_INTEGER);

	$sth->execute;
	
	$sth->finish;    
    }
    elsif ( $PerlSpace::SysMtExecuter::db eq "mysql" )
    {
	$sth = $dbh->prepare("select newProject(?,?);");
	
	$sth->bind_param(1, $prjname, DBI::SQL_VARCHAR);
	$sth->bind_param(2, $prjdesc, DBI::SQL_VARCHAR);    

	$sth->execute;
	$pid = $sth->fetchrow_array;

	$sth->finish;

    }
    elsif ( $PerlSpace::SysMtExecuter::db eq "db2" )
    {
	$sth = $dbh->prepare(q{call newProject(?,?,?)});
	
	$sth->bind_param(1, $prjname, DBI::SQL_VARCHAR);
	$sth->bind_param(2, $prjdesc, DBI::SQL_VARCHAR);    
	$sth->bind_param_inout(3, \$pid, 100, DBI::SQL_INTEGER);

	$sth->execute;

	$sth->finish;

    }

    # PerlSpace::SysMtUtil::logMtAction($dbh, $mid, "Changed thread to " . $thrid . " by " . $user);
	
    my $n;
    return sysmtMtResource($dbh, $user, $mid, $n, $n, $n, $stmt, $ordering, $thrstmt, $thrordering);    
}

sub sysmtMtResourceUpdEntry
{

    my ( $dbh, $user, $mid, $rpeid, $activity, $stmt, $ordering, $thrstmt, $thrordering) = @_;


    if ( PerlSpace::SysMtUtil::checkResourceWrite($dbh, $user, $mid) == 0 )
    {
        die "No appropriate right\n";
    }

    my $sth = $dbh->prepare("update sysmt_resourceplan set activity = ? where rpeid = ?;");
    $sth->bind_param(1, $activity, DBI::SQL_VARCHAR);
    $sth->bind_param(2, $rpeid, DBI::SQL_INTEGER);

    $sth->execute;

    $sth->finish;    
    
    
    my $n;
    return sysmtMtResource($dbh, $user, $mid, $n, $n, $n, $stmt, $ordering, $thrstmt, $thrordering);    
}

sub sysmtMtResourceDelEntry
{

    my ( $dbh, $user, $mid, $rpeid, $stmt, $ordering, $thrstmt, $thrordering) = @_;


    if ( PerlSpace::SysMtUtil::checkResourceWrite($dbh, $user, $mid) == 0 )
    {
        die "No appropriate right\n";
    }

    my $sth = $dbh->prepare("delete from sysmt_resourceplan where rpeid = ?;");
    $sth->bind_param(1, $rpeid, DBI::SQL_INTEGER);

    $sth->execute;

    $sth->finish;    
    
    
    my $n;
    return sysmtMtResource($dbh, $user, $mid, $n, $n, $n, $stmt, $ordering, $thrstmt, $thrordering);    
}

sub sysmtMtApprove
{
    
    my ( $dbh, $user, $mid, $bgname, $stmt, $ordering, $thrstmt, $thrordering ) = @_;


    if ( PerlSpace::SysMtUtil::checkMtWrite($dbh, $user, $mid) == 0 )
    {
        die "No appropriate right\n";
    }

    my $dbdata;

    $$dbdata{'user'} = $user;

    my $bgid = PerlSpace::SysMtUtil::getBGid($dbh, $bgname);
    
    my $sth = $dbh->prepare("update sysmt_mtapproval set status = 'Approved' where mid = ? and bgid = ?;");
    $sth->bind_param(1, $mid, DBI::SQL_INTEGER);
    $sth->bind_param(2, $bgid, DBI::SQL_INTEGER);

    # warn "Mid = " . $mid . " Bgid = " . $bgid;

    $sth->execute;

    $sth->finish;    


    my $sth = $dbh->prepare("select count(*) from sysmt_mtapproval where mid = ? and status = 'Requested';");
    $sth->bind_param(1, $mid, DBI::SQL_INTEGER);
    
    $sth->execute;

    my $reqcount;
    ( $reqcount) = $sth->fetchrow_array;    
    $sth->finish;

    if ( $reqcount == 0 )
    {

	my $sth = $dbh->prepare("update sysmt_mt set status = 'Approved' where mid = ?;");
	$sth->bind_param(1, $mid, DBI::SQL_INTEGER);

	# warn "Mid = " . $mid . " Bgid = " . $bgid;

	$sth->execute;
	
	$sth->finish;    
	
    }

    PerlSpace::SysMtUtil::logMtAction($dbh, $mid, "Approved for " . $bgname . " by " . $user);
    
    return sysmtMt($dbh, $user, $mid, $stmt, $ordering, $thrstmt, $thrordering);    

}


sub sysmtMtVerify
{
    
    my ( $dbh, $user, $mid, $bgname, $stmt, $ordering, $thrstmt, $thrordering ) = @_;


    if ( PerlSpace::SysMtUtil::checkMtWrite($dbh, $user, $mid) == 0 )
    {
        die "No appropriate right\n";
    }

    my $dbdata;

    $$dbdata{'user'} = $user;

    my $bgid = PerlSpace::SysMtUtil::getBGid($dbh, $bgname);
    
    my $sth = $dbh->prepare("update sysmt_mtverification set status = 'Verified' where mid = ? and bgid = ?;");
    $sth->bind_param(1, $mid, DBI::SQL_INTEGER);
    $sth->bind_param(2, $bgid, DBI::SQL_INTEGER);

    # warn "Mid = " . $mid . " Bgid = " . $bgid;

    $sth->execute;

    $sth->finish;    


    my $sth = $dbh->prepare("select count(*) from sysmt_mtverification where mid = ? and status = 'Requested';");
    $sth->bind_param(1, $mid, DBI::SQL_INTEGER);
    
    $sth->execute;

    my $reqcount;
    ( $reqcount) = $sth->fetchrow_array;    
    $sth->finish;

    if ( $reqcount == 0 )
    {

	my $sth = $dbh->prepare("update sysmt_mt set status = 'Verified' where mid = ?;");
	$sth->bind_param(1, $mid, DBI::SQL_INTEGER);

	# warn "Mid = " . $mid . " Bgid = " . $bgid;

	$sth->execute;
	
	$sth->finish;    
	
    }

    PerlSpace::SysMtUtil::logMtAction($dbh, $mid, "Verified for " . $bgname . " by " . $user);
    
    return sysmtMt($dbh, $user, $mid, $stmt, $ordering, $thrstmt, $thrordering);    

}

sub sysmtMtApprovalReset
{
    
    my ( $dbh, $user, $mid, $stmt, $ordering, $thrstmt, $thrordering ) = @_;

    if ( PerlSpace::SysMtUtil::checkMtWrite($dbh, $user, $mid) == 0 )
    {
        die "No appropriate right\n";
    }

    my $dbdata;

    $$dbdata{'user'} = $user;

    # my $bgid = PerlSpace::SysMtUtil::getBGid($dbh, $bgname);

    if ( $PerlSpace::SysMtExecuter::db eq "cego" )
    {
	my $sth = $dbh->prepare("call resetApproval ( ? );");    
	$sth->bind_param(1, $mid, DBI::SQL_INTEGER);

	$sth->execute;	
	$sth->finish;    
    }
    elsif ( $PerlSpace::SysMtExecuter::db eq "mysql" )
    {
	$sth = $dbh->prepare("select resetApproval(?);");
	$sth->bind_param(1, $mid, DBI::SQL_INTEGER);	
	
	$sth->execute;
	my $r = $sth->fetchrow_array;
	$sth->finish;
	
    }
    elsif ( $PerlSpace::SysMtExecuter::db eq "db2" )
    {
	my $sth = $dbh->prepare("{call resetApproval ( ? )}");    
	$sth->bind_param(1, $mid, DBI::SQL_INTEGER);	
	$sth->execute;
	$sth->finish;
    }

    PerlSpace::SysMtUtil::logMtAction($dbh, $mid, "Approval reset by " . $user);
    
    return sysmtMt($dbh, $user, $mid, $stmt, $ordering, $thrstmt, $thrordering);    

}

sub sysmtMtSetThread
{

    my ( $dbh, $user, $mid, $thrid, $stmt, $ordering, $thrstmt, $thrordering) = @_;


    if ( PerlSpace::SysMtUtil::checkMtWrite($dbh, $user, $mid) == 0 )
    {
        die "No appropriate right\n";
    }

    $sth = $dbh->prepare("update sysmt_mt set thrid = ? where mid = ?;");
    $sth->bind_param(1, $thrid, DBI::SQL_INTEGER);
    $sth->bind_param(2, $mid, DBI::SQL_INTEGER);

    $sth->execute;

    $sth->finish;    

    PerlSpace::SysMtUtil::logMtAction($dbh, $mid, "Changed thread to " . $thrid . " by " . $user);
	
    return sysmtMt($dbh, $user, $mid, $stmt, $ordering, $thrstmt, $thrordering);    
}


sub sysmtMtOvMaster
{

    my ( $dbh, $user ) = @_;

    my $dbdata;

    $$dbdata{'user'} = $user;

    my @prjlist = PerlSpace::SysMtUtil::getMtReadProjectForUser($dbh, $user);
    
    $i=0;
    foreach my $prj ( @prjlist )
    {
	$$dbdata{'projectlist'}[$i] = $prj;
	$i++;
    }

    my @setlist = PerlSpace::SysMtUtil::getMtReadSysSetForUser($dbh, $user);
    
    $i=0;
    foreach my $set ( @setlist )
    {
	$$dbdata{'setlist'}[$i] = $set;
	$i++;
    }

    $$dbdata{'curmonth'} = PerlSpace::SysMtUtil::getCurrentMonth();
    $$dbdata{'curyear'} = PerlSpace::SysMtUtil::getCurrentYear();    

    my ( $headmsg, $fullname, $sysmsg )  = PerlSpace::SysMtUtil::getHeaderInfo($dbh, $user);
    $$dbdata{'headertext'} = $headmsg;
    $$dbdata{'fullname'} = $fullname;
    $$dbdata{'sysmsg'} = $sysmsg;
    $$dbdata{'content'} = "sysmt_mtovmaster.html";

    $TT ||= Template->new({ INCLUDE_PATH  => $PerlSpace::SysMtExecuter::tmplpath });
    $TT->process('sysmt_frame.html', $dbdata) || die $TT->error(), "\n";

    return 0;
}


sub sysmtMtOverview
{
    
    my ( $dbh, $user, $project, $year, $month ) = @_;

    my $dbdata;

    $$dbdata{'user'} = $user;

    $$dbdata{'title'} = "Project " . $project;
    $$dbdata{'year'} = $year;
    $$dbdata{'month'} = $month;


    my $sth = $dbh->prepare("select sid, mtinfo from sysmt_systemview where prjname = ?;");

    $sth->bind_param(1, $project, DBI::SQL_VARCHAR);
    $sth->execute;

    my $sid;
    my $mtinfo;
    my $i=0;
    
    while ( ($sid, $mtinfo) = $sth->fetchrow_array) 
    {
	$$dbdata{'sidlist'}[$i]{'name'} = $sid;
	$$dbdata{'sidlist'}[$i]{'mtinfo'} = $mtinfo;
	$mtinfo="NA";
	$i++;
    }    
    $sth->finish;

    my @daylist;
    @daylist = PerlSpace::SysMtUtil::getDayList($year, $month );
   
    for ( $i=0; $i< @daylist; $i++)
    {
	$$dbdata{'daylist'}[$i]{'daynum'} = $daylist[$i];
	$$dbdata{'daylist'}[$i]{'weekday'} = PerlSpace::SysMtUtil::get_day($daylist[$i] . "." . $month . "." . $year );
    }

    if ( $PerlSpace::SysMtExecuter::db eq "cego" )
    {
	$sth = $dbh->prepare("select mid, date2str(downfrom,'%d'), date2str(downfrom,'%m'), date2str(downto,'%d'), date2str(downto,'%m'), sid, shortdesc, status from sysmt_mtview where ( date2str(downfrom, '%m') = ? and date2str(downfrom, '%Y') = ? ) or ( date2str(downto, '%m') = ? and date2str(downto, '%Y') = ? ) or ( date2str(downfrom, '%m') < ? and date2str(downto, '%m') > ? and date2str(downfrom, '%Y') = ? and date2str(downto, '%Y') = ? ) and sid in ( select sid from sysmt_systemview where prjname = ? );");

	$sth->bind_param(1, $month, DBI::SQL_VARCHAR);
	$sth->bind_param(2, $year, DBI::SQL_VARCHAR);
	$sth->bind_param(3, $month, DBI::SQL_VARCHAR);
	$sth->bind_param(4, $year, DBI::SQL_VARCHAR);
	$sth->bind_param(5, $month, DBI::SQL_VARCHAR);
	$sth->bind_param(6, $month, DBI::SQL_VARCHAR);
	$sth->bind_param(7, $year, DBI::SQL_VARCHAR);
	$sth->bind_param(8, $year, DBI::SQL_VARCHAR);
	$sth->bind_param(9, $project, DBI::SQL_VARCHAR);


    }
    elsif ( $PerlSpace::SysMtExecuter::db eq "mysql" )
    {

	$sth = $dbh->prepare("select mid, day(downfrom), month(downfrom), day(downto), month(downto), sid, shortdesc, status from sysmt_mtview where ( month(downfrom) = ? and year(downfrom) = ? ) or ( month(downto) = ? and year(downto) = ? ) or ( month(downfrom) < ? and month(downto) > ? and year(downfrom) = ? and year(downto) = ? ) and sid in ( select sid from sysmt_systemview where prjname = ? )");

	$sth->bind_param(1, $month, DBI::SQL_INTEGER);
	$sth->bind_param(2, $year, DBI::SQL_INTEGER);
	$sth->bind_param(3, $month, DBI::SQL_INTEGER);
	$sth->bind_param(4, $year, DBI::SQL_INTEGER);
	$sth->bind_param(5, $month, DBI::SQL_INTEGER);
	$sth->bind_param(6, $month, DBI::SQL_INTEGER);
	$sth->bind_param(7, $year, DBI::SQL_INTEGER);
	$sth->bind_param(8, $year, DBI::SQL_INTEGER);
	$sth->bind_param(9, $project, DBI::SQL_VARCHAR);

    }
    elsif ( $PerlSpace::SysMtExecuter::db eq "db2" )
    {
	$month =~ s/^0//;
	# warn "Executing with " . $month . " " . $year . " PRJ=" . $project;
	

	# $sth = $dbh->prepare("select mid, day(downfrom), month(downfrom), day(downto), month(downto), sid, shortdesc, status from sysmt_mtview where ( month(downfrom) = ? and year(downfrom) = ? ) or ( month(downto) = ? and year(downto) = ? ) or ( month(downfrom) < ? and month(downto) > ? and year(downfrom) = ? and year(downto) = ? ) and sid in ( select sid from sysmt_systemview where prjname = ? );");

	$sth = $dbh->prepare("select mid, day(downfrom), month(downfrom), day(downto), month(downto), sid, shortdesc, status from sysmt_mtview where ( month(downfrom) = ? and year(downfrom) = ? ) or ( month(downto) = ? and year(downto) = ? ) or ( month(downfrom) < ? and month(downto) > ? and year(downfrom) = ? and year(downto) = ? ) and sid in ( select sid from sysmt_systemview where prjname = ? )");

	$sth->bind_param(1, $month, DBI::SQL_INTEGER);
	$sth->bind_param(2, $year, DBI::SQL_INTEGER);
	$sth->bind_param(3, $month, DBI::SQL_INTEGER);
	$sth->bind_param(4, $year, DBI::SQL_INTEGER);
	$sth->bind_param(5, $month, DBI::SQL_INTEGER);
	$sth->bind_param(6, $month, DBI::SQL_INTEGER);
	$sth->bind_param(7, $year, DBI::SQL_INTEGER);
	$sth->bind_param(8, $year, DBI::SQL_INTEGER);
	$sth->bind_param(9, $project, DBI::SQL_VARCHAR);

    }
    
    $sth->execute;
    
    my $mid;
    my $shortdesc;
    $i=0;
    
    while ( ($mid, $dayfrom, $monthfrom, $dayto, $monthto, $sid, $shortdesc, $status) = $sth->fetchrow_array) 
    {

	if ( $PerlSpace::SysMtExecuter::db eq "db2" )
	{
	    $dayfrom = "0" . $dayfrom;
	    $dayfrom = substr($dayfrom, -2, 2);
 
	    $dayto = "0" . $dayto;
	    $dayto = substr($dayto, -2, 2);

	    $monthfrom = "0" . $monthfrom;
	    $monthfrom = substr($monthfrom, -2, 2);

	    $monthto = "0" . $monthto;
	    $monthto = substr($monthto, -2, 2);
	}
	
	$$dbdata{'ov'}[$i]{'mid'} = $mid;
	$$dbdata{'ov'}[$i]{'dayfrom'} = $dayfrom;
	$$dbdata{'ov'}[$i]{'monthfrom'} = $monthfrom;
	$$dbdata{'ov'}[$i]{'dayto'} = $dayto;
	$$dbdata{'ov'}[$i]{'monthto'} = $monthto;
	$$dbdata{'ov'}[$i]{'sid'} = $sid;
	$$dbdata{'ov'}[$i]{'shortdesc'} = $shortdesc;
	$$dbdata{'ov'}[$i]{'status'} = $status;
	$i++;
    }
    
    $sth->finish;    

    my ( $headmsg, $fullname, $sysmsg )  = PerlSpace::SysMtUtil::getHeaderInfo($dbh, $user);
    $$dbdata{'headertext'} = $headmsg;
    $$dbdata{'fullname'} = $fullname;
    $$dbdata{'sysmsg'} = $sysmsg;
    $$dbdata{'content'} = "sysmt_mtov.html";
    
    $TT ||= Template->new({ INCLUDE_PATH  => $PerlSpace::SysMtExecuter::tmplpath });
    $TT->process('sysmt_frame.html', $dbdata) || die $TT->error(), "\n";
    
    return 0;
}


sub sysmtMtOverviewBySet
{
    
    my ( $dbh, $user, $sysset, $year, $month ) = @_;
    my $dbdata;

    $$dbdata{'user'} = $user;

    $$dbdata{'title'} = "System Set " . $sysset;
    $$dbdata{'year'} = $year;
    $$dbdata{'month'} = $month;


    my $sth = $dbh->prepare("select sid, mtinfo from sysmt_system s, sysmt_systemset ss, sysmt_sys2set s2s where ss.setname = ? and ss.setid = s2s.setid and s2s.sysid = s.sysid;");

    $sth->bind_param(1, $sysset, DBI::SQL_VARCHAR);
    $sth->execute;

    my $sid;
    my $mtinfo;

    my $i=0;
    
    while ( ($sid, $mtinfo) = $sth->fetchrow_array) 
    {
	$$dbdata{'sidlist'}[$i]{'name'} = $sid;
	$$dbdata{'sidlist'}[$i]{'mtinfo'} = $mtinfo;
	$i++;
    }    
    $sth->finish;


    my @daylist;
    @daylist = PerlSpace::SysMtUtil::getDayList($year, $month );
   
    for ( $i=0; $i< @daylist; $i++)
    {
	$$dbdata{'daylist'}[$i]{'daynum'} = $daylist[$i];
	$$dbdata{'daylist'}[$i]{'weekday'} = PerlSpace::SysMtUtil::get_day($daylist[$i] . "." . $month . "." . $year );
    }


    if ( $PerlSpace::SysMtExecuter::db eq "cego" )
    {


	$sth = $dbh->prepare("select mid, date2str(downfrom,'%d'), date2str(downfrom,'%m'), date2str(downto,'%d'), date2str(downto,'%m'), sid, shortdesc, status from sysmt_mtview where ( date2str(downfrom, '%m') = ? and date2str(downfrom, '%Y') = ? ) or ( date2str(downto, '%m') = ? and date2str(downto, '%Y') = ? ) or ( date2str(downfrom, '%m') < ? and date2str(downto, '%m') > ? and date2str(downfrom, '%Y') = ? and date2str(downto, '%Y') = ? ) and sid in ( select sid  from sysmt_system s, sysmt_systemset ss, sysmt_sys2set s2s where ss.setname = ? and ss.setid = s2s.setid and s2s.sysid = s.sysid);");
    
	$sth->bind_param(1, $month, DBI::SQL_VARCHAR);
	$sth->bind_param(2, $year, DBI::SQL_VARCHAR);
	$sth->bind_param(3, $month, DBI::SQL_VARCHAR);
	$sth->bind_param(4, $year, DBI::SQL_VARCHAR);
	$sth->bind_param(5, $month, DBI::SQL_VARCHAR);
	$sth->bind_param(6, $month, DBI::SQL_VARCHAR);
	$sth->bind_param(7, $year, DBI::SQL_VARCHAR);
	$sth->bind_param(8, $year, DBI::SQL_VARCHAR);
	$sth->bind_param(9, $sysset, DBI::SQL_VARCHAR);
    }

    elsif ( $PerlSpace::SysMtExecuter::db eq "mysql" )
    {
	# not implemented
    }
    elsif ( $PerlSpace::SysMtExecuter::db eq "db2" )
    {
	# not implemented
    }

    
    $sth->execute;
    
    my $mid;
    my $shortdesc;
    $i=0;


    while ( ($mid, $dayfrom, $monthfrom, $dayto, $monthto, $sid, $shortdesc, $status) = $sth->fetchrow_array) 
	
    {
	
	
	$$dbdata{'ov'}[$i]{'mid'} = $mid;
	$$dbdata{'ov'}[$i]{'dayfrom'} = $dayfrom;
	$$dbdata{'ov'}[$i]{'monthfrom'} = $monthfrom;
	$$dbdata{'ov'}[$i]{'dayto'} = $dayto;
	$$dbdata{'ov'}[$i]{'monthto'} = $monthto;
	$$dbdata{'ov'}[$i]{'sid'} = $sid;
	$$dbdata{'ov'}[$i]{'shortdesc'} = $shortdesc;
	$$dbdata{'ov'}[$i]{'status'} = $status;
	
	$i++;
    }
    
    $sth->finish;    

    my ( $headmsg, $fullname, $sysmsg )  = PerlSpace::SysMtUtil::getHeaderInfo($dbh, $user);
    $$dbdata{'headertext'} = $headmsg;
    $$dbdata{'fullname'} = $fullname;
    $$dbdata{'sysmsg'} = $sysmsg;
    $$dbdata{'content'} = "sysmt_mtov.html";
    
    $TT ||= Template->new({ INCLUDE_PATH  => $PerlSpace::SysMtExecuter::tmplpath });
    $TT->process('sysmt_frame.html', $dbdata) || die $TT->error(), "\n";

    return 0;
}


sub sysmtMtCSV
{

    my ( $dbh, $user, $ccname, $ccspec ) = @_;
    
    my $sth = $dbh->prepare("select prjname | ',' | sid | ',' | mttype | ',' | shortdesc | ',' | mtfrom | ',' | mtto | ',' | downfrom | ',' | downto | ',' | status |','| ticketnr from sysmt_mtview m where " . $ccspec . " and m.pid in ( select pid from sysmt_prj2bgrp where bgid in ( select bgid from sysmt_usr2bgrp u2g, sysmt_user u where u2g.uid = u.uid and u.dbuser = ? ));");

    # bgid in ( select bgid from sysmt_usr2bgrp u2g, sysmt_user u where u2g.uid = u.uid and u.dbuser = ?);");
    $sth->bind_param(1, $user, DBI::SQL_VARCHAR);

    $sth->execute;

    my $i=0;
    my $dbdata;

    my $csv;

    $$dbdata{'ccname'}[$i] = $ccname;
    $$dbdata{'csvlist'}[$i] = "Project,SID,Type,ShortDesc,MTFrom,MTTo,DownFrom,DownTo,Status,Ticket";
    $i++;

    while ( ($csv) = $sth->fetchrow_array) 
    {
	$$dbdata{'csvlist'}[$i] = $csv;
	$i++;
    }    
    $sth->finish;


    my ( $headmsg, $fullname, $sysmsg )  = PerlSpace::SysMtUtil::getHeaderInfo($dbh, $user);
    $$dbdata{'headertext'} = $headmsg;
    $$dbdata{'fullname'} = $fullname;
    $$dbdata{'sysmsg'} = $sysmsg;
    $$dbdata{'content'} = "sysmt_mtcsv.html";
    
    $TT ||= Template->new({ INCLUDE_PATH  => $PerlSpace::SysMtExecuter::tmplpath });
    $TT->process('sysmt_frame.html', $dbdata) || die $TT->error(), "\n";
    
    return 0;
}

sub sysmtMtStatMaster
{

    my ( $dbh, $user ) = @_;

    my $dbdata;

    $$dbdata{'user'} = $user;

    my @prjlist = PerlSpace::SysMtUtil::getMtReadProjectForUser($dbh, $user);
    
    $i=0;
    foreach my $prj ( @prjlist )
    {
	$$dbdata{'projectlist'}[$i] = $prj;
	$i++;
    }

    my @setlist = PerlSpace::SysMtUtil::getMtReadSysSetForUser($dbh, $user);
    
    $i=0;
    foreach my $set ( @setlist )
    {
	$$dbdata{'setlist'}[$i] = $set;
	$i++;
    }

    $$dbdata{'curmonth'} = PerlSpace::SysMtUtil::getCurrentMonth();
    $$dbdata{'curyear'} = PerlSpace::SysMtUtil::getCurrentYear();    

    @yearlist = PerlSpace::SysMtUtil::getYearList();

    $i=0;
    foreach my $year ( @yearlist )
    {
	$$dbdata{'yearlist'}[$i] = $year;
	$i++;
    }

    my ( $headmsg, $fullname, $sysmsg )  = PerlSpace::SysMtUtil::getHeaderInfo($dbh, $user);
    $$dbdata{'headertext'} = $headmsg;
    $$dbdata{'fullname'} = $fullname;
    $$dbdata{'sysmsg'} = $sysmsg;
    $$dbdata{'content'} = "sysmt_mtstatmaster.html";


    $TT ||= Template->new({ INCLUDE_PATH  => $PerlSpace::SysMtExecuter::tmplpath });
    $TT->process('sysmt_frame.html', $dbdata) || die $TT->error(), "\n";

    return 0;
}

sub sysmtMtReportMaster
{

    my ( $dbh, $user ) = @_;

    my $dbdata;

    $$dbdata{'user'} = $user;

    my @prjlist = PerlSpace::SysMtUtil::getMtReadProjectForUser($dbh, $user);
    
    $i=0;
    foreach my $prj ( @prjlist )
    {
	$$dbdata{'projectlist'}[$i] = $prj;
	$i++;
    }

    my @setlist = PerlSpace::SysMtUtil::getMtReadSysSetForUser($dbh, $user);
    
    $i=0;
    foreach my $set ( @setlist )
    {
	$$dbdata{'setlist'}[$i] = $set;
	$i++;
    }

    $$dbdata{'curmonth'} = PerlSpace::SysMtUtil::getCurrentMonth();
    $$dbdata{'curyear'} = PerlSpace::SysMtUtil::getCurrentYear();    

    @yearlist = PerlSpace::SysMtUtil::getYearList();
    @monthlist = PerlSpace::SysMtUtil::getMonthList();

    $i=0;
    foreach my $year ( @yearlist )
    {
	$$dbdata{'yearlist'}[$i] = $year;
	$i++;
    }

    $i=0;
    foreach my $month ( @monthlist )
    {
	$$dbdata{'monthlist'}[$i] = $month;
	$i++;
    }

    my ( $headmsg, $fullname, $sysmsg )  = PerlSpace::SysMtUtil::getHeaderInfo($dbh, $user);
    $$dbdata{'headertext'} = $headmsg;
    $$dbdata{'fullname'} = $fullname;
    $$dbdata{'sysmsg'} = $sysmsg;
    $$dbdata{'content'} = "sysmt_mtrepmaster.html";


    $TT ||= Template->new({ INCLUDE_PATH  => $PerlSpace::SysMtExecuter::tmplpath });
    $TT->process('sysmt_frame.html', $dbdata) || die $TT->error(), "\n";

    return 0;
}

sub sysmtMtReport
{
    
    my ( $dbh, $user, $sysset, $month, $year ) = @_;

    my $stmt;

    # warn "Year =" . $year . " month = " . $month . " set = " . $sysset;

    if ( $PerlSpace::SysMtExecuter::db eq "cego" )
    {
	$stmt = "select mid, prjname, sid, shortdesc, mtfrom, mtto, downfrom, downto, status, repcomment, repappcheck " .
	    " from sysmt_mtview mtv, sysmt_sys2set s2s, sysmt_systemset ss where date2str(mtfrom, '%Y') = '" . $year . "' and date2str(mtfrom, '%m') = '" . $month . "' and ss.setname = '" . $sysset . "' and ss.setid = s2s.setid and s2s.sysid = mtv.sysid order by mtfrom;";
    }
    elsif ( $PerlSpace::SysMtExecuter::db eq "mysql" )
    {
	$stmt = "select " .
	    $mysql_selection .
	    " from sysmt_mtview mtv, sysmt_sys2set s2s, sysmt_systemset ss where year(mtfrom) = " . $year . " and ss.setname = '" . $sysset . "' and ss.setid = s2s.setid and s2s.sysid = mtv.sysid order by mtfrom;";
    }
    elsif ( $PerlSpace::SysMtExecuter::db eq "db2" )
    {
	$stmt = "select mid, prjname, sid, shortdesc, ts_fmt(mtfrom, 'dd.mm.yyyy hh:mi:ss'),ts_fmt(mtto, 'dd.mm.yyyy hh:mi:ss'), ts_fmt(downfrom, 'dd.mm.yyyy hh:mi:ss'),ts_fmt(downto, 'dd.mm.yyyy hh:mi:ss'), status, repcomment, repappcheck " .
	    " from sysmt_mtview m, sysmt_sys2set s2s, sysmt_systemset ss where year(mtfrom) = " . $year . " and month(mtfrom) = " . $month . " and ss.setname = '" . $sysset . "' and ss.setid = s2s.setid and s2s.sysid = m.sysid order by mtfrom";
    }

    my $sth = $dbh->prepare($stmt);

    $sth->execute;
    
    my $dbdata;

    $$dbdata{'year'} = $year;
    $$dbdata{'month'} = $month;
    $$dbdata{'sysset'} = $sysset;

    my $mid;
    my $prjname;
    my $sid;
    my $shortdesc;    
    my $mtfrom;
    my $mtto;
    my $status;
    my $ticket;
    
    my $i=0;
    while ( ($mid, $prjname, $sid, $shortdesc, $mtfrom, $mtto, $downfrom, $downto, $status, $repcomment, $repappcheck) = $sth->fetchrow_array) 
    {

	if ( $mtfrom eq "null" )
	{
	    $mtfrom = "";
	}
	if ( $mtto eq "null" )
	{
	    $mtto = "";
	}

	$$dbdata{'mtreplist'}[$i]{'mid'} = $mid;
	$$dbdata{'mtreplist'}[$i]{'prjname'} = $prjname;
	$$dbdata{'mtreplist'}[$i]{'sid'} = $sid;
	$$dbdata{'mtreplist'}[$i]{'shortdesc'} = $shortdesc;
	$$dbdata{'mtreplist'}[$i]{'mtfrom'} = $mtfrom;
	$$dbdata{'mtreplist'}[$i]{'mtto'} = $mtto;
	$$dbdata{'mtreplist'}[$i]{'downfrom'} = $downfrom;
	$$dbdata{'mtreplist'}[$i]{'downto'} = $downto;

	$$dbdata{'mtreplist'}[$i]{'status'} = $status;
	$$dbdata{'mtreplist'}[$i]{'repcomment'} = $repcomment;
	$$dbdata{'mtreplist'}[$i]{'repappcheck'} = $repappcheck;

	$i++;
    }
    
    $sth->finish;    

    my ( $headmsg, $fullname, $sysmsg )  = PerlSpace::SysMtUtil::getHeaderInfo($dbh, $user);
    $$dbdata{'headertext'} = $headmsg;
    $$dbdata{'fullname'} = $fullname;
    $$dbdata{'sysmsg'} = $sysmsg;
    $$dbdata{'content'} = "sysmt_mtreport.html";

    $TT ||= Template->new({
	INCLUDE_PATH  => $PerlSpace::SysMtExecuter::tmplpath  });
    $TT->process('sysmt_frame.html', $dbdata) || die $TT->error(), "\n";

    return 0;

}

sub sysmtMtReportUpdate
{

    my ( $dbh, $user, $sysset, $month, $year, $mid, $repcomment, $repappcheck ) = @_;
        
    my $sth = $dbh->prepare("update sysmt_mt set repcomment = ?, repappcheck = ? where mid = ?;");
    
    $sth->bind_param(1, $repcomment, DBI::SQL_VARCHAR);
    $sth->bind_param(2, $repappcheck, DBI::SQL_VARCHAR);
    $sth->bind_param(3, $mid, DBI::SQL_INTEGER);
         
    $sth->execute;
    
    $sth->finish;    

    return sysmtMtReport($dbh, $user, $sysset, $month, $year );
}

sub sysmtMtReportMail
{

    my ( $dbh, $user, $sysset, $month, $year, $mailto, $sig1, $sig2 ) = @_;


    my $sig1opt;
    my $sig2opt;

    if ( $sig1 )
    {
	$sig1opt="-b '" . $sig1 . "'"; 
    }

    if ( $sig2 )
    {
	$sig2opt="-c '" . $sig2 . "'"; 
    }

    $title = "SysMT Report for " . $sysset . " from " . $month . "/" . $year;

    open(MAILOUT, "/erpwork/batch/sysmtrep -m " . $month . " -y " . $year . " -a " . $mailto . " -s " . $sysset . " -o /tmp/sysmtrep  -d '" . $title . "' " . $sig1opt . " " . $sig2opt . " -t SysMT-Report |");

    return sysmtMtReport($dbh, $user, $sysset, $month, $year );

}

sub sysmtMtStatAll
{
    
    my ( $dbh, $user, $year ) = @_;

    my $dbdata;

    $$dbdata{'user'} = $user;
    $$dbdata{'title'} = "All ";
    $$dbdata{'year'} = $year;
    $$dbdata{'dim'} = "Month";
    $$dbdata{'mtentry'} = 13;    

        
    $$dbdata{'mtstat'}[0] = [ "01", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0" ];
    $$dbdata{'mtstat'}[1] = [ "02", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0" ];
    $$dbdata{'mtstat'}[2] = [ "03", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0" ];
    $$dbdata{'mtstat'}[3] = [ "04", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0" ];
    $$dbdata{'mtstat'}[4] = [ "05", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0" ];
    $$dbdata{'mtstat'}[5] = [ "06", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0" ];
    $$dbdata{'mtstat'}[6] = [ "07", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0" ];
    $$dbdata{'mtstat'}[7] = [ "08", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0" ];
    $$dbdata{'mtstat'}[8] = [ "09", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0" ];
    $$dbdata{'mtstat'}[9] = [ "10", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0" ];
    $$dbdata{'mtstat'}[10] = [ "11", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0" ];
    $$dbdata{'mtstat'}[11] = [ "12", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0" ];


    my $mtnum;
    my $month;
    my $pos=1;

    ####### All Requested eintries ####

    my $query="select month, count(*) from sysmt_mtmonthprj m where status = 'Requested' and year = ? and m.pid in " .
	" ( select pid from sysmt_prj2bgrp where bgid in " .
	" ( select distinct u2g.bgid from sysmt_usr2bgrp u2g, sysmt_user u, sysmt_bgright r " .
	" where ( r.bgright = 'mtread' or r.bgright = 'mtwrite' ) and r.bgid = u2g.bgid and  u2g.uid = u.uid and u.dbuser = ?))" .
	" group by month order by month;";
    
    my $sth = $dbh->prepare($query);
    $sth->bind_param(1, $year, DBI::SQL_VARCHAR);
    $sth->bind_param(2, $user, DBI::SQL_VARCHAR);

    $sth->execute;

    while (($month, $mtnum) = $sth->fetchrow_array) 
    {
	$month = substr "0" . $month, -2, 2;
	$midx = PerlSpace::SysMtUtil::getMonthIndex($month);
	$$dbdata{'mtstat'}[$midx][$pos] = $mtnum;       
    }

    $pos=$pos+2;    
    $sth->finish;

    ####### All Approved eintries ####

    my $query="select month, count(*) from sysmt_mtmonthprj m where status = 'Approved' and year = ? and m.pid in " .
	" ( select pid from sysmt_prj2bgrp where bgid in " .
	" ( select distinct u2g.bgid from sysmt_usr2bgrp u2g, sysmt_user u, sysmt_bgright r " .
	" where ( r.bgright = 'mtread' or r.bgright = 'mtwrite' ) and r.bgid = u2g.bgid and  u2g.uid = u.uid and u.dbuser = ?))" .
	" group by month order by month;";
    
    my $sth = $dbh->prepare($query);
    $sth->bind_param(1, $year, DBI::SQL_VARCHAR);
    $sth->bind_param(2, $user, DBI::SQL_VARCHAR);

    $sth->execute;

    while (($month, $mtnum) = $sth->fetchrow_array) 
    {
	$month = substr "0" . $month, -2, 2;
	$midx = PerlSpace::SysMtUtil::getMonthIndex($month);
	$$dbdata{'mtstat'}[$midx][$pos] = $mtnum;
    }
    
    $pos=$pos+2;

    $sth->finish;

    ####### All Done eintries ####

    my $query="select month, count(*) from sysmt_mtmonthprj m where status = 'Done' and year = ? and m.pid in " .
	" ( select pid from sysmt_prj2bgrp where bgid in " .
	" ( select distinct u2g.bgid from sysmt_usr2bgrp u2g, sysmt_user u, sysmt_bgright r " .
	" where ( r.bgright = 'mtread' or r.bgright = 'mtwrite' ) and r.bgid = u2g.bgid and  u2g.uid = u.uid and u.dbuser = ?))" .
	" group by month order by month;";
    
    my $sth = $dbh->prepare($query);
    $sth->bind_param(1, $year, DBI::SQL_VARCHAR);
    $sth->bind_param(2, $user, DBI::SQL_VARCHAR);

    $sth->execute;

    while (($month, $mtnum) = $sth->fetchrow_array) 
    {
	$month = substr "0" . $month, -2, 2;
	$midx = PerlSpace::SysMtUtil::getMonthIndex($month);
	$$dbdata{'mtstat'}[$midx][$pos] = $mtnum;
    }
    
    $pos=$pos+2;

    $sth->finish;


    ####### All Aborted eintries ####

    my $query="select month, count(*) from sysmt_mtmonthprj m where status = 'Aborted' and year = ? and m.pid in " .
	" ( select pid from sysmt_prj2bgrp where bgid in " .
	" ( select distinct u2g.bgid from sysmt_usr2bgrp u2g, sysmt_user u, sysmt_bgright r " .
	" where ( r.bgright = 'mtread' or r.bgright = 'mtwrite' ) and r.bgid = u2g.bgid and  u2g.uid = u.uid and u.dbuser = ?))" .
	" group by month order by month;";
    
    my $sth = $dbh->prepare($query);
    $sth->bind_param(1, $year, DBI::SQL_VARCHAR);
    $sth->bind_param(2, $user, DBI::SQL_VARCHAR);

    $sth->execute;

    while (($month, $mtnum) = $sth->fetchrow_array) 
    {
	$month = substr "0" . $month, -2, 2;
	$midx = PerlSpace::SysMtUtil::getMonthIndex($month);
	$$dbdata{'mtstat'}[$midx][$pos] = $mtnum;
    }

    $pos=$pos+2;

    $sth->finish;


    ####### All Claimed eintries ####

    my $query="select month, count(*) from sysmt_mtmonthprj m where status = 'Claimed' and year = ? and m.pid in " .
	" ( select pid from sysmt_prj2bgrp where bgid in " .
	" ( select distinct u2g.bgid from sysmt_usr2bgrp u2g, sysmt_user u, sysmt_bgright r " .
	" where ( r.bgright = 'mtread' or r.bgright = 'mtwrite' ) and r.bgid = u2g.bgid and  u2g.uid = u.uid and u.dbuser = ?))" .
	" group by month order by month;";
    
    my $sth = $dbh->prepare($query);
    $sth->bind_param(1, $year, DBI::SQL_VARCHAR);
    $sth->bind_param(2, $user, DBI::SQL_VARCHAR);

    $sth->execute;

    while (($month, $mtnum) = $sth->fetchrow_array) 
    {
	$month = substr "0" . $month, -2, 2;
	$midx = PerlSpace::SysMtUtil::getMonthIndex($month);
	$$dbdata{'mtstat'}[$midx][$pos] = $mtnum;
    }

    $pos=$pos+2;

    $sth->finish;

    ####### All Attention eintries ####

    my $query="select month, count(*) from sysmt_mtmonthprj m where status = 'Attention' and year = ? and m.pid in " .
	" ( select pid from sysmt_prj2bgrp where bgid in " .
	" ( select distinct u2g.bgid from sysmt_usr2bgrp u2g, sysmt_user u, sysmt_bgright r " .
	" where ( r.bgright = 'mtread' or r.bgright = 'mtwrite' ) and r.bgid = u2g.bgid and  u2g.uid = u.uid and u.dbuser = ?))" .
	" group by month order by month;";
    
    my $sth = $dbh->prepare($query);
    $sth->bind_param(1, $year, DBI::SQL_VARCHAR);
    $sth->bind_param(2, $user, DBI::SQL_VARCHAR);

    $sth->execute;

    while (($month, $mtnum) = $sth->fetchrow_array) 
    {
	$month = substr "0" . $month, -2, 2;
	$midx = PerlSpace::SysMtUtil::getMonthIndex($month);
	$$dbdata{'mtstat'}[$midx][$pos] = $mtnum;
    }

    $sth->finish;


    # calculate max peek for scaling

    $maxnum=1;        

    my $j;
    for ( $j=0; $j<12; $j++ )	
    {
	$lmaxnum=0;
	for ( $pos=1; $pos<=12; $pos=$pos+2 )
	{ 	
	    $lmaxnum += $$dbdata{'mtstat'}[$j][$pos];
	}
	if ( $lmaxnum > $maxnum )
	{
	    $maxnum=$lmaxnum;
	}
    }

    # calculate percent values

    for ( $pos=1; $pos<=12; $pos=$pos+2 )
    {
	my $j;
	for ( $j=0; $j<12; $j++ )
	{ 	
	    my $percent = POSIX::ceil(( $scale * 100 / $maxnum ) * $$dbdata{'mtstat'}[$j][$pos]);
	    $$dbdata{'mtstat'}[$j][$pos+1] = $percent;
	    # if ( $$dbdata{'mtstat'}[$j][$pos+1] == 0 )
	    # {
	    #	$$dbdata{'mtstat'}[$j][$pos] = "";
	    # }
	}
    }

    my ( $headmsg, $fullname, $sysmsg )  = PerlSpace::SysMtUtil::getHeaderInfo($dbh, $user);
    $$dbdata{'headertext'} = $headmsg;
    $$dbdata{'fullname'} = $fullname;
    $$dbdata{'sysmsg'} = $sysmsg;
    $$dbdata{'content'} = "sysmt_mtstat.html";

    $TT ||= Template->new({ INCLUDE_PATH  => $PerlSpace::SysMtExecuter::tmplpath });

    $TT->process('sysmt_frame.html', $dbdata) || die $TT->error(), "\n";
    
    return 0;
}

sub sysmtMtStatProject
{
    
    my ( $dbh, $user, $project, $year ) = @_;

    my $dbdata;

    $$dbdata{'user'} = $user;

    $$dbdata{'title'} = "Project " . $project;
    $$dbdata{'year'} = $year;
    $$dbdata{'dim'} = "Month";
    $$dbdata{'mtentry'} = 13;

    my $mtnum = 0;
    my $month = 0;
    

    $$dbdata{'mtstat'}[0] = [ "01", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0" ];
    $$dbdata{'mtstat'}[1] = [ "02", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0" ];
    $$dbdata{'mtstat'}[2] = [ "03", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0" ];
    $$dbdata{'mtstat'}[3] = [ "04", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0" ];
    $$dbdata{'mtstat'}[4] = [ "05", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0" ];
    $$dbdata{'mtstat'}[5] = [ "06", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0" ];
    $$dbdata{'mtstat'}[6] = [ "07", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0" ];
    $$dbdata{'mtstat'}[7] = [ "08", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0" ];
    $$dbdata{'mtstat'}[8] = [ "09", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0" ];
    $$dbdata{'mtstat'}[9] = [ "10", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0" ];
    $$dbdata{'mtstat'}[10] = [ "11", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0" ];
    $$dbdata{'mtstat'}[11] = [ "12", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0" ];


    my $mtnum;
    my $month;
    my $pos=1;

    @mtstats = ("Requested","Approved","Done", "Aborted", "Claimed", "Attention");

    foreach ( @mtstats )
    {
	$stat = $_;
	

	my $query="select month, count(*) from sysmt_mtmonthprj where status = ? and prjname = ? and year = ? group by month order by month;";
	
	my $sth = $dbh->prepare($query);
	$sth->bind_param(1, $stat, DBI::SQL_VARCHAR);
	$sth->bind_param(2, $project, DBI::SQL_VARCHAR);
	$sth->bind_param(3, $year, DBI::SQL_VARCHAR);
	
	$sth->execute;
	
	$lmaxnum = 0;
	while (($month, $mtnum) = $sth->fetchrow_array) 
	{
	    
	    $month = substr "0" . $month, -2, 2;
	    $midx = PerlSpace::SysMtUtil::getMonthIndex($month);
	    $$dbdata{'mtstat'}[$midx][$pos] = $mtnum;
	}
	
	$pos=$pos+2;    
	$sth->finish;
    }

    # calculate max peek for scaling

    $maxnum=1;        

    my $j;
    for ( $j=0; $j<12; $j++ )	
    {
	$lmaxnum=0;
	for ( $pos=1; $pos<=12; $pos=$pos+2 )
	{ 	
	    $lmaxnum += $$dbdata{'mtstat'}[$j][$pos];
	}
	if ( $lmaxnum > $maxnum )
	{
	    $maxnum=$lmaxnum;
	}
    }

    # calculate percent values

    for ( $pos=1; $pos<=12; $pos=$pos+2 )
    {
	my $j;
	for ( $j=0; $j<12; $j++ )
	{ 	
	    my $percent = POSIX::ceil(( $scale * 100 / $maxnum ) * $$dbdata{'mtstat'}[$j][$pos]);
	    $$dbdata{'mtstat'}[$j][$pos+1] = $percent;
	}
    }

    my ( $headmsg, $fullname, $sysmsg )  = PerlSpace::SysMtUtil::getHeaderInfo($dbh, $user);
    $$dbdata{'headertext'} = $headmsg;
    $$dbdata{'fullname'} = $fullname;
    $$dbdata{'sysmsg'} = $sysmsg;
    $$dbdata{'content'} = "sysmt_mtstat.html";

    $TT ||= Template->new({ INCLUDE_PATH  => $PerlSpace::SysMtExecuter::tmplpath });

    $TT->process('sysmt_frame.html', $dbdata) || die $TT->error(), "\n";
    
    return 0;
}

sub sysmtMtStatSystemSet
{
    
    my ( $dbh, $user, $sysset, $year ) = @_;

    my $dbdata;

    $$dbdata{'user'} = $user;

    $$dbdata{'title'} = "System Set " . $sysset;
    $$dbdata{'year'} = $year;
    $$dbdata{'dim'} = "Month";
    $$dbdata{'mtentry'} = 13;

    my $mtnum = 0;
    my $month = 0;
    

    $$dbdata{'mtstat'}[0] = [ "01", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0" ];
    $$dbdata{'mtstat'}[1] = [ "02", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0" ];
    $$dbdata{'mtstat'}[2] = [ "03", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0" ];
    $$dbdata{'mtstat'}[3] = [ "04", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0" ];
    $$dbdata{'mtstat'}[4] = [ "05", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0" ];
    $$dbdata{'mtstat'}[5] = [ "06", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0" ];
    $$dbdata{'mtstat'}[6] = [ "07", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0" ];
    $$dbdata{'mtstat'}[7] = [ "08", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0" ];
    $$dbdata{'mtstat'}[8] = [ "09", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0" ];
    $$dbdata{'mtstat'}[9] = [ "10", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0" ];
    $$dbdata{'mtstat'}[10] = [ "11", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0" ];
    $$dbdata{'mtstat'}[11] = [ "12", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0" ];


    my $mtnum;
    my $month;
    my $pos=1;

    @mtstats = ("Requested","Approved","Done", "Aborted", "Claimed", "Attention");

    foreach ( @mtstats )
    {
	$stat = $_;
	

	my $query="select month, count(*) from sysmt_mtmonthset where status = ? and setname = ? and year = ? group by month order by month;";
	
	my $sth = $dbh->prepare($query);
	$sth->bind_param(1, $stat, DBI::SQL_VARCHAR);
	$sth->bind_param(2, $sysset, DBI::SQL_VARCHAR);
	$sth->bind_param(3, $year, DBI::SQL_VARCHAR);
	
	$sth->execute;
	
	$lmaxnum = 0;
	while (($month, $mtnum) = $sth->fetchrow_array) 
	{
	    
	    $month = substr "0" . $month, -2, 2;
	    $midx = PerlSpace::SysMtUtil::getMonthIndex($month);
	    $$dbdata{'mtstat'}[$midx][$pos] = $mtnum;
	}
	
	$pos=$pos+2;    
	$sth->finish;
    }

    # calculate max peek for scaling

    $maxnum=1;        

    my $j;
    for ( $j=0; $j<12; $j++ )	
    {
	$lmaxnum=0;
	for ( $pos=1; $pos<=12; $pos=$pos+2 )
	{ 	
	    $lmaxnum += $$dbdata{'mtstat'}[$j][$pos];
	}
	if ( $lmaxnum > $maxnum )
	{
	    $maxnum=$lmaxnum;
	}
    }

    # calculate percent values

    for ( $pos=1; $pos<=12; $pos=$pos+2 )
    {
	my $j;
	for ( $j=0; $j<12; $j++ )
	{ 	
	    my $percent = POSIX::ceil(( $scale * 100 / $maxnum ) * $$dbdata{'mtstat'}[$j][$pos]);
	    $$dbdata{'mtstat'}[$j][$pos+1] = $percent;
	}
    }

    my ( $headmsg, $fullname, $sysmsg )  = PerlSpace::SysMtUtil::getHeaderInfo($dbh, $user);
    $$dbdata{'headertext'} = $headmsg;
    $$dbdata{'fullname'} = $fullname;
    $$dbdata{'sysmsg'} = $sysmsg;
    $$dbdata{'content'} = "sysmt_mtstat.html";

    $TT ||= Template->new({ INCLUDE_PATH  => $PerlSpace::SysMtExecuter::tmplpath });

    $TT->process('sysmt_frame.html', $dbdata) || die $TT->error(), "\n";
    
    return 0;
}



sub sysmtMtSysStatAll
{
    
    my ( $dbh, $user, $year ) = @_;

    my $dbdata;

    $$dbdata{'user'} = $user;
    $$dbdata{'title'} = "All ";
    $$dbdata{'year'} = $year;
    $$dbdata{'dim'} = "SID";

    my $query="select sid, count(*) from sysmt_mtview m where date2str(mtfrom, '%Y') = ? and m.pid in " .
	" ( select pid from sysmt_prj2bgrp where bgid in " .
	" ( select distinct bgid from sysmt_usr2bgrp u2g, sysmt_user u, sysmt_bgright r " .
	" where ( r.bgright = 'mtread' or r.bgright = 'mtwrite' ) and r.bgid = u2g.bgid and  u2g.uid = u.uid and u.dbuser = ?))" .
	" group by sid order by sid;";
    
    my $sth = $dbh->prepare($query);
    $sth->bind_param(1, $year, DBI::SQL_VARCHAR);
    $sth->bind_param(2, $user, DBI::SQL_VARCHAR);

    $sth->execute;

    my $maxnum = 1;
    my $mtnum = 0;

    $i=0;
    while (($sid, $mtnum) = $sth->fetchrow_array)
    {
	$$dbdata{'mtstat'}[$i] = [ $sid, $mtnum ];
	$i++;

	if ( $mtnum > $maxnum )
	{
	    $maxnum = $mtnum;
	}
    }

    $$dbdata{'mtentry'} = $i+1;

    my $j;
    for ( $j=0; $j<$i; $j++ )
    { 	
     	my $percent = (( $scale * 100 / $maxnum ) * $$dbdata{'mtstat'}[$j][1]);
    	$$dbdata{'mtstat'}[$j][2] = $percent;
    }
    
    $sth->finish;

    my ( $headmsg, $fullname, $sysmsg )  = PerlSpace::SysMtUtil::getHeaderInfo($dbh, $user);
    $$dbdata{'headertext'} = $headmsg;
    $$dbdata{'fullname'} = $fullname;
    $$dbdata{'sysmsg'} = $sysmsg;
    $$dbdata{'content'} = "sysmt_mtstat.html";


    $TT ||= Template->new({ INCLUDE_PATH  => $PerlSpace::SysMtExecuter::tmplpath });

    $TT->process('sysmt_frame.html', $dbdata) || die $TT->error(), "\n";
    
    return 0;
}

sub sysmtMtSysStatProject
{
    
    my ( $dbh, $user, $project, $year ) = @_;

    my $dbdata;

    $$dbdata{'user'} = $user;
    $$dbdata{'title'} = $project;
    $$dbdata{'year'} = $year;
    $$dbdata{'dim'} = "SID";

    my $query="select sid, count(*) from sysmt_mtview m where date2str(mtfrom, '%Y') = ? and prjname = ? group by sid order by sid;";
    
    my $sth = $dbh->prepare($query);
    $sth->bind_param(1, $year, DBI::SQL_VARCHAR);
    $sth->bind_param(2, $project, DBI::SQL_VARCHAR);

    $sth->execute;

    my $maxnum = 1;
    my $mtnum = 0;

    $i=0;
    while (($sid, $mtnum) = $sth->fetchrow_array)
    {
	$$dbdata{'mtstat'}[$i] = [ $sid, $mtnum ];
	$i++;

	if ( $mtnum > $maxnum )
	{
	    $maxnum = $mtnum;
	}
    }

    $$dbdata{'mtentry'} = $i+1;

    my $j;
    for ( $j=0; $j<$i; $j++ )
    { 	
     	my $percent = (( $scale * 100 / $maxnum ) * $$dbdata{'mtstat'}[$j][1]);
    	$$dbdata{'mtstat'}[$j][2] = $percent;
    }
    
    $sth->finish;

    my ( $headmsg, $fullname, $sysmsg )  = PerlSpace::SysMtUtil::getHeaderInfo($dbh, $user);
    $$dbdata{'headertext'} = $headmsg;
    $$dbdata{'fullname'} = $fullname;
    $$dbdata{'sysmsg'} = $sysmsg;
    $$dbdata{'content'} = "sysmt_mtstat.html";

    $TT ||= Template->new({ INCLUDE_PATH  => $PerlSpace::SysMtExecuter::tmplpath });
    $TT->process('sysmt_frame.html', $dbdata) || die $TT->error(), "\n";
    
    return 0;
}

sub sysmtUserSearchNew
{

    my ( $dbh, $user ) = @_;

    my $dbdata;

    $$dbdata{'user'} = $user;

    my ( $headmsg, $fullname, $sysmsg )  = PerlSpace::SysMtUtil::getHeaderInfo($dbh, $user);
    $$dbdata{'headertext'} = $headmsg;
    $$dbdata{'fullname'} = $fullname;
    $$dbdata{'sysmsg'} = $sysmsg;
    $$dbdata{'content'} = "sysmt_usnew.html";

    $TT ||= Template->new({ INCLUDE_PATH  => $PerlSpace::SysMtExecuter::tmplpath });
    $TT->process('sysmt_frame.html', $dbdata) || die $TT->error(), "\n";
    
    return 0;
}

sub sysmtUserSearchCreate
{

    my ( $dbh, $user, $usname, $usspec ) = @_;

    my $dbdata;

    $$dbdata{'user'} = $user;


    if ( $PerlSpace::SysMtExecuter::db eq "cego" )
    {
	$usspec =~ s/'/''/g;

	$sth = $dbh->prepare("? = call newUserSearch ( ?, ?, ? );");
    
	$sth->bind_param_inout(1, \$usid, 10);
	$sth->bind_param(2, $usname, DBI::SQL_VARCHAR);
	$sth->bind_param(3, $usspec, DBI::SQL_VARCHAR);
	$sth->bind_param(4, $user, DBI::SQL_VARCHAR);
	
	$sth->execute;

    }
    elsif ( $PerlSpace::SysMtExecuter::db eq "mysql" )
    {
	# todo
    }
    elsif ( $PerlSpace::SysMtExecuter::db eq "db2" )
    {

	$sth = $dbh->prepare(q{call newUserSearch ( ?, ?, ?, ?)});
    
	$sth->bind_param(1, $usname, DBI::SQL_VARCHAR);
	$sth->bind_param(2, $usspec, DBI::SQL_VARCHAR);
	$sth->bind_param(3, $user, DBI::SQL_VARCHAR);
	$sth->bind_param_inout(4, \$usid, 10);
	
	$sth->execute;

    }

    $sth->finish;

    return sysmtMtMaster($dbh, $user);

}


sub sysmtUserSearch
{

    my ( $dbh, $user, $usid ) = @_;

    my $dbdata;

    $$dbdata{'user'} = $user;
    $$dbdata{'usid'} = $usid;

    my $sth = $dbh->prepare("select usname, usspec, uid from sysmt_usersearch where usid = ?;");
    $sth->bind_param(1, $usid, DBI::SQL_INTEGER);
    
    $sth->execute;
    
    my $usname;
    my $usspec;

    ( $usname, $usspec, $uid ) = $sth->fetchrow_array; 

    $sth->finish;


    $$dbdata{'usname'} = $usname;
    $$dbdata{'usspec'} = $usspec;

    my ( $headmsg, $fullname, $sysmsg )  = PerlSpace::SysMtUtil::getHeaderInfo($dbh, $user);
    $$dbdata{'headertext'} = $headmsg;
    $$dbdata{'fullname'} = $fullname;
    $$dbdata{'sysmsg'} = $sysmsg;
    $$dbdata{'content'} = "sysmt_us.html";
    

    $TT ||= Template->new({ INCLUDE_PATH  => $PerlSpace::SysMtExecuter::tmplpath });
    $TT->process('sysmt_frame.html', $dbdata) || die $TT->error(), "\n";
    
    return 0;

}

sub sysmtUserSearchUpdate
{

    my ( $dbh, $user, $usid, $usname, $usspec ) = @_;


    if ( $PerlSpace::SysMtExecuter::db eq "cego" )
    {
	$usspec =~ s/'/''/g; 
    }

    my $sth;
    $sth = $dbh->prepare("update sysmt_usersearch set usname = ?, usspec = ?, uid = ( select uid from sysmt_user where dbuser = ? ) where usid = ?;");
    $sth->bind_param(1, $usname, DBI::SQL_VARCHAR);
    $sth->bind_param(2, $usspec, DBI::SQL_VARCHAR);
    $sth->bind_param(3, $user, DBI::SQL_VARCHAR);
    $sth->bind_param(4, $usid, DBI::SQL_INTEGER);
    
    
    $sth->execute;
    
    $sth->finish;

    return sysmtMtMaster($dbh, $user);

}

sub sysmtUserSearchDelete
{

    my ( $dbh, $user, $usid ) = @_;

    my $dbdata;

    $$dbdata{'user'} = $user;

    my $sth = $dbh->prepare("delete from sysmt_usersearch where usid = ?;");
    $sth->bind_param(1, $usid, DBI::SQL_INTEGER);
    
    $sth->execute;
    
    $sth->finish;

    return sysmtMtMaster($dbh, $user);

}

1;
