#
# sysmt_prj.pm
# ------------
#
# Design and Implementation by Bjoern Lemke               
#           
# (C)opyright 2010,2011,2012 by Bjoern Lemke
#                                              
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2, or (at your option)
# any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; see the file COPYING.  If not, write to
# the Free Software Foundation, 59 Temple Place - Suite 330,
# Boston, MA 02111-1307, USA.
#

package PerlSpace::SysMtProject;

sub sysmtProjectMaster
{

    my ( $dbh, $user ) = @_;

    my ( $headmsg, $fullname, $sysmsg )  = PerlSpace::SysMtUtil::getHeaderInfo($dbh, $user);
    $$dbdata{'headertext'} = $headmsg;
    $$dbdata{'fullname'} = $fullname;
    $$dbdata{'sysmsg'} = $sysmsg;
    $$dbdata{'content'} = "sysmt_prjmaster.html";

    $TT ||= Template->new({ INCLUDE_PATH  => $PerlSpace::SysMtExecuter::tmplpath });
    $TT->process('sysmt_frame.html', $dbdata) || die $TT->error(), "\n";

    return 0;

}

sub sysmtPrjList
{
    
    my ( $dbh, $user, $prjname) = @_;    

    my $stmt = "select pid, prjname, prjdesc from sysmt_project where prjname like '%" . $prjname . "%'";    
    my $ordering = "order by prjname";
 
    sysmtPrjExecuteList($dbh, $user, $stmt, $ordering, 1);

    return 0;    

}

sub sysmtPrjExecuteList
{
    
    my ( $dbh, $user, $stmt, $ordering, $enableEdit ) = @_;

    my $sth = $dbh->prepare($stmt . " " . $ordering . ";");

    $sth->execute;
    
    my $dbdata;

    $$dbdata{'ordering'} = $ordering;
    $$dbdata{'stmt'} = $stmt;

    my $pid;
    my $prjname;
    my $prjdesc;
    my $i=0;
    while ( ($pid, $prjname, $prjdesc ) = $sth->fetchrow_array) 
    {
	$$dbdata{'prjlist'}[$i]{'pid'} = $pid;
	$$dbdata{'prjlist'}[$i]{'prjname'} = $prjname;
	$$dbdata{'prjlist'}[$i]{'prjdesc'} = $prjdesc;
	$i++;
    }
    
    $sth->finish;    

    my ( $headmsg, $fullname, $sysmsg )  = PerlSpace::SysMtUtil::getHeaderInfo($dbh, $user);
    $$dbdata{'headertext'} = $headmsg;
    $$dbdata{'fullname'} = $fullname;
    $$dbdata{'sysmsg'} = $sysmsg;

    if ( $enableEdit )
    {
	$$dbdata{'content'} = "sysmt_prjlist.html";
    }
    else
    {
	$$dbdata{'content'} = "sysmt_prjview.html";
    }

    $TT ||= Template->new({ INCLUDE_PATH  => $PerlSpace::SysMtExecuter::tmplpath });
    $TT->process('sysmt_frame.html', $dbdata) || die $TT->error(), "\n";

    return 0;
}


sub sysmtPrj
{
    
    my ( $dbh, $user, $pid, $stmt, $ordering ) = @_;
    
    my $dbdata;


    $$dbdata{'ordering'} = $ordering;
    $$dbdata{'stmt'} = $stmt;


    # reached groups retrievel
    $stmt="select bgname from sysmt_bgroup bg where bgid in ( select bgid from sysmt_prj2bgrp p2g where p2g.pid = ? ) order by bgname;";
    $sth = $dbh->prepare($stmt);
    $sth->bind_param(1, $pid, DBI::SQL_INTEGER);

    $sth->execute;
        
    my $bgroups = "";
    $$dbdata{'bgroups'} = "";
    $i=0;
    while ( ($bg) = $sth->fetchrow_array) 
    {

	$$dbdata{'delbglist'}[$i] = $bg;

	if ( $$dbdata{'bgroups'} eq "" )
	{
	    $$dbdata{'bgroups'} = $bg;
	}
	else
	{
	    $$dbdata{'bgroups'} = $$dbdata{'bgroups'} . "," . $bg;
	}
	$i++;
    }
    
    $sth->finish;    

    # reached approval groups retrievel
    $stmt="select bgname from sysmt_bgroup bg where bgid in ( select bgid from sysmt_prj2approval p2g where p2g.pid = ? ) order by bgname;";
    $sth = $dbh->prepare($stmt);
    $sth->bind_param(1, $pid, DBI::SQL_INTEGER);

    $sth->execute;
        
    my $agroups = "";
    $$dbdata{'agroups'} = "";
    $i=0;
    while ( ($bg) = $sth->fetchrow_array) 
    {

	$$dbdata{'delappbglist'}[$i] = $bg;

	if ( $$dbdata{'agroups'} eq "" )
	{
	    $$dbdata{'agroups'} = $bg;
	}
	else
	{
	    $$dbdata{'agroups'} = $$dbdata{'agroups'} . "," . $bg;
	}
	$i++;
    }
    
    $sth->finish;    

    # reached notification groups retrievel
    $stmt="select bgname from sysmt_bgroup bg where bgid in ( select bgid from sysmt_prj2notification p2nf where p2nf.pid = ? ) order by bgname;";
    $sth = $dbh->prepare($stmt);
    $sth->bind_param(1, $pid, DBI::SQL_INTEGER);
    
    $sth->execute;
        
    my $nfgroups = "";
    $$dbdata{'nfgroups'} = "";
    $i=0;
    while ( ($bg) = $sth->fetchrow_array) 
    {

	$$dbdata{'delnfbglist'}[$i] = $bg;

	if ( $$dbdata{'nfgroups'} eq "" )
	{
	    $$dbdata{'nfgroups'} = $bg;
	}
	else
	{
	    $$dbdata{'nfgroups'} = $$dbdata{'nfgroups'} . "," . $bg;
	}
	$i++;
    }
    
    $sth->finish;    


    # reached verification groups retrievel
    $stmt="select bgname from sysmt_bgroup bg where bgid in ( select bgid from sysmt_prj2verification p2vf where p2vf.pid = ? ) order by bgname;";
    $sth = $dbh->prepare($stmt);
    $sth->bind_param(1, $pid, DBI::SQL_INTEGER);

    $sth->execute;
        
    my $vfgroups = "";
    $$dbdata{'vfgroups'} = "";
    $i=0;
    while ( ($bg) = $sth->fetchrow_array) 
    {

	$$dbdata{'delvfbglist'}[$i] = $bg;

	if ( $$dbdata{'vfgroups'} eq "" )
	{
	    $$dbdata{'vfgroups'} = $bg;
	}
	else
	{
	    $$dbdata{'vfgroups'} = $$dbdata{'vfgroups'} . "," . $bg;
	}
	$i++;
    }
    
    $sth->finish;    

    # reached workflow groups retrievel
    $stmt="select bgname, seqnr from sysmt_bgroup bg, sysmt_prj2workflow p2wf where p2wf.pid = ? and p2wf.bgid = bg.bgid order by seqnr;";
    $sth = $dbh->prepare($stmt);
    $sth->bind_param(1, $pid, DBI::SQL_INTEGER);
    
    $sth->execute;
        
    my $wfgroups = "";
    $$dbdata{'wfgroups'} = "";
    $i=0;
    while ( ($bg, $seqnr) = $sth->fetchrow_array) 
    {

	$$dbdata{'delwfbglist'}[$i] = $bg;

	if ( $$dbdata{'wfgroups'} eq "" )
	{
	    $$dbdata{'wfgroups'} = $seqnr . "." . $bg;
	}
	else
	{
	    $$dbdata{'wfgroups'} = $$dbdata{'wfgroups'} . "," . $seqnr . "." . $bg;
	}
	$i++;
    }
    
    $sth->finish;    


    $$dbdata{'sids'} = "";

    my $sth = $dbh->prepare("select sid from sysmt_system s where pid = ? order by sid;");
    $sth->bind_param(1, $pid, DBI::SQL_INTEGER);
    
    $sth->execute;
    
    my $sid;

    while ( ( $sid ) = $sth->fetchrow_array )
    {	

	if ( $$dbdata{'sids'} eq "" )
	{
	    $$dbdata{'sids'} = $sid;
	}
	else
	{	    
	    $$dbdata{'sids'} = $$dbdata{'sids'} . ", " . $sid;
	}
    }
        
    $sth->finish;

    
    # retrieve project information

    $stmt="select pid, prjname, prjdesc, prjmail from sysmt_project p where p.pid = ?;";
    $sth = $dbh->prepare($stmt);
    $sth->bind_param(1, $pid, DBI::SQL_INTEGER);
    
    $sth->execute;
    
    my $pid;
    my $prjname;
    my $prjdesc;

    ( $pid, $prjname, $prjdesc, $prjmail ) = $sth->fetchrow_array; 

    $$dbdata{'pid'} = $pid;
    $$dbdata{'prjname'} = $prjname;
    $$dbdata{'prjdesc'} = $prjdesc;
    $$dbdata{'prjmail'} = $prjmail;

    $sth->fetchrow_array; 
    $sth->finish;

    # retrieve adding business groups information

    $stmt="select bgname from sysmt_bgroup bg where bgid not in ( select bgid from sysmt_prj2bgrp p2g where p2g.pid = ? ) order by bgname;";

    $sth = $dbh->prepare($stmt);
    $sth->bind_param(1, $pid, DBI::SQL_INTEGER);

    $sth->execute;
        
    my $sidname;	
    my $i=0;
    while ( ($group) = $sth->fetchrow_array) 
    {
	$$dbdata{'addbglist'}[$i] = $group;
	$i++;
    }
    
    $sth->finish;


    # retrieve adding approval business groups information

    $stmt="select bgname from sysmt_bgroup bg where bgid not in ( select bgid from sysmt_prj2workflow p2wf where p2wf.pid = ? ) order by bgname;";
    
    $sth = $dbh->prepare($stmt);
    $sth->bind_param(1, $pid, DBI::SQL_INTEGER);
    
    $sth->execute;
        
    my $i=0;
    while ( ($group) = $sth->fetchrow_array) 
    {
	$$dbdata{'addwfbglist'}[$i] = $group;
	$i++;
    }
    
    $sth->finish;


    # retrieve adding notification business groups information

    $stmt="select bgname from sysmt_bgroup bg where bgid not in ( select bgid from sysmt_prj2notification p2n where p2n.pid = ? ) order by bgname;";
    
    $sth = $dbh->prepare($stmt);
    $sth->bind_param(1, $pid, DBI::SQL_INTEGER);
    
    $sth->execute;
        
    my $i=0;
    while ( ($group) = $sth->fetchrow_array) 
    {
	$$dbdata{'addnfbglist'}[$i] = $group;
	$i++;
    }
    
    $sth->finish;

    # retrieve adding verification business groups information

    $stmt="select bgname from sysmt_bgroup bg where bgid not in ( select bgid from sysmt_prj2verification p2vf where p2vf.pid = ? ) order by bgname;";
    
    $sth = $dbh->prepare($stmt);
    $sth->bind_param(1, $pid, DBI::SQL_INTEGER);
    
    $sth->execute;
        
    my $i=0;
    while ( ($group) = $sth->fetchrow_array) 
    {
	$$dbdata{'addvfbglist'}[$i] = $group;
	$i++;
    }
    
    $sth->finish;


    # retrieve adding workflow business groups information

    $stmt="select bgname from sysmt_bgroup bg where bgid not in ( select bgid from sysmt_prj2approval p2g where p2g.pid = ? ) order by bgname;";
    
    $sth = $dbh->prepare($stmt);
    $sth->bind_param(1, $pid, DBI::SQL_INTEGER);
    
    $sth->execute;
        
    my $i=0;
    while ( ($group) = $sth->fetchrow_array) 
    {
	$$dbdata{'addappbglist'}[$i] = $group;
	$i++;
    }
    
    $sth->finish;

    my ( $headmsg, $fullname, $sysmsg )  = PerlSpace::SysMtUtil::getHeaderInfo($dbh, $user);
    $$dbdata{'headertext'} = $headmsg;
    $$dbdata{'fullname'} = $fullname;
    $$dbdata{'sysmsg'} = $sysmsg;
    $$dbdata{'content'} = "sysmt_prj.html";

    $TT ||= Template->new({ INCLUDE_PATH  => $PerlSpace::SysMtExecuter::tmplpath });
    $TT->process('sysmt_frame.html', $dbdata) || die $TT->error(), "\n";
    
    return 0;
}

sub sysmtPrjNew
{

    my ( $dbh, $user ) = @_;

    my $dbdata;

    $sth = $dbh->prepare("select bgname from sysmt_bgroup;");
    
    $sth->execute;

    my $i=0;
    while ( ($bgname) = $sth->fetchrow_array) 
    {
	$$dbdata{'bglist'}[$i] = $bgname;
	$i++;
    }
    
    $sth->finish;

    my ( $headmsg, $fullname, $sysmsg )  = PerlSpace::SysMtUtil::getHeaderInfo($dbh, $user);
    $$dbdata{'headertext'} = $headmsg;
    $$dbdata{'fullname'} = $fullname;
    $$dbdata{'sysmsg'} = $sysmsg;
    $$dbdata{'content'} = "sysmt_prjnew.html";

    $TT ||= Template->new({ INCLUDE_PATH  => $PerlSpace::SysMtExecuter::tmplpath });
    $TT->process('sysmt_frame.html', $dbdata) || die $TT->error(), "\n";
    
    return 0;
}

sub sysmtPrjCreate
{

    my ( $dbh, $user, $prjname, $prjdesc, $stmt, $ordering ) = @_;


    # trim left and right whitespaces
    $prjname =~ s/^\s+//;
    $prjname =~ s/\s+$//;

    my $dbdata;
    my $pid;
    
    if ( $PerlSpace::SysMtExecuter::db eq "cego" )
    {
	$sth = $dbh->prepare("? = call newProject ( ?, ? );");
	
	$sth->bind_param_inout(1, \$pid, 10);
	$sth->bind_param(2, $prjname, DBI::SQL_VARCHAR);
	$sth->bind_param(3, $prjdesc, DBI::SQL_VARCHAR);    
	
	$sth->execute;
	
	$sth->finish;    
    }
    elsif ( $PerlSpace::SysMtExecuter::db eq "mysql" )
    {
	$sth = $dbh->prepare("select newProject(?,?);");
	
	$sth->bind_param(1, $prjname, DBI::SQL_VARCHAR);
	$sth->bind_param(2, $prjdesc, DBI::SQL_VARCHAR);    

	$sth->execute;
	$pid = $sth->fetchrow_array;

	$sth->finish;

    }
    elsif ( $PerlSpace::SysMtExecuter::db eq "db2" )
    {
	$sth = $dbh->prepare(q{call newProject(?,?,?)});
	
	$sth->bind_param(1, $prjname, DBI::SQL_VARCHAR);
	$sth->bind_param(2, $prjdesc, DBI::SQL_VARCHAR);    
	$sth->bind_param_inout(3, \$pid, 100, DBI::SQL_INTEGER);

	$sth->execute;

	$sth->finish;

    }

    return sysmtPrj($dbh, $user, $pid, $stmt, $ordering);

}

sub sysmtPrjUpdate
{

    my ( $dbh, $user, $pid, $prjname, $prjdesc, $prjmail, $stmt, $ordering ) = @_;

        
    $sth = $dbh->prepare("update sysmt_project set prjname = ?, prjdesc = ?, prjmail = ? where pid = ?;");
     
    $sth->bind_param(1, $prjname, DBI::SQL_VARCHAR);
    $sth->bind_param(2, $prjdesc, DBI::SQL_VARCHAR);
    $sth->bind_param(3, $prjmail, DBI::SQL_VARCHAR);
    $sth->bind_param(4, $pid, DBI::SQL_INTEGER);

    $sth->execute;

    $sth->finish;    

    return sysmtPrj($dbh, $user, $pid, $stmt, $ordering);

}


sub sysmtPrjDelete
{

    my ( $dbh, $user, $pid ) = @_;


    if ( $PerlSpace::SysMtExecuter::db eq "cego" )
    {
	$sth = $dbh->prepare("call deleteProject ( ? );");
	
	$sth->bind_param(1, $pid, DBI::SQL_INTEGER);
	
	$sth->execute;

	$sth->finish;    
    }
    elsif ( $PerlSpace::SysMtExecuter::db eq "mysql" )
    {
	$sth = $dbh->prepare("select deleteProject(?);");
	$sth->bind_param(1, $pid, DBI::SQL_INTEGER);	

	$sth->execute;

	$sth->finish;

    }
    elsif ( $PerlSpace::SysMtExecuter::db eq "db2" )
    {
	$sth = $dbh->prepare(q{call deleteProject ( ? )});
	
	$sth->bind_param(1, $pid, DBI::SQL_INTEGER);
	
	$sth->execute;
	
	$sth->finish;    
    }

    return sysmtProjectMaster($dbh, $user);

}


sub sysmtPrjAdd2Grp
{

    my ( $dbh, $user, $pid, $bgname, $stmt, $ordering ) = @_;

    my $dbdata;
    
    $sth = $dbh->prepare("insert into sysmt_prj2bgrp values ( ?, ( select bgid from sysmt_bgroup where bgname = ? ));");
    
    $sth->bind_param(1, $pid, DBI::SQL_INTEGER);
    $sth->bind_param(2, $bgname, DBI::SQL_VARCHAR);


    $sth->execute;

    $sth->finish;    

    return sysmtPrj($dbh, $user, $pid, $stmt, $ordering);

}


sub sysmtPrjDelFromGrp
{

    my ( $dbh, $user, $pid, $bgname, $stmt, $ordering ) = @_;

    my $dbdata;

    $sth = $dbh->prepare("delete from sysmt_prj2bgrp where bgid = ( select bgid from sysmt_bgroup where bgname = ? ) and pid = ?;");
    
    $sth->bind_param(1, $bgname, DBI::SQL_VARCHAR);
    $sth->bind_param(2, $pid, DBI::SQL_INTEGER);

    $sth->execute;

    $sth->finish;

    return sysmtPrj($dbh, $user, $pid, $stmt, $ordering);

}

sub sysmtPrjAddApproval
{

    my ( $dbh, $user, $pid, $bgname, $stmt, $ordering ) = @_;

    my $dbdata;
    
    $sth = $dbh->prepare("insert into sysmt_prj2approval values ( ?, ( select bgid from sysmt_bgroup where bgname = ? ));");
    
    $sth->bind_param(1, $pid, DBI::SQL_INTEGER);
    $sth->bind_param(2, $bgname, DBI::SQL_VARCHAR);

    $sth->execute;

    $sth->finish;    

    return sysmtPrj($dbh, $user, $pid, $stmt, $ordering,);

}


sub sysmtPrjDelApproval
{

    my ( $dbh, $user, $pid, $bgname, $stmt, $ordering ) = @_;

    my $dbdata;

    $sth = $dbh->prepare("delete from sysmt_prj2approval where bgid = ( select bgid from sysmt_bgroup where bgname = ? ) and pid = ?;");
    
    $sth->bind_param(1, $bgname, DBI::SQL_VARCHAR);
    $sth->bind_param(2, $pid, DBI::SQL_INTEGER);

    $sth->execute;

    $sth->finish;

    return sysmtPrj($dbh, $user, $pid, $stmt, $ordering);

}


sub sysmtPrjAddNotification
{

    my ( $dbh, $user, $pid, $bgname, $stmt, $ordering ) = @_;

    my $dbdata;
    
    $sth = $dbh->prepare("insert into sysmt_prj2notification values ( ?, ( select bgid from sysmt_bgroup where bgname = ? ));");
    
    $sth->bind_param(1, $pid, DBI::SQL_INTEGER);
    $sth->bind_param(2, $bgname, DBI::SQL_VARCHAR);

    $sth->execute;

    $sth->finish;    

    return sysmtPrj($dbh, $user, $pid, $stmt, $ordering);

}


sub sysmtPrjDelNotification
{

    my ( $dbh, $user, $pid, $bgname, $stmt, $ordering ) = @_;

    my $dbdata;

    $sth = $dbh->prepare("delete from sysmt_prj2notification where bgid = ( select bgid from sysmt_bgroup where bgname = ? ) and pid = ?;");
    
    $sth->bind_param(1, $bgname, DBI::SQL_VARCHAR);
    $sth->bind_param(2, $pid, DBI::SQL_INTEGER);

    $sth->execute;

    $sth->finish;

    return sysmtPrj($dbh, $user, $pid, $stmt, $ordering);

}

sub sysmtPrjAddVerification
{

    my ( $dbh, $user, $pid, $bgname, $stmt, $ordering ) = @_;

    my $dbdata;
    
    $sth = $dbh->prepare("insert into sysmt_prj2verification values ( ?, ( select bgid from sysmt_bgroup where bgname = ? ));");
    
    $sth->bind_param(1, $pid, DBI::SQL_INTEGER);
    $sth->bind_param(2, $bgname, DBI::SQL_VARCHAR);

    $sth->execute;

    $sth->finish;    

    return sysmtPrj($dbh, $user, $pid, $stmt, $ordering);

}


sub sysmtPrjDelVerification
{

    my ( $dbh, $user, $pid, $bgname, $stmt, $ordering ) = @_;

    my $dbdata;

    $sth = $dbh->prepare("delete from sysmt_prj2verification where bgid = ( select bgid from sysmt_bgroup where bgname = ? ) and pid = ?;");
    
    $sth->bind_param(1, $bgname, DBI::SQL_VARCHAR);
    $sth->bind_param(2, $pid, DBI::SQL_INTEGER);

    $sth->execute;

    $sth->finish;

    return sysmtPrj($dbh, $user, $pid, $stmt, $ordering);

}

sub sysmtPrjAddWorkflow
{

    my ( $dbh, $user, $pid, $bgname, $seqnr, $stmt, $ordering ) = @_;

    my $dbdata;
    
    $sth = $dbh->prepare("insert into sysmt_prj2workflow values ( ?, ( select bgid from sysmt_bgroup where bgname = ? ), ?);");
    
    $sth->bind_param(1, $pid, DBI::SQL_INTEGER);
    $sth->bind_param(2, $bgname, DBI::SQL_VARCHAR);
    $sth->bind_param(3, $seqnr, DBI::SQL_INTEGER);

    $sth->execute;

    $sth->finish;    

    return sysmtPrj($dbh, $user, $pid, $stmt, $ordering);

}

sub sysmtPrjDelWorkflow
{

    my ( $dbh, $user, $pid, $bgname, $stmt, $ordering ) = @_;

    my $dbdata;

    $sth = $dbh->prepare("delete from sysmt_prj2workflow where bgid = ( select bgid from sysmt_bgroup where bgname = ? ) and pid = ?;");
    
    $sth->bind_param(1, $bgname, DBI::SQL_VARCHAR);
    $sth->bind_param(2, $pid, DBI::SQL_INTEGER);

    $sth->execute;

    $sth->finish;

    return sysmtPrj($dbh, $user, $pid, $stmt, $ordering);

}

sub sysmtProjectView
{
    
    my ( $dbh, $user ) = @_;
    
    my $stmt = "select distinct p.pid, prjname, prjdesc from sysmt_project p, sysmt_prj2bgrp p2g, sysmt_usr2bgrp u2g, sysmt_user u where p.pid = p2g.pid and p2g.bgid = u2g.bgid and u.dbuser = '" . $user . "' and u.uid = u2g.uid";
    
    my $ordering = "order by prjname";
    
    sysmtPrjExecuteList($dbh, $user, $stmt, $ordering, 0);
    
    return 0;    
}

1;
