#
# sysmt_report.pm
# --------------
#
# Design and Implementation by Bjoern Lemke               
#           
# (C)opyright 2010,2011 by Bjoern Lemke
#                                              
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2, or (at your option)
# any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; see the file COPYING.  If not, write to
# the Free Software Foundation, 59 Temple Place - Suite 330,
# Boston, MA 02111-1307, USA.
#

my $scale=2;

package PerlSpace::SysMtReport;

sub sysmtSysReportMaster
{

    my ( $dbh, $user ) = @_;

    my @sidlist = PerlSpace::SysMtUtil::getRepSidForUser($dbh, $user);
    
    $i=0;
    foreach my $sid ( @sidlist )
    {
	$$dbdata{'sidlist'}[$i] = $sid;
	$i++;
    }


    my @prjlist = PerlSpace::SysMtUtil::getRepProjectForUser($dbh, $user);
    
    $i=0;
    foreach my $prj ( @prjlist )
    {
	$$dbdata{'projectlist'}[$i] = $prj;
	$i++;
    }

    my ( $headmsg, $fullname, $sysmsg )  = PerlSpace::SysMtUtil::getHeaderInfo($dbh, $user);
    $$dbdata{'headertext'} = $headmsg;
    $$dbdata{'fullname'} = $fullname;
    $$dbdata{'sysmsg'} = $sysmsg;
    $$dbdata{'content'} = "sysmt_sysrepmaster.html";


    $TT ||= Template->new({ INCLUDE_PATH  => $PerlSpace::SysMtExecuter::tmplpath });
    $TT->process('sysmt_frame.html', $dbdata) || die $TT->error(), "\n";

    return 0;

}

sub sysmtReportForSystem
{
    
    my ( $dbh, $user, $sid ) = @_;

    my $dbdata;
    
    $$dbdata{'sid'} = $sid;

    $$dbdata{'project'} = PerlSpace::SysMtUtil::getProjectForSid($dbh, $sid);

    my $vip = PerlSpace::SysMtUtil::getVipForSid($dbh, $sid);
    $$dbdata{'vip'} = $vip;

    my $sysid = PerlSpace::SysMtUtil::getIdForSid($dbh, $sid);

    my $zoneA = PerlSpace::SysMtUtil::getValueForSys($dbh, $sysid, 'zoneA');
    my $zoneB = PerlSpace::SysMtUtil::getValueForSys($dbh, $sysid, 'zoneB');
    my $platform = PerlSpace::SysMtUtil::getValueForSys($dbh, $sysid, 'platform');

    # warn "Zone info : A=" . $zoneA . " B=" . $zoneB;


    # system retrievel
    $stmt="select hostname, hostinfo, osinfo, cpuinfo, meminfo from sysmt_host where hid in ( select hid from sysmt_vip2host where vip = ?);";

    $sth = $dbh->prepare($stmt);
    $sth->bind_param(1, $vip, DBI::SQL_VARCHAR);

    $sth->execute;

    my $i = 0;
    my @hostlist;


    while ( ($hostname, $hostinfo, $osinfo, $cpuinfo, $meminfo) = $sth->fetchrow_array) 
    {
	$hostlist[$i] = $hostname;

	$$dbdata{'hostlist'}[$i]{'vip'} = $vip;
	$$dbdata{'hostlist'}[$i]{'hostname'} = $hostname;
	$$dbdata{'hostlist'}[$i]{'hostinfo'} = $hostinfo;
	$$dbdata{'hostlist'}[$i]{'osinfo'} = $osinfo;
	$$dbdata{'hostlist'}[$i]{'cpuinfo'} = $cpuinfo;
	$$dbdata{'hostlist'}[$i]{'meminfo'} = $meminfo;
	$i++;
    }
    
    $sth->finish;
    
    if ( $platform eq "Solaris" )
    {
	
	foreach my $vip ( @hostlist )
	{
	    
	    $stmt="select hostname, hostinfo, osinfo, cpuinfo, meminfo from sysmt_host where hid in ( select hid from sysmt_vip2host where vip = ?);";
	    
	    $sth = $dbh->prepare($stmt);
	    $sth->bind_param(1, $vip, DBI::SQL_VARCHAR);
	    	    
	    $sth->execute;

	    while ( ($hostname, $hostinfo, $osinfo, $cpuinfo, $meminfo) = $sth->fetchrow_array) 
	    {
		$hostlist[$i] = $hostname;
		
		$$dbdata{'hostlist'}[$i]{'vip'} = $vip;
		$$dbdata{'hostlist'}[$i]{'hostname'} = $hostname;
		$$dbdata{'hostlist'}[$i]{'hostinfo'} = $hostinfo;
		$$dbdata{'hostlist'}[$i]{'osinfo'} = $osinfo;
		$$dbdata{'hostlist'}[$i]{'cpuinfo'} = $cpuinfo;
		$$dbdata{'hostlist'}[$i]{'meminfo'} = $meminfo;
		$i++;
	    }
	    
	    $sth->finish;
	
	}
    }
    
    # disk information retrievel
    $stmt="select sum(disksize) / ( 1024  * 1000 ), count(*) from sysmt_disk where status = 'valid' and ( upper(diskvg) like ? or upper(diskvg) like ? or diskvg = ? or diskvg = ? or diskvg = ? );";

    $sth = $dbh->prepare($stmt);
    $sth->bind_param(1, "VGSAP" . $sid . "%", DBI::SQL_VARCHAR);
    $sth->bind_param(2, "VGDB" . $sid . "%", DBI::SQL_VARCHAR);
    $sth->bind_param(3,  $zoneA . "_dg", DBI::SQL_VARCHAR);
    $sth->bind_param(4,  $zoneB . "_dg", DBI::SQL_VARCHAR);
    $sth->bind_param(5,  "vg_" . $vip , DBI::SQL_VARCHAR);
    
    $sth->execute;

    if ( ( $sodsize, $sodnum )  = $sth->fetchrow_array )
    {
	$$dbdata{'sodsize'} = $sodsize . " GB";
	$$dbdata{'sodnum'} = $sodnum;
    }
    else
    {
	$$dbdata{'sodsize'} = 'NA';
	$$dbdata{'sodnum'} = 'NA';
       
    }

    $sth->finish;

    $stmt="select sum(disksize) / ( 1024  * 1000 ), count(*) from sysmt_disk where status = 'valid' and slaid is not null and ( upper(diskvg) like ? or upper(diskvg) like ? or diskvg = ? or diskvg = ? or diskvg = ? );";

    $sth = $dbh->prepare($stmt);
    $sth->bind_param(1, "VGSAP" . $sid . "%", DBI::SQL_VARCHAR);
    $sth->bind_param(2, "VGDB" . $sid . "%", DBI::SQL_VARCHAR);
    $sth->bind_param(3,  $zoneA . "_dg", DBI::SQL_VARCHAR);
    $sth->bind_param(4,  $zoneB . "_dg", DBI::SQL_VARCHAR);
    $sth->bind_param(5,  "vg_" . $vip , DBI::SQL_VARCHAR);
    
    $sth->execute;

    if ( ( $slasize, $slanum )  = $sth->fetchrow_array )
    {	
	$$dbdata{'slasize'} = $slasize . " GB";
	$$dbdata{'slanum'} = $slanum;
    }
    else
    {
	$$dbdata{'slasize'} = 'NA';
	$$dbdata{'slanum'} = 'NA';
    }

    $sth->finish;

    $stmt="select sum(fssize) / 1000 from sysmt_filesys where sysid = ?;";

    $sth = $dbh->prepare($stmt);
    $sth->bind_param(1, $sysid, DBI::SQL_INTEGER);

    
    $sth->execute;

    if ( ( $fssize )  = $sth->fetchrow_array ) 
    {	
	$$dbdata{'fssize'} = $fssize . " GB";
    }
    else
    {
	$$dbdata{'fssize'} = 'NA';	
    }

    $sth->finish;


    my ( $headmsg, $fullname, $sysmsg )  = PerlSpace::SysMtUtil::getHeaderInfo($dbh, $user);
    $$dbdata{'headertext'} = $headmsg;
    $$dbdata{'fullname'} = $fullname;
    $$dbdata{'sysmsg'} = $sysmsg;
    $$dbdata{'content'} = "sysmt_repsys.html";


    $TT ||= Template->new({ INCLUDE_PATH  => $PerlSpace::SysMtExecuter::tmplpath });
    $TT->process('sysmt_frame.html', $dbdata) || die $TT->error(), "\n";


    return 0;

}

sub sysmtReportForProject
{
    
    my ( $dbh, $user, $prjname ) = @_;

    my $dbdata;

    $$dbdata{'project'} = $prjname;

    
    # system retrievel
    $stmt="select sid, vip from sysmt_systemview where prjname = ? order by sid;";

    $sth = $dbh->prepare($stmt);
    $sth->bind_param(1, $prjname, DBI::SQL_VARCHAR);
    
    $sth->execute;

    my $i = 0;
    while ( ( $sid, $vip) = $sth->fetchrow_array) 
    {
	$$dbdata{'syslist'}[$i]{'sid'} = $sid;
	$$dbdata{'syslist'}[$i]{'vip'} = $vip;
	$i++;
    }
    
    $sth->finish;


    $$dbdata{'sodnumsum'} = 0;
    $$dbdata{'sodsizesum'} = 0;

    my $j = 0;
    while ( $j < $ i )
    {


	my $sysid = PerlSpace::SysMtUtil::getIdForSid($dbh, $$dbdata{'syslist'}[$j]{'sid'});
	my $zoneA = PerlSpace::SysMtUtil::getValueForSys($dbh, $sysid, 'zoneA');
	my $zoneB = PerlSpace::SysMtUtil::getValueForSys($dbh, $sysid, 'zoneB');


	my $vip = PerlSpace::SysMtUtil::getVipForSid($dbh, $$dbdata{'syslist'}[$j]{'sid'});

	# disk information retrievel

	$stmt="select sum(disksize), count(*) from sysmt_disk where status = 'valid' and ( upper(diskvg) like ? or upper(diskvg) like ? or diskvg = ? or diskvg = ? or diskvg = ? );";
	
	$sth = $dbh->prepare($stmt);
	$sth->bind_param(1, "VGSAP" . $$dbdata{'syslist'}[$j]{'sid'} . "%", DBI::SQL_VARCHAR);
	$sth->bind_param(2, "VGDB" . $$dbdata{'syslist'}[$j]{'sid'} . "%", DBI::SQL_VARCHAR);
	$sth->bind_param(3,  $zoneA . "_dg", DBI::SQL_VARCHAR);
	$sth->bind_param(4,  $zoneB . "_dg", DBI::SQL_VARCHAR);
	$sth->bind_param(5,  "vg_" . $vip , DBI::SQL_VARCHAR);
	
	$sth->execute;
	
	if ( ( $sodsize, $sodnum )  = $sth->fetchrow_array )
	{	

	    if ( $sodsize )
	    {
		$sodsize = $sodsize / ( 1024  * 1000 );
		
		$$dbdata{'sodsizesum'} += $sodsize;
		$$dbdata{'sodnumsum'} += $sodnum;
		
		$$dbdata{'syslist'}[$j]{'sodsize'} = $sodsize . " GB";
		$$dbdata{'syslist'}[$j]{'sodnum'} = $sodnum;

	    }
	}
	else
	{
	    $$dbdata{'syslist'}[$j]{'sodsize'} = 'NA';
	    $$dbdata{'syslist'}[$j]{'sodnum'} = 'NA';	    
	}

	$sth->finish;

	# sla disks
	$stmt="select sum(disksize), count(*) from sysmt_disk where status = 'valid' and slaid is not null and ( upper(diskvg) like ? or upper(diskvg) like ? or diskvg = ? or diskvg = ? or diskvg = ? );";
	
	$sth = $dbh->prepare($stmt);
	$sth->bind_param(1, "VGSAP" . $$dbdata{'syslist'}[$j]{'sid'} . "%", DBI::SQL_VARCHAR);
	$sth->bind_param(2, "VGDB" . $$dbdata{'syslist'}[$j]{'sid'} . "%", DBI::SQL_VARCHAR);
	$sth->bind_param(3,  $zoneA . "_dg", DBI::SQL_VARCHAR);
	$sth->bind_param(4,  $zoneB . "_dg", DBI::SQL_VARCHAR);
	$sth->bind_param(5,  "vg_" . $vip , DBI::SQL_VARCHAR);

	$sth->execute;

	if ( ( $slasize, $slanum )  = $sth->fetchrow_array )
	{	

	    if ( $slasize )
	    {
		$slasize = $slasize / ( 1024  * 1000 );
		$$dbdata{'slasizesum'} += $slasize;
		$$dbdata{'slanumsum'} += $slanum;
		
		$$dbdata{'syslist'}[$j]{'slasize'} = $slasize . " GB";
		$$dbdata{'syslist'}[$j]{'slanum'} = $slanum;	    
	    }
	}
	else
	{
	    $$dbdata{'syslist'}[$j]{'slasize'} = 'NA';
	    $$dbdata{'syslist'}[$j]{'slanum'} = 'NA';	    	   
	}
	$sth->finish;

	$j++;
    }

    $$dbdata{'sodsizesum'} = $$dbdata{'sodsizesum'} . " GB";
    $$dbdata{'slasizesum'} = $$dbdata{'slasizesum'} . " GB";


    my ( $headmsg, $fullname, $sysmsg )  = PerlSpace::SysMtUtil::getHeaderInfo($dbh, $user);
    $$dbdata{'headertext'} = $headmsg;
    $$dbdata{'fullname'} = $fullname;
    $$dbdata{'sysmsg'} = $sysmsg;
    $$dbdata{'content'} = "sysmt_repprj.html";


    $TT ||= Template->new({ INCLUDE_PATH  => $PerlSpace::SysMtExecuter::tmplpath });
    $TT->process('sysmt_frame.html', $dbdata) || die $TT->error(), "\n";

    return 0;

}

1;
