#
# sysmt_resource.pm
# -----------------
#
# Design and Implementation by Bjoern Lemke               
#           
# (C)opyright 2011,2012 by Bjoern Lemke
#                                              
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2, or (at your option)
# any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; see the file COPYING.  If not, write to
# the Free Software Foundation, 59 Temple Place - Suite 330,
# Boston, MA 02111-1307, USA.
#

package PerlSpace::SysMtResource;


############################
### resource methods ###
############################

sub sysmtResourceMaster
{
    
    my ( $dbh, $user ) = @_;
    
    my $stmt;
    my $dbdata;

    my ( $headmsg, $fullname, $sysmsg )  = PerlSpace::SysMtUtil::getHeaderInfo($dbh, $user);
    $$dbdata{'headertext'} = $headmsg;
    $$dbdata{'fullname'} = $fullname;
    $$dbdata{'sysmsg'} = $sysmsg;
    $$dbdata{'content'} = "sysmt_resmaster.html";

    $TT ||= Template->new({ INCLUDE_PATH  => $PerlSpace::SysMtExecuter::tmplpath });
    $TT->process('sysmt_frame.html', $dbdata) || die $TT->error(), "\n";
    
    return 0;
    
}

sub sysmtResourcePlanMaster
{
    
    my ( $dbh, $user ) = @_;
    
    my $stmt;
    my $dbdata;

    my $sth = $dbh->prepare("select resname from sysmt_resource;");
    $sth->execute;    
    my $i=0;
    while ( (my $resname) = $sth->fetchrow_array) 
    {
	$$dbdata{'reslist'}[$i]{'resname'} = $resname;
	$i++;
    }    
    $sth->finish;    

    $TT ||= Template->new({ INCLUDE_PATH  => $PerlSpace::SysMtExecuter::tmplpath });
    $TT->process('sysmt_resmaster.html', $dbdata);
    
    return 0;
    
}

sub sysmtResourcePlanListByName
{
    
    my ( $dbh, $user, $resname ) = @_;

    my $sth = $dbh->prepare("select resname, resfrom, resto, activity from sysmt_resplanview where resname = ?;");
    $sth->bind_param(1, $resname, DBI::SQL_VARCHAR);
    $sth->execute;
    
    my $i=0;
    while ( (my $resname, $resfrom, $resto, $activity ) = $sth->fetchrow_array) 
    {

	$$dbdata{'rpelist'}[$i]{'resname'} = $resname;
	$$dbdata{'rpelist'}[$i]{'resfrom'} = $resfrom;
	$$dbdata{'rpelist'}[$i]{'resto'} = $resto;
	$$dbdata{'rpelist'}[$i]{'activity'} = $activity;
	$i++;
    }
    
    $sth->finish;    

    my ( $headmsg, $fullname, $sysmsg )  = PerlSpace::SysMtUtil::getHeaderInfo($dbh, $user);
    $$dbdata{'headertext'} = $headmsg;
    $$dbdata{'fullname'} = $fullname;
    $$dbdata{'sysmsg'} = $sysmsg;
    $$dbdata{'content'} = "sysmt_rpelist.html";

    $TT ||= Template->new({ INCLUDE_PATH  => $PerlSpace::SysMtExecuter::tmplpath });
    $TT->process('sysmt_frame.html', $dbdata) || die $TT->error(), "\n";


    return 0;
}



sub sysmtResourceList
{
    
    my ( $dbh, $user, $resname) = @_;    

    my $stmt = "select resid, resname from sysmt_resource where resname like '%" . $resname . "%'";    
    my $ordering = "order by resname";
 
    sysmtResourceSearchExecuteList($dbh, $user, $stmt, $ordering);

    return 0;    

}

sub sysmtResourceSearchExecuteList
{
    
    my ( $dbh, $user, $stmt, $ordering ) = @_;

    my $sth = $dbh->prepare($stmt . " " . $ordering . ";");

    $sth->execute;
    
    my $dbdata;

    $$dbdata{'stmt'} = $stmt;

    my $resid;
    my $resname;
    
    my $i=0;
    while ( ($resid, $resname ) = $sth->fetchrow_array) 
    {

	$$dbdata{'reslist'}[$i]{'resid'} = $resid;
	$$dbdata{'reslist'}[$i]{'resname'} = $resname;

	$i++;
    }
    
    $sth->finish;    

    my ( $headmsg, $fullname, $sysmsg )  = PerlSpace::SysMtUtil::getHeaderInfo($dbh, $user);
    $$dbdata{'headertext'} = $headmsg;
    $$dbdata{'fullname'} = $fullname;
    $$dbdata{'sysmsg'} = $sysmsg;
    $$dbdata{'content'} = "sysmt_reslist.html";

    $TT ||= Template->new({ INCLUDE_PATH  => $PerlSpace::SysMtExecuter::tmplpath });
    $TT->process('sysmt_frame.html', $dbdata) || die $TT->error(), "\n";

    return 0;
}


sub sysmtResource
{    
    my ( $dbh, $user, $resid ) = @_;
    
    my $dbdata;

    $stmt="select resname, resdesc from sysmt_resource where resid = ?;";
    $sth = $dbh->prepare($stmt);
    $sth->bind_param(1, $resid, DBI::SQL_INTEGER);
    
    $sth->execute;

    ( $resname, $resdesc ) = $sth->fetchrow_array;     
    
    $sth->finish;

    $$dbdata{'resid'} = $resid;
    $$dbdata{'resname'} = $resname;
    $$dbdata{'resdesc'} = $resdesc;


    # reached projects retrievel
    $stmt="select prjname from sysmt_project prj where pid in ( select pid from sysmt_res2prj r2p where r2p.resid = ? ) order by prjname;";
    $sth = $dbh->prepare($stmt);
    $sth->bind_param(1, $resid, DBI::SQL_INTEGER);

    $sth->execute;
        
    my $projects = "";
    $$dbdata{'projects'} = "";
    $i=0;
    while ( ($prjname) = $sth->fetchrow_array) 
    {

	$$dbdata{'delprjlist'}[$i] = $prjname;

	if ( $$dbdata{'projects'} eq "" )
	{
	    $$dbdata{'projects'} = $prjname;
	}
	else
	{
	    $$dbdata{'projects'} = $$dbdata{'projects'} . "," . $prjname;
	}
	$i++;
    }
    
    $sth->finish;    

    # retrieve adding project information

    $stmt="select prjname from sysmt_project p where pid not in ( select pid from sysmt_res2prj r2p where r2p.resid = ? ) order by prjname;";

    $sth = $dbh->prepare($stmt);
    $sth->bind_param(1, $resid, DBI::SQL_INTEGER);

    $sth->execute;
        
    my $i=0;
    while ( ($prjname) = $sth->fetchrow_array) 
    {
	$$dbdata{'addprjlist'}[$i] = $prjname;
	$i++;
    }
    
    $sth->finish;

    # reached skills retrievel
    $stmt="select skname from sysmt_skill sk where skid in ( select skid from sysmt_res2skill r2sk where r2sk.resid = ? ) order by skname;";
    $sth = $dbh->prepare($stmt);
    $sth->bind_param(1, $resid, DBI::SQL_INTEGER);

    $sth->execute;
        
    my $projects = "";
    $$dbdata{'skills'} = "";
    $i=0;
    while ( ($sk) = $sth->fetchrow_array) 
    {

	$$dbdata{'delsklist'}[$i] = $sk;

	if ( $$dbdata{'skills'} eq "" )
	{
	    $$dbdata{'skills'} = $sk;
	}
	else
	{
	    $$dbdata{'skills'} = $$dbdata{'skills'} . "," . $sk;
	}
	$i++;
    }
    
    $sth->finish;    

    # retrieve adding skill information

    $stmt="select skname from sysmt_skill sk where skid not in ( select skid from sysmt_res2skill r2sk where r2sk.resid = ? ) order by skname;";

    $sth = $dbh->prepare($stmt);
    $sth->bind_param(1, $resid, DBI::SQL_INTEGER);

    $sth->execute;
        
    my $i=0;
    while ( ($skname) = $sth->fetchrow_array) 
    {
	$$dbdata{'addsklist'}[$i] = $skname;
	$i++;
    }
    
    $sth->finish;

    my ( $headmsg, $fullname, $sysmsg )  = PerlSpace::SysMtUtil::getHeaderInfo($dbh, $user);
    $$dbdata{'headertext'} = $headmsg;
    $$dbdata{'fullname'} = $fullname;
    $$dbdata{'sysmsg'} = $sysmsg;
    $$dbdata{'content'} = "sysmt_res.html";

    $TT ||= Template->new({ INCLUDE_PATH  => $PerlSpace::SysMtExecuter::tmplpath });
    $TT->process('sysmt_frame.html', $dbdata) || die $TT->error(), "\n";

    
    return 0;
    
}

sub sysmtResourceNew
{

    my ( $dbh, $user ) = @_;

    my $dbdata;


    my ( $headmsg, $fullname, $sysmsg )  = PerlSpace::SysMtUtil::getHeaderInfo($dbh, $user);
    $$dbdata{'headertext'} = $headmsg;
    $$dbdata{'fullname'} = $fullname;
    $$dbdata{'sysmsg'} = $sysmsg;
    $$dbdata{'content'} = "sysmt_resnew.html";

    $TT ||= Template->new({ INCLUDE_PATH  => $PerlSpace::SysMtExecuter::tmplpath });
    $TT->process('sysmt_frame.html', $dbdata) || die $TT->error(), "\n";
    
    return 0;
}


sub sysmtResourceCreate
{

    my ( $dbh, $user, $resname, $resdesc) = @_;

    my $dbdata;

    my $resid;

    # trim left and right whitespaces
    $resname =~ s/^\s+//;
    $resname =~ s/\s+$//;


    if ( $PerlSpace::SysMtExecuter::db eq "cego" )
    {

	$sth = $dbh->prepare("? = call newResource ( ?, ? );");
	
	$sth->bind_param_inout(1, \$resid, 10);
	$sth->bind_param(2, $resname, DBI::SQL_VARCHAR);
	$sth->bind_param(3, $resdesc, DBI::SQL_VARCHAR);
	
	$sth->execute;

    }
    elsif ( $PerlSpace::SysMtExecuter::db eq "mysql" )
    {
	$sth = $dbh->prepare("select newResource(?,?);");

	$sth->bind_param(1, $resname, DBI::SQL_VARCHAR);
	$sth->bind_param(2, $resdesc, DBI::SQL_VARCHAR);
	
	$sth->execute;
	$resid = $sth->fetchrow_array;	
    }
    elsif ( $PerlSpace::SysMtExecuter::db eq "db2" )
    {
	$sth = $dbh->prepare(q{call newResource(?,?,?)});

	$sth->bind_param(1, $resname, DBI::SQL_VARCHAR);
	$sth->bind_param(2, $resdesc, DBI::SQL_VARCHAR);
	$sth->bind_param_inout(3, \$resid, 100, DBI::SQL_INTEGER);

	$sth->execute;
    }

    $sth->finish;    

    return sysmtResource($dbh, $user, $resid);

}

sub sysmtResourceUpdate
{

    my ( $dbh, $user, $resid, $resname, $resdesc ) = @_;

    my $dbdata;

    $sth = $dbh->prepare("update sysmt_resource set resname = ?, resdesc = ? where resid = ?;");

    $sth->bind_param(1, $resname, DBI::SQL_VARCHAR);
    $sth->bind_param(2, $resdesc, DBI::SQL_VARCHAR);
    $sth->bind_param(3, $resid, DBI::SQL_INTEGER);

    $sth->execute;

    $sth->finish;    

    return sysmtResource($dbh, $user, $resid);

}


sub sysmtResourceDelete
{

    my ( $dbh, $user, $resid ) = @_;

    my $dbdata;

    $sth = $dbh->prepare("delete from sysmt_resourceplan where resid = ?;");
   
    $sth->bind_param(1, $resid, DBI::SQL_INTEGER);

    $sth->execute;

    $sth->finish;    

    $sth = $dbh->prepare("delete from sysmt_resource where resid = ?;");
   
    $sth->bind_param(1, $resid, DBI::SQL_INTEGER);

    $sth->execute;

    $sth->finish;    

    return sysmtResourceMaster($dbh, $user);

}


sub sysmtResourceAdd2Project
{

    my ( $dbh, $user, $resid, $prjname ) = @_;

    my $dbdata;
    
    $sth = $dbh->prepare("insert into sysmt_res2prj values ( ?, ( select pid from sysmt_project where prjname = ? ));");
    
    $sth->bind_param(1, $resid, DBI::SQL_INTEGER);
    $sth->bind_param(2, $prjname, DBI::SQL_VARCHAR);

    $sth->execute;

    $sth->finish;    

    return sysmtResource($dbh, $user, $resid);

}


sub sysmtResourceDelFromProject
{

    my ( $dbh, $user, $resid, $prjname ) = @_;

    my $dbdata;

    $sth = $dbh->prepare("delete from sysmt_res2prj where pid = ( select pid from sysmt_project where prjname = ? ) and resid = ?;");
    
    $sth->bind_param(1, $prjname, DBI::SQL_VARCHAR);
    $sth->bind_param(2, $resid, DBI::SQL_INTEGER);

    $sth->execute;

    $sth->finish;

    return sysmtResource($dbh, $user, $resid);

}

sub sysmtResourceAdd2Skill
{

    my ( $dbh, $user, $resid, $skname ) = @_;

    my $dbdata;
    
    $sth = $dbh->prepare("insert into sysmt_res2skill values ( ?, ( select skid from sysmt_skill where skname = ? ));");
    
    $sth->bind_param(1, $resid, DBI::SQL_INTEGER);
    $sth->bind_param(2, $skname, DBI::SQL_VARCHAR);

    $sth->execute;

    $sth->finish;    

    return sysmtResource($dbh, $user, $resid);

}


sub sysmtResourceDelFromSkill
{

    my ( $dbh, $user, $resid, $skname ) = @_;

    my $dbdata;

    $sth = $dbh->prepare("delete from sysmt_res2skill where skid = ( select skid from sysmt_skill where skname = ? ) and resid = ?;");
    
    $sth->bind_param(1, $skname, DBI::SQL_VARCHAR);
    $sth->bind_param(2, $resid, DBI::SQL_INTEGER);

    $sth->execute;

    $sth->finish;

    return sysmtResource($dbh, $user, $resid);

}


########################
### skill methods ###
########################


sub sysmtSkillList
{
    
    my ( $dbh, $user, $skname) = @_;    

    my $stmt = "select skid, skname from sysmt_skill where skname like '%" . $skname . "%'";    
    my $ordering = "order by skname";
 
    sysmtSkillSearchExecuteList($dbh, $user, $stmt, $ordering);

    return 0;    

}

sub sysmtSkillSearchExecuteList
{
    
    my ( $dbh, $user, $stmt, $ordering ) = @_;

    my $sth = $dbh->prepare($stmt . " " . $ordering . ";");

    $sth->execute;
    
    my $dbdata;

    $$dbdata{'stmt'} = $stmt;

    my $psid;
    my $psname;
    
    my $i=0;
    while ( ($skid, $skname ) = $sth->fetchrow_array) 
    {

	$$dbdata{'sklist'}[$i]{'skid'} = $skid;
	$$dbdata{'sklist'}[$i]{'skname'} = $skname;

	$i++;
    }
    
    $sth->finish;    

    my ( $headmsg, $fullname, $sysmsg )  = PerlSpace::SysMtUtil::getHeaderInfo($dbh, $user);
    $$dbdata{'headertext'} = $headmsg;
    $$dbdata{'fullname'} = $fullname;
    $$dbdata{'sysmsg'} = $sysmsg;
    $$dbdata{'content'} = "sysmt_sklist.html";

    $TT ||= Template->new({ INCLUDE_PATH  => $PerlSpace::SysMtExecuter::tmplpath });
    $TT->process('sysmt_frame.html', $dbdata) || die $TT->error(), "\n";


    return 0;
}


sub sysmtSkill
{    
    my ( $dbh, $user, $skid ) = @_;
    
    my $dbdata;

    $stmt="select skname, skdesc from sysmt_skill where skid = ?;";
    $sth = $dbh->prepare($stmt);
    $sth->bind_param(1, $skid, DBI::SQL_INTEGER);
    
    $sth->execute;

    ( $skname, $skdesc ) = $sth->fetchrow_array;     
    
    $sth->finish;

    $$dbdata{'skid'} = $skid;
    $$dbdata{'skname'} = $skname;
    $$dbdata{'skdesc'} = $skdesc;

    $sth->finish;    

    my ( $headmsg, $fullname, $sysmsg )  = PerlSpace::SysMtUtil::getHeaderInfo($dbh, $user);
    $$dbdata{'headertext'} = $headmsg;
    $$dbdata{'fullname'} = $fullname;
    $$dbdata{'sysmsg'} = $sysmsg;
    $$dbdata{'content'} = "sysmt_sk.html";

    $TT ||= Template->new({ INCLUDE_PATH  => $PerlSpace::SysMtExecuter::tmplpath });
    $TT->process('sysmt_frame.html', $dbdata) || die $TT->error(), "\n";

    return 0;
        
}

sub sysmtSkillNew
{

    my ( $dbh, $user ) = @_;

    my $dbdata;

    my ( $headmsg, $fullname, $sysmsg )  = PerlSpace::SysMtUtil::getHeaderInfo($dbh, $user);
    $$dbdata{'headertext'} = $headmsg;
    $$dbdata{'fullname'} = $fullname;
    $$dbdata{'sysmsg'} = $sysmsg;
    $$dbdata{'content'} = "sysmt_sknew.html";

    $TT ||= Template->new({ INCLUDE_PATH  => $PerlSpace::SysMtExecuter::tmplpath });
    $TT->process('sysmt_frame.html', $dbdata) || die $TT->error(), "\n";
    
    return 0;
    
}


sub sysmtSkillCreate
{

    my ( $dbh, $user, $skname, $skdesc) = @_;

    my $dbdata;

    my $skid;

    # trim left and right whitespaces
    $skname =~ s/^\s+//;
    $skname =~ s/\s+$//;

    if ( $PerlSpace::SysMtExecuter::db eq "cego" )
    {

	$sth = $dbh->prepare("? = call newSkill ( ?, ? );");
	
	$sth->bind_param_inout(1, \$skid, 10);
	$sth->bind_param(2, $skname, DBI::SQL_VARCHAR);
	$sth->bind_param(3, $skdesc, DBI::SQL_VARCHAR);
	
        $sth->execute;

    }
    elsif ( $PerlSpace::SysMtExecuter::db eq "mysql" )
    {
	$sth = $dbh->prepare("select newSkill(?,?);");

	$sth->bind_param(1, $skname, DBI::SQL_VARCHAR);
	$sth->bind_param(2, $skdesc, DBI::SQL_VARCHAR);
	
	$sth->execute;
	$skid = $sth->fetchrow_array;	
    }
    elsif ( $PerlSpace::SysMtExecuter::db eq "db2" )
    {
	$sth = $dbh->prepare(q{call newSkill(?,?,?)});

	$sth->bind_param(1, $skname, DBI::SQL_VARCHAR);
	$sth->bind_param(2, $skdesc, DBI::SQL_VARCHAR);
	$sth->bind_param_inout(3, \$skid, 100, DBI::SQL_INTEGER);
    
        $sth->execute;

    }
    $sth->finish;    

    return sysmtSkill($dbh, $user, $skid);

}

sub sysmtSkillUpdate
{

    my ( $dbh, $user, $skid, $skname, $skdesc ) = @_;

    my $dbdata;

    $sth = $dbh->prepare("update sysmt_skill set skname = ?, skdesc = ? where skid = ?;");

    $sth->bind_param(1, $skname, DBI::SQL_VARCHAR);
    $sth->bind_param(2, $skdesc, DBI::SQL_VARCHAR);
    $sth->bind_param(3, $skid, DBI::SQL_INTEGER);

    $sth->execute;

    $sth->finish;    

    return sysmtSkill($dbh, $user, $skid);

}


sub sysmtSkillDelete
{

    my ( $dbh, $user, $skid ) = @_;

    my $dbdata;

    $sth = $dbh->prepare("delete from sysmt_res2skill where skid = ?;");
   
    $sth->bind_param(1, $skid, DBI::SQL_INTEGER);

    $sth->execute;

    $sth->finish;    

    $sth = $dbh->prepare("delete from sysmt_skill where skid = ?;");
   
    $sth->bind_param(1, $skid, DBI::SQL_INTEGER);

    $sth->execute;

    $sth->finish;    

    return sysmtResourceMaster($dbh, $user);

}

sub sysmtResourceStatMaster
{

    my ( $dbh, $user) = @_;

    if ( PerlSpace::SysMtUtil::checkResourceRead($dbh, $user) == 0 )
    {
        die "No appropriate right\n";
    }

    $$dbdata{'curmonth'} = PerlSpace::SysMtUtil::getCurrentMonth();
    $$dbdata{'curyear'} = PerlSpace::SysMtUtil::getCurrentYear();    

    my ( $headmsg, $fullname, $sysmsg )  = PerlSpace::SysMtUtil::getHeaderInfo($dbh, $user);
    $$dbdata{'headertext'} = $headmsg;
    $$dbdata{'fullname'} = $fullname;
    $$dbdata{'sysmsg'} = $sysmsg;
    $$dbdata{'content'} = "sysmt_resstatmaster.html";
    
    $TT ||= Template->new({ INCLUDE_PATH  => $PerlSpace::SysMtExecuter::tmplpath });
    $TT->process('sysmt_frame.html', $dbdata) || die $TT->error(), "\n";
    
    return 0;

    
}

sub sysmtResourceStat
{
    
    my ( $dbh, $user, $month, $year ) = @_;

    my $rh=12; # bar height
    my $hs=3; # hour step

    my $startdate = "01." . $month . "." . $year . " 0:00:00";

    $stmt="select resid, resname from sysmt_resource;";
    $sth = $dbh->prepare($stmt);
    $sth->execute;

    my @residx;

    my $i=0;
    while ( my ( $resid, $resname)  = $sth->fetchrow_array )
    {
	$residx[$i]{'resid'} = $resid;
	$residx[$i]{'resname'} = $resname;
	$i++;
    }
    $sth->finish;

    my @daylist = PerlSpace::SysMtUtil::getDayList($year, $month);


    my $maxh= 24 * ( $#daylist + 1 ); 
    
    my $maxpos=0;
    for ( my $h=0; $h<$maxh; $h=$h+$hs)
    {
	$maxpos++;
    }
    $maxpos--;

    $$dbdata{'maxpos'} = $maxpos;
    $$dbdata{'month'} = $month;
    $$dbdata{'year'} = $year;


    # setting up scale
    $$dbdata{'scalelist'}[0]{'span'} = 1;
    $$dbdata{'scalelist'}[0]{'day'} = "Day";
    
    my $i=1;
    for ( my $h=0; $h<$maxh; $h=$h+$hs)
    {
	if ( $h % 24 == 0)
	{
	    $$dbdata{'scalelist'}[$i]{'span'} = 24 / $hs;
	    $$dbdata{'scalelist'}[$i]{'day'} = $i;
	    $i++;
	}
    }


    my $pos=0;
    for ( my $h=0; $h<$maxh; $h=$h+$hs)
    {

	$sec=$h*3600;
	$tosec=($h + $hs)*3600;

	# get resource for the current hour

	my @booklist;
	
	my $stmt="select resid, resname from sysmt_resplanview wpv where \
                  ( resfrom > int2date(date2int(date('%d.%m.%Y %H:%M:%S', ?)) + ?) \
                  and resfrom < int2date(date2int(date('%d.%m.%Y %H:%M:%S', ?)) + ?)) or \
                  ( resto > int2date(date2int(date('%d.%m.%Y %H:%M:%S', ?)) + ?) \
                  and resto < int2date(date2int(date('%d.%m.%Y %H:%M:%S', ?)) + ?)) or \
                  ( resfrom < int2date(date2int(date('%d.%m.%Y %H:%M:%S', ?)) + ?) \
                  and resto > int2date(date2int(date('%d.%m.%Y %H:%M:%S', ?)) + ?));";

	my $sth = $dbh->prepare($stmt);

	$sth->bind_param(1, $startdate, DBI::SQL_VARCHAR);
	$sth->bind_param(2, $sec, DBI::SQL_INTEGER);
	$sth->bind_param(3, $startdate, DBI::SQL_VARCHAR);
	$sth->bind_param(4, $tosec, DBI::SQL_INTEGER);

	$sth->bind_param(5, $startdate, DBI::SQL_VARCHAR);
	$sth->bind_param(6, $sec, DBI::SQL_INTEGER);
	$sth->bind_param(7, $startdate, DBI::SQL_VARCHAR);
	$sth->bind_param(8, $tosec, DBI::SQL_INTEGER);

	$sth->bind_param(9, $startdate, DBI::SQL_VARCHAR);
	$sth->bind_param(10, $sec, DBI::SQL_INTEGER);
	$sth->bind_param(11, $startdate, DBI::SQL_VARCHAR);
	$sth->bind_param(12, $tosec, DBI::SQL_INTEGER);



	$sth->execute;
        
	$i=0;
	while ( ($resid, $resname ) = $sth->fetchrow_array) 
	{       
	    # warn "Fetch resource " . $resname;
	    $booklist[$i]{'resid'} = $resid;
	    $booklist[$i]{'resname'} = $resname;
	    $i++;
	}
	
	$sth->finish;    

	for ( my $r=0; $r<=$#residx; $r++)
	{
	    $i=($r*($maxpos+1))+$pos;

	    # warn "Setting pos " . $pos . " max pos = " . $maxpos;

	    $$dbdata{'reslist'}[$i]{'respos'} = $pos;
	    $$dbdata{'reslist'}[$i]{'resw'} = $hs;
	    $$dbdata{'reslist'}[$i]{'resh'} = $rh;
	    $$dbdata{'reslist'}[$i]{'resstat'} = "free";

	    if ( $pos == 0 )
	    {
		# warn "Setting res " . $residx[$r]{'resname'};

		$$dbdata{'reslist'}[$i]{'resname'} = $residx[$r]{'resname'};
	    }

	    for ( my $j=0; $j<=$#booklist; $j++)
	    {
		if ( $booklist[$j]{'resid'} == $residx[$r]{'resid'} )
		{
		    $$dbdata{'reslist'}[$i]{'resstat'} = "occupied";
		}
	    }
	}

	$pos++;

    }    

    my ( $headmsg, $fullname, $sysmsg )  = PerlSpace::SysMtUtil::getHeaderInfo($dbh, $user);
    $$dbdata{'headertext'} = $headmsg;
    $$dbdata{'fullname'} = $fullname;
    $$dbdata{'sysmsg'} = $sysmsg;
    $$dbdata{'content'} = "sysmt_resstat.html";
    
    $TT ||= Template->new({ INCLUDE_PATH  => $PerlSpace::SysMtExecuter::tmplpath });
    $TT->process('sysmt_frame.html', $dbdata) || die $TT->error(), "\n";

    return 0;
}


1;
