#
# sysmt_sla.pm
# ------------
#
# Design and Implementation by Bjoern Lemke               
#           
# (C)opyright 2010,2011 by Bjoern Lemke
#                                              
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2, or (at your option)
# any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; see the file COPYING.  If not, write to
# the Free Software Foundation, 59 Temple Place - Suite 330,
# Boston, MA 02111-1307, USA.
#

my $scale=2;

package PerlSpace::SysMtSLA;

sub sysmtSLAMaster
{

    my ( $dbh, $user ) = @_;


    my @sidlist = PerlSpace::SysMtUtil::getSLASidForUser($dbh, $user);

    $i=0;
    foreach my $sid ( @sidlist )
    {
	$$dbdata{'sidlist'}[$i] = $sid;
	$i++;
    }

    my @prjlist = PerlSpace::SysMtUtil::getSLAProjectForUser($dbh, $user);
    
    $i=0;
    foreach my $prj ( @prjlist )
    {
	$$dbdata{'projectlist'}[$i] = $prj;
	$i++;
    }

    my ( $headmsg, $fullname, $sysmsg )  = PerlSpace::SysMtUtil::getHeaderInfo($dbh, $user);
    $$dbdata{'headertext'} = $headmsg;
    $$dbdata{'fullname'} = $fullname;
    $$dbdata{'sysmsg'} = $sysmsg;
    $$dbdata{'content'} = "sysmt_slamaster.html";

    $TT ||= Template->new({ INCLUDE_PATH  => $PerlSpace::SysMtExecuter::tmplpath });
    $TT->process('sysmt_frame.html', $dbdata) || die $TT->error(), "\n";

    return 0;

}

sub sysmtSLAListByName
{
    
    my ( $dbh, $user, $slanr ) = @_;

    
    my $sth = $dbh->prepare("select slaid, slanr, shortdesc from sysmt_sla where slanr like ? order by slanr;");
    $sth->bind_param(1, "%" . $slanr . "%", DBI::SQL_VARCHAR);

    sysmtSLAExecuteList($dbh, $user, $sth, 1);


    return 0;    
}

sub sysmtSLAListByProject
{
    
    my ( $dbh, $user, $user, $project ) = @_;
    
    my $sth = $dbh->prepare("select sl.slaid, sl.slanr, shortdesc from sysmt_sla sl, sysmt_sla2prj s2p, sysmt_project p where prjname= ? and p.pid = s2p.pid and s2p.slaid = sl.slaid order by slanr;");
    $sth->bind_param(1, $project, DBI::SQL_VARCHAR);

    sysmtSLAExecuteList($dbh, $user, $sth, 1);

    return 0;    
}

sub sysmtSLAListBySid
{
    
    my ( $dbh, $user, $sid ) = @_;
    
    my $sth = $dbh->prepare("select sl.slaid, slanr, shortdesc from sysmt_sla sl, sysmt_sla2prj s2p, sysmt_system s where s.sid= ? and s.pid = s2p.pid and s2p.slaid = sl.slaid order by slanr;");
    $sth->bind_param(1, $sid, DBI::SQL_VARCHAR);

    sysmtSLAExecuteList($dbh, $user, $sth, 1);

    return 0;
}

sub sysmtSLAExecuteList
{
    
    my ( $dbh, $user, $sth ) = @_;

    $sth->execute;

    my $dbdata;

    my $slaid;
    my $slanr;
    my $shortdesc;    
    
    my $i=0;
    while ( ($slaid, $slanr, $shortdesc ) = $sth->fetchrow_array) 
    {
	$$dbdata{'slalist'}[$i]{'slaid'} = $slaid;
	$$dbdata{'slalist'}[$i]{'slanr'} = $slanr;
	$$dbdata{'slalist'}[$i]{'shortdesc'} = $shortdesc;
	$i++;
    }
    
    $sth->finish;

    my ( $headmsg, $fullname, $sysmsg )  = PerlSpace::SysMtUtil::getHeaderInfo($dbh, $user);
    $$dbdata{'headertext'} = $headmsg;
    $$dbdata{'fullname'} = $fullname;
    $$dbdata{'sysmsg'} = $sysmsg;
    $$dbdata{'content'} = "sysmt_slalist.html";

    $TT ||= Template->new({ INCLUDE_PATH  => $PerlSpace::SysMtExecuter::tmplpath });
    $TT->process('sysmt_frame.html', $dbdata) || die $TT->error(), "\n";

    return 0;

}

sub sysmtSLA
{
    
    my ( $dbh, $user, $slaid, $lastquery, $ordering ) = @_;
    
    my $dbdata;

    $$dbdata{'stmt'} = $lastquery;
    $$dbdata{'ordering'} = $ordering;
    $$dbdata{'user'} = $user;

    my $sth;

    # adding projects retrievel
    $stmt="select prjname from sysmt_project where pid not in ( select pid from sysmt_sla2prj where slaid = ?) order by prjname;";
    $sth = $dbh->prepare($stmt);
    $sth->bind_param(1, $slaid, DBI::SQL_INTEGER);
    
    $sth->execute;

    my $i=0;
    my $prjname;
    while ( ($prjname) = $sth->fetchrow_array) 
    {
	$$dbdata{'addprjlist'}[$i] = $prjname;
	$i++;
    }
    
    $sth->finish;    

    # removing projects retrievel
    $stmt="select prjname from sysmt_project where pid in ( select pid from sysmt_sla2prj where slaid = ?) order by prjname;";
    $sth = $dbh->prepare($stmt);
    $sth->bind_param(1, $slaid, DBI::SQL_INTEGER);
    
    $sth->execute;

    $$dbdata{'slaprj'} = "";
    $i=0;
    while ( ($prjname) = $sth->fetchrow_array) 
    {
	$$dbdata{'delprjlist'}[$i] = $prjname;

	if ( $$dbdata{'slaprj'} eq "" )
	{
	    $$dbdata{'slaprj'} = $prjname;
	}
	else
	{
	    $$dbdata{'slaprj'} = $$dbdata{'slaprj'} . ", " . $prjname;
	}

	$i++;
    }
    
    $sth->finish;    

    $sth = $dbh->prepare("select slaid, slanr, shortdesc from sysmt_sla where slaid = ?;");
    $sth->bind_param(1, $slaid, DBI::SQL_INTEGER);
    
    $sth->execute;
    

    my $slaid;
    my $slanr;
    my $shortdesc;
    my $prjname;


    ( $slaid, $slanr, $shortdesc ) = $sth->fetchrow_array; 

    $$dbdata{'slaid'} = $slaid;
    $$dbdata{'slanr'} = $slanr;
    $$dbdata{'shortdesc'} = $shortdesc;

    
    $sth->fetchrow_array; 
    $sth->finish;


    my ( $headmsg, $fullname, $sysmsg )  = PerlSpace::SysMtUtil::getHeaderInfo($dbh, $user);
    $$dbdata{'headertext'} = $headmsg;
    $$dbdata{'fullname'} = $fullname;
    $$dbdata{'sysmsg'} = $sysmsg;
    $$dbdata{'content'} = "sysmt_sla.html";

    $TT ||= Template->new({ INCLUDE_PATH  => $PerlSpace::SysMtExecuter::tmplpath });
    $TT->process('sysmt_frame.html', $dbdata) || die $TT->error(), "\n";

    return 0;

}

sub sysmtSLANew
{

    my ( $dbh, $user ) = @_;

    my $dbdata;

    my ( $headmsg, $fullname, $sysmsg )  = PerlSpace::SysMtUtil::getHeaderInfo($dbh, $user);
    $$dbdata{'headertext'} = $headmsg;
    $$dbdata{'fullname'} = $fullname;
    $$dbdata{'sysmsg'} = $sysmsg;
    $$dbdata{'content'} = "sysmt_slanew.html";

    $TT ||= Template->new({ INCLUDE_PATH  => $PerlSpace::SysMtExecuter::tmplpath });
    $TT->process('sysmt_frame.html', $dbdata) || die $TT->error(), "\n";

    return 0;

}

sub sysmtSLACreate
{

    my ( $dbh, $user, $slanr, $shortdesc ) = @_;

    my $dbdata;
    
    if ( $PerlSpace::SysMtExecuter::db eq "cego" )
    {

	$sth = $dbh->prepare("? = call newSLA ( ?, ? );");
	
	$sth->bind_param_inout(1, \$slaid, 10);
	$sth->bind_param(2, $slanr, DBI::SQL_VARCHAR);
	$sth->bind_param(3, $shortdesc, DBI::SQL_VARCHAR);

	$sth->execute;

    }
    elsif ( $PerlSpace::SysMtExecuter::db eq "mysql" )
    {
	$sth = $dbh->prepare("select newSLA(?,?);");

	$sth->bind_param(1, $slanr, DBI::SQL_VARCHAR);
	$sth->bind_param(2, $shortdesc, DBI::SQL_VARCHAR);
	
	$sth->execute;
	$slaid = $sth->fetchrow_array;	
    }
    elsif ( $PerlSpace::SysMtExecuter::db eq "db2" )
    {
	$sth = $dbh->prepare(q{call newSLA(?,?,?)});

	$sth->bind_param(1, $slanr, DBI::SQL_VARCHAR);
	$sth->bind_param(2, $shortdesc, DBI::SQL_VARCHAR);
	$sth->bind_param_inout(3, \$slaid, 100, DBI::SQL_INTEGER);

	$sth->execute;
    }


    $sth->finish;    

    return sysmtSLA($dbh, $user, $slaid );

}

sub sysmtSLAUpdate
{

    my ( $dbh,
	 $user,
	 $slaid, 
	 $slanr, 
	 $shortdesc ) = @_;


    my $dbdata;

    # warn "Project is <" . $project . ">";
    
    $sth = $dbh->prepare("update sysmt_sla set slanr = ?,\
                                                  shortdesc = ? \
                                                  where slaid = ?;");


    my $i=1;
 
    $sth->bind_param($i, $slanr, DBI::SQL_VARCHAR);
    $i++;
    $sth->bind_param($i, $shortdesc, DBI::SQL_VARCHAR);
    $i++;
    $sth->bind_param($i, $slaid, DBI::SQL_INTEGER);


    $sth->execute;

    $sth->finish;    
    
    return sysmtSLA($dbh, $user, $slaid );

}

sub sysmtSLADelete
{

    my ( $dbh,
	 $user,
	 $slaid ) = @_;

    my $dbdata;

    # warn "Project is <" . $project . ">";
    
    $sth = $dbh->prepare("update sysmt_disk set slanr = null where slaid = ?;");

    $sth->bind_param(1, $slaid, DBI::SQL_INTEGER);

    $sth->execute;

    $sth->finish;    

    $sth = $dbh->prepare("update sysmt_system set slanr = null where slaid = ?;");

    $sth->bind_param(1, $slaid, DBI::SQL_INTEGER);

    $sth->execute;

    $sth->finish;

    $sth = $dbh->prepare("delete from sysmt_sla2prj where slaid = ?;");

    $sth->bind_param(1, $slaid, DBI::SQL_INTEGER);

    $sth->execute;

    $sth->finish;

    $sth = $dbh->prepare("delete from sysmt_sla where slaid = ?;");

    $sth->bind_param(1, $slaid, DBI::SQL_INTEGER);

    $sth->execute;

    $sth->finish;

    return sysmtSLAMaster($dbh, $user );

}

sub sysmtSLAAddProject
{

    my ( $dbh, $user, $slaid, $prjname, $stmt, $ordering ) = @_;

    
    $sth = $dbh->prepare("insert into sysmt_sla2prj ( slaid, pid ) values ( ?, ( select pid from sysmt_project where prjname = ? ));");
    
    $sth->bind_param(1, $slaid, DBI::SQL_INTEGER);
    $sth->bind_param(2, $prjname, DBI::SQL_VARCHAR);

    $sth->execute;

    $sth->finish;    

    return sysmtSLA($dbh, $user, $slaid, $stmt, $ordering);

}

sub sysmtSLADelProject
{

    my ( $dbh, $user, $slaid, $prjname, $stmt, $ordering ) = @_;


    $sth = $dbh->prepare("delete from sysmt_sla2prj where slaid = ? and pid = ( select pid from sysmt_project where prjname = ? );");

    $sth->bind_param(1, $slaid, DBI::SQL_INTEGER);    
    $sth->bind_param(2, $prjname, DBI::SQL_VARCHAR);

    $sth->execute;

    $sth->finish;

    return sysmtSLA($dbh, $user, $slaid, $stmt, $ordering);

}

sub sysmtSLAReport
{
    
    my ( $dbh, $user, $slaid, $stmt, $ordering ) = @_;

    my $stmt;
    my $dbdata;

    $$dbdata{'stmt'} = $stmt;
    $$dbdata{'ordering'} = $ordering;


    $$dbdata{'slanr'} = PerlSpace::SysMtUtil::getSLAForId($dbh, $slaid);

    # project list
    $stmt="select prjname from sysmt_project where pid in ( select pid from sysmt_sla2prj where slaid = ?) order by prjname;";
    $sth = $dbh->prepare($stmt);
    $sth->bind_param(1, $slaid, DBI::SQL_INTEGER);

    $sth->execute;

    $i=0;
    while ( ($prjname) = $sth->fetchrow_array) 
    {
	$$dbdata{'prjlist'}[$i] = $prjname;
	$i++;
    }
    
    $sth->finish;    


    # local zone retrievel
    $stmt="select hostname, hostinfo, osinfo, cpuinfo, meminfo from sysmt_host where hostname in ( select zoneA from sysmt_system where slaid = ? ) or hostname in ( select zoneB from sysmt_system where slaid = ? ) order by hostinfo, osinfo;";

    $sth = $dbh->prepare($stmt);

    $sth->bind_param(1, $slaid, DBI::SQL_INTEGER);
    $sth->bind_param(2, $slaid, DBI::SQL_INTEGER);

    $sth->execute;

    my $i=0;
    while ( ( $name, $info, $os, $cpu, $mem ) = $sth->fetchrow_array) 
    {
	$$dbdata{'zonelist'}[$i]{'name'} = $name;
	$$dbdata{'zonelist'}[$i]{'info'} = $info;
	$$dbdata{'zonelist'}[$i]{'os'} = $os;
	$$dbdata{'zonelist'}[$i]{'cpu'} = $cpu;
	$$dbdata{'zonelist'}[$i]{'mem'} = $mem;
	$i++;
    }
    
    $sth->finish;    


    # partition retrievel
    $stmt="select hostname, hostinfo, osinfo, cpuinfo, meminfo from sysmt_host where hostname in ( select partA from sysmt_system where slaid = ? ) or hostname in ( select partB from sysmt_system where slaid = ? ) or hostname in ( select partC from sysmt_system where slaid = ? ) or hostname in ( select partD from sysmt_system where slaid = ? ) order by hostinfo, osinfo;";

    $sth = $dbh->prepare($stmt);

    $sth->bind_param(1, $slaid, DBI::SQL_INTEGER);
    $sth->bind_param(2, $slaid, DBI::SQL_INTEGER);
    $sth->bind_param(3, $slaid, DBI::SQL_INTEGER);
    $sth->bind_param(4, $slaid, DBI::SQL_INTEGER);

    $sth->execute;

    $i=0;
    while ( ( $name, $info, $os, $cpu, $mem ) = $sth->fetchrow_array) 
    {
	$$dbdata{'partlist'}[$i]{'name'} = $name;
	$$dbdata{'partlist'}[$i]{'info'} = $info;
	$$dbdata{'partlist'}[$i]{'os'} = $os;
	$$dbdata{'partlist'}[$i]{'cpu'} = $cpu;
	$$dbdata{'partlist'}[$i]{'mem'} = $mem;
	$i++;
    }
    
    $sth->finish;    

    # disk retrievel
    $stmt="select diskvg, sum(disksize / ( 1024 * 1024) ) from sysmt_disk where slaid = ? and status = 'valid' group by diskvg order by diskvg;";

    $sth = $dbh->prepare($stmt);

    $sth->bind_param(1, $slaid, DBI::SQL_INTEGER);

    $sth->execute;

    $i=0;
    while ( ( $diskvg, $disksize ) = $sth->fetchrow_array) 
    {
	$$dbdata{'disklist'}[$i]{'diskvg'} = $diskvg;
	$$dbdata{'disklist'}[$i]{'disksize'} = $disksize;
	$i++;
    }
    
    $sth->finish;    

    my ( $headmsg, $fullname, $sysmsg )  = PerlSpace::SysMtUtil::getHeaderInfo($dbh, $user);
    $$dbdata{'headertext'} = $headmsg;
    $$dbdata{'fullname'} = $fullname;
    $$dbdata{'sysmsg'} = $sysmsg;
    $$dbdata{'content'} = "sysmt_slarep.html";

    $TT ||= Template->new({ INCLUDE_PATH  => $PerlSpace::SysMtExecuter::tmplpath });
    $TT->process('sysmt_frame.html', $dbdata) || die $TT->error(), "\n";

    return 0;

}


1;
