#
# sysmt_sysset.pm
# ---------------
#
# Design and Implementation by Bjoern Lemke               
#           
# (C)opyright 2010,2011,2012 by Bjoern Lemke
#                                              
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2, or (at your option)
# any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; see the file COPYING.  If not, write to
# the Free Software Foundation, 59 Temple Place - Suite 330,
# Boston, MA 02111-1307, USA.
#

######### System Set #########

package PerlSpace::SysMtSysSet;


sub sysmtSysSetMaster
{

    my ( $dbh, $user ) = @_;

    my ( $headmsg, $fullname, $sysmsg )  = PerlSpace::SysMtUtil::getHeaderInfo($dbh, $user);
    $$dbdata{'headertext'} = $headmsg;
    $$dbdata{'fullname'} = $fullname;
    $$dbdata{'sysmsg'} = $sysmsg;
    $$dbdata{'content'} = "sysmt_syssetmaster.html";

    $TT ||= Template->new({ INCLUDE_PATH  => $PerlSpace::SysMtExecuter::tmplpath });
    $TT->process('sysmt_frame.html', $dbdata) || die $TT->error(), "\n";

    return 0;

}

sub sysmtSysSet
{
    
    my ( $dbh, $user, $setid ) = @_;

    my $dbdata;

    # reached groups retrievel
    $stmt="select bgname from sysmt_bgroup bg, sysmt_set2bgrp s2g where s2g.setid = ? and s2g.bgid = bg.bgid order by bgname;";
    $sth = $dbh->prepare($stmt);
    $sth->bind_param(1, $setid, DBI::SQL_INTEGER);
    
    $sth->execute;
        
    my $bgroups = "";
    $$dbdata{'bgroups'} = "";
    $i=0;
    while ( ($bg) = $sth->fetchrow_array) 
    {
	if ( $$dbdata{'bgroups'} eq "" )
	{
	    $$dbdata{'bgroups'} = $bg;
	}
	else
	{
	    $$dbdata{'bgroups'} = $$dbdata{'bgroups'} . ", " . $bg;
	}

	$$dbdata{'delbglist'}[$i] = $bg;

	$i++;
    }
    
    $sth->finish;    


    # reached groups retrievel
    $stmt="select bgname from sysmt_bgroup bg where bgid not in ( select bgid from sysmt_set2bgrp s2g where s2g.setid = ? ) order by bgname;";
    $sth = $dbh->prepare($stmt);
    $sth->bind_param(1, $setid, DBI::SQL_INTEGER);

    $sth->execute;
    
    $i=0;
    while ( ($bgname) = $sth->fetchrow_array) 
    {
	$$dbdata{'addbglist'}[$i] = $bgname;
	$i++;
    }


    my $sth = $dbh->prepare("select setname, description from sysmt_systemset where setid = ?;");
    $sth->bind_param(1, $setid, DBI::SQL_INTEGER);
    
    $sth->execute;
    
    my $sysset;
    my $description;

    ( $sysset, $description ) = $sth->fetchrow_array; 
    
    $$dbdata{'sids'} = "";

    $$dbdata{'setid'} = $setid;
    $$dbdata{'sysset'} = $sysset;
    $$dbdata{'description'} = $description;

    $sth->fetchrow_array; 
    $sth->finish;

    my $sth = $dbh->prepare("select sid from sysmt_system s, sysmt_sys2set s2s, sysmt_systemset ss where ss.setid = ? and ss.setid = s2s.setid and s2s.sysid = s.sysid order by sid;");
    $sth->bind_param(1, $setid, DBI::SQL_INTEGER);
    
    $sth->execute;
    
    my $sid;
    
    $i=0;    
    while ( ( $sid ) = $sth->fetchrow_array )
    {	

	if ( $$dbdata{'sids'} eq "" )
	{
	    $$dbdata{'sids'} = $sid;
	}
	else
	{	    
	    $$dbdata{'sids'} = $$dbdata{'sids'} . ", " . $sid;
	}

	$$dbdata{'delsidlist'}[$i] = $sid;
	$i++;
    }
        
    $sth->finish;

    $sth = $dbh->prepare("select sid from sysmt_system s where sid not in ( select sid from sysmt_system s, sysmt_sys2set s2s, sysmt_systemset ss where ss.setid = ? and ss.setid = s2s.setid and s2s.sysid = s.sysid ) order by sid;");

    $sth->bind_param(1, $setid, DBI::SQL_INTEGER);

    $sth->execute;

    $i=0;
    while ( ($sid) = $sth->fetchrow_array) 
    {
	$$dbdata{'addsidlist'}[$i] = $sid;
	$i++;
    }

    my ( $headmsg, $fullname, $sysmsg )  = PerlSpace::SysMtUtil::getHeaderInfo($dbh, $user);
    $$dbdata{'headertext'} = $headmsg;
    $$dbdata{'fullname'} = $fullname;
    $$dbdata{'sysmsg'} = $sysmsg;
    $$dbdata{'content'} = "sysmt_sysset.html";

    $TT ||= Template->new({ INCLUDE_PATH  => $PerlSpace::SysMtExecuter::tmplpath });
    $TT->process('sysmt_frame.html', $dbdata) || die $TT->error(), "\n";

    return 0;

}


sub sysmtSysSetList
{
    
    my ( $dbh, $user, $sysset ) = @_;
    
    my $sth = $dbh->prepare("select setid, setname from sysmt_systemset where setname like ? order by setname;");
    $sth->bind_param(1, "%" . $sysset . "%", DBI::SQL_VARCHAR);
    
    $sth->execute;

    my $dbdata;

    my $setid;
    my $sysset;

    my $i=0;
    while ( ($setid, $sysset ) = $sth->fetchrow_array) 
    {
	$$dbdata{'setlist'}[$i]{'setid'} = $setid;
	$$dbdata{'setlist'}[$i]{'sysset'} = $sysset;
	$i++;
    }
    
    $sth->finish;

    my ( $headmsg, $fullname, $sysmsg )  = PerlSpace::SysMtUtil::getHeaderInfo($dbh, $user);
    $$dbdata{'headertext'} = $headmsg;
    $$dbdata{'fullname'} = $fullname;
    $$dbdata{'sysmsg'} = $sysmsg;
    $$dbdata{'content'} = "sysmt_syssetlist.html";

    $TT ||= Template->new({ INCLUDE_PATH  => $PerlSpace::SysMtExecuter::tmplpath });
    $TT->process('sysmt_frame.html', $dbdata) || die $TT->error(), "\n";

    return 0;

}


sub sysmtSysSetNew
{

    my ( $dbh, $user ) = @_;

    my $dbdata;

    my ( $headmsg, $fullname, $sysmsg )  = PerlSpace::SysMtUtil::getHeaderInfo($dbh, $user);
    $$dbdata{'headertext'} = $headmsg;
    $$dbdata{'fullname'} = $fullname;
    $$dbdata{'sysmsg'} = $sysmsg;
    $$dbdata{'content'} = "sysmt_syssetnew.html";

    $TT ||= Template->new({ INCLUDE_PATH  => $PerlSpace::SysMtExecuter::tmplpath });
    $TT->process('sysmt_frame.html', $dbdata) || die $TT->error(), "\n";
    
    return 0;
}



sub sysmtSysSetCreate
{

    my ( $dbh, $user, $sysset, $description ) = @_;

    # trim left and right whitespaces
    $sysset =~ s/^\s+//;
    $sysset =~ s/\s+$//;

    my $dbdata;
    my $setid;

    
    if ( $PerlSpace::SysMtExecuter::db eq "cego" )
    {
	$sth = $dbh->prepare("? = call newSystemSet(?, ? );");
	
	$sth->bind_param_inout(1, \$setid, 10);
	$sth->bind_param(2, $sysset, DBI::SQL_VARCHAR);
	$sth->bind_param(3, $description, DBI::SQL_VARCHAR);
	
        $sth->execute;

    }
    elsif ( $PerlSpace::SysMtExecuter::db eq "mysql" )
    {
	$sth = $dbh->prepare("select newSystemSet(?,?);");

	$sth->bind_param(1, $sysset, DBI::SQL_VARCHAR);
	$sth->bind_param(2, $description, DBI::SQL_VARCHAR);
	
	$sth->execute;
	$setid = $sth->fetchrow_array;	
    }
    elsif ( $PerlSpace::SysMtExecuter::db eq "db2" )
    {
	$sth = $dbh->prepare(q{call newSystemSet ( ?, ?, ?)});
	
	$sth->bind_param(1, $sysset, DBI::SQL_VARCHAR);
	$sth->bind_param(2, $description, DBI::SQL_VARCHAR);
	$sth->bind_param_inout(3, \$setid, 10);
	
        $sth->execute;

    }
    

    $sth->finish;    

    return sysmtSysSet($dbh, $user, $setid);

}



sub sysmtSysSetUpdate
{

    my ( $dbh, $user, $setid, $sysset, $description ) = @_;

    my $dbdata;
    
    $sth = $dbh->prepare("update sysmt_systemset set setname = ?, description = ? where setid = ?;");

    $sth->bind_param(1, $sysset, DBI::SQL_VARCHAR); 
    $sth->bind_param(2, $description, DBI::SQL_VARCHAR);
    $sth->bind_param(3, $setid, DBI::SQL_INTEGER);

    $sth->execute;

    $sth->finish;    

    return sysmtSysSet($dbh, $user, $setid);

}


sub sysmtSysSetDelete
{

    my ( $dbh, $user, $setid ) = @_;

    my $dbdata;

    $sth = $dbh->prepare("delete from sysmt_sys2set where setid = ?;");   
    $sth->bind_param(1, $setid, DBI::SQL_INTEGER);

    $sth->execute;

    $sth->finish;    

    
    $sth = $dbh->prepare("delete from sysmt_systemset where setid = ?;");   
    $sth->bind_param(1, $setid, DBI::SQL_INTEGER);

    $sth->execute;

    $sth->finish;

    return sysmtSysSetMaster($dbh, $user);

}


sub sysmtSysSetAdd2Grp
{

    my ( $dbh, $user, $setid, $bgname ) = @_;

    my $dbdata;
    
    $sth = $dbh->prepare("insert into sysmt_set2bgrp values ( ?, ( select bgid from sysmt_bgroup where bgname = ? ));");
    
    $sth->bind_param(1, $setid, DBI::SQL_INTEGER);
    $sth->bind_param(2, $bgname, DBI::SQL_VARCHAR);

    $sth->execute;

    $sth->finish;    

    return sysmtSysSet($dbh, $user, $setid);

}


sub sysmtSysSetDelFromGrp
{

    my ( $dbh, $user, $setid, $bgname ) = @_;

    my $dbdata;

    
    $sth = $dbh->prepare("delete from sysmt_set2bgrp where bgid = ( select bgid from sysmt_bgroup where bgname = ? ) and setid = ?;");
    
    $sth->bind_param(1, $bgname, DBI::SQL_VARCHAR);
    $sth->bind_param(2, $setid, DBI::SQL_INTEGER);

    $sth->execute;

    $sth->finish;

    return sysmtSysSet($dbh, $user, $setid);

}

sub sysmtSysSetAddSID
{
    
    my ( $dbh, $user, $setid, $sid ) = @_;
        
    $sth = $dbh->prepare("insert into sysmt_sys2set values ( ( select sysid from sysmt_system where sid = ? ) , ? );");
    
    $sth->bind_param(1, $sid, DBI::SQL_VARCHAR);
    $sth->bind_param(2, $setid, DBI::SQL_INTEGER);

    $sth->execute;
    
    $sth->finish;    
    
    return sysmtSysSet($dbh, $user, $setid );
    
}

sub sysmtSysSetDelSID
{
    
    my ( $dbh, $user, $setid, $sid ) = @_;
    
        
    $sth = $dbh->prepare("delete from sysmt_sys2set where setid = ? and sysid = ( select sysid from sysmt_system where sid = ? );");
    
    $sth->bind_param(1, $setid, DBI::SQL_INTEGER);
    $sth->bind_param(2, $sid, DBI::SQL_VARCHAR);
    
    $sth->execute;
    
    $sth->finish;
    
    return sysmtSysSet($dbh, $user, $setid );
    
}

sub sysmtSysSetView
{

    my ( $dbh, $user ) = @_;

    my $sth = $dbh->prepare("select ss.setid, ss.setname, ss.description  from sysmt_systemset ss, sysmt_set2bgrp s2g, sysmt_usr2bgrp u2g, sysmt_user u where ss.setid = s2g.setid and s2g.bgid = u2g.bgid and u.dbuser = ? and u.uid = u2g.uid order by setname;");

    $sth->bind_param(1, $user, DBI::SQL_VARCHAR);

    $sth->execute;

    my $dbdata;

    my $sysid;
    my $sid;
    my $description;


    my $i=0;
    while ( ($setid, $setname, $description ) = $sth->fetchrow_array)
    {
        $$dbdata{'setlist'}[$i]{'setid'} = $setid;
        $$dbdata{'setlist'}[$i]{'desc'} = $description;
        $$dbdata{'setlist'}[$i]{'setname'} = $setname;
        $i++;
    }
    
    $sth->finish;
    
    
    for ( my $j=0; $j<$i; $j++ )
    {
	
        my $setid = $$dbdata{'setlist'}[$j]{'setid'};

        my $sth = $dbh->prepare("select sid from sysmt_system s, sysmt_sys2set s2s, sysmt_systemset ss where ss.setid = ? and ss.setid = s2s.setid and s2s.sysid = s.sysid;");
        $sth->bind_param(1, $setid, DBI::SQL_INTEGER);

        $sth->execute;

        my $sid;
        my $c=0;

        while ( ( $sid ) = $sth->fetchrow_array )
        {
	    
            if ( $$dbdata{'setlist'}[$j]{'sids'} eq "" )
            {
                $$dbdata{'setlist'}[$j]{'sids'} = $sid;
            }
            else
            {
		
                if ( $c == 10 )
                {
                    $$dbdata{'setlist'}[$j]{'sids'} = $$dbdata{'setlist'}[$j]{'sids'} . ",\n" . $sid;
                    $c=0;
                }
                else
                {
                    $$dbdata{'setlist'}[$j]{'sids'} = $$dbdata{'setlist'}[$j]{'sids'} . "," . $sid;
                    $c++;
                }
            }
        }
	
        $sth->finish;
    }


    my ( $headmsg, $fullname, $sysmsg )  = PerlSpace::SysMtUtil::getHeaderInfo($dbh, $user);
    $$dbdata{'headertext'} = $headmsg;
    $$dbdata{'fullname'} = $fullname;
    $$dbdata{'sysmsg'} = $sysmsg;
    $$dbdata{'content'} = "sysmt_setview.html";

    $TT ||= Template->new({ INCLUDE_PATH  => $PerlSpace::SysMtExecuter::tmplpath });
    $TT->process('sysmt_frame.html', $dbdata) || die $TT->error(), "\n";
    
    return 0;

}

1;
