#
# sysmt_thread.pm
# ---------------
#
# Design and Implementation by Bjoern Lemke               
#           
# (C)opyright 2010,2011,2012 by Bjoern Lemke
#                                              
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2, or (at your option)
# any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; see the file COPYING.  If not, write to
# the Free Software Foundation, 59 Temple Place - Suite 330,
# Boston, MA 02111-1307, USA.
#

package PerlSpace::SysMtThread;

my $cego_selection="thrid, tgname, created, shortdesc, bgname, status, readstat, date2str(remind, '%d.%m.%Y'), remstat, lastedit, lasteditby";
my $mysql_selection="thrid, tgname, date_format(created, '%d.%m.%Y %m:%i:%s'), shortdesc, bgname, status, readstat, date_format(remind, '%d.%m.%Y %m:%i:%s'), remstat, lastedit, lasteditby";
my $db2_selection="thrid, tgname, ts_fmt(created, 'dd.mm.yyyy hh:mi:ss'), shortdesc, bgname, status, readstat, ts_fmt(remind, 'dd.mm.yyyy'),remstat, ts_fmt(lastedit, 'dd.mm.yyyy hh:mi:ss'), lasteditby";

sub sysmtThreadMaster
{
    
    my ( $dbh, $user ) = @_;
    
    my $dbdata;
    
    $$dbdata{'curyear'} = PerlSpace::SysMtUtil::getCurrentYear();

    my @tglist = PerlSpace::SysMtUtil::getTGForUser($dbh, $user);
    
    $i=0;
    foreach my $tg ( @tglist )
    {
	$$dbdata{'tglist'}[$i] = $tg;
	$i++;
    }

    my ( $headmsg, $fullname, $sysmsg )  = PerlSpace::SysMtUtil::getHeaderInfo($dbh, $user);
    $$dbdata{'headertext'} = $headmsg;
    $$dbdata{'fullname'} = $fullname;
    $$dbdata{'sysmsg'} = $sysmsg;
    $$dbdata{'content'} = "sysmt_threadmaster.html";


    $TT ||= Template->new({ INCLUDE_PATH  => $PerlSpace::SysMtExecuter::tmplpath });
    $TT->process('sysmt_frame.html', $dbdata) || die $TT->error(), "\n";
    
    return 0;
    
}

sub sysmtThreadNew
{
    
    my ( $dbh, $user, $tgname) = @_;
    
    my $dbdata;

    $$dbdata{'tgname'} = $tgname;    

    my @bglist = PerlSpace::SysMtUtil::getBGroupForTGroup($dbh, $tgname);
    
    $i=0;
    foreach my $bg ( @bglist )
    {
	$$dbdata{'bglist'}[$i] = $bg;
	$i++;
    }

    my ( $headmsg, $fullname, $sysmsg )  = PerlSpace::SysMtUtil::getHeaderInfo($dbh, $user);
    $$dbdata{'headertext'} = $headmsg;
    $$dbdata{'fullname'} = $fullname;
    $$dbdata{'sysmsg'} = $sysmsg;
    $$dbdata{'content'} = "sysmt_threadnew.html";


    $TT ||= Template->new({ INCLUDE_PATH  => $PerlSpace::SysMtExecuter::tmplpath });
    $TT->process('sysmt_frame.html', $dbdata) || die $TT->error(), "\n";
    
    return 0;
}


sub sysmtThreadCreate
{
    
    my ( $dbh, $user, $tgname, $shortdesc, $bgname, $remind ) = @_;
    
    my $thrid;

    if ( ! $remind )
    {
	$remind = PerlSpace::SysMtUtil::getCurrentDate();
    }

    if ( $PerlSpace::SysMtExecuter::db eq "cego" )
    {
	
	$sth = $dbh->prepare("? = call newThread ( ?, ?, ?, date('%d.%m.%Y %H:%M:%S', ?));");
	
	$sth->bind_param_inout(1, \$thrid, 10);
	$sth->bind_param(2, $tgname, DBI::SQL_VARCHAR);
	$sth->bind_param(3, $shortdesc, DBI::SQL_VARCHAR);
	$sth->bind_param(4, $bgname, DBI::SQL_VARCHAR);
	$sth->bind_param(5, $remind . " 00:00:00", DBI::SQL_VARCHAR);
	
	$sth->execute;

    }
    elsif ( $PerlSpace::SysMtExecuter::db eq "mysql" )
    {
	$sth = $dbh->prepare("select newThread(?,?,?,?);");
	
	$sth->bind_param(1, $tgname, DBI::SQL_VARCHAR);
	$sth->bind_param(2, $shortdesc, DBI::SQL_VARCHAR);
	$sth->bind_param(3, $bgname, DBI::SQL_VARCHAR);
	$sth->bind_param(4, PerlSpace::SysMtUtil::mysqlDate($remind), DBI::SQL_VARCHAR);
	
	$sth->execute;
	$thrid = $sth->fetchrow_array;	
    }
    elsif ( $PerlSpace::SysMtExecuter::db eq "db2" )
    {
	$sth = $dbh->prepare(q{call newThread(?,?,?,?,?)});
	
	$sth->bind_param(1, $tgname, DBI::SQL_VARCHAR);
	$sth->bind_param(2, $shortdesc, DBI::SQL_VARCHAR);
	$sth->bind_param(3, $bgname, DBI::SQL_VARCHAR);
	$sth->bind_param(4, PerlSpace::SysMtUtil::db2Date($remind), DBI::SQL_VARCHAR);
	$sth->bind_param_inout(5, \$thrid, 100, DBI::SQL_INTEGER);
	
	$sth->execute;

    }
    
    $sth->finish;    
    
    return sysmtThreadBase($dbh, $user, $tgname, $thrid );
    
}

sub sysmtThreadBase
{
    
    my ( $dbh, $user, $tgname, $thrid, $thrstmt, $thrordering ) = @_;

    my $dbdata;

    $$dbdata{'tgname'} = $tgname;
    $$dbdata{'thrid'} = $thrid;
    $$dbdata{'thrstmt'} = $thrstmt; # PerlSpace::SysMtUtil::cgiEncode($thrstmt);
    $$dbdata{'thrordering'} = $thrordering; # PerlSpace::SysMtUtil::cgiEncode($thrordering);


    my $uid = PerlSpace::SysMtUtil::getUid($dbh, $user);

    $$dbdata{'thrstmt'} = $thrstmt;
    $$dbdata{'thrordering'} = $thrordering;
            
    my $sth;

    if ( $PerlSpace::SysMtExecuter::db eq "cego" )
    {
	$sth = $dbh->prepare("select tgid,tgname,created,shortdesc,description,date2str(remind,'%d.%m.%Y'),bgname, status, readstat from sysmt_threadview where thrid = ? and uid = ?;");
    } 
    elsif ( $PerlSpace::SysMtExecuter::db eq "mysql" )
    {
	$sth = $dbh->prepare("select tgid,tgname,date_format(created, '%d.%m.%Y %m:%i:%s'),shortdesc,description,date_format(remind, '%d.%m.%Y'),bgname,status, readstat from sysmt_threadview where thrid = ? and uid = ?;");

    }
    elsif ( $PerlSpace::SysMtExecuter::db eq "db2" )
    {
	$sth = $dbh->prepare("select tgid,tgname,ts_fmt(created, 'dd.mm.yyyy hh:mi:ss'),shortdesc,description,ts_fmt(remind, 'dd.mm.yyyy'),bgname,status, readstat from sysmt_threadview where thrid = ? and uid = ?;");
    }

    $sth->bind_param(1, $thrid, DBI::SQL_INTEGER);
    $sth->bind_param(2, $uid, DBI::SQL_INTEGER);
        
    $sth->execute;
   
    if ( ( ( $tgid, $tgname, $created, $shortdesc, $description, $remind, $bgname, $status, $readstat ) = $sth->fetchrow_array ) == 0 )
    {	
        die  "Cannot access thrid " . $thrid;
    }
    
    $$dbdata{'thrid'} = $thrid;
    $$dbdata{'tgname'} = $tgname;
    $$dbdata{'created'} = $created;
    $$dbdata{'shortdesc'} = $shortdesc;
    $$dbdata{'description'} = $description;
    $$dbdata{'remind'} = $remind;
    $$dbdata{'status'} = $status;
    $$dbdata{'readstat'} = $readstat;
    $$dbdata{'bgname'} = $bgname;

    $sth->finish;


    my @sidlist = PerlSpace::SysMtUtil::getSidListForThreadGroup($dbh, $tgid);
    
    $i=0;
    foreach my $sid ( @sidlist )
    {
	$$dbdata{'sidlist'}[$i] = $sid;
	$i++;
    }

    my @bglist = PerlSpace::SysMtUtil::getBGroupForTGroup($dbh, $tgname);
    
    $i=0;
    foreach my $bg ( @bglist )
    {
	$$dbdata{'bglist'}[$i] = $bg;
	$i++;
    }

    my @userlist = PerlSpace::SysMtUtil::getUserListForThreadGroup($dbh, $tgname);
    
    $i=0;
    foreach my $ul ( @userlist )
    {
	my ( $dbuser, $username ) = split(/:/, $ul);
	$$dbdata{'userlist'}[$i]{'dbuser'} = $dbuser;
	$$dbdata{'userlist'}[$i]{'username'} = $username;
	$i++;
    }

    if ( $PerlSpace::SysMtExecuter::db eq "cego" )
    {
	$sth = $dbh->prepare("select logts, dbuser, logentry from sysmt_threadlog where thrid = ? order by logts desc;");
    } 
    elsif ( $PerlSpace::SysMtExecuter::db eq "mysql" )
    {
	$sth = $dbh->prepare("select date_format(logts, '%d.%m.%Y %m:%i:%s'), dbuser, logentry from sysmt_threadlog where thrid = ? order by logts desc;");

    }
    elsif ( $PerlSpace::SysMtExecuter::db eq "db2" )
    {
	$sth = $dbh->prepare("select ts_fmt(logts, 'dd.mm.yyyy hh:mi:ss'), dbuser, logentry from sysmt_threadlog where thrid = ? order by logts desc;");
    }

    $sth->bind_param(1, $thrid, DBI::SQL_INTEGER);

    $sth->execute;

    my $logts;
    my $logentry;
    my $dbuser;

    $i=0;
    while ( ( $logts, $dbuser, $logentry ) = $sth->fetchrow_array )
    {
	$$dbdata{'loglist'}[$i]{'logts'} = $logts;
	$$dbdata{'loglist'}[$i]{'dbuser'} = $dbuser;
        
        $logentry =~ s!(\s)(http://\w.*?)(\s)!$1<a href="$2">$2</a>$3!gm;
        $logentry =~ s/\n/<br>/g; 
	$$dbdata{'loglist'}[$i]{'logentry'} = $logentry;
	$i++;
    }

    $sth->finish;


    $$dbdata{'mtnum'} = PerlSpace::SysMtUtil::getNumMtForThread($dbh, $user, $thrid);

    PerlSpace::SysMtUtil::threadMarkRead($dbh, $user, $thrid);

    
    my ( $headmsg, $fullname, $sysmsg )  = PerlSpace::SysMtUtil::getHeaderInfo($dbh, $user);
    $$dbdata{'headertext'} = $headmsg;
    $$dbdata{'fullname'} = $fullname;
    $$dbdata{'sysmsg'} = $sysmsg;
    $$dbdata{'content'} = "sysmt_threadbase.html";

    $TT ||= Template->new({ INCLUDE_PATH  => $PerlSpace::SysMtExecuter::tmplpath });
    $TT->process('sysmt_frame.html', $dbdata) || die $TT->error(), "\n";
    
    return 0;
}

sub sysmtThreadLog
{
    
    my ( $dbh, $user, $tgname, $thrid, $thrstmt, $thrordering ) = @_;

    my $dbdata;

    $$dbdata{'tgname'} = $tgname;
    $$dbdata{'thrid'} = $thrid;
    $$dbdata{'thrstmt'} = $thrstmt;
    $$dbdata{'thrordering'} = $thrordering;
    
    if ( $PerlSpace::SysMtExecuter::db eq "cego" )
    {
	$sth = $dbh->prepare("select logts, dbuser, logentry from sysmt_threadlog where thrid = ? order by logts desc;");
    } 
    elsif ( $PerlSpace::SysMtExecuter::db eq "mysql" )
    {
	$sth = $dbh->prepare("select date_format(logts, '%d.%m.%Y %m:%i:%s'), dbuser, logentry from sysmt_threadlog where thrid = ? order by logts desc;");

    }
    elsif ( $PerlSpace::SysMtExecuter::db eq "db2" )
    {
	$sth = $dbh->prepare("select ts_fmt(logts, 'dd.mm.yyyy hh:mi:ss'), dbuser, logentry from sysmt_threadlog where thrid = ? order by logts desc;");
    }

    $sth->bind_param(1, $thrid, DBI::SQL_INTEGER);

    $sth->execute;

    my $logts;
    my $logentry;
    my $dbuser;

    $i=0;
    while ( ( $logts, $dbuser, $logentry ) = $sth->fetchrow_array )
    {
	$$dbdata{'loglist'}[$i]{'logts'} = $logts;
	$$dbdata{'loglist'}[$i]{'dbuser'} = $dbuser;
        
        $logentry =~ s!(\s)(http://\w.*?)(\s)!$1<a href="$2">$2</a>$3!gm;
        $logentry =~ s/\n/<br>/g; 
	$$dbdata{'loglist'}[$i]{'logentry'} = $logentry;
	$i++;
    }

    $sth->finish;

    my ( $headmsg, $fullname, $sysmsg )  = PerlSpace::SysMtUtil::getHeaderInfo($dbh, $user);
    $$dbdata{'headertext'} = $headmsg;
    $$dbdata{'fullname'} = $fullname;
    $$dbdata{'sysmsg'} = $sysmsg;
    $$dbdata{'content'} = "sysmt_threadlog.html";

    $TT ||= Template->new({ INCLUDE_PATH  => $PerlSpace::SysMtExecuter::tmplpath });
    $TT->process('sysmt_frame.html', $dbdata) || die $TT->error(), "\n";

    return 0;
}

sub sysmtThreadDocument
{
    
    my ( $dbh, $user, $tgname, $thrid, $thrstmt, $thrordering, $docid ) = @_;
    
    my $dbdata;

    $$dbdata{'tgname'} = $tgname;
    $$dbdata{'thrid'} = $thrid;
    $$dbdata{'thrstmt'} = $thrstmt;
    $$dbdata{'thrordering'} = $thrordering;

    # retrieve all documents

    my $sth = $dbh->prepare("select d.docid, doctype, docname from sysmt_document d, sysmt_doc2thread d2t where d2t.thrid = ? and d2t.docid = d.docid;");
    $sth->bind_param(1, $thrid, DBI::SQL_INTEGER);

    $sth->execute;
        
    my $docid;
    my $doctype;
    my $docname;
    
    $i=0;
    while ( ( $docid, $doctype, $docname ) = $sth->fetchrow_array )
    {
	$$dbdata{'doclist'}[$i]{'docid'} = $docid;
	$$dbdata{'doclist'}[$i]{'doctype'} = $doctype;
	$$dbdata{'doclist'}[$i]{'docname'} = $docname;
	$$dbdata{'doclist'}[$i]{'url'} = "<a href=http://" . $PerlSpace::SysMtExecuter::httphost  . "/docs/" . $docid . "." . $doctype . ">" . $docname . "</a>";
	$i++;
    }

    $sth->finish;

    my ( $headmsg, $fullname, $sysmsg )  = PerlSpace::SysMtUtil::getHeaderInfo($dbh, $user);
    $$dbdata{'headertext'} = $headmsg;
    $$dbdata{'fullname'} = $fullname;
    $$dbdata{'sysmsg'} = $sysmsg;
    $$dbdata{'content'} = "sysmt_threaddoc.html";

    $TT ||= Template->new({ INCLUDE_PATH  => $PerlSpace::SysMtExecuter::tmplpath });
    $TT->process('sysmt_frame.html', $dbdata) || die $TT->error(), "\n";
    
    return 0;
}

sub sysmtThreadDocumentView
{
    
    my ( $dbh, $user, $tgname, $thrid, $thrstmt, $thrordering, $docid, $doctype ) = @_;
    
    my $dbdata;

    $$dbdata{'tgname'} = $tgname;
    $$dbdata{'thrid'} = $thrid;
    $$dbdata{'thrstmt'} = $thrstmt;
    $$dbdata{'thrordering'} = $thrordering;

    $$dbdata{'src'} = "/docs/" . $docid . "." . $doctype;

    my ( $headmsg, $fullname, $sysmsg )  = PerlSpace::SysMtUtil::getHeaderInfo($dbh, $user);
    $$dbdata{'headertext'} = $headmsg;
    $$dbdata{'fullname'} = $fullname;
    $$dbdata{'sysmsg'} = $sysmsg;
    $$dbdata{'content'} = "sysmt_threaddocview.html";

    $TT ||= Template->new({ INCLUDE_PATH  => $PerlSpace::SysMtExecuter::tmplpath });
    $TT->process('sysmt_frame.html', $dbdata) || die $TT->error(), "\n";

    return 0;

}


sub sysmtThreadListByGroup
{
    
    my ( $dbh, $user, $tgname ) = @_;
    my $ordering = "order by created";

    
    my $uid = PerlSpace::SysMtUtil::getUid($dbh, $user);

    my $stmt;

    if ( $PerlSpace::SysMtExecuter::db eq "cego" )
    {
	$stmt = "select " .
	    $cego_selection .
	    " from sysmt_threadview t where t.tgname = '" . $tgname . "' and status != 'CLOSED' and uid = " . $uid;

    }
    elsif ( $PerlSpace::SysMtExecuter::db eq "mysql" )
    {
	$stmt = "select " .
	    $mysql_selection .
	    " from sysmt_threadview t where t.tgname = '" . $tgname . "'  and status != 'CLOSED' and uid = " . $uid;
    }
    elsif ( $PerlSpace::SysMtExecuter::db eq "db2" )
    {
	$stmt = "select " .
	    $db2_selection .
	    " from sysmt_threadview t where t.tgname = '" . $tgname . "' and status != 'CLOSED' and uid = " . $uid;
    }
    return sysmtThreadExecuteList($dbh, $user, $stmt, $ordering);

}

sub sysmtThreadListByActive
{
    
    my ( $dbh, $user ) = @_;
    my $ordering = "order by created";

    my $uid = PerlSpace::SysMtUtil::getUid($dbh, $user);
    
    my $stmt;

    if ( $PerlSpace::SysMtExecuter::db eq "cego" )
    {
	$stmt = "select " .
	    $cego_selection .
	    " from sysmt_threadview t where t.status = 'OPEN' and uid = " . $uid . " and t.bgname in ( select bgname from sysmt_bgroup bg, sysmt_usr2bgrp u2g, sysmt_user u where bg.bgid = u2g.bgid and u2g.uid = u.uid and u.dbuser = '" . $user . "')";

    }
    elsif ( $PerlSpace::SysMtExecuter::db eq "mysql" )
    {
	$stmt = "select " .
	    $mysql_selection .
	    " from sysmt_threadview t where t.status = 'OPEN' and uid = " . $uid . " and t.bgname in ( select bgname from sysmt_bgroup bg, sysmt_usr2bgrp u2g, sysmt_user u where bg.bgid = u2g.bgid and u2g.uid = u.uid and u.dbuser = '" . $user . "')";
    }
    elsif ( $PerlSpace::SysMtExecuter::db eq "db2" )
    {
	$stmt = "select " .
	    $db2_selection .
	    " from sysmt_threadview t where t.status = 'OPEN' and uid = " . $uid . " and t.bgname in ( select bgname from sysmt_bgroup bg, sysmt_usr2bgrp u2g, sysmt_user u where bg.bgid = u2g.bgid and u2g.uid = u.uid and u.dbuser = '" . $user . "')";
    }
    return sysmtThreadExecuteList($dbh, $user, $stmt, $ordering);

}

sub sysmtThreadListByStatus
{
    
    my ( $dbh, $user, $status ) = @_;
    my $ordering = "order by created";

    my $uid = PerlSpace::SysMtUtil::getUid($dbh, $user);

    my $stmt;

    if ( $PerlSpace::SysMtExecuter::db eq "cego" )
    {
	$stmt = "select " .
	    $cego_selection .
	    " from sysmt_threadview t where t.status = '" . $status . "' and uid = " . $uid .
	    " and t.tgid in " .
	    " ( select tgid from sysmt_tg2bgrp where bgid in " .
	    " ( select distinct u2g.bgid from sysmt_usr2bgrp u2g, sysmt_user u, sysmt_bgright r " .
	    " where r.bgright = 'thread' and r.bgid = u2g.bgid and  u2g.uid = u.uid and u.dbuser = '" . $user ."'))";
    }
    elsif ( $PerlSpace::SysMtExecuter::db eq "mysql" )
    {
	$stmt = "select " .
	    $mysql_selection .
	    " from sysmt_threadview t where t.status = '" . $status . "' and uid = " . $uid .
	    " and t.tgid in " .
	    " ( select tgid from sysmt_tg2bgrp where bgid in " .
	    " ( select distinct u2g.bgid from sysmt_usr2bgrp u2g, sysmt_user u, sysmt_bgright r " .
	    " where r.bgright = 'thread' and r.bgid = u2g.bgid and  u2g.uid = u.uid and u.dbuser = '" . $user ."'))";	
    }
    elsif ( $PerlSpace::SysMtExecuter::db eq "db2" )
    {
	$stmt = "select " .
	    $db2_selection .
	    " from sysmt_threadview t where t.status = '" . $status . "' and uid = " . $uid .
	    " and t.tgid in " .
	    " ( select tgid from sysmt_tg2bgrp where bgid in " .
	    " ( select distinct u2g.bgid from sysmt_usr2bgrp u2g, sysmt_user u, sysmt_bgright r " .
	    " where r.bgright = 'thread' and r.bgid = u2g.bgid and  u2g.uid = u.uid and u.dbuser = '" . $user ."'))";
    }

    return sysmtThreadExecuteList($dbh, $user, $stmt, $ordering);

}

sub sysmtThreadListByShortDesc
{
    
    my ( $dbh, $user, $tgname, $shortdesc ) = @_;
    my $ordering = "order by created";

    my $uid = PerlSpace::SysMtUtil::getUid($dbh, $user);

    my $stmt;

    if ( $PerlSpace::SysMtExecuter::db eq "cego" )
    {
	$stmt = "select " .
	    $cego_selection .
	    " from sysmt_threadview t where t.tgname = '" . $tgname . "' and uid = " . $uid . " and shortdesc like '%" . $shortdesc . "%'";
    }
    elsif ( $PerlSpace::SysMtExecuter::db eq "mysql" )
    {
	$stmt = "select " .
	    $mysql_selection .
	    " from sysmt_threadview t where t.tgname = '" . $tgname . "' and uid = " . $uid . " and shortdesc like '%" . $shortdesc . "%'";

    }
    elsif ( $PerlSpace::SysMtExecuter::db eq "db2" )
    {
	$stmt = "select " .
	    $db2_selection .
	    " from sysmt_threadview t where t.tgname = '" . $tgname . "' and uid = " . $uid . " and shortdesc like '%" . $shortdesc . "%'";
    }

    return sysmtThreadExecuteList($dbh, $user, $stmt, $ordering);

}


sub sysmtThreadListByRemind
{
    
    my ( $dbh, $user, $tgname, $remind ) = @_;
    my $ordering = "order by created";

    my $uid = PerlSpace::SysMtUtil::getUid($dbh, $user);

    my $stmt;

    if ( $PerlSpace::SysMtExecuter::db eq "cego" )
    {
	$stmt = "select " .
	    $cego_selection .
	    " from sysmt_threadview t where t.remind < date('%d.%m.%Y', '" . $remind . "') and status != 'CLOSED' and uid = " . $uid . " and tgname = '"  . $tgname . "'".
	    " and t.tgid in " .
	    " ( select tgid from sysmt_tg2bgrp where bgid in " .
	    " ( select distinct bgid from sysmt_usr2bgrp u2g, sysmt_user u, sysmt_bgright r " .
	    " where r.bgright = 'thread' and r.bgid = u2g.bgid and  u2g.uid = u.uid and u.dbuser = '" . $user ."'))";
    }
    elsif ( $PerlSpace::SysMtExecuter::db eq "mysql" )
    {

	$mysqlremind = PerlSpace::SysMtUtil::mysqlDate($remind);

	$stmt = "select " .
	    $mysql_selection .
	    " from sysmt_threadview t where t.remind < '" . $mysqlremind . "' and status != 'CLOSED' and uid = " . $uid . " and tgname = '"  . $tgname . "'".
	    " and t.tgid in " .
	    " ( select tgid from sysmt_tg2bgrp where bgid in " .
	    " ( select distinct u2g.bgid from sysmt_usr2bgrp u2g, sysmt_user u, sysmt_bgright r " .
	    " where r.bgright = 'thread' and r.bgid = u2g.bgid and  u2g.uid = u.uid and u.dbuser = '" . $user ."'))";	
    }
    elsif ( $PerlSpace::SysMtExecuter::db eq "db2" )
    {

	$db2remind = PerlSpace::SysMtUtil::db2Date($remind);

	$stmt = "select " .
	    $db2_selection .
	    " from sysmt_threadview t where t.remind < '" . $db2remind . "' and status != 'CLOSED' and uid = " . $uid . " and tgname = '" . $tgname . "'"  .
	    " and t.tgid in " .
	    " ( select tgid from sysmt_tg2bgrp where bgid in " .
	    " ( select distinct u2g.bgid from sysmt_usr2bgrp u2g, sysmt_user u, sysmt_bgright r " .
	    " where r.bgright = 'thread' and r.bgid = u2g.bgid and  u2g.uid = u.uid and u.dbuser = '" . $user ."'))";	
    }

    return sysmtThreadExecuteList($dbh, $user, $stmt, $ordering);

}


sub sysmtThreadExecuteList
{
    
    my ( $dbh, $user, $thrstmt, $thrordering ) = @_;

    my $dbdata;
    
    if ( $thrstmt )
    {

	my $query = $thrstmt . " " . $thrordering . ";";

	my $sth = $dbh->prepare($query);
	
	$sth->execute;
	
	$$dbdata{'thrstmt'} = $thrstmt;
	$$dbdata{'thrordering'} = $thrordering;
	$$dbdata{'user'} = $user;
	
	my $i=0;
	
	while ( ($thrid, $tgname, $created, $shortdesc, $bgname, $status, $readstat, $remind, $remstat, $lastedit, $lasteditby) 
		= $sth->fetchrow_array) 
	{
	    
	    if ( $remind eq "null" )
	    {
		$remind = "";
	    }
	    
	    $$dbdata{'threadlist'}[$i]{'thrid'} = $thrid;
	    $$dbdata{'threadlist'}[$i]{'tgname'} = $tgname;
	    $$dbdata{'threadlist'}[$i]{'created'} = $created;
	    $$dbdata{'threadlist'}[$i]{'shortdesc'} = $shortdesc;
	    $$dbdata{'threadlist'}[$i]{'bgname'} = $bgname;
	    $$dbdata{'threadlist'}[$i]{'status'} = $status;
	    $$dbdata{'threadlist'}[$i]{'readstat'} = $readstat;
	    $$dbdata{'threadlist'}[$i]{'remind'} = $remind;
	    $$dbdata{'threadlist'}[$i]{'remstat'} = $remstat;
	    $$dbdata{'threadlist'}[$i]{'lastedit'} = $lastedit;
	    $$dbdata{'threadlist'}[$i]{'lasteditby'} = $lasteditby;

	    $i++;
	}
    
	$sth->finish;    
    }

    my ( $headmsg, $fullname, $sysmsg )  = PerlSpace::SysMtUtil::getHeaderInfo($dbh, $user);
    $$dbdata{'headertext'} = $headmsg;
    $$dbdata{'fullname'} = $fullname;
    $$dbdata{'sysmsg'} = $sysmsg;
    $$dbdata{'content'} = "sysmt_threadlist.html";

    $TT ||= Template->new({ INCLUDE_PATH  => $PerlSpace::SysMtExecuter::tmplpath });
    $TT->process('sysmt_frame.html', $dbdata) || die $TT->error(), "\n";

    return 0;
}

sub sysmtThreadUpdate
{

    my ( $dbh, $user, $tgname, $thrid, $shortdesc, $remind, $bgname, $status, $thrstmt, $thrordering ) = @_;
    
    if ( $PerlSpace::SysMtExecuter::db eq "cego" )
    {
	$sth = $dbh->prepare("update sysmt_thread set shortdesc = ?, remind = date('%d.%m.%Y %H:%M:%S', ?), bgid = ( select bgid from sysmt_bgroup where bgname = ? ), status = ? where thrid = ?;");
	
	$sth->bind_param(1, $shortdesc, DBI::SQL_VARCHAR);
	$sth->bind_param(2, $remind . " 00:00:00", DBI::SQL_VARCHAR);
	$sth->bind_param(3, $bgname, DBI::SQL_VARCHAR);
	$sth->bind_param(4, $status, DBI::SQL_VARCHAR);
	$sth->bind_param(5, $thrid, DBI::SQL_INTEGER);
	
    }
    elsif ( $PerlSpace::SysMtExecuter::db eq "mysql" )
    {
	$sth = $dbh->prepare("update sysmt_thread set shortdesc = ?, remind = ?, bgid = ( select bgid from sysmt_bgroup where bgname = ? ), status = ? where thrid = ?;");       		
	$sth->bind_param(1, $shortdesc, DBI::SQL_VARCHAR);
	$sth->bind_param(2, PerlSpace::SysMtUtil::mysqlDate($remind), DBI::SQL_VARCHAR);
	$sth->bind_param(3, $bgname, DBI::SQL_VARCHAR);
	$sth->bind_param(4, $status, DBI::SQL_VARCHAR);
	$sth->bind_param(5, $thrid, DBI::SQL_INTEGER);
    }
    elsif ( $PerlSpace::SysMtExecuter::db eq "db2" )
    {
	$sth = $dbh->prepare("update sysmt_thread set shortdesc = ?, remind = ?, bgid = ( select bgid from sysmt_bgroup where bgname = ? ), status = ? where thrid = ?;");
	
	$sth->bind_param(1, $shortdesc, DBI::SQL_VARCHAR);
	$sth->bind_param(2, PerlSpace::SysMtUtil::db2Date($remind), DBI::SQL_VARCHAR);
	$sth->bind_param(3, $bgname, DBI::SQL_VARCHAR);
	$sth->bind_param(4, $status, DBI::SQL_VARCHAR);
	$sth->bind_param(5, $thrid, DBI::SQL_INTEGER);
	
    }

    $sth->execute;

    $sth->finish;    


    my $logentry="Thread updated";

    addLogEntry($dbh, $user, $thrid, $logentry);
    PerlSpace::SysMtUtil::threadMarkRead($dbh, $user, $thrid);


    return sysmtThreadBase($dbh, $user, $tgname, $thrid, $thrstmt, $thrordering);

}


sub sysmtThreadAdd2Grp
{

    my ( $dbh, $user, $tgname, $thrid, $tgname, $bgname, $thrstmt, $thrordering ) = @_;

    my $dbdata;
    
    $sth = $dbh->prepare("insert into sysmt_thr2bgrp values ( ?, ( select bgid from sysmt_bgroup where bgname = ? ));");
    
    $sth->bind_param(1, $thrid, DBI::SQL_INTEGER);
    $sth->bind_param(2, $bgname, DBI::SQL_VARCHAR);

    $sth->execute;

    $sth->finish;    

    return sysmtThreadBase($dbh, $user, $tgname, $thrid, $thrstmt, $thrordering);

}

sub sysmtThreadDelFromGrp
{

    my ( $dbh, $user, $tgname, $thrid, $bgname, $thrstmt, $thrordering ) = @_;

    my $dbdata;

    $sth = $dbh->prepare("delete from sysmt_thr2bgrp where bgid = ( select bgid from sysmt_bgroup where bgname = ? ) and thrid = ?;");
    
    $sth->bind_param(1, $bgname, DBI::SQL_VARCHAR);
    $sth->bind_param(2, $thrid, DBI::SQL_INTEGER);

    $sth->execute;

    $sth->finish;

    return sysmtThreadBase($dbh, $user, $tgname, $thrid, $thrstmt, $thrordering);

}

sub sysmtThreadAddLog
{

    my ( $dbh, $user, $tgname,  $thrid, $logentry, $thrstmt, $thrordering ) = @_;
    
    addLogEntry($dbh, $user, $thrid, $logentry);
    PerlSpace::SysMtUtil::threadMarkRead($dbh, $user, $thrid);

    return sysmtThreadBase($dbh, $user, $tgname, $thrid, $thrstmt, $thrordering);

}

sub sysmtThreadDeleteDoc
{

    my ( $dbh, $user, $tgname, $thrid, $docid, $thrstmt, $thrordering ) = @_;

    $sth = $dbh->prepare("delete from sysmt_doc2thread where docid = ? and thrid = ?;");
    
    $sth->bind_param(1, $docid, DBI::SQL_INTEGER);
    $sth->bind_param(2, $thrid, DBI::SQL_INTEGER);

    $sth->execute;

    $sth->finish;

    my $logentry = "Document " . $docid . " deleted";
    addLogEntry($dbh, $user, $thrid, $logentry);
    PerlSpace::SysMtUtil::threadMarkRead($dbh, $user, $thrid);


    return sysmtThreadDocument($dbh, $user, $tgname, $thrid, $thrstmt, $thrordering);

}

sub sysmtThreadDelete
{

    my ( $dbh, $user, $tgname, $thrid, $thrstmt, $thrordering ) = @_;

    $sth = $dbh->prepare("delete from sysmt_threadlog where thrid = ?;");
    $sth->bind_param(1, $thrid, DBI::SQL_INTEGER);

    $sth->execute;

    $sth->finish;
    
    $sth = $dbh->prepare("delete from sysmt_doc2thread where thrid = ?;");
    $sth->bind_param(1, $thrid, DBI::SQL_INTEGER);

    $sth->execute;

    $sth->finish;
    
    $sth = $dbh->prepare("update sysmt_mt set thrid = null where thrid = ?;");
    $sth->bind_param(1, $thrid, DBI::SQL_INTEGER);
    
    $sth->execute;

    $sth->finish;
    
    $sth = $dbh->prepare("delete from sysmt_thread where thrid = ?;");
    $sth->bind_param(1, $thrid, DBI::SQL_INTEGER);
    
    $sth->execute;

    return sysmtThreadExecuteList($dbh, $user, $thrstmt, $thrordering);

}

sub sysmtThreadNotify
{

    my ( $dbh, $user, $tgname, $thrid, $thrcomment, $dbuser, $thrstmt, $thrordering ) = @_;

    # send notification ...

    my $mailfrom = PerlSpace::SysMtUtil::getEmailForUser($dbh, $user);
    my $mailto = PerlSpace::SysMtUtil::getEmailForUser($dbh, $dbuser);
    my $threadinfo = PerlSpace::SysMtUtil::getThreadInfo($dbh, $thrid, $thrcomment);

    my $mfarg="";

    if ( $mailfrom ) 
    {
	$mfarg= "-r $mailfrom";
    }
    
    if ( ! $mailto )
    {
	die "No email defined for user $dbuser\n";
    }

    open(MAIL, "| " . $PerlSpace::SysMtExecuter::mailx . " -s \"SysMT Thread Notification $tgname-$thrid\" $mfarg $mailto ") || die "Mailer failed: $!\n";
    
    print MAIL $threadinfo;
    
    close MAIL;
    
    $sth = $dbh->prepare("delete from sysmt_threadstat where thrid = ?;");
    $sth->bind_param(1, $thrid, DBI::SQL_INTEGER);    
    $sth->execute;
    $sth->finish;

    my $logentry="Notification send to $mailto";

    addLogEntry($dbh, $user, $thrid, $logentry);
    PerlSpace::SysMtUtil::threadMarkRead($dbh, $user, $thrid);


    return sysmtThreadBase($dbh, $user, $tgname, $thrid, $thrstmt, $thrordering);

}


############################
### thread group methods ###
############################

sub sysmtTGMaster
{

    my ( $dbh, $user ) = @_;

    my ( $headmsg, $fullname, $sysmsg )  = PerlSpace::SysMtUtil::getHeaderInfo($dbh, $user);
    $$dbdata{'headertext'} = $headmsg;
    $$dbdata{'fullname'} = $fullname;
    $$dbdata{'sysmsg'} = $sysmsg;
    $$dbdata{'content'} = "sysmt_tgmaster.html";

    $TT ||= Template->new({ INCLUDE_PATH  => $PerlSpace::SysMtExecuter::tmplpath });
    $TT->process('sysmt_frame.html', $dbdata) || die $TT->error(), "\n";

    return 0;

}

sub sysmtTGList
{
    
    my ( $dbh, $user, $tgname) = @_;    

    my $stmt = "select tgid, tgname from sysmt_threadgroup where tgname like '%" . $tgname . "%'";    
    my $ordering = "order by tgname";
 
    return sysmtTGExecuteList($dbh, $user, $stmt, $ordering);

}

sub sysmtTGExecuteList
{
    
    my ( $dbh, $user, $stmt, $ordering ) = @_;

    my $sth = $dbh->prepare($stmt . " " . $ordering . ";");

    $sth->execute;
    
    my $dbdata;

    $$dbdata{'stmt'} = $stmt;

    
    my $i=0;
    while ( ($tgid, $tgname ) = $sth->fetchrow_array) 
    {
	$$dbdata{'tglist'}[$i]{'tgid'} = $tgid;
	$$dbdata{'tglist'}[$i]{'tgname'} = $tgname;
	$i++;
    }
    
    $sth->finish;    

    my ( $headmsg, $fullname, $sysmsg )  = PerlSpace::SysMtUtil::getHeaderInfo($dbh, $user);
    $$dbdata{'headertext'} = $headmsg;
    $$dbdata{'fullname'} = $fullname;
    $$dbdata{'sysmsg'} = $sysmsg;    
    $$dbdata{'content'} = "sysmt_tglist.html";

    $TT ||= Template->new({ INCLUDE_PATH  => $PerlSpace::SysMtExecuter::tmplpath });
    $TT->process('sysmt_frame.html', $dbdata) || die $TT->error(), "\n";

    return 0;

}


sub sysmtTG
{
    
    my ( $dbh, $user, $tgid ) = @_;

    my $dbdata;

    # reached groups retrievel
    $stmt="select bgname from sysmt_bgroup bg, sysmt_tg2bgrp tg2g where tg2g.tgid = ? and tg2g.bgid = bg.bgid;";
    $sth = $dbh->prepare($stmt);
    $sth->bind_param(1, $tgid, DBI::SQL_INTEGER);
    
    $sth->execute;
        
    my $bgroups = "";
    $$dbdata{'bgroups'} = "";
    $i=0;
    while ( ($bg) = $sth->fetchrow_array) 
    {

	$$dbdata{'delbglist'}[$i] = $bg;

	if ( $$dbdata{'bgroups'} eq "" )
	{
	    $$dbdata{'bgroups'} = $bg;
	}
	else
	{
	    $$dbdata{'bgroups'} = $$dbdata{'bgroups'} . "," . $bg;
	}
	$i++;
    }
    
    $sth->finish;    


    my $sth = $dbh->prepare("select tgname, tgdesc from sysmt_threadgroup where tgid = ?;");
    $sth->bind_param(1, $tgid, DBI::SQL_INTEGER);

    $sth->execute;
        
    my $tgname;
    my $tgdesc;

    ( $tgname, $tgdesc) = $sth->fetchrow_array; 

    $$dbdata{'tgid'} = $tgid;
    $$dbdata{'tgname'} = $tgname;
    $$dbdata{'tgdesc'} = $tgdesc;
    
    $sth->fetchrow_array; 
    $sth->finish;

    # retrieve adding business groups information

    $stmt="select bgname from sysmt_bgroup bg where bgid not in ( select bgid from sysmt_tg2bgrp tg2g where tg2g.tgid = ? ) order by bgname;";

    $sth = $dbh->prepare($stmt);
    $sth->bind_param(1, $tgid, DBI::SQL_INTEGER);

    $sth->execute;
        
    my $sidname;	
    my $i=0;
    while ( ($group) = $sth->fetchrow_array) 
    {
	$$dbdata{'addbglist'}[$i] = $group;
	$i++;
    }
    
    $sth->finish;

    my ( $headmsg, $fullname, $sysmsg )  = PerlSpace::SysMtUtil::getHeaderInfo($dbh, $user);
    $$dbdata{'headertext'} = $headmsg;
    $$dbdata{'fullname'} = $fullname;
    $$dbdata{'sysmsg'} = $sysmsg;
    $$dbdata{'content'} = "sysmt_tg.html";

    $TT ||= Template->new({ INCLUDE_PATH  => $PerlSpace::SysMtExecuter::tmplpath });
    $TT->process('sysmt_frame.html', $dbdata) || die $TT->error(), "\n";

    return 0;

}


sub sysmtTGNew
{

    my ( $dbh, $user ) = @_;

    my $dbdata;

    my ( $headmsg, $fullname, $sysmsg )  = PerlSpace::SysMtUtil::getHeaderInfo($dbh, $user);
    $$dbdata{'headertext'} = $headmsg;
    $$dbdata{'fullname'} = $fullname;
    $$dbdata{'sysmsg'} = $sysmsg;
    $$dbdata{'content'} = "sysmt_tgnew.html";

    $TT ||= Template->new({ INCLUDE_PATH  => $PerlSpace::SysMtExecuter::tmplpath });
    $TT->process('sysmt_frame.html', $dbdata) || die $TT->error(), "\n";

    return 0;

}

sub sysmtTGCreate
{

    my ( $dbh, $user, $tgname, $tgdesc ) = @_;


    # trim left and right whitespaces
    $tgname =~ s/^\s+//;
    $tgname =~ s/\s+$//;

    my $dbdata;
    my $tgid;

    if ( $PerlSpace::SysMtExecuter::db eq "cego" )
    {
	$sth = $dbh->prepare("? = call newThreadGroup ( ?, ? );");	      
	$sth->bind_param_inout(1, \$tgid, 10);
	$sth->bind_param(2, $tgname, DBI::SQL_VARCHAR);
	$sth->bind_param(3, $tgdesc, DBI::SQL_VARCHAR);
    
	$sth->execute;

    }
    elsif ( $PerlSpace::SysMtExecuter::db eq "mysql" )
    {
	$sth = $dbh->prepare("select newThreadGroup(?, ?);");

	$sth->bind_param(1, $tgname, DBI::SQL_VARCHAR);
	$sth->bind_param(2, $tgdesc, DBI::SQL_VARCHAR);

	$sth->execute;
	$tgid = $sth->fetchrow_array;

    }
    elsif ( $PerlSpace::SysMtExecuter::db eq "db2" )
    {
	$sth = $dbh->prepare(q{call newThreadGroup ( ?, ?, ?)});

	$sth->bind_param(1, $tgname, DBI::SQL_VARCHAR);
	$sth->bind_param(2, $tgdesc, DBI::SQL_VARCHAR);
	$sth->bind_param_inout(3, \$tgid, 10);

	$sth->execute;

    }

    $sth->finish;    

    return sysmtTG($dbh, $user, $tgid);

}

sub sysmtTGUpdate
{

    my ( $dbh, $user, $tgid, $tgname, $tgdesc ) = @_;
        
    $sth = $dbh->prepare("update sysmt_threadgroup set tgname = ?, tgdesc = ? where tgid = ?;");
     
    $sth->bind_param(1, $tgname, DBI::SQL_VARCHAR);
    $sth->bind_param(2, $tgdesc, DBI::SQL_VARCHAR);
    $sth->bind_param(3, $tgid, DBI::SQL_INTEGER);

    $sth->execute;

    $sth->finish;    

    return sysmtTG($dbh, $user, $tgid);

}

sub sysmtTGDelete
{

    my ( $dbh, $user, $tgid ) = @_;
    
    my $dbdata;
    
    $sth = $dbh->prepare("delete from sysmt_tg2bgrp where tgid = ?;");    
    $sth->bind_param(1, $uid, DBI::SQL_INTEGER);

    $sth->execute;

    $sth->finish;    

    $sth = $dbh->prepare("delete from sysmt_threadgroup where tgid = ?;");   
    $sth->bind_param(1, $tgid, DBI::SQL_INTEGER);

    $sth->execute;

    $sth->finish;    

    return sysmtTGList($dbh, $user, "");

}


sub sysmtTGAdd2Grp
{

    my ( $dbh, $user, $tgid, $bgname ) = @_;
    
    my $dbdata;
    
    $sth = $dbh->prepare("insert into sysmt_tg2bgrp values ( ?, ( select bgid from sysmt_bgroup where bgname = ? ));");
    
    $sth->bind_param(1, $tgid, DBI::SQL_INTEGER);
    $sth->bind_param(2, $bgname, DBI::SQL_VARCHAR);
    
    $sth->execute;

    $sth->finish;    

    return sysmtTG($dbh, $user, $tgid);

}


sub sysmtTGDelFromGrp
{

    my ( $dbh, $user, $tgid, $bgname ) = @_;

    my $dbdata;

    
    $sth = $dbh->prepare("delete from sysmt_tg2bgrp where bgid = ( select bgid from sysmt_bgroup where bgname = ? ) and tgid = ?;");
    
    $sth->bind_param(1, $bgname, DBI::SQL_VARCHAR);
    $sth->bind_param(2, $tgid, DBI::SQL_INTEGER);

    $sth->execute;

    $sth->finish;

    return sysmtTG($dbh, $user, $tgid);

}

sub addLogEntry
{

    my ( $dbh, $user, $thrid, $logentry ) = @_;

    $logentry = " " . $logentry . " ";

    # $logentry =~ s!(\s)(http://\w.*?)(\s)!$1<a href="$2">$2</a>$3!gm;


    if ( $PerlSpace::SysMtExecuter::db eq "cego" )
    {
	$sth = $dbh->prepare("insert into sysmt_threadlog ( logts, dbuser, logentry, thrid ) values ( sysdate, ?, ?, ?);");
    }
    elsif ( $PerlSpace::SysMtExecuter::db eq "mysql" )
    {
	$sth = $dbh->prepare("insert into sysmt_threadlog ( logts, dbuser, logentry, thrid ) values ( now(), ?, ?, ?);");
    }
    elsif ( $PerlSpace::SysMtExecuter::db eq "db2" )
    {
	$sth = $dbh->prepare("insert into sysmt_threadlog ( logts, dbuser, logentry, thrid ) values ( current timestamp, ?, ?, ?);");
    }

    $sth->bind_param(1, $user, DBI::SQL_VARCHAR);
    $sth->bind_param(2, $logentry, DBI::SQL_VARCHAR);
    $sth->bind_param(3, $thrid, DBI::SQL_INTEGER);

    $sth->execute;

    $sth->finish;


    if ( $PerlSpace::SysMtExecuter::db eq "cego" )
    {
	$sth = $dbh->prepare("update sysmt_thread set lastedit = sysdate, lasteditby = ? where thrid = ?;");
    }
    elsif ( $PerlSpace::SysMtExecuter::db eq "mysql" )
    {
	$sth = $dbh->prepare("update sysmt_thread set lastedit = now(), lasteditby = ? where thrid = ?;");
    }
    elsif ( $PerlSpace::SysMtExecuter::db eq "db2" )
    {
	$sth = $dbh->prepare("update sysmt_thread set lastedit = current timestamp, lasteditby = ? where thrid = ?;");
    }

    $sth->bind_param(1, $user, DBI::SQL_VARCHAR);
    $sth->bind_param(2, $thrid, DBI::SQL_INTEGER);

    $sth->execute;

    $sth->finish;


    $sth = $dbh->prepare("delete from sysmt_threadstat where thrid = ?;");
    $sth->bind_param(1, $thrid, DBI::SQL_INTEGER);
    
    $sth->execute;

    $sth->finish;
    
}

1;
