#
# sysmt_util.pm
# -------------
#
# Design and Implementation by Bjoern Lemke               
#           
# (C)opyright 2010,2011,2012 by Bjoern Lemke
#                                              
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2, or (at your option)
# any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; see the file COPYING.  If not, write to
# the Free Software Foundation, 59 Temple Place - Suite 330,
# Boston, MA 02111-1307, USA.
#

package PerlSpace::SysMtUtil;

sub getYearList
{
    return ("2008", "2009","2010", "2011", "2012", "2013","2014","2015","2016");
}

sub getMonthList
{
    return ("01","02","03","04","05","06","07","08","09","10","11","12");
}

sub getDayList
{
    my ( $year, $month ) = @_;

    if ( $month eq "01" || $month eq "03" || $month eq "05" || $month eq "07" || $month eq "08" || $month eq "10" || $month eq "12" )
    {
	return ("01","02","03","04","05","06","07","08","09","10","11","12","13","14","15","16","17","18","19","20","21","22","23","24","25","26","27","28","29","30","31");    
    }
    elsif ( $month eq "04" || $month eq "06" || $month eq "09" || $month eq "11" )
    {
	return ("01","02","03","04","05","06","07","08","09","10","11","12","13","14","15","16","17","18","19","20","21","22","23","24","25","26","27","28","29","30");    
    }
    elsif ( $month eq "02" )
    {
	if ( $year eq "2012" || $year eq "2016" ) 
	{
	    return ("01","02","03","04","05","06","07","08","09","10","11","12","13","14","15","16","17","18","19","20","21","22","23","24","25","26","27","28","29");
	}
	else
	{
	    return ("01","02","03","04","05","06","07","08","09","10","11","12","13","14","15","16","17","18","19","20","21","22","23","24","25","26","27","28");
	}
    }

    return ("01","02","03","04");    
}

sub get_day 
{
    my @weekday = qw(So Mo Di Mi Do Fr Sa );

    my $date = shift || return(0);
    my ($mday,$month,$year) = $date =~ /(\d+).(\d+).(\d+)/;
    my $epochtime = Time::Local::timelocal_nocheck(0, 0, 0, $mday, $month-1, $year);
    my $day = (localtime($epochtime))[6];
    return $weekday[$day];
}


sub getMtReadSidForUser
{

    my ( $dbh, $user ) = @_;

    $stmt="select distinct sid from sysmt_system s, sysmt_project p, sysmt_prj2bgrp p2g, sysmt_usr2bgrp u2g, sysmt_bgright r, sysmt_user u  where s.pid = p.pid and p.pid = p2g.pid and p.pid = p2g.pid and p2g.bgid = u2g.bgid and u.dbuser = ? and u.uid = u2g.uid and r.bgid = u2g.bgid and r.bgright = 'mtread' order by sid;";

    my $sth = $dbh->prepare($stmt);
    $sth->bind_param(1, $user, DBI::SQL_VARCHAR);
    
    return executeListStmt($sth);
    
}


sub getMtReadProjectForUser
{

    my ( $dbh, $user ) = @_;

    my $stmt="select distinct prjname from sysmt_project p, sysmt_prj2bgrp p2g, sysmt_usr2bgrp u2g, sysmt_bgright r, sysmt_user u  where p.pid = p2g.pid and p2g.bgid = u2g.bgid and u.dbuser = ? and u.uid = u2g.uid and r.bgid = u2g.bgid and r.bgright = 'mtread' order by prjname;";

    my $sth = $dbh->prepare($stmt);
    $sth->bind_param(1, $user, DBI::SQL_VARCHAR);
    
    return executeListStmt($sth);

}

sub getMtWriteSidForUser
{

    my ( $dbh, $user ) = @_;

    $stmt="select distinct sid from sysmt_system s, sysmt_project p, sysmt_prj2bgrp p2g, sysmt_usr2bgrp u2g, sysmt_bgright r, sysmt_user u where s.pid = p.pid and p.pid = p2g.pid and p.pid = p2g.pid and p2g.bgid = u2g.bgid and u.dbuser = ? and u.uid = u2g.uid and r.bgid = u2g.bgid  and r.bgright = 'mtwrite' order by sid;";

    my $sth = $dbh->prepare($stmt);
    $sth->bind_param(1, $user, DBI::SQL_VARCHAR);
    
    return executeListStmt($sth);
    
}


sub getMtWriteProjectForUser
{

    my ( $dbh, $user ) = @_;

    my $stmt="select distinct prjname from sysmt_project p, sysmt_prj2bgrp p2g, sysmt_usr2bgrp u2g, sysmt_bgright r, sysmt_user u  where p.pid = p2g.pid and p2g.bgid = u2g.bgid and u.dbuser = ? and u.uid = u2g.uid and r.bgid = u2g.bgid and r.bgright = 'mtwrite' order by prjname;";


    my $sth = $dbh->prepare($stmt);
    $sth->bind_param(1, $user, DBI::SQL_VARCHAR);
    
    return executeListStmt($sth);
    
}


sub getSysReadSidForUser
{

    my ( $dbh, $user ) = @_;

    $stmt="select distinct sid from sysmt_system s, sysmt_project p, sysmt_prj2bgrp p2g, sysmt_usr2bgrp u2g, sysmt_bgright r, sysmt_user u where s.pid = p.pid and p.pid = p2g.pid and p.pid = p2g.pid and p2g.bgid = u2g.bgid and u.dbuser = ? and u.uid = u2g.uid and r.bgid = u2g.bgid and r.bgright = 'sysread' order by sid;";

    my $sth = $dbh->prepare($stmt);
    $sth->bind_param(1, $user, DBI::SQL_VARCHAR);
    
    return executeListStmt($sth);
    
}


sub getSysReadProjectForUser
{

    my ( $dbh, $user ) = @_;

    my $stmt="select distinct prjname from sysmt_project p, sysmt_prj2bgrp p2g, sysmt_usr2bgrp u2g, sysmt_bgright r, sysmt_user u  where p.pid = p2g.pid and p2g.bgid = u2g.bgid and u.dbuser = ? and u.uid = u2g.uid and r.bgid = u2g.bgid and r.bgright = 'sysread' order by prjname;";

    my $sth = $dbh->prepare($stmt);
    $sth->bind_param(1, $user, DBI::SQL_VARCHAR);
    
    return executeListStmt($sth);
    
}


sub getSysWriteSidForUser
{

    my ( $dbh, $user ) = @_;

    $stmt="select distinct sid from sysmt_system s, sysmt_project p, sysmt_prj2bgrp p2g, sysmt_usr2bgrp u2g, sysmt_bgright r, sysmt_user u where s.pid = p.pid and p.pid = p2g.pid and p.pid = p2g.pid and p2g.bgid = u2g.bgid and u.dbuser = ? and u.uid = u2g.uid and r.bgid = u2g.bgid and r.bgright = 'syswrite' order by sid;";

    my $sth = $dbh->prepare($stmt);
    $sth->bind_param(1, $user, DBI::SQL_VARCHAR);
    
    return executeListStmt($sth);
    
}


sub getSysWriteProjectForUser
{

    my ( $dbh, $user ) = @_;

    my $stmt="select distinct prjname from sysmt_project p, sysmt_prj2bgrp p2g, sysmt_usr2bgrp u2g, sysmt_bgright r, sysmt_user u  where p.pid = p2g.pid and p2g.bgid = u2g.bgid and u.dbuser = ? and u.uid = u2g.uid and r.bgid = u2g.bgid and r.bgright = 'syswrite' order by prjname;";

    my $sth = $dbh->prepare($stmt);
    $sth->bind_param(1, $user, DBI::SQL_VARCHAR);
    
    return executeListStmt($sth);
    
}


sub getRepSidForUser
{

    my ( $dbh, $user ) = @_;

    $stmt="select distinct sid from sysmt_system s, sysmt_project p, sysmt_prj2bgrp p2g, sysmt_usr2bgrp u2g, sysmt_bgright r, sysmt_user u where s.pid = p.pid and p.pid = p2g.pid and p.pid = p2g.pid and p2g.bgid = u2g.bgid and u.dbuser = ? and u.uid = u2g.uid and r.bgid = u2g.bgid and r.bgright = 'report' order by sid;";

    my $sth = $dbh->prepare($stmt);
    $sth->bind_param(1, $user, DBI::SQL_VARCHAR);
    
    return executeListStmt($sth);
    
}


sub getRepProjectForUser
{

    my ( $dbh, $user ) = @_;

    my $stmt="select distinct prjname from sysmt_project p, sysmt_prj2bgrp p2g, sysmt_usr2bgrp u2g, sysmt_bgright r, sysmt_user u where p.pid = p2g.pid and p2g.bgid = u2g.bgid and u.dbuser = ? and u.uid = u2g.uid and r.bgid = u2g.bgid and r.bgright = 'report' order by prjname;";

    my $sth = $dbh->prepare($stmt);
    $sth->bind_param(1, $user, DBI::SQL_VARCHAR);
    
    return executeListStmt($sth);
    
}

sub getMtReadSysSetForUser
{

    my ( $dbh, $user ) = @_;

    my $stmt="select distinct setname from sysmt_systemset ss, sysmt_set2bgrp s2g, sysmt_bgright r, sysmt_usr2bgrp u2g, sysmt_user u where ss.setid = s2g.setid and s2g.bgid = u2g.bgid and r.bgright = 'mtread' and r.bgid = u2g.bgid and u.dbuser = ? and u.uid = u2g.uid order by setname;";

    my $sth = $dbh->prepare($stmt);
    $sth->bind_param(1, $user, DBI::SQL_VARCHAR);
    
    return executeListStmt($sth);

}

sub getSysReadSysSetForUser
{

    my ( $dbh, $user ) = @_;

    my $stmt="select distinct setname from sysmt_systemset ss, sysmt_set2bgrp s2g, sysmt_bgright r, sysmt_usr2bgrp u2g, sysmt_user u where ss.setid = s2g.setid and s2g.bgid = u2g.bgid and r.bgright = 'sysread' and r.bgid = u2g.bgid and u.dbuser = ? and u.uid = u2g.uid order by setname;";


    my $sth = $dbh->prepare($stmt);
    $sth->bind_param(1, $user, DBI::SQL_VARCHAR);
    
    return executeListStmt($sth);

}

sub getSysWriteSysSetForUser
{

    my ( $dbh, $user ) = @_;

    my $stmt="select distinct setname from sysmt_systemset ss, sysmt_set2bgrp s2g, sysmt_bgright r, sysmt_usr2bgrp u2g, sysmt_user u where ss.setid = s2g.setid and s2g.bgid = u2g.bgid and r.bgright = 'sysread' and r.bgid = u2g.bgid and u.dbuser = ? and u.uid = u2g.uid order by setname;";


    my $sth = $dbh->prepare($stmt);
    $sth->bind_param(1, $user, DBI::SQL_VARCHAR);
    
    return executeListStmt($sth);

}


sub getSLAProjectForUser
{

    my ( $dbh, $user ) = @_;

    my $stmt="select distinct prjname from sysmt_project p, sysmt_prj2bgrp p2g, sysmt_usr2bgrp u2g, sysmt_bgright r, sysmt_user u where p.pid = p2g.pid and p2g.bgid = u2g.bgid and u.dbuser = ? and u.uid = u2g.uid and r.bgid = u2g.bgid and r.bgright = 'sla' order by prjname;";


    my $sth = $dbh->prepare($stmt);
    $sth->bind_param(1, $user, DBI::SQL_VARCHAR);
    
    return executeListStmt($sth);
    
}

sub getSLASidForUser
{

    my ( $dbh, $user ) = @_;

    my $stmt="select distinct sid from sysmt_system s, sysmt_prj2bgrp p2g, sysmt_usr2bgrp u2g, sysmt_bgright r, sysmt_user u where s.pid = p2g.pid and p2g.bgid = u2g.bgid and u.dbuser = ? and u.uid = u2g.uid and r.bgid = u2g.bgid and r.bgright = 'sla' order by sid;";

    my $sth = $dbh->prepare($stmt);
    $sth->bind_param(1, $user, DBI::SQL_VARCHAR);
    
    return executeListStmt($sth);
    
}

sub getBGroupForUser
{

    my ( $dbh, $user ) = @_;

    my $stmt="select distinct bgname from sysmt_bgroup bg, sysmt_usr2bgrp u2g, sysmt_bgright r, sysmt_user u where bg.bgid = u2g.bgid and u.dbuser = ? and u.uid = u2g.uid and r.bgid = u2g.bgid and r.bgright = 'thread' order by bgname;";

    my $sth = $dbh->prepare($stmt);
    $sth->bind_param(1, $user, DBI::SQL_VARCHAR);
    
    return executeListStmt($sth);
    
}


sub getBGroupForTGroup
{

    my ( $dbh, $tgname ) = @_;

    my $stmt="select distinct bgname from sysmt_bgroup bg, sysmt_tg2bgrp tg2bg, sysmt_threadgroup tg where bg.bgid = tg2bg.bgid and tg2bg.tgid = tg.tgid and tg.tgname = ? order by bgname;";

    my $sth = $dbh->prepare($stmt);
    $sth->bind_param(1, $tgname, DBI::SQL_VARCHAR);
    
    return executeListStmt($sth);
    
}


sub getFWSGList
{

    my ( $dbh ) = @_;

    my $stmt="select sgname from sysmt_fwsg order by sgname;";

    my $sth = $dbh->prepare($stmt);
    # $sth->bind_param(1, $user, DBI::SQL_VARCHAR);
    
    return executeListStmt($sth);
    
}

sub getFWPSList
{

    my ( $dbh ) = @_;

    my $stmt="select psname from sysmt_fwps order by psname;";

    my $sth = $dbh->prepare($stmt);
    # $sth->bind_param(1, $user, DBI::SQL_VARCHAR);
    
    return executeListStmt($sth);
    
}

sub getSLAForSysId
{

    my ( $dbh, $sysid ) = @_;


    my $stmt="select distinct slanr from sysmt_sla sl, sysmt_sla2prj s2p, sysmt_system s where s.sysid = ? and s.pid = s2p.pid and s2p.slaid = sl.slaid order by slanr;";

    my $sth = $dbh->prepare($stmt);
    $sth->bind_param(1, $sysid, DBI::SQL_INTEGER);
    
    return executeListStmt($sth);
    
}


sub executeListStmt
{

    my ( $sth ) = @_;

    $sth->execute;
    
    my $val;	
    my @vallist;
    $i=0;
    while ( ($val) = $sth->fetchrow_array) 
    {
	# warn "Adding Val " . $val;

	$vallist[$i] = $val;
	$i++;
    }
    
    $sth->finish;    

    return @vallist;

}

sub getValueForSys
{

    my ( $dbh, $sysid, $attr ) = @_;

    my $stmt="select " . $attr . " from sysmt_system where sysid = ?;";

    my $sth = $dbh->prepare($stmt);
    $sth->bind_param(1, $sysid, DBI::SQL_INTEGER);
    
    $sth->execute;
    
    my $val;	

    ( $val ) = $sth->fetchrow_array;
    
    $sth->finish;

    return $val;
    
}

sub getPlatform
{

    my ( $dbh, $sysid ) = @_;

    my $stmt="select platform from sysmt_system where sysid = ?;";

    my $sth = $dbh->prepare($stmt);
    $sth->bind_param(1, $sysid, DBI::SQL_INTEGER);
    
    $sth->execute;
    
    my $platform;	

    ( $platform ) = $sth->fetchrow_array;
    
    $sth->finish;

    return $platform;
    
}

sub getCITmplForSys
{

    my ( $dbh, $sysid ) = @_;

    my $stmt="select tmplid, fstmplrule from sysmt_filesystmpl where fstmpltype = 'CI';";

    my $sth = $dbh->prepare($stmt);
    
    $sth->execute;
    
    my $tmplid;
    my $rule;
    my @tmplcache;
    
    $i=0;
    while ( ($tmplid, $rule) = $sth->fetchrow_array) 
    {
	$tmplcache[$i]{'tmplid'} = $tmplid;
	$tmplcache[$i]{'tmplrule'} = $rule;
	$i++;
    }
    $sth->finish;    

    $i=0;
    $j=0;
    my @tmplidlist;
    foreach my $tmpl ( @tmplcache )
    {
	if (  PerlSpace::SysMtUtil::checkSysForRule($dbh, $sysid, $$tmpl{'tmplrule'}) eq "ok" )
	{
	    $tmplidlist[$j] = $$tmpl{'tmplid'};
	    $j++;
	}
	$i++;
    }

    return @tmplidlist;
    
}

sub getDITmplForSys
{

    my ( $dbh, $sysid ) = @_;

    my $stmt="select tmplid, fstmplrule from sysmt_filesystmpl where fstmpltype = 'DI';";

    my $sth = $dbh->prepare($stmt);
    
    $sth->execute;
    
    my $tmplid;
    my $rule;
    my @tmplcache;
    
    $i=0;
    while ( ($tmplid, $rule) = $sth->fetchrow_array) 
    {
	$tmplcache[$i]{'tmplid'} = $tmplid;
	$tmplcache[$i]{'tmplrule'} = $rule;
	$i++;
    }
    $sth->finish;    

    $i=0;
    my @tmplidlist;
    foreach my $tmpl ( @tmplcache )
    {
	if (  PerlSpace::SysMtUtil::checkInstForRule($dbh, $sysid, $$tmpl{'tmplrule'}) eq "ok" )
	{
	    $tmplidlist[$i] = $$tmpl{'tmplid'};
	    $i++;
	}
    }

    return @tmplidlist;
    
}

sub checkSysForRule
{

    my ( $dbh, $sysid, $rule ) = @_;

    # warn "sysid=" . $sysid;

    my $stmt="select 'x' from sysmt_systemview sys where sysid = ? and " . $rule . ";";
    
    # warn "SysRule Stmt=" . $stmt;
    
    my $sth = $dbh->prepare($stmt);
    $sth->bind_param(1, $sysid, DBI::SQL_INTEGER);
    
    $sth->execute;
    
    my $ret="notok";
    if ( ($x) = $sth->fetchrow_array) 
    {
	$ret="ok";
    }
    $sth->finish;    
    
    return $ret;
    
}

sub checkInstForRule
{

    my ( $dbh, $sysid, $rule ) = @_;

    # warn "sysid=" . $sysid;

    my $stmt="select 'x' from sysmt_instance i, sysmt_system s where s.sysid = i.sysid and s.sysid = ? and " . $rule . ";";

    # warn "InstRule Stmt=" . $stmt;    
    # warn "Stmt=" . $stmt;
    
    my $sth = $dbh->prepare($stmt);
    $sth->bind_param(1, $sysid, DBI::SQL_INTEGER);    
    
    $sth->execute;
    
    my $ret="notok";
    if ( ($x) = $sth->fetchrow_array) 
    {
	$ret="ok";
    }
    $sth->finish;    
    
    return $ret;
    
}


sub getUserSearchForUser
{

    my ( $dbh, $user ) = @_;

    my @uslist;

    my $stmt="select usid, usname, usspec from sysmt_usersearch us where uid = ( select uid from sysmt_user where dbuser = ? );";

    my $sth = $dbh->prepare($stmt);
    $sth->bind_param(1, $user, DBI::SQL_VARCHAR);
        
    $sth->execute;
        
    $i=0;
    while ( ($usid, $usname, $usspec) = $sth->fetchrow_array) 
    {       
	$uslist[$i]{'usid'} = $usid;
	$uslist[$i]{'usname'} = $usname;
	$uslist[$i]{'usspec'} = $usspec;
	$i++;
    }
    
    $sth->finish;    

    return @uslist;
    
}

sub getGroupSearchForUser
{

    my ( $dbh, $user ) = @_;

    my @gslist;


    my $stmt="select gsid, gsname, gsspec from sysmt_groupsearch gs where gs.gsid in ( select gsid from sysmt_gs2bgrp where bgid in ( select bgid from sysmt_usr2bgrp u2g, sysmt_user u where u2g.uid = u.uid and u.dbuser = '" . $user ."'));";

    my $sth = $dbh->prepare($stmt);
        
    $sth->execute;
 
    my $i=0;
    while ( ($gsid, $gsname, $gsspec) = $sth->fetchrow_array) 
    {       
	$gslist[$i]{'gsid'} = $gsid;
	$gslist[$i]{'gsname'} = $gsname;
	$gslist[$i]{'gsspec'} = $gsspec;
	$i++;
    }
    
    $sth->finish;

    return @gslist;
}

sub getUserName
{

    my ( $dbh, $uid ) = @_;

    my $stmt="select dbuser from sysmt_user where uid = ?;";
    my $sth = $dbh->prepare($stmt);
    $sth->bind_param(1, $uid, DBI::SQL_INTEGER);
    
    $sth->execute;
    
    my $dbuser = $sth->fetchrow_array;
    
    $sth->finish;    

    return $dbuser;
    
}

sub getUid
{

    my ( $dbh, $user ) = @_;

    my $stmt="select uid from sysmt_user where dbuser = ?;";
    my $sth = $dbh->prepare($stmt);
    $sth->bind_param(1, $user, DBI::SQL_VARCHAR);
    
    $sth->execute;
    
    my $uid = $sth->fetchrow_array;
    
    $sth->finish;    

    return $uid;
    
}



sub getUserFullname
{

    my ( $dbh, $user ) = @_;

    my $stmt="select username from sysmt_user where dbuser = ?;";
    my $sth = $dbh->prepare($stmt);
    $sth->bind_param(1, $user, DBI::SQL_VARCHAR);
    
    $sth->execute;
    
    my $fullname = $sth->fetchrow_array;
    
    $sth->finish;    

    return $fullname;
    
}


sub getHeaderInfo
{

    my ( $dbh, $user ) = @_;

    my $stmt="select username from sysmt_user where dbuser = ?;";
    my $sth = $dbh->prepare($stmt);
    $sth->bind_param(1, $user, DBI::SQL_VARCHAR);
    
    $sth->execute;
    
    my $fullname = $sth->fetchrow_array;
    
    $sth->finish;    

    my $sysmsg = getSystemParameter($dbh, 'SYSMSG');
    my $headmsg = getSystemParameter($dbh, 'HEADMSG');

    return ( $headmsg, $fullname, $sysmsg );
    
}



sub checkAdminRight
{

    my ( $dbh, $user ) = @_;

    my $stmt="select userright from sysmt_user where dbuser = ?;";
    my $sth = $dbh->prepare($stmt);
    $sth->bind_param(1, $user, DBI::SQL_VARCHAR);
    
    $sth->execute;
    
    my $userright = $sth->fetchrow_array;

    $sth->finish;
    
    if ( $userright eq "admin" )
    {
	return 1;
    }

    return 0;
    
}


sub checkMtWrite
{

    my ( $dbh, $user, $mid ) = @_;

    $stmt="select mid from sysmt_mt mt, sysmt_system s, sysmt_project p, sysmt_prj2bgrp p2g, sysmt_usr2bgrp u2g, sysmt_bgright r, sysmt_user u  where mt.mid = ? and  mt.sysid = s.sysid and s.pid = p.pid and s.pid = p.pid and p.pid = p2g.pid and p.pid = p2g.pid and p2g.bgid = u2g.bgid and u.dbuser = ? and u.uid = u2g.uid and r.bgid = u2g.bgid  and r.bgright = 'mtwrite';";

    my $sth = $dbh->prepare($stmt);
    $sth->bind_param(1, $mid, DBI::SQL_INTEGER);
    $sth->bind_param(2, $user, DBI::SQL_VARCHAR);
    
    
    $sth->execute;
    
    my $checkmid = $sth->fetchrow_array;

    $sth->finish;
    
    if ( $checkmid eq $mid )
    {
	return 1;
    }

    return 0;
    
}


sub checkResourceWrite
{

    my ( $dbh, $user, $mid ) = @_;

    $stmt="select mid from sysmt_mt mt, sysmt_system s, sysmt_project p, sysmt_prj2bgrp p2g, sysmt_usr2bgrp u2g, sysmt_bgright r, sysmt_user u  where mt.mid = ? and  mt.sysid = s.sysid and s.pid = p.pid and s.pid = p.pid and p.pid = p2g.pid and p.pid = p2g.pid and p2g.bgid = u2g.bgid and u.dbuser = ? and u.uid = u2g.uid and r.bgid = u2g.bgid  and r.bgright = 'reswrite';";

    my $sth = $dbh->prepare($stmt);
    $sth->bind_param(1, $mid, DBI::SQL_INTEGER);
    $sth->bind_param(2, $user, DBI::SQL_VARCHAR);
    
    $sth->execute;
    
    my $checkmid = $sth->fetchrow_array;

    $sth->finish;
    
    if ( $checkmid eq $mid )
    {
	return 1;
    }

    return 0;
    
}


sub checkResourceRead
{

    my ( $dbh, $user ) = @_;

    $stmt="select bgid from sysmt_usr2bgrp u2g, sysmt_bgright r, sysmt_user u where u.dbuser = ? and u.uid = u2g.uid and r.bgid = u2g.bgid and r.bgright = 'resread';";

    my $sth = $dbh->prepare($stmt);
    $sth->bind_param(1, $user, DBI::SQL_VARCHAR);
    
    $sth->execute;
    
    my $bgid = $sth->fetchrow_array;

    $sth->finish;
    
    if ( $bgid )
    {
	return 1;
    }

    return 0;
    
}



sub checkSysRead
{

    my ( $dbh, $user, $sysid ) = @_;
    
    $stmt="select sysid from sysmt_system s, sysmt_project p, sysmt_prj2bgrp p2g, sysmt_usr2bgrp u2g, sysmt_bgright r, sysmt_user u where s.sysid = ? and s.pid = p.pid and s.pid = p.pid and p.pid = p2g.pid and p.pid = p2g.pid and p2g.bgid = u2g.bgid and u.dbuser = ? and u.uid = u2g.uid and r.bgid = u2g.bgid and r.bgright = 'sysread';";

    return checkSys($dbh, $user, $sysid, $stmt);
}

sub checkSysWrite
{

    my ( $dbh, $user, $sysid ) = @_;

    $stmt="select sysid from sysmt_system s, sysmt_project p, sysmt_prj2bgrp p2g, sysmt_usr2bgrp u2g, sysmt_bgright r, sysmt_user u where s.sysid = ? and s.pid = p.pid and s.pid = p.pid and p.pid = p2g.pid and p.pid = p2g.pid and p2g.bgid = u2g.bgid and u.dbuser = ? and u.uid = u2g.uid and r.bgid = u2g.bgid and r.bgright = 'syswrite';";

    return checkSys($dbh, $user, $sysid, $stmt);
}

sub checkSys
{

    my ( $dbh, $user, $sysid, $stmt ) = @_;
    
    my $sth = $dbh->prepare($stmt);
    $sth->bind_param(1, $sysid, DBI::SQL_INTEGER);
    $sth->bind_param(2, $user, DBI::SQL_VARCHAR);
    
    $sth->execute;
    
    my $checksysid = $sth->fetchrow_array;

    $sth->finish;
 
    if ( $checksysid eq $sysid )
    {
	return 1;
    }

    return 0;
    
}


sub getGroupSetForUser
{

    my ( $dbh, $user ) = @_;

    my $stmt="select distinct bgname from sysmt_bgroup g, sysmt_usr2bgrp u2g, sysmt_user u where g.bgid = u2g.bgid and u2g.uid = u.uid and u.dbuser = ?;";

    my $sth = $dbh->prepare($stmt);
    $sth->bind_param(1, $user, DBI::SQL_VARCHAR);
    
    $sth->execute;
    
    my $group;	
    my @grouplist;
    
    $i=0;
    while ( ($group) = $sth->fetchrow_array) 
    {
	$grouplist[$i] = $group;
	$i++;
    }
    
    $sth->finish;    

    return @grouplist;

}

sub getApprovalStatus
{

    my ( $dbh, $mid, $bgname ) = @_;

    my $stmt="select status from sysmt_mtapproval ma, sysmt_bgroup g where ma.mid = ? and ma.bgid = g.bgid and g.bgname = ?;";
    my $sth = $dbh->prepare($stmt);
    $sth->bind_param(1, $mid, DBI::SQL_INTEGER);
    $sth->bind_param(2, $bgname, DBI::SQL_VARCHAR);
    
    $sth->execute;
    
    my $status;
    if ( !( $status = $sth->fetchrow_array ) )
    {
	$status = "NA";
    }
    else
    {
	$status = "NA";
    }
    
    $sth->finish;    

    return $status;

}

sub setApprovalStatus
{

    my ( $dbh, $mid, $bgname, $status ) = @_;
    
    
    $sth = $dbh->prepare("update sysmt_mtapproval set status = ? where mid = ? and bgid = ( select bgid from sysmt_bgroup where gbname = ? ) ;");
    $sth->bind_param(1, $status, DBI::SQL_VARCHAR);
    $sth->bind_param(2, $mid, DBI::SQL_INTEGER);
    $sth->bind_param(3, $bgname, DBI::SQL_VARCHAR);
    
    $sth->execute;

    $sth->finish;
}

sub getApprovalInfo
{

    my ( $dbh, $mid ) = @_;

    my $stmt="select bgname, status from sysmt_mtapproval ma, sysmt_bgroup g where ma.mid = ? and ma.bgid = g.bgid order by bgname;";
    my $sth = $dbh->prepare($stmt);
    $sth->bind_param(1, $mid, DBI::SQL_INTEGER);
    
    $sth->execute;
    
    my $appinfo = "<table class=approval style=\"table-layout:fixed;width:150px\">";
    $appinfo = $appinfo . "<colgroup><col style=\"width:60px\"><col style=\"width:45px\"></colgroup>";
    while ( ( $bgname, $status) = $sth->fetchrow_array )
    {
	$appinfo = $appinfo . "<tr><td class=approval>" .$bgname . "</td><td class=". $status . ">" . $status . "</td></tr>";
    }
    $sth->finish;    


    # warn "Appinfo is " . $appinfo;
    $appinfo = $appinfo . "</table>";

    return $appinfo;
    
}

sub getVerificationInfo
{

    my ( $dbh, $mid ) = @_;

    my $stmt="select bgname, status from sysmt_mtverification ma, sysmt_bgroup g where ma.mid = ? and ma.bgid = g.bgid order by bgname;";
    my $sth = $dbh->prepare($stmt);
    $sth->bind_param(1, $mid, DBI::SQL_INTEGER);

    $sth->execute;

    my $verinfo = "<table class=verification>";
    while ( ( $bgname, $status) = $sth->fetchrow_array )
    {
        $verinfo = $verinfo . "<tr><td class=verification>" .$bgname . "</td><td class=". $status . ">" . $status . "</td></tr>";
    }
    $sth->finish;


    $verinfo = $verinfo . "</table>";

    return $verinfo;

}



sub getBGid
{

    my ( $dbh, $bgname ) = @_;

    my $stmt="select bgid from sysmt_bgroup where bgname = ?;";
    my $sth = $dbh->prepare($stmt);
    $sth->bind_param(1, $bgname, DBI::SQL_VARCHAR);
    
    $sth->execute;
    
    my $bgid = $sth->fetchrow_array;
    $sth->finish;    

    return $bgid;

}

sub getVipForSid
{

    my ( $dbh, $sid ) = @_;

    my $stmt="select vip from sysmt_system where sid = ?;";
    my $sth = $dbh->prepare($stmt);
    $sth->bind_param(1, $sid, DBI::SQL_VARCHAR);
    
    $sth->execute;
    
    my $vip = $sth->fetchrow_array;
    $sth->finish;    

    return $vip;

}

sub getIdForSid
{

    my ( $dbh, $sid ) = @_;

    my $stmt="select sysid from sysmt_system where sid = ?;";
    my $sth = $dbh->prepare($stmt);
    $sth->bind_param(1, $sid, DBI::SQL_VARCHAR);
    
    $sth->execute;
    
    my $sysid = $sth->fetchrow_array;
    $sth->finish;    

    return $sysid;

}


sub getProjectForSid
{

    my ( $dbh, $sid ) = @_;

    my $stmt="select prjname from sysmt_systemview where sid = ?;";
    my $sth = $dbh->prepare($stmt);
    $sth->bind_param(1, $sid, DBI::SQL_VARCHAR);
    
    $sth->execute;
    
    my $project;
    if ( ! ( $project = $sth->fetchrow_array ) )
    {
	$project="";
    }
    $sth->finish;    

    return $project;

}

sub getSLAForId
{

    my ( $dbh, $slaid ) = @_;

    my $stmt="select slanr from sysmt_sla where slaid = ?;";
    my $sth = $dbh->prepare($stmt);
    $sth->bind_param(1, $slaid, DBI::SQL_INTEGER);
    
    $sth->execute;

    my $slanr = $sth->fetchrow_array;
    $sth->finish;    

    return $slanr;

}


sub getSystemParameter
{

    my ( $dbh, $pname ) = @_;

    my $stmt="select pval from sysmt_sysparam where pname = ?;";
    my $sth = $dbh->prepare($stmt);
    $sth->bind_param(1, $pname, DBI::SQL_VARCHAR);
    
    $sth->execute;

    my $pval = $sth->fetchrow_array;
    $sth->finish;    

    return $pval;

}


sub getCurrentDate
{
    ($second, $minute, $hour, $day, $month, $year, $weekDay, $dayOfYear, $isDST) = localtime(time);

    $year += 1900;
    $month++;
    $mstr = substr "0" . $month, -2, 2;
    $dstr = substr "0" . $day, -2, 2;

    return $dstr . "." . $mstr . "." . $year;
}

sub getCurrentMonth
{

    ($second, $minute, $hour, $day, $month, $year, $weekDay, $dayOfYear, $isDST) = localtime(time);
    $year += 1900;
    $month++;

    $mstr = substr "0" . $month, -2, 2;

    return $mstr;
}

sub getCurrentYear
{

    ($second, $minute, $hour, $day, $month, $year, $weekDay, $dayOfYear, $isDST) = localtime(time);
    $year += 1900;
    $month++;

    return $year;
}


sub getMonthIndex
{

    my ( $month ) = @_;

    if ( $month eq "01" )
    {
	return 0;
    }
    elsif ( $month eq "02" )
    {
	return 1;
    }
    elsif ( $month eq "03" )
    {
	return 2;
    }
    elsif ( $month eq "04" )
    {
	return 3;
    }
    elsif ( $month eq "05" )
    {
	return 4;
    }
    elsif ( $month eq "06" )
    {
	return 5;
    }
    elsif ( $month eq "07" )
    {
	return 6;
    }
    elsif ( $month eq "08" )
    {
	return 7;
    }
    elsif ( $month eq "09" )
    {
	return 8;
    }
    elsif ( $month eq "10" )
    {
	return 9;
    }
    elsif ( $month eq "11" )
    {
	return 10;
    }
    elsif ( $month eq "12" )
    {
	return 11;
    }
    return 0;
}

sub mysqlDate
{

    my ( $datestring ) = @_;
    
    my ( $d,$t ) = split(/ /, $datestring);
    my ( $day,$month,$year ) = split(/\./, $d);
    my ( $hour,$minute,$second ) = split(/:/, $t);

    return $year . "-" . $month . "-" . $day . " " . $t;
}

sub db2Date 
{
    my ( $d ) = @_;   
    my ($day,$month,$year) = $d =~ /(\d+).(\d+).(\d+)/;
    return $year . '-' . $month . '-' . $day . "-00.00.00";
}

sub db2DateTime
{
    my ( $d ) = @_;   
    my ($day,$month,$year,$hour,$min,$sec) = $d =~ /(\d+).(\d+).(\d+) (\d+):(\d+):(\d+)/;
    return $year . '-' . $month . '-' . $day . "-" . $hour . "." . $min . "." . $sec;
}

sub cgiEncode
{
    my ( $s ) = @_;   
    $s =~ s/ /\+/g;
    $s =~ s/,/%2C/g;
    $s =~ s/\(/%28/g;
    $s =~ s/'/%27/g;
    $s =~ s/%/%25/g;
    return $s;
}


sub logMtAction
{

    my ( $dbh, $mid, $logmsg  ) = @_;

    if ( $PerlSpace::SysMtExecuter::db eq "cego" )
    {
	$sth = $dbh->prepare("insert into sysmt_mtlog values ( sysdate, ?, ?);");
    }
    elsif ( $PerlSpace::SysMtExecuter::db eq "mysql" )
    {
	$sth = $dbh->prepare("insert into sysmt_mtlog values ( now(), ?, ?);");
    }
    elsif ( $PerlSpace::SysMtExecuter::db eq "db2" )
    {
	$sth = $dbh->prepare("insert into sysmt_mtlog values ( current timestamp, ?, ?);");
    }

    $sth->bind_param(1, $mid, DBI::SQL_INTEGER);
    $sth->bind_param(2, $logmsg, DBI::SQL_VARCHAR);

    $sth->execute;

    $sth->finish;    
}

sub addDocument
{

    my ( $dbh, $user, $doctype, $docpath  ) = @_;

    $docpath =~ s/\\/\//g;

    my ( @chunks ) = split(/\//, $docpath);    

    my $lastidx = @chunks-1;
    my $docname = $chunks[$lastidx];
    my $docid;

    if ( $PerlSpace::SysMtExecuter::db eq "cego" )
    {       
	$sth = $dbh->prepare("? = call newDocument ( ?, ? );");	
	$sth->bind_param_inout(1, \$docid, 10);
	$sth->bind_param(2, $doctype, DBI::SQL_VARCHAR);
	$sth->bind_param(3, $docname, DBI::SQL_VARCHAR);
    }
    elsif ( $PerlSpace::SysMtExecuter::db eq "mysql" )
    {	
	$sth = $dbh->prepare("select newDocument(?, ? );");
	$sth->bind_param(1, $doctype, DBI::SQL_VARCHAR);
	$sth->bind_param(2, $docname, DBI::SQL_VARCHAR);
	
    }
    elsif ( $PerlSpace::SysMtExecuter::db eq "db2" )
    {	
	$sth = $dbh->prepare(q{call newDocument(?,?,?)});	
	$sth->bind_param(1, $doctype, DBI::SQL_VARCHAR);
	$sth->bind_param(2, $docname, DBI::SQL_VARCHAR);
	$sth->bind_param_inout(3, \$docid, 100, DBI::SQL_INTEGER);
    }

    if ( $PerlSpace::SysMtExecuter::db eq "cego" )
    {	
	$sth->execute;
    }
    elsif ( $PerlSpace::SysMtExecuter::db eq "mysql" )
    {
	$sth->execute;
	$docid = $sth->fetchrow_array;
    }
    elsif ( $PerlSpace::SysMtExecuter::db eq "db2" )
    {
	$sth->execute;
    }
    
    $sth->finish;

    return $docid;

}


sub getSidsForSet
{

    my ( $dbh, $setname ) = @_;

    my $stmt="select sid from sysmt_system s, sysmt_sys2set s2s, sysmt_systemset ss where ss.setname = ? and ss.setid = s2s.setid and s2s.sysid = s.sysid;";

    my $sth = $dbh->prepare($stmt);
    $sth->bind_param(1, $setname, DBI::SQL_VARCHAR);

    $sth->execute;
    
    my $sids;

    ( $sids ) = $sth->fetchrow_array;

    my $i = 1;
    while ( ( $sid ) = $sth->fetchrow_array )
    {
	$sids = $sids . " " . $sid;
	$i++;
	if ( $i % 10 == 0)
	{
	    $sids = $sids . "\n";
	}
    }
    $sth->finish;

    return $sids;
}

sub getFWRSListForSys
{

    my ( $dbh, $sysid ) = @_;

    my $stmt="select rsid, rscond from sysmt_fwrs;";

    my $sth = $dbh->prepare($stmt);
    
    $sth->execute;
    
    my $rsid;
    my $rscond;
    my @rscache;
    
    $i=0;
    while ( ($rsid, $rscond) = $sth->fetchrow_array) 
    {
	$rscache[$i]{'rsid'} = $rsid;
	$rscache[$i]{'rscond'} = $rscond;
	$i++;
    }
    $sth->finish;    

    $i=0;
    my @rslist;
    foreach my $rs ( @rscache )
    {
	# warn "Checking system " . $sysid . " and cond " . $$rs{'rscond'};

	if (  PerlSpace::SysMtUtil::checkSysForRule($dbh, $sysid, $$rs{'rscond'}) eq "ok" )
	{
	    # warn "ok";

	    $rslist[$i] = $$rs{'rsid'};
	    $i++;
	}
    }

    return @rslist;
    
}

sub getSidListForThreadGroup
{

    my ( $dbh, $tgid ) = @_;

    my $stmt="select distinct sid from sysmt_tg2bgrp t2g, sysmt_prj2bgrp p2g, sysmt_system s where t2g.tgid = ? and t2g.bgid = p2g.bgid and p2g.pid = s.pid;";

    my $sth = $dbh->prepare($stmt);
    
    $sth->bind_param(1, $tgid, DBI::SQL_INTEGER);
    
    $sth->execute;
    
    my $sid;
    my @sidlist;
    
    $i=0;
    while ( $sid = $sth->fetchrow_array) 
    {
	$sidlist[$i] = $sid;
	$i++;
    }
    $sth->finish;    

    return @sidlist;
    
}


sub getUserListForThreadGroup
{

    my ( $dbh, $tgname ) = @_;

    my $stmt="select distinct dbuser, username from sysmt_user u, sysmt_usr2bgrp u2bg, sysmt_tg2bgrp tg2bg, sysmt_threadgroup tg where u.uid = u2bg.uid and u2bg.bgid = tg2bg.bgid and tg2bg.tgid = tg.tgid and tg.tgname = ? order by username;";

    my $sth = $dbh->prepare($stmt);
    
    $sth->bind_param(1, $tgname, DBI::SQL_VARCHAR);
    
    $sth->execute;
    
    my $dbuser;
    my $username;
    my @userlist;
    
    $i=0;
    while ( ( $dbuser, $username ) = $sth->fetchrow_array) 
    {
	$userlist[$i] = $dbuser . ":" . $username;
	$i++;
    }
    $sth->finish;    

    return @userlist;
    
}


sub getTGForUser
{

    my ( $dbh, $user ) = @_;

    $stmt="select distinct tgname from sysmt_threadgroup tg, sysmt_tg2bgrp tg2g, sysmt_usr2bgrp u2g, sysmt_bgright r, sysmt_user u where tg.tgid = tg2g.tgid and tg2g.bgid = u2g.bgid and u2g.uid = u.uid and u.dbuser = ? and r.bgid = tg2g.bgid and r.bgright = 'thread';";

    my $sth = $dbh->prepare($stmt);
    $sth->bind_param(1, $user, DBI::SQL_VARCHAR);
    
    return executeListStmt($sth);
    
}

sub checkFWWrite
{

    my ( $dbh, $user ) = @_;

    $stmt="select count(*) from sysmt_usr2bgrp u2g, sysmt_bgright r, sysmt_user u where u.dbuser = ? and u.uid = u2g.uid and r.bgid = u2g.bgid and r.bgright = 'fw';";

    my $sth = $dbh->prepare($stmt);
    $sth->bind_param(1, $user, DBI::SQL_VARCHAR);
        
    $sth->execute;

    my $numbg = $sth->fetchrow_array;

    $sth->finish;
 
    if ( $numbg > 0 )
    {
	return 1;
    }

    return 0;

}

sub getEmailForUser
{

    my ( $dbh, $dbuser ) = @_;

    $stmt="select usermail from sysmt_user where dbuser = ?;";

    my $sth = $dbh->prepare($stmt);
    $sth->bind_param(1, $dbuser, DBI::SQL_VARCHAR);
    
    $sth->execute;
    
    my $usermail = $sth->fetchrow_array;

    $sth->finish;

    return $usermail;
    
}

sub getThreadInfo
{

    my ( $dbh, $thrid, $thrcomment ) = @_;

    my $threadinfo;

    $stmt="select tgname, shortdesc from sysmt_threadview where thrid = ?;";

    my $sth = $dbh->prepare($stmt);
    $sth->bind_param(1, $thrid, DBI::SQL_INTEGER);
    
    $sth->execute;
    
    my $tgname;
    my $shortdesc;
    ( $tgname, $shortdesc ) = $sth->fetchrow_array;

    $sth->finish;

    $thrcomment =~ s/\r//g;

    $threadinfo = $thrcomment . "\n\n\n=============================================\n";
    $threadinfo = $threadinfo . $tgname . "-" . $thrid . " - " . $shortdesc . "\n";
    $threadinfo = $threadinfo . "=============================================\n\n\n";
   
    my $stmt;
 
    if ( $PerlSpace::SysMtExecuter::db eq "cego" )
    {  
       $stmt="select logts, logentry, dbuser from sysmt_threadlog where thrid = ? order by logts desc;";
    }
    elsif ( $PerlSpace::SysMtExecuter::db eq "mysql" )
    {
       $stmt="select logts, logentry, dbuser from sysmt_threadlog where thrid = ? order by logts desc;";
    }
    elsif ( $PerlSpace::SysMtExecuter::db eq "db2" )
    {
       $stmt="select ts_fmt(logts, 'dd.mm.yyyy hh:mi:ss'), logentry, dbuser from sysmt_threadlog where thrid = ? order by logts desc;";
    }

    my $sth = $dbh->prepare($stmt);
    $sth->bind_param(1, $thrid, DBI::SQL_INTEGER);
    
    $sth->execute;
    
    my $logts;
    my $logentry;
    my $dbuser;

    while (  ( $logts, $logentry, $dbuser ) = $sth->fetchrow_array )
    {

	$logentry =~ s/^\s+//;
	$logentry =~ s/\s+$//;
	# $logentry =~ s/\n/XXX/g;
	$logentry =~ s/\r//g;

	$threadinfo = $threadinfo . $logts . " - " . $dbuser . "\n---------------------------------------------\n" . $logentry . "\n\n";
    }

    $sth->finish;

    return $threadinfo;
    
}

sub getNumMtForThread
{

    my ( $dbh, $user, $thrid ) = @_;

    $stmt="select count(*) from sysmt_mtview m where thrid = ? and m.pid in " .
	" ( select pid from sysmt_prj2bgrp where bgid in " .
	" ( select distinct u2g.bgid from sysmt_usr2bgrp u2g, sysmt_user u, sysmt_bgright r " .
	" where ( r.bgright = 'mtread' or r.bgright = 'mtwrite' ) and r.bgid = u2g.bgid and  u2g.uid = u.uid and u.dbuser = ?));";
    
    my $sth = $dbh->prepare($stmt);
    $sth->bind_param(1, $thrid, DBI::SQL_INTEGER);
    $sth->bind_param(2, $user, DBI::SQL_VARCHAR);
    

    $sth->execute;
    
    ( $mtnum ) = $sth->fetchrow_array;

    $sth->finish;

    return $mtnum;
}

sub threadMarkRead
{

    my ( $dbh, $user, $thrid ) = @_;

    my $uid = getUid($dbh, $user);

    $stmt="select count(*) from sysmt_threadstat where thrid = ? and uid = ?;";
    
    my $sth = $dbh->prepare($stmt);
    $sth->bind_param(1, $thrid, DBI::SQL_INTEGER);
    $sth->bind_param(2, $uid, DBI::SQL_INTEGER);
    
    $sth->execute;
    
    ( $mark ) = $sth->fetchrow_array;

    $sth->finish;

    if ( $mark == 0 )
    {
	$sth = $dbh->prepare("insert into sysmt_threadstat ( thrid, uid, readstat ) values ( ?, ?, 'READ' );");
	$sth->bind_param(1, $thrid, DBI::SQL_INTEGER);
	$sth->bind_param(2, $uid, DBI::SQL_INTEGER);
	
	$sth->execute;

	$sth->finish;	
    }
    
}

sub getBGroupRightList
{

    my ( $dbh, $bgid ) = @_;

    $stmt="select bgright from sysmt_bgright where bgid = ?;";
    $sth = $dbh->prepare($stmt);
    $sth->bind_param(1, $bgid, DBI::SQL_INTEGER);

    $sth->execute;
    
    my $r;
    my @rightlist;
    
    $i=0;
    while ( $r = $sth->fetchrow_array) 
    {
	$rightlist[$i] = $r;
	$i++;
    }
    $sth->finish;    

    return @rightlist;
    
}

sub getBGroupRightListToAdd
{

    my ( $dbh, $bgid ) = @_;

    $stmt="select bgright from sysmt_bgright where bgid = ?;";
    $sth = $dbh->prepare($stmt);
    $sth->bind_param(1, $bgid, DBI::SQL_INTEGER);

    $sth->execute;
    
    my $r;
    my @rightlist;
    
    $rightlist[0] = "mtread";
    $rightlist[1] = "mtwrite";
    $rightlist[2] = "sysread";
    $rightlist[3] = "syswrite";
    $rightlist[4] = "report";
    $rightlist[5] = "sla";
    $rightlist[6] = "thread";
    $rightlist[7] = "fw";
    $rightlist[8] = "reswrite";
    $rightlist[9] = "resread";
    
    while ( $r = $sth->fetchrow_array) 
    {
	$i=0;
	$found=0;
	while ( $i <= $#rightlist && $found == 0 )
	{
	    if ( $rightlist[$i] eq $r )
	    {
		$rightlist[$i]=$rightlist[$#rightlist];
		pop(@rightlist);
		$found=1;
	    }
	    else
	    {
		$i++;
	    }
	}
    }
    $sth->finish;    

    return @rightlist;
    
}


sub getAvailableResources
{

    my ( $dbh, $mid, $skid, $resfrom, $resto ) = @_;

    
    my @avrlist;


    my $stmt;

    if ( $PerlSpace::SysMtExecuter::db eq "cego" )
    {  

	$stmt="select resid, resname from sysmt_resource r \
    where resid in ( select resid from sysmt_res2skill where skid = ? ) \
    and resid in ( select resid from sysmt_res2prj r2p, sysmt_system s, sysmt_mt m \
                   where r2p.pid = s.pid and s.sysid = m.sysid and m.mid = ? ) \
    and not exists ( select resid from sysmt_resourceplan where resid = r.resid and \
     ((resfrom < date('%d.%m.%Y %H:%M:%S', ?) and resto > date('%d.%m.%Y %H:%M:%S', ?)) or \
      (resfrom < date('%d.%m.%Y %H:%M:%S', ?) and resto > date('%d.%m.%Y %H:%M:%S', ?)) or \
      (resfrom < date('%d.%m.%Y %H:%M:%S', ?) and resto > date('%d.%m.%Y %H:%M:%S', ?)) or \
      (resfrom > date('%d.%m.%Y %H:%M:%S', ?) and resto < date('%d.%m.%Y %H:%M:%S', ?))));";

    }
    elsif ( $PerlSpace::SysMtExecuter::db eq "mysql" )
    {
	$stmt="XXX";
    }
    elsif ( $PerlSpace::SysMtExecuter::db eq "db2" )
    {
	$stmt="XXX";
    }

    my $sth = $dbh->prepare($stmt);
    $sth->bind_param(1, $skid, DBI::SQL_INTEGER);
    $sth->bind_param(2, $mid, DBI::SQL_INTEGER);

    $sth->bind_param(3, $resfrom, DBI::SQL_VARCHAR);
    $sth->bind_param(4, $resfrom, DBI::SQL_VARCHAR);

    $sth->bind_param(5, $resto, DBI::SQL_VARCHAR);
    $sth->bind_param(6, $resto, DBI::SQL_VARCHAR);

    $sth->bind_param(7, $resfrom, DBI::SQL_VARCHAR);
    $sth->bind_param(8, $resto, DBI::SQL_VARCHAR);

    $sth->bind_param(9, $resfrom, DBI::SQL_VARCHAR);
    $sth->bind_param(10, $resto, DBI::SQL_VARCHAR);

        
    $sth->execute;
        
    $i=0;
    while ( (my $resid, $resname ) = $sth->fetchrow_array) 
    {       
	$avrlist[$i]{'resid'} = $resid;
	$avrlist[$i]{'resname'} = $resname;
	$i++;
    }
    
    $sth->finish;    

    return @avrlist;
    
}



1;
