#!/usr/bin/perl


use DBI;
use DBI qw(:sql_types);
use Getopt::Long;
use POSIX qw/strftime/;

my $mode="console";

usage() if ( @ARGV < 1 or
! GetOptions ("db=s" => \$db,
	      "name=s" => \$name,
	      "port=i" => \$port,
	      "host=s" => \$host,
	      "user=s" => \$user,
	      "pwd=s" => \$pwd,
	      "impfile=s" => \$impfile)
	     or defined $help );

sub usage
{
    print "Unknown option: @_\n" if ( @_ );
    print "usage: hostimp.pl [--db=[ db2 | cego | mysql ]] [--name=<name>] [--port=<port>] [--host=<host>]  [--user=<user>] [--pwd=<pwd>] --impfile=<import file> \n";
    exit;
}

if ( $db eq "cego" )
{
    $url="dbi:Cego:tableset=$name;hostname=$host;port=$port;logfile=;logmode=notice";
    $DTFORMAT="%Y-%m-%d-%H.%M.%S";
    $DTFUNC="date2str";
    $dberrorcode=-1;
}
elsif ( $db eq "mysql" )
{
    $url="DBI:mysql:database=$name:host=$host";
    $DTFORMAT="%Y-%m-%d-%H.%M.%S";
    $DTFUNC="date2str";
    $dberrorcode=-1;
}
elsif ( $db eq "db2" )
{
    $url="DBI:DB2:$name";
    $DTFORMAT="yyyy-mm-dd-hh.mi.ss";
    $DTFUNC="ts_fmt";
    $dberrorcode=0;
}


my $dbh = DBI->connect ($url,$user,$pwd)
or die "Can't connect to database: $DBI::errstr\n";

if ( $db eq "cego" )
{
    $dbh->do("set append off;");
}

# mark all disks as obsolete
$dbh->do("update sysmt_disk set status = 'obsolete';");

open ( IMPFILE, "<$impfile");

while(<IMPFILE>) 
{ 
    
    my($line) = $_; 
    chomp($line); 

    my ($hostname,$scandate,$osinfo,$diskinfo) = split(/;/, $line);

    # print "HostName=" . $hostname . "\n";
    @diskarray = split(/,/, $diskinfo);

    $diskcount=@diskarray;

    # print "DiskCount=" . $diskcount . "\n";

    for ( $i=0; $i<@diskarray; $i++)
    {
	# print "Device=" . $diskarray[$i] . "\n";

	@diskparam = split(/:/, $diskarray[$i]);

	$device=$diskparam[0];
	$info=$diskparam[1];
	$size=$diskparam[2] + 0;
	$id=$diskparam[3];
	$vg=$diskparam[4];

	# if the device name is longer than 40 signs, we assume this 
	# is a Solaris device path with included device id
	if ( length($device) > 40 )
	{
	    $fullid=$id . "@" . $device;
	}
	else
	{
	    $fullid=$id;
	}
	# print "Host " . $hostname . " Importing disk " . $fullid . " for vg " . $vg . "\n";

        # we just import disks, where vg is known, otherwise vg information can be deleted by duplicates without vg info 
        if ( $vg )
	{ 

	    if ( $db eq "cego" )
	    {
		$dbh->do("call impDisk('$fullid', date('%Y.%m.%d', '$scandate'), $size, '$info', '$vg', '$hostname');");
	    }
	    elsif ( $db eq "mysql" )
	    {
		# todo
	    }
	    elsif ( $db eq "db2" )
	    {
		$dbh->do("call impDisk('$fullid', current timestamp, $size, '$info', '$vg', '$hostname');");
	    }
        }
	# print "call impDisk('$fullid', date('%Y.%m.%d', '$scandate'), $size, '$info', '$vg', '$hostname');";	    
	
    }
    
}

$dbh->{AutoCommit} = 1;
$dbh->disconnect;

