#!/usr/bin/perl

use DBI;
use DBI qw(:sql_types);
use Getopt::Long;
use POSIX qw/strftime/;

my $mode="console";

usage() if ( @ARGV < 1 or
! GetOptions ("db=s" => \$db,
	      "name=s" => \$name,
	      "port=i" => \$port,
	      "host=s" => \$host,
	      "user=s" => \$user,
	      "pwd=s" => \$pwd,
	      "mode=s" => \$mode)
	     or defined $help );

sub usage
{
    print "Unknown option: @_\n" if ( @_ );
    print "usage: mtNotify.pl [--db=[ db2 | cego | mysql ]] [--name=<name>] [--port=<port>] [--host=<host>]  [--user=<user>] [--pwd=<pwd>] [--mode=[ console | mai l] \n";
    exit;
}

# db connection parameter
# $db="cego";
# $dbhost="localhost";
# $dbport="2200";
# $tableset="sysmt";
# $user="sysmt";
# $pwd="sysmt";
# other 

$dayahead=60;

my $url;

if ( $db eq "cego" )
{
    $url="dbi:Cego:tableset=$name;hostname=$host;port=$port;logfile=;logmode=notice";
    $DTFORMAT="%Y-%m-%d-%H.%M.%S";
    $DTFUNC="date2str";
    $dberrorcode=-1;
}
elsif ( $db eq "mysql" )
{
    $url="DBI:mysql:database=$name:host=$host";
    $DTFORMAT="%Y-%m-%d-%H.%M.%S";
    $DTFUNC="date2str";
    $dberrorcode=-1;
}
elsif ( $db eq "db2" )
{
    $url="DBI:DB2:$name";
    $DTFORMAT="yyyy-mm-dd-hh.mi.ss";
    $DTFUNC="ts_fmt";
    $dberrorcode=0;
}

my $notifyref;

$mailmap{'XXX/AL'}= 'hugo.hurz@hugo.com,Andreas.Mueller@hugo.com';
$mailmap{'BLA-BLU'}= 'bla.bla@blu.com,bli.bla@blu.com';

$ts = strftime('%d.%m.%Y %H:%M:%S',localtime);
 
#connect to MySQL database
my $dbh = DBI->connect ($url,$user,$pwd)
or die "Can't connect to database: $DBI::errstr\n";

my $sth;

if ( $db eq "cego" )
{
    $sth = $dbh->prepare("select m.mid, s.sid, m.shortdesc, m.mtfrom, g.bgname \
from sysmt_mt m, sysmt_mtapproval a, sysmt_bgroup g, sysmt_system s\
where int2date(date2int(m.mtfrom) - 60*60*24*$dayahead) < date('%d.%m.%Y %H:%M:%S', ?) \
and m.status = 'Requested' \
and a.mid = m.mid and a.status = 'Requested' and m.sysid = s.sysid and g.bgid = a.bgid order by g.bgname,  mtfrom;");
    $sth->bind_param(1, $ts, DBI::SQL_VARCHAR);
}
elsif ( $db eq "mysql" )
{
    # todo
}
elsif ( $db eq "db2" )
{
    $sth = $dbh->prepare("select m.mid, s.sid, m.shortdesc, m.mtfrom, g.bgname \
from sysmt_mt m, sysmt_mtapproval a, sysmt_bgroup g, sysmt_system s\
where m.mtfrom <  current timestamp + ? days \
and m.status = 'Requested' \
and a.mid = m.mid and a.status = 'Requested' and m.sysid = s.sysid and g.bgid = a.bgid order by g.bgname,  mtfrom;");
    
    $sth->bind_param(1, $dayahead, DBI::SQL_INTEGER);
}


$sth->execute;

while (($mid, $sid, $shortdesc, $mtfrom, $bgroup ) = $sth->fetchrow_array) 
{
    if ( $mtfrom )
    {
	$notifyref->{$bgroup} = $notifyref->{$bgroup} . "$mid $sid $mtfrom $shortdesc\n";
    }
    # print "Sending mail for $bgroup to $mailmap{$bgroup}\n";
    # print  "A=$mid B=$mtfrom G=$bgroup\n";
}

while( my ($k, $v) = each %$notifyref )
{   
    if ( $mode eq "mail" )
    {
	if ( $mailmap{$k} )
	{
	    print "Sending mail to $mailmap{$k}\n";
	    open(MAIL, "| /usr/bin/mail -s \"SysMT Nofification\" $mailmap{$k} ") || die "mailx failed: $!\n";
	    print MAIL "Pending requests in group $k ( $dayahead days forecast )\n------------------------------------------------------\n$v\n";
	}
    }
    elsif ( $mode eq "console" )
    {
	print "Pending requests in group $k ( $dayahead days forecast )\n----------------------------------------------------\n$v\n";
    }
}

# $dbh->{AutoCommit} = 1;
$dbh->disconnect;

