#!/usr/bin/perl

use DBI;
use DBI qw(:sql_types);
use Getopt::Long;
use POSIX qw/strftime/;

my $mode="console";

usage() if ( @ARGV < 1 or
! GetOptions ("db=s" => \$db,
	      "name=s" => \$name,
	      "port=i" => \$port,
	      "host=s" => \$host,
	      "user=s" => \$user,
	      "pwd=s" => \$pwd,
	      "impfile=s" => \$impfile)
	     or defined $help );

sub usage
{
    print "Unknown option: @_\n" if ( @_ );
    print "usage: hostimp.pl [--db=[ db2 | cego | mysql ]] [--name=<name>] [--port=<port>] [--host=<host>]  [--user=<user>] [--pwd=<pwd>] --impfile=<import file> \n";
    exit;
}

if ( $db eq "cego" )
{
    $url="dbi:Cego:tableset=$name;hostname=$host;port=$port;logfile=;logmode=notice";
    $DTFORMAT="%Y-%m-%d-%H.%M.%S";
    $DTFUNC="date2str";
    $dberrorcode=-1;
}
elsif ( $db eq "mysql" )
{
    $url="DBI:mysql:database=$name:host=$host";
    $DTFORMAT="%Y-%m-%d-%H.%M.%S";
    $DTFUNC="date2str";
    $dberrorcode=-1;
}
elsif ( $db eq "db2" )
{
    $url="DBI:DB2:$name";
    $DTFORMAT="yyyy-mm-dd-hh.mi.ss";
    $DTFUNC="ts_fmt";
    $dberrorcode=0;
}


my $dbh = DBI->connect ($url,$user,$pwd)
or die "Can't connect to database: $DBI::errstr\n";

if ( $db eq "cego" )
{
    $dbh->do("set append off;");
}

open ( IMPFILE, "<$impfile");

while(<IMPFILE>) 
{ 
    
    my($line) = $_; 
    chomp($line); 
    # $line =~ tr/[a-z]/[A-Z]/; 
    # Print the line to the screen and add a newline 
    # print "$line\n";


    my ($sid,$shortdesc,$description,$mtfrom,$mtto,$downfrom,$downto,$mttype) = split(/,/, $line);


    $status="Requested"; 
    $ticket=0;

	# print "Importing zone " . $zone . " " . $status . "...\n";
	    
    # $dbh->do("call newMt('$sid','$shortdesc','$desc', '$status');");	    
    $sth = $dbh->prepare(q{call newMt(?,?,?,?,?,?,?,?,?,?,?)});

    $sth->bind_param(1, $sid, DBI::SQL_VARCHAR);
    $sth->bind_param(2, $shortdesc, DBI::SQL_VARCHAR);
    $sth->bind_param(3, $description, DBI::SQL_VARCHAR);
    $sth->bind_param(4, PerlSpace::SysMtUtil::db2Date($mtfrom), DBI::SQL_VARCHAR);
    $sth->bind_param(5, PerlSpace::SysMtUtil::db2Date($mtto), DBI::SQL_VARCHAR);
    $sth->bind_param(6, PerlSpace::SysMtUtil::db2Date($downfrom), DBI::SQL_VARCHAR);
    $sth->bind_param(7, PerlSpace::SysMtUtil::db2Date($downto), DBI::SQL_VARCHAR);
    $sth->bind_param(8, $status, DBI::SQL_VARCHAR);
    $sth->bind_param(9, $ticket, DBI::SQL_INTEGER);
    $sth->bind_param(10, $mttype, DBI::SQL_VARCHAR);
    $sth->bind_param_inout(11, \$mid, 100, DBI::SQL_INTEGER);

    
}

$dbh->{AutoCommit} = 1;
$dbh->disconnect;

sub db2Date
{
    my ( $d ) = @_;
    my ($day,$month,$year,$hour,$min,$sec) = $d =~ /(\d+).(\d+).(\d+) (\d+):(\d+):(\d+)/;
    return $year . '-' . $month . '-' . $day . "-" . $hour . "." . $min . "." . $sec;
}

