#!/usr/bin/perl
use DBI;
use DBD::Cego;
use POSIX qw/strftime/;
use Getopt::Long;

usage() if ( @ARGV < 1 or
! GetOptions ("db=s" => \$db,
              "name=s" => \$name,
              "port=i" => \$port,
              "host=s" => \$host,
              "user=s" => \$user,
              "pwd=s" => \$pwd,
              "mode=s" => \$mode)
             or defined $help );

sub usage
{
    print "Unknown option: @_\n" if ( @_ );
    print "usage: rep001.pl [--db=[ db2 | cego | mysql ]] [--name=<name>] [--port=<port>] [--host=<host>]  [--user=<user>] [--pwd=<pwd>]\n";
    exit;
}


$mailto= 'lemke@lemke-it.com,lemke@sysmt.eu';

$ts = strftime('%d.%m.%Y %H:%M:%S',localtime);

if ( $db eq "cego" )
{
    $url="dbi:Cego:tableset=$name;hostname=$host;port=$port;logfile=;logmode=notice";
    $DTFORMAT="%Y-%m-%d-%H.%M.%S";
    $DTFUNC="date2str";
    $dberrorcode=-1;
}
elsif ( $db eq "mysql" )
{
    $url="DBI:mysql:database=$name:host=$host";
    $DTFORMAT="%Y-%m-%d-%H.%M.%S";
    $DTFUNC="date2str";
    $dberrorcode=-1;
}
elsif ( $db eq "db2" )
{
    $url="DBI:DB2:$name";
    $DTFORMAT="yyyy-mm-dd-hh.mi.ss";
    $DTFUNC="ts_fmt";
    $dberrorcode=0;
}

my $dbh = DBI->connect ($url,$user,$pwd)
or die "Can't connect to database: $DBI::errstr\n";


my $sth = $dbh->prepare("select sid from sysmt_systemview where prjname = 'Unassigned'");

$sth->execute;

open(MAIL, "| /usr/bin/mailx -s \"SysMT Unassigned SIDs\" $mailto ") || die "mailx failed: $!\n";
# open (MAIL, "| cat");

print MAIL "Unassigned SIDs :\n";

$i=0;
while (($sid ) = $sth->fetchrow_array) 
{
    # print MAIL "$mid" . "," . $sid . "," . $status . "\n";
    print MAIL $sid . "\n";
    $i++;	
}

if ( $i == 0 )
{
   print MAIL "No unassigned SIDs found";	
}

close MAIL;

# $dbh->{AutoCommit} = 1;
$dbh->disconnect;

