#!/usr/bin/perl

use DBI;
use DBI qw(:sql_types);
use Getopt::Long;
use POSIX qw/strftime/;

my $mode="console";

usage() if ( @ARGV < 1 or
! GetOptions ("db=s" => \$db,
	      "name=s" => \$name,
	      "port=i" => \$port,
	      "host=s" => \$host,
	      "user=s" => \$user,
	      "pwd=s" => \$pwd,
	      "mode=s" => \$mode)
	     or defined $help );

sub usage
{
    print "Unknown option: @_\n" if ( @_ );
    print "usage: syncFW [--db=[ db2 | cego | mysql ]] [--name=<name>] [--port=<port>] [--host=<host>]  [--user=<user>] [--pwd=<pwd>] \n";
    exit;
}

# db connection parameter
# $db="cego";
# $dbhost="localhost";
# $dbport="2200";
# $tableset="sysmt";
# $user="sysmt";
# $pwd="sysmt";
# other 

my $url;

if ( $db eq "cego" )
{
    $url="dbi:Cego:tableset=$name;hostname=$host;port=$port;logfile=;logmode=notice";
    $DTFORMAT="%Y-%m-%d-%H.%M.%S";
    $DTFUNC="date2str";
    $dberrorcode=-1;
}
elsif ( $db eq "mysql" )
{
    $url="DBI:mysql:database=$name:host=$host";
    $DTFORMAT="%Y-%m-%d-%H.%M.%S";
    $DTFUNC="date2str";
    $dberrorcode=-1;
}
elsif ( $db eq "db2" )
{
    $url="DBI:DB2:$name";
    $DTFORMAT="yyyy-mm-dd-hh.mi.ss";
    $DTFUNC="ts_fmt";
    $dberrorcode=0;
}

my $dbh = DBI->connect ($url,$user,$pwd)
or die "Can't connect to database: $DBI::errstr\n";

my $sth;

# $dbh->do("set append off;");

# my $sth = $dbh->prepare("select sysid, sid, partA, partB, partC, partD, vip from sysmt_system where sid = 'GP1';");
my $sth = $dbh->prepare("select sysid, sid, partA, partB, partC, partD, vip from sysmt_system;");
$sth->execute;

my $iplist;
my @sidlist;

my $s=0;
my $i=0;
while (($sysid, $sid, $partA, $partB, $partC, $partD, $vip ) = $sth->fetchrow_array) 
{
    # print MAIL "$mid" . "," . $sid . "," . $status . "\n";
    
    $sidlist[$s]=$sid;
    $s++;

    if ( $partA )
    {
	$$iplist{'hinfo'}[$i]{'sid'}=$sid;
	$$iplist{'hinfo'}[$i]{'hostname'}=$partA;
	$$iplist{'hinfo'}[$i]{'ipval'}=IPLookup($partA);
	$i++;
    }

    if ( $partB )
    {
	$$iplist{'hinfo'}[$i]{'sid'}=$sid;
	$$iplist{'hinfo'}[$i]{'hostname'}=$partB;
	$$iplist{'hinfo'}[$i]{'ipval'}=IPLookup($partB);
	$i++;
    }

    if ( $partC )
    {
	$$iplist{'hinfo'}[$i]{'sid'}=$sid;
	$$iplist{'hinfo'}[$i]{'hostname'}=$partC;
	$$iplist{'hinfo'}[$i]{'ipval'}=IPLookup($partC);
	$i++;
    }

    if ( $partD )
    {
	$$iplist{'hinfo'}[$i]{'sid'}=$sid;
	$$iplist{'hinfo'}[$i]{'hostname'}=$partD;
	$$iplist{'hinfo'}[$i]{'ipval'}=IPLookup($partD);
	$i++;
    }

    if ( $vip )
    {
	$$iplist{'hinfo'}[$i]{'sid'}=$sid;
	$$iplist{'hinfo'}[$i]{'hostname'}=$vip;
	$$iplist{'hinfo'}[$i]{'ipval'}=IPLookup($vip);
	$i++;
    }
}

$sth->finish();

# adding instance adresses
for ( my $j=0; $j<$s; $j++ )
{
   my $sid = $sidlist[$j];
   my $sth = $dbh->prepare("select instvip, instzone from sysmt_instance where sysid = ( select sysid from sysmt_system where sid = ?);");
   $sth->bind_param(1, $sid, DBI::SQL_VARCHAR);
   $sth->execute;

   while (($instvip, $instzone ) = $sth->fetchrow_array)
   {
       if ( $instvip )
       {
	  $$iplist{'hinfo'}[$i]{'sid'}=$sid;
	  $$iplist{'hinfo'}[$i]{'hostname'}=$instvip;
	  $$iplist{'hinfo'}[$i]{'ipval'}=IPLookup($instvip);
	  $i++;
       }
       if ( $instzone )
       {
	  $$iplist{'hinfo'}[$i]{'sid'}=$sid;
	  $$iplist{'hinfo'}[$i]{'hostname'}=$instzone;
	  $$iplist{'hinfo'}[$i]{'ipval'}=IPLookup($instzone);
	  $i++;
       }
      
   } 
   $sth->finish();
   
}

for ( my $j=0; $j<$s; $j++ )
{
    print "Preparing server group for " . $sidlist[$j] . "\n";
    
    my $sid = $sidlist[$j];

    my $sth = $dbh->prepare("select count(*) from sysmt_fwsg where sgname = ?;");
    $sth->bind_param(1, $sid . "_sg", DBI::SQL_VARCHAR);

    $sth->execute;
    $scheck = $sth->fetchrow_array;
    $sth->finish();

    if ( $scheck == 0 )
    {
	if ( $db eq "cego" )
	{	
	    $sth = $dbh->prepare("? = call newFWSG (?,?);");	
	    $sth->bind_param_inout(1, \$sgid, 10);
	    $sth->bind_param(2, $sgname, DBI::SQL_VARCHAR);
	    $sth->bind_param(3, $sgdesc, DBI::SQL_VARCHAR);
	    
	    if ( $sth->execute ne "0E0" )
	    {
		$PerlSpace::SysMtExecuter::errmsg = $sth->errstr;
		return 1;
	    }
	}
	elsif ( $db eq "mysql" )
	{
	    $sth = $dbh->prepare("select newFWSG(?,?);");
	    
	    $sth->bind_param(1, $sgname, DBI::SQL_VARCHAR);
	    $sth->bind_param(2, $sgdesc, DBI::SQL_VARCHAR);
	    
	    $sth->execute;
	    $sgid = $sth->fetchrow_array;
	}
	elsif ( $db eq "db2" )
	{
	    print "Creating new server group for " . $sid . "\n";
	    $sth = $dbh->prepare(q{call newFWSG(?,?,?)});
	    
	    my $sgname = $sid . "_sg";
	    my $sgdesc = "Autogenerated Server Group";
	    $sth->bind_param(1, $sgname, DBI::SQL_VARCHAR);
	    $sth->bind_param(2, $sgdesc, DBI::SQL_VARCHAR);
	    $sth->bind_param_inout(3, \$sgid, 100, DBI::SQL_INTEGER);
	    
	    $sth->execute;
	}

	$sth->finish;
    }
    else
    {

	print "Deleting old ip entry for " . $sid . "\n";
	my $sth = $dbh->prepare("delete from sysmt_fwsgentry where sgid = ( select sgid from sysmt_fwsg where sgname = ?);");
	$sth->bind_param(1, $sid . "_sg", DBI::SQL_VARCHAR);	
	$sth->execute;
	$sth->finish();
    }
}

for ( my $j=0; $j<$i; $j++ )
{
    my $sysid = $$iplist{'hinfo'}[$j]{'sysid'};
    my $sid = $$iplist{'hinfo'}[$j]{'sid'};
    my $hostname = $$iplist{'hinfo'}[$j]{'hostname'};
    my $ipinfo = $$iplist{'hinfo'}[$j]{'ipval'};
    
    print "Inserting new ip " . $ipinfo . " for " . $sid . "\n";
    my $sth = $dbh->prepare("insert into sysmt_fwsgentry ( sgid, ipval, ipdesc ) values ( ( select sgid from sysmt_fwsg where sgname = ? ), ?, ?);");
    $sth->bind_param(1, $sid . "_sg", DBI::SQL_VARCHAR);
    $sth->bind_param(2, $ipinfo, DBI::SQL_VARCHAR);
    $sth->bind_param(3, "IP for " . $hostname, DBI::SQL_VARCHAR);
    $sth->execute;
    $sth->finish();
}

# $dbh->{AutoCommit} = 1;
$dbh->disconnect;

1;


sub IPLookup
{

    my ( $hostname ) = @_;

    print "Looking up " . $hostname . "\n";

    if ( $hostname eq "" )
    {
        print "Error : no hostname given for IP lookup\n";
        return 0;
    }

    my $ip = NativeLookup($hostname);

    if ( $ip )
    {
	return $ip;
    }
    
    $fullhostname = $hostname . ".edc.corpintra.net";

    my $ip = NativeLookup($fullhostname);

    if ( $ip )
    {
	return $ip;
    }

    $fullhostname = $hostname . ".emea.isn.corpintra.net";

    my $ip = NativeLookup($fullhostname);

    if ( $ip )
    {
	return $ip;
    }

    $fullhostname = $hostname . ".americas.bg.corpintra.net";

    my $ip = NativeLookup($fullhostname);

    if ( $ip )
    {
	return $ip;
    }

    $fullhostname = $hostname . ".emea.bg.corpintra.net";

    my $ip = NativeLookup($fullhostname);

    if ( $ip )
    {
	return $ip;
    }

    $fullhostname = $hostname . ".usfdc.corpintra.net";

    my $ip = NativeLookup($fullhostname);

    if ( $ip )
    {
	return $ip;
    }

    print "Error : Cannot resolve host $hostname\n";
    return 0;
	
}

sub NativeLookup
{

    my ( $hostname ) = @_;

    open (IPLK, "/usr/bin/nslookup " . $hostname . "| tail -2 | grep Address | awk \'{print \$2}\'|");

    my $ip = <IPLK>;
    chop $ip;
    return $ip;
	
}

