#!/usr/bin/perl

use DBI;
use DBI qw(:sql_types);
use Getopt::Long;
use POSIX qw/strftime/;

my $mode="console";

usage() if ( @ARGV < 1 or
! GetOptions ("db=s" => \$db,
	      "name=s" => \$name,
	      "port=i" => \$port,
	      "host=s" => \$host,
	      "user=s" => \$user,
	      "pwd=s" => \$pwd,
	      "impfile=s" => \$impfile)
	     or defined $help );

sub usage
{
    print "Unknown option: @_\n" if ( @_ );
    print "usage: hostimp.pl [--db=[ db2 | cego | mysql ]] [--name=<name>] [--port=<port>] [--host=<host>]  [--user=<user>] [--pwd=<pwd>] --impfile=<import file> \n";
    exit;
}

if ( $db eq "cego" )
{
    $url="dbi:Cego:tableset=$name;hostname=$host;port=$port;logfile=;logmode=notice";
    $DTFORMAT="%Y-%m-%d-%H.%M.%S";
    $DTFUNC="date2str";
    $dberrorcode=-1;
}
elsif ( $db eq "mysql" )
{
    $url="DBI:mysql:database=$name:host=$host";
    $DTFORMAT="%Y-%m-%d-%H.%M.%S";
    $DTFUNC="date2str";
    $dberrorcode=-1;
}
elsif ( $db eq "db2" )
{
    $url="DBI:DB2:$name";
    $DTFORMAT="yyyy-mm-dd-hh.mi.ss";
    $DTFUNC="ts_fmt";
    $dberrorcode=0;
}


my $dbh = DBI->connect ($url,$user,$pwd)
or die "Can't connect to database: $DBI::errstr\n";

if ( $db eq "cego" )
{
    $dbh->do("set append off;");
}

open ( IMPFILE, "<$impfile");

while(<IMPFILE>) 
{ 
    
    my($line) = $_; 
    chomp($line); 
    # $line =~ tr/[a-z]/[A-Z]/; 
    # Print the line to the screen and add a newline 
    # print "$line\n";


    my ($hostname,$scandate,$confzone,$actzone,$zonesize) = split(/;/, $line);

    @confzonearray = split(/ /, $confzone);
    @actzonearray = split(/ /, $actzone);

    $zonecount=@confzonearray;

    for ( $i=0; $i<@confzonearray; $i++)
    {	
	$zone=$confzonearray[$i];
	$isactive=0;
	$j=0;
	while ( $j<@actzonearray && $isactive == 0 )
	{
	    # print "Comparing zone " . $zone . " and " . $actzonearray[$j] ."\n";
	    if ( $zone eq $actzonearray[$j] )
	    {
		$isactive=1;
	    }
	    $j++;
	}
	    
	if ( $isactive == 1 )
	{
	    $status="Active";
	}
	else
	{
	    $status="Configured";
	}

	# print "Importing zone " . $zone . " " . $status . "...\n";
	    
	$dbh->do("call impVip2Host('$zone', '$hostname', '$status');");	    
	
    }
    
}

$dbh->{AutoCommit} = 1;
$dbh->disconnect;

