--
-- SysMT cego procedure definitions
--

drop if exists procedure getSysId;
@
create procedure getSysId(sid in string(20)) return int
begin
   var actId int;
   var retval bool;
   :actId = 0;
   cursor actIdCur as
      select sysid as sysid
      from sysmt_system
      where sid = :sid;
   :retval = fetch actIdCur into (:actId);
   close actIdCur;
   return :actId;
end;
@

drop if exists procedure getSetId;
@
create procedure getSetId(setname in string(20)) return int
begin
   var actId int;
   var retval bool;
   :actId = 0;
   cursor actIdCur as
      select setid as setid
      from sysmt_systemset where setname = :setname;
   :retval = fetch actIdCur into (:actId);
   close actIdCur;
   return :actId;
end;
@


drop if exists procedure getPid;
@
create procedure getPid(prjname in string(100)) return int
begin
   var actId int;
   var retval bool;
   :actId = 0;
   cursor actIdCur as
      select pid as pid
      from sysmt_project
      where prjname = :prjname;
   :retval = fetch actIdCur into (:actId);
   close actIdCur;
   return :actId;
end;
@

drop if exists procedure getPidForSid;
@
create procedure getPidForSid(sid in string(20)) return int
begin
   var actId int;
   var retval bool;
   :actId = 0;
   cursor actIdCur as
      select pid as pid
      from sysmt_system
      where sid = :sid;
   :retval = fetch actIdCur into (:actId);
   close actIdCur;
   return :actId;
end;
@


drop if exists procedure getUid;
@
create procedure getUid(dbuser in string(20)) return int
begin
   var actId int;
   var retval bool;
   :actId = 0;
   cursor actIdCur as
      select
       uid as uid
      from
       sysmt_user@sysmt sysmt_user
      where
             dbuser = :dbuser
;
   :retval = fetch actIdCur into (:actId);
   close actIdCur;
   return :actId;
end;
@


drop if exists procedure getBgid;
@
create procedure getBgid(bgname in string(20)) return int
begin
   var actId int;
   var retval bool;
   :actId = 0;
   cursor actIdCur as
      select bgid as bgid
      from sysmt_bgroup sysmt_bgroup
      where bgname = :bgname;
   :retval = fetch actIdCur into (:actId);
   close actIdCur;
   return :actId;
end;
@


drop if exists procedure getDiskId;
@
create procedure getDiskId(diskname in string(20)) return int
begin
   var actId int;
   :actId = (select sysmt_disk.did as did 
             from sysmt_disk where sysmt_disk.diskname = :diskname);
   return :actId;
end;
@

drop if exists procedure newThreadGroup;
@
create procedure newThreadGroup(tgname in string(30),
     tgdesc in string(1000)) return int
begin
   var tgid int;
   :tgid = nextId('TGID');
   insert into sysmt_threadgroup ( tgid, tgname, tgdesc )
    values (:tgid, :tgname, :tgdesc);
   return :tgid;
end;
@

drop if exists procedure newSystemSet;
@
create procedure newSystemSet(setname in string(10),
     description in string(1000)) return int
begin
   var setid int;
   :setid = nextId('SETID');
   insert into sysmt_systemset ( setid, setname, description )
    values (:setid, :setname, :description);
   return :setid;
end;
@

drop if exists procedure newGroup;
@
create procedure newGroup(bgname in string(20),
     bgdesc in string(100)) return int
begin
   var bgid int;
   :bgid = nextId('BGID');
   insert into sysmt_bgroup ( bgid, bgname, bgdesc )
    values (:bgid, :bgname, :bgdesc);
   return :bgid;
end;
@

drop if exists procedure sysWfFire;
@
create procedure sysWfFire(sysid in int,
     bgname in string(20),
     dbuser in string(20),
     comment in string(500)) return int
begin
   var seqnr int;
   :seqnr = (select
 sysmt_sysworkflow.seqnr as seqnr
from
 sysmt_sysworkflow@sysmt sysmt_sysworkflow
where
 ( sysmt_sysworkflow.sysid = :sysid
  and
 sysmt_sysworkflow.bgid = (select
 sysmt_bgroup.bgid as bgid
from
 sysmt_bgroup@sysmt sysmt_bgroup
where
 sysmt_bgroup.bgname = :bgname
) )
);
   update sysmt_sysworkflow set status='Done', released=sysdate, comment=:comment, dbuser=:dbuser where ( sysid = :sysid
 and
seqnr = :seqnr );
   update sysmt_sysworkflow set status='Requested', assigned=sysdate where ( sysid = :sysid
 and
seqnr = :seqnr + 1 );
   return :seqnr + 1;
end;
@

drop if exists procedure impSys;
@
create procedure impSys(sid in string(10),
     sysdesc in string(1000)) return int
begin
   var sysid int;
   :sysid = getSysId(:sid);
   if :sysid = 0
   then
      :sysid = newSystem(:sid,'Unassigned','NA','NA','NA');
      update sysmt_system set sysdesc=:sysdesc where sysid = :sysid;
   else
   update sysmt_system set status='Xandria' where sid = :sid;
   end;
   return :sysid;
end;
@

drop if exists procedure newSystem;
@
create procedure newSystem(sid in string(30),
     prjname in string(20),
     category in string(10),
     platform in string(10),
     status in string(10)) return int
begin
   var pid int;
   var sysid int;
   var wfgid int;
   var seqnr int;
   var wfstatus string(10);
   var startdate datetime;
   :sysid = nextId('SYSID');
   :pid = getPid(:prjname);
   insert into sysmt_system ( sysid, sid, category, platform, status, pid )
    values (:sysid, :sid, :category, :platform, :status, :pid);
   cursor agCur as
      select
       bgid as bgid,
       seqnr as seqnr
      from
       sysmt_prj2workflow@sysmt sysmt_prj2workflow
      where
             pid = :pid

      order by
             seqnr;
   :wfstatus = 'Requested';
   :startdate = sysdate;
   while fetch agCur into (:wfgid, :seqnr) = true
   begin
      insert into sysmt_sysworkflow ( sysid, bgid, seqnr, assigned, status )
       values (:sysid, :wfgid, :seqnr, :startdate, :wfstatus);
      :wfstatus = 'Waiting';
      :startdate = null;
   end;
   close agCur;
   return :sysid;
end;
@

drop if exists procedure newThread;
@
create procedure newThread(tgname in string(30),
     shortdesc in string(100),
     bgname in string(20),
     remind in datetime) return int
begin
   var tgid int;
   var thrid int;
   :tgid = (select
 sysmt_threadgroup.tgid as tgid
from
 sysmt_threadgroup@sysmt sysmt_threadgroup
where
 sysmt_threadgroup.tgname = :tgname
);
   :thrid = nextId('THRID');
   insert into sysmt_thread ( thrid, tgid, shortdesc, created, remind, bgid, status )
   values (:thrid, :tgid, :shortdesc, sysdate, :remind, (select bgid as bgid
                                                         from sysmt_bgroup@sysmt sysmt_bgroup
                                                         where bgname = :bgname), 'OPEN');
   return :thrid;
end;
@

drop if exists procedure impDisk;
@
create procedure impDisk(diskname in string(100),
     scandate in datetime,
     disksize in long,
     diskusage in string(100),
     diskvg in string(100),
     hostname in string(30)) return int
begin
   var did int;
   var hid int;
   var d2h int;
   :did = getDiskId(:diskname);
   :hid = getHostId(:hostname);
   if :did = null
   then
      :did = nextId('DID');
      insert into sysmt_disk ( did, scandate, status, diskname, disksize, diskusage, diskvg )
       values (:did, :scandate, 'new', :diskname, :disksize, :diskusage, :diskvg);
      if :hid != null
      then
            insert into sysmt_disk2host ( did, hid )
             values (:did, :hid);
      end;
   else
   update sysmt_disk set scandate=:scandate, status='valid', diskusage=:diskusage, diskvg=:diskvg where did = :did;
:d2h = (select
 count(*)
from
 sysmt_disk2host@sysmt sysmt_disk2host
where
 ( sysmt_disk2host.hid = :hid
  and
 sysmt_disk2host.did = :did )
);
if :d2h = 0 and :hid != null
then
insert into sysmt_disk2host ( did, hid )
 values (:did, :hid);
end;
   end;
   return :did;
end;
@

drop if exists procedure resetApproval;
@
create procedure resetApproval(mid in int)
begin
   var sid string(20);
   var sysid int;
   var pid int;
   var status string(20);
   delete from sysmt_mtapproval where mid = :mid;
   delete from sysmt_mtverification where mid = :mid;
   :status = (select
 sysmt_mtview.status as status
from
 sysmt_mtview sysmt_mtview
where
 sysmt_mtview.mid = :mid
);
   if :status != 'Claimed'
   then
      var agid int;
      :sid = (select
 sysmt_mtview.sid as sid
from
 sysmt_mtview sysmt_mtview
where
 sysmt_mtview.mid = :mid
);
      :sysid = (select
 sysmt_mt.sysid as sysid
from
 sysmt_mt@sysmt sysmt_mt
where
 sysmt_mt.mid = :mid
);
      :pid = getPidForSid(:sid);
      cursor agCur as
            select
             bgid as bgid
            from
             sysmt_prj2approval@sysmt sysmt_prj2approval
            where
                         pid = :pid
;
      while fetch agCur into (:agid) = true
      begin
            insert into sysmt_mtapproval ( mid, bgid, status )
             values (:mid, :agid, 'Requested');
      end;
      close agCur;

      cursor verCur as
            select
             bgid as bgid
            from
             sysmt_prj2verification@sysmt sysmt_prj2verification
            where
                         pid = :pid
;
      while fetch verCur into (:agid) = true
      begin
            insert into sysmt_mtverification ( mid, bgid, status )
             values (:mid, :agid, 'Requested');
      end;
      close verCur;

      update sysmt_mt set status='Requested' where mid = :mid;
   end;
end;
@

drop if exists procedure deleteProject;
@
create procedure deleteProject(pid in int)
begin
   var sysid int;
   cursor sysCur as
      select
       sysid as sysid
      from
       sysmt_system@sysmt sysmt_system
      where
             pid = :pid
;
   while fetch sysCur into (:sysid) = true
   begin
      deleteSystem(:sysid);
   end;
   close sysCur;
   delete from sysmt_prj2approval where pid = :pid;
   delete from sysmt_prj2bgrp where pid = :pid;
   delete from sysmt_project where pid = :pid;
end;
@

drop if exists procedure sysWfReset;
@
create procedure sysWfReset(sysid in int) return int
begin
   var pid int;
   var seqnr int;
   var wfgid int;
   var wfstatus string(10);
   var startdate datetime;
   delete from sysmt_sysworkflow where sysid = :sysid;
   :pid = (select
 sysmt_system.pid as pid
from
 sysmt_system@sysmt sysmt_system
where
 sysmt_system.sysid = :sysid
);
   cursor agCur as
      select
       bgid as bgid,
       seqnr as seqnr
      from
       sysmt_prj2workflow@sysmt sysmt_prj2workflow
      where
             pid = :pid

      order by
             seqnr;
   :wfstatus = 'Requested';
   :startdate = sysdate;
   while fetch agCur into (:wfgid, :seqnr) = true
   begin

       if :seqnr = 1
       then 
          :wfstatus = 'Requested';
	  :startdate = sysdate;
       else
          :wfstatus = 'Waiting';
          :startdate = null;
       end;

      insert into sysmt_sysworkflow ( sysid, bgid, seqnr, assigned, status )
       values (:sysid, :wfgid, :seqnr, :startdate, :wfstatus);

   end;
   close agCur;
   return 0;
end;
@

drop if exists procedure nextId;
@
create procedure nextId(id in string(30)) return int
begin
   var idval int;
   update sysmt_id set idval=idval + 1 where id = :id return :idval = idval;
   return :idval;
end;
@

drop if exists procedure impHost;
@
create procedure impHost(hostname in string(30),
     scandate in datetime,
     hostinfo in string(100),
     osinfo in string(100),
     cpuinfo in string(100),
     meminfo in string(100)) return int
begin
   var hid int;
   :hid = getHostId(:hostname);
   if :hid = null
   then
      :hid = nextId('HID');
      insert into sysmt_host ( hid, scandate, status, hostname, hostinfo, osinfo, cpuinfo, meminfo )
       values (:hid, :scandate, 'valid', :hostname, :hostinfo, :osinfo, :cpuinfo, :meminfo);
   else
   update sysmt_host set scandate=:scandate, status='valid', hostinfo=:hostinfo, osinfo=:osinfo, cpuinfo=:cpuinfo, meminfo=:meminfo where hid = :hid;
   end;
   return :hid;
end;
@

drop if exists procedure newFWPS;
@
create procedure newFWPS(psname in string(30),
            psdesc in string(500)) return int
begin
   var psid int;
   :psid = nextId('PSID');
   insert into sysmt_fwps ( psid, psname, psdesc )
    values (:psid, :psname, :psdesc);
   return :psid;
end;
@

drop if exists procedure newFileSysTmpl;
@
create procedure newFileSysTmpl(fstmplname in string(50),
     fstmpltype in string(10),
     fstmplrule in string(200),
     fstmpldesc in string(500)) return int
begin
   var tmplid int;
   :tmplid = nextId('TMPLID');
   insert into sysmt_filesystmpl ( tmplid, fstmplname, fstmpltype, fstmplrule, fstmpldesc )
    values (:tmplid, :fstmplname, :fstmpltype, :fstmplrule, :fstmpldesc);
   return :tmplid;
end;
@

drop if exists procedure newAddon;
@
create procedure newAddon(sysid in int,
     aotype in string(20),
     aoname in string(20)) return int
begin
   var aoid int;
   :aoid = nextId('AOID');
   insert into sysmt_addon ( aoid, aotype, aoname, sysid )
    values (:aoid, :aotype, :aoname, :sysid);
   return :aoid;
end;
@

drop if exists procedure newNFS;
@
create procedure newNFS(sysid in int,
     nfspath in string(100),
     nfsnode in string(100),
     nfsmount in string(100)) return int
begin
   var nfsid int;
   :nfsid = nextId('NFSID');
   insert into sysmt_nfs ( nfsid, nfspath, nfsnode, nfsmount, sysid )
    values (:nfsid, :nfspath, :nfsnode, :nfsmount, :sysid);
   return :nfsid;
end;
@

drop if exists procedure newDocument;
@
create procedure newDocument(doctype in string(10),
     docname in string(200)) return int
begin
   var docid int;
   :docid = nextId('DOCID');
   insert into sysmt_document ( docid, doctype, docname )
    values (:docid, :doctype, :docname);
   return :docid;
end;
@

drop if exists procedure newProject;
@
create procedure newProject(prjname in string(100),
     prjdesc in string(1000)) return int
begin
   var pid int;
   :pid = nextId('PID');
   insert into sysmt_project ( pid, prjname, prjdesc )
    values (:pid, :prjname, :prjdesc);
   return :pid;
end;
@

drop if exists procedure getHostId;
@
create procedure getHostId(hostname in string(20)) return int
begin
   var actId int;
   :actId = (select
 sysmt_host.hid as hid
from
 sysmt_host@sysmt sysmt_host
where
 sysmt_host.hostname = :hostname
);
   return :actId;
end;
@

drop if exists procedure newUserSearch;
@
create procedure newUserSearch(usname in string(30),
     usspec in string(100),
     dbuser in string(20)) return int
begin
   var usid int;
   var uid int;
   :usid = nextId('USID');
   :uid = getUid(:dbuser);
   insert into sysmt_usersearch ( usid, usname, usspec, uid )
    values (:usid, :usname, :usspec, :uid);
   return :usid;
end;
@

drop if exists procedure newUser;
@
create procedure newUser(dbuser in string(20),
     username in string(20),
     userdesc in string(1000),
     userright in string(10),
     usermail in string(100)) return int
begin
   var uid int;
   :uid = nextId('UID');
   insert into sysmt_user ( uid, dbuser, username, userdesc, userright, usermail )
    values (:uid, :dbuser, :username, :userdesc, :userright, :usermail);
   return :uid;
end;
@

drop if exists procedure newInstance;
@
create procedure newInstance(sysid in int,
     instnr in string(10),
     instvip in string(50),
     instsmd in string(10),
     instsaptype in string(10),
     instjavaport in string(10),
     instzone in string(50),
     instarch in string(10),
     instdisp in string(10)) return int
begin
   var instid int;
   :instid = nextId('INSTID');
   insert into sysmt_instance ( instid, instnr, instvip, instsmd, instsaptype, instjavaport, instzone, instarch, instdisp, sysid )
    values (:instid, :instnr, :instvip, :instsmd, :instsaptype, :instjavaport, :instzone, :instarch, :instdisp, :sysid);
   return :instid;
end;
@

drop if exists procedure newFileSysTmplEntry;
@
create procedure newFileSysTmplEntry(tmplid in int,
     fstype in string(50),
     fspath in string(100),
     fsvg in string(100),
     fslv in string(100),
     fsopt in string(100),
     fssizesmall in long,
     fssizebig in long) return int
begin
   var fsid int;
   :fsid = nextId('FSID');
   insert into sysmt_filesystmplentry ( fsid, tmplid, fstype, fspath, fsvg, fslv, fsopt, fssizesmall, fssizebig )
    values (:fsid, :tmplid, :fstype, :fspath, :fsvg, :fslv, :fsopt, :fssizesmall, :fssizebig);
   return :fsid;
end;
@

drop if exists procedure newFWSG;
@
create procedure newFWSG(sgname in string(30),
     sgdesc in string(500)) return int
begin
   var sgid int;
   :sgid = nextId('SGID');
   insert into sysmt_fwsg ( sgid, sgname, sgdesc )
    values (:sgid, :sgname, :sgdesc);
   return :sgid;
end;
@

drop if exists procedure newSysFW;
@
create procedure newSysFW(sgfrom in string(30),
     sgto in string(30),
     portset in string(30),
     fwrdesc in string(500),
     sid in string(20)) return int
begin
   var fwrid int;
   :fwrid = nextId('FWRID');
   insert into sysmt_sysfw ( fwrid, sgidfrom, sgidto, psid, sysid, fwrdesc )
    values (:fwrid, 
    (select sgid from sysmt_fwsg where sgname = :sgfrom ),
    (select sgid from sysmt_fwsg where sgname = :sgto ),
    (select psid from sysmt_fwps where psname = :portset ),
    (select sysid from sysmt_system where sid = :sid),
    :fwrdesc);
   return :fwrid;
end;
@

drop if exists procedure deleteSystem;
@
create procedure deleteSystem(sysid in int)
begin
   var mid int;
   cursor midCur as
      select
       mid as mid
      from
       sysmt_mt@sysmt sysmt_mt
      where sysid = :sysid;
   while fetch midCur into (:mid) = true
   begin
      delete from sysmt_mtapproval where mid = :mid;
      delete from sysmt_mtlog where mid = :mid;
      delete from sysmt_mt where mid = :mid;
   end;
   close midCur;
   delete from sysmt_sys2set where sysid = :sysid;
   delete from sysmt_system where sysid = :sysid;
   delete from sysmt_instance where sysid = :sysid;
end;
@


drop if exists procedure impVip2Host;
@
create procedure impVip2Host(vip in string(30),
     hostname in string(30),
     status in string(15))
begin
   var hid int;
   :hid = getHostId(:hostname);
   if :hid != null
   then
      delete from sysmt_vip2host where ( vip = :vip and hid = :hid );
      insert into sysmt_vip2host ( vip, hid, status )
       values (:vip, :hid, :status);
   end;
end;
@

drop if exists procedure newGroupSearch;
@
create procedure newGroupSearch(gsname in string(30),
     gsspec in string(100)) return int
begin
   var gsid int;
   :gsid = nextId('GSID');
   insert into sysmt_groupsearch ( gsid, gsname, gsspec )
    values (:gsid, :gsname, :gsspec);
   return :gsid;
end;
@

drop if exists procedure newMt;
@
create procedure newMt(sid in string(20),
     shortdesc in string(50),
     description in string(500),
     mtfrom in datetime,
     mtto in datetime,
     downfrom in datetime,
     downto in datetime,
     status in string(10),
     ticketnr in bigint(20),
     mttype in string(10),
     thrid in int) return int
begin
   var mid int;
   var sysid int;
   var pid int;
   var agid int;
   :mid = nextId('MID');
   :sysid = getSysId(:sid);
   insert into sysmt_mt ( mid, sysid, shortdesc, description, mtfrom, mtto, downfrom, downto, status, ticketnr, mttype, thrid )
    values (:mid, :sysid, :shortdesc, :description, :mtfrom, :mtto, :downfrom, :downto, :status, :ticketnr, :mttype, :thrid);
   :pid = getPidForSid(:sid);
   cursor agCur as
      select
       bgid as bgid
      from
       sysmt_prj2approval@sysmt sysmt_prj2approval
      where pid = :pid;
   while fetch agCur into (:agid) = true
   begin
      insert into sysmt_mtapproval ( mid, bgid, status )
       values (:mid, :agid, 'Requested');
   end;
   close agCur;
   return :mid;
end;
@

drop if exists procedure newSLA;
@
create procedure newSLA(slanr in string(30),
     shortdesc in string(100)) return int
begin
   var slaid int;
   :slaid = nextId('SLAID');
   insert into sysmt_sla ( slaid, slanr, shortdesc )
    values (:slaid, :slanr, :shortdesc);
   return :slaid;
end;
@

drop if exists procedure impFS;
@
create procedure impFS(sid in string(20),
     fspath in string(100),
     fssize in long)
begin
   var sysid int;
   :sysid = getSysId(:sid);
   if :sysid != null
   then
      update sysmt_filesys set fssize=:fssize where ( sysid = :sysid
 and
fspath = :fspath );
   end;
end;
@

drop if exists procedure newResource;
@
create procedure newResource(resname in string(100),
     resdesc in string(1000)) return int
begin
   var resid int;
   :resid = nextId('RESID');
   insert into sysmt_resource ( resid, resname, resdesc )
    values (:resid, :resname, :resdesc);
   return :resid;
end;
@

drop if exists procedure newSkill;
@
create procedure newSkill(skname in string(100),
     skdesc in string(1000)) return int
begin
   var skid int;
   :skid = nextId('SKID');
   insert into sysmt_skill ( skid, skname, skdesc )
    values (:skid, :skname, :skdesc);
   return :skid;
end;
@

drop if exists procedure newResourcePlanEntry;
@
create procedure newResourcePlanEntry(activity in string(200),
     resfrom in datetime,
     resto in datetime,
     resid in int,
     mid in int) return int
begin
   var rpeid int;
   :rpeid = nextId('RPEID');
   insert into sysmt_resourceplan ( rpeid, activity, resfrom, resto, resid, mid )
    values (:rpeid, :activity, :resfrom, :resto, :resid, :mid);
   return :rpeid;
end;
@

drop if exists procedure newResourceEntry;
@
create procedure newResourceEntry(activity in string(200),
     resfrom in datetime,
     resto in datetime,
     resid in int,
     mid in int) return int
begin
   var rpeid int;
   :rpeid = nextId('RPEID');
   insert into sysmt_resourceplan ( rpeid, activity, resfrom, resto, resid, mid )
    values (:rpeid, :activity, :resfrom, :resto, :resid, :mid);
   return :rpeid;
end;
@

