--
-- SysMT cego table definitions
--


-- sysmtem parameters
drop if exists table sysmt_sysparam;
create table sysmt_sysparam(pname string(20) not null,
       pval string(200));
create primary index on sysmt_sysparam(pname);

-- system addon
drop if exists table sysmt_addon;
create table sysmt_addon(aoid int not null, 
       aotype string(20), 
       aoname string(20),
       aohome string(100),
       aouser string(100),
       aogroup string(100),
       aoexepath string(100),
       aologpath string(100), 
       sysid int);
create primary index on sysmt_addon(aoid);

-- business group
drop if exists table sysmt_bgroup;
create table sysmt_bgroup(bgid int not null,
       bgname string(20), 
       bgdesc string(10000));

create primary index on sysmt_bgroup(bgid);
create index sysmt_bgroup_i1 on sysmt_bgroup(bgname);

-- business group right
drop if exists table sysmt_bgright;
create table sysmt_bgright(bgid int not null,
       bgright string(20) not null);


-- custom search condition
drop if exists table sysmt_custcond;
create table sysmt_custcond(ccid int not null,
       ccname string(20),
       ccspec string(100),
       uid int,
       cctype string(20));

create primary index on sysmt_custcond(ccid);

-- displacement system
drop if exists table sysmt_dispsys;
create table sysmt_dispsys(sysid int not null, 
       dispsysid int not null);
create primary index on sysmt_dispsys(sysid, dispsysid);

-- disk
drop if exists table sysmt_disk;
create table sysmt_disk(did int not null, 
       scandate datetime,
       status string(20),
       diskname string(100),
       disksize long,
       diskusage string(100),
       diskvg string(100), slaid int);
create primary index on sysmt_disk(did);

-- disk 2 host
drop if exists table sysmt_disk2host;
create table sysmt_disk2host(did int not null, 
       hid int not null);

-- document
drop if exists table sysmt_document;
create table sysmt_document(docid int not null,
       doctype string(10),
       docname string(200));

create primary index on sysmt_document(docid);

-- document 2 thread
drop if exists table sysmt_doc2thread;
create table sysmt_doc2thread(docid int not null, 
       thrid int not null);
create primary index on sysmt_doc2thread(docid, thrid);

-- filesystem
drop if exists table sysmt_filesys;
create table sysmt_filesys(fstype string(50),
       fspath string(100) not null,
       fsvg string(100) not null,
       fssize long not null,
       sysid int not null,
       fsopt string(100),
       fslv string(100));

-- file system template
drop if exists table sysmt_filesystmpl;
create table sysmt_filesystmpl(tmplid int not null, 
       fstmplname string(50),
       fstmpldesc string(500),
       fstmplrule string(200),
       fstmpltype string(10));

-- file system template entry
drop if exists table sysmt_filesystmplentry;
create table sysmt_filesystmplentry(tmplid int not null, 
       fstype string(50), 
       fspath string(100) not null, 
       fsvg string(100) not null, 
       fssizesmall long not null, 
       fsopt string(100), 
       fsid int, 
       fssizebig long, 
       fslv string(100));

-- firewall port set
drop if exists table sysmt_fwps;
create table sysmt_fwps(psid int not null,
       psname string(30),
       psdesc string(500));

create primary index on sysmt_fwps(psid);

-- firewall port set entry
drop if exists table sysmt_fwpsentry;
create table sysmt_fwpsentry(psid int, 
       portval string(30),
       porttype string(10),	
       portdesc string(500));

-- firewall server group
drop if exists table sysmt_fwsg;
create table sysmt_fwsg(sgid int not null, 
       sgname string(30),
       sgdesc string(500));

create primary index on sysmt_fwsg(sgid);

-- firewall server group entry
drop if exists table sysmt_fwsgentry;
create table sysmt_fwsgentry(sgid int,
       ipval string(30),
       ipdesc string(500));

-- group search
drop if exists table sysmt_groupsearch;
create table sysmt_groupsearch(gsid int not null, 
       gsname string(20), 
       gsspec string(100));
create primary index on sysmt_groupsearch(gsid);

-- group search 2 group
drop if exists table sysmt_gs2bgrp;
create table sysmt_gs2bgrp(gsid int not null, 
       bgid int not null);
create primary index on sysmt_gs2bgrp(gsid, bgid);

-- host
drop if exists table sysmt_host;
create table sysmt_host(hid int not null, 
       scandate datetime,
       status string(20),
       hostname string(30),
       hostinfo string(100),
       osinfo string(30),
       cpuinfo string(30),
       meminfo string(30));

create primary index on sysmt_host(hid);

-- identificator
drop if exists table sysmt_id;
create table sysmt_id(id string(10) not null, 
       idval int);
create primary index on sysmt_id(id);

-- system instance
drop if exists table sysmt_instance;
create table sysmt_instance(instid int not null,
       instnr string(10) not null,
       instvip string(50) not null,
       instsmd string(10) not null,
       instzone string(50),
       instarch string(10),
       sysid int not null,
       created datetime default sysdate not null,
       instsaptype string(10),
       instjavaport string(10),
       instdisp string(10));

create primary index on sysmt_instance(instid);

-- maintain
drop if exists table sysmt_mt;
create table sysmt_mt(mid int not null,
       shortdesc string(100),
       description string(500),
       mtfrom datetime,
       mtto datetime,
       status string(10),
       ticketnr bigint(10),
       sysid int,
       lockby string(20),
       mttype string(10),
       downfrom datetime,
       downto datetime,
       repcomment string(50),
       repappcheck string(10),
       thrid int);

create primary index on sysmt_mt(mid);
-- create index sysmt_mt_i1 on sysmt_mt(status);
create index sysmt_mt_i2 on sysmt_mt(mtfrom);
create index sysmt_mt_i3 on sysmt_mt(sysid);
create index sysmt_mt_i4 on sysmt_mt(mtto);

-- maintain approval
drop if exists table sysmt_mtapproval;
create table sysmt_mtapproval(mid int not null, bgid int not null, status string(10));
create index sysmt_mtapproval_i1 on sysmt_mtapproval(mid);

-- maintain log
drop if exists table sysmt_mtlog;
create table sysmt_mtlog(logts datetime, mid int, logentry string(100));

-- maintain verification
drop if exists table sysmt_mtverification;
create table sysmt_mtverification(mid int not null,
       bgid int not null,
       status string(10));

-- project
drop if exists table sysmt_project;
create table sysmt_project(pid int not null,
       prjname string(100),
       prjdesc string(1000),
       prjmail string(100));

create primary index on sysmt_project(pid);
create unique index sysmt_project_i1 on sysmt_project(prjname);


-- project 2 approval
drop if exists table sysmt_prj2approval;
create table sysmt_prj2approval(pid int not null, 
       bgid int not null);
create primary index on sysmt_prj2approval(pid, bgid);

-- project 2 group
drop if exists table sysmt_prj2bgrp;
create table sysmt_prj2bgrp(pid int not null,
       bgid int not null);

create primary index on sysmt_prj2bgrp(pid,bgid);
create index sysmt_prj2bgrp_i1 on sysmt_prj2bgrp(bgid);
create index sysmt_prj2bgrp_i2 on sysmt_prj2bgrp(pid);


-- project 2 notification
drop if exists table sysmt_prj2notification;
create table sysmt_prj2notification(pid int not null,
       bgid int not null);

create primary index on sysmt_prj2notification(pid,bgid);

-- project 2 workflow
drop if exists table sysmt_prj2workflow;
create table sysmt_prj2workflow(pid int not null,
       bgid int not null,
       seqnr int);

-- project 2 verification
drop if exists table sysmt_prj2verification;
create table sysmt_prj2verification(pid int not null,
       bgid int not null);

-- SLA
drop if exists table sysmt_sla;
create table sysmt_sla(slaid int not null,
       slanr string(30),
       shortdesc string(100));

create primary index on sysmt_sla(slaid);


-- SLA 2 project
drop if exists table sysmt_sla2prj;
create table sysmt_sla2prj(slaid int not null,
       pid int not null);

-- system firewall entry
drop if exists table sysmt_sysfw;
create table sysmt_sysfw(fwrid int not null,
       sgidfrom int,
       sgidto int,
       psid int,
       sysid int,
       fwrdesc string(500));

create primary index on sysmt_sysfw(fwrid);

-- system
drop if exists table sysmt_system;
create table sysmt_system(sysid int not null, 
       sid string(20), 
       category string(10),
       sysdesc string(1000),
       pid int,
       systype string(10),
       mtinfo string(300),
       platform string(10),
       status string(10),
       saptype string(10),
       vip string(20),
       sysnr string(10),
       scs string(10),
       javaport string(10),
       smdid string(10),
       zoneA string(20),
       zoneB string(20),
       partA string(20),
       partB string(20),
       partC string(20),
       partD string(20),
       restartzones string(100),
       created datetime default sysdate,
       dbtype string(10), 
       arch string(10),
       nfsvip string(30),
       vipip string(20),
       vipif string(20),
       dbversion string(20),
       sharedfs string(300),
       parthalog string(300),
       slaid int,
       sapversion string(20),
       sdbtype string(10),
       dbvip string(20),
       dbvA string(20),
       dbvB string(20),
       scandbversion string(100),
       scansapversion string(100));

create primary index on sysmt_system(sysid);
create index sysmt_system_i1 on sysmt_system(pid);

-- system 2 set
drop if exists table sysmt_sys2set;
create table sysmt_sys2set(sysid int not null,
       setid int not null);


-- system set
drop if exists table sysmt_systemset;
create table sysmt_systemset(setid int not null, 
       setname string(20),
       description string(1000));

create primary index on sysmt_systemset(setid);

-- system set 2 group
drop if exists table sysmt_set2bgrp;
create table sysmt_set2bgrp(setid int not null, bgid int not null);

-- system workflow
drop if exists table sysmt_sysworkflow;
create table sysmt_sysworkflow(sysid int not null,
       bgid int not null,
       seqnr int,
       assigned datetime,
       released datetime,
       dbuser string(20),
       comment string(500),
       status string(10));

-- system nfs
drop if exists table sysmt_nfs;
create table sysmt_nfs(nfsid int not null,
       nfspath string(100),
       nfsnode string(100),
       nfsmount string(100),
       sysid int);

-- thread group 2 business group
drop if exists table sysmt_tg2bgrp;
create table sysmt_tg2bgrp(tgid int not null, bgid int not null);

create primary index on sysmt_tg2bgrp(tgid,bgid);

-- thread
drop if exists table sysmt_thread;
create table sysmt_thread(thrid int not null,
       shortdesc string(100),
       description string(1000),
       created datetime,
       remind datetime,
       lastedit datetime,
       lasteditby string(20), 
       status string(15),
       tgid int,
       bgid int);

create primary index on sysmt_thread(thrid);
create index sysmt_thread_i1 on sysmt_thread(tgid);

-- thread rstat
drop if exists table sysmt_threadstat;
create table sysmt_threadstat(thrid int not null,
       uid int not null,
       readstat string(15));

create primary index on sysmt_threadstat(thrid, uid);

-- thread group
drop if exists table sysmt_threadgroup;
create table sysmt_threadgroup(tgid int not null,
       tgname string(30),
       tgdesc string(500));
create primary index on sysmt_threadgroup(tgid);

-- thread log
drop if exists table sysmt_threadlog;
create table sysmt_threadlog(logts datetime,
       logentry string(1000),
       thrid int,
       dbuser string(20));

-- user
drop if exists table sysmt_user;
create table sysmt_user(uid int not null,
       dbuser string(20),
       username string(20),
       userdesc string(1000),
       userright string(10),
       usermail string(100));

create primary index on sysmt_user(uid);
create unique index sysmt_user_i1 on sysmt_user(dbuser);

-- user 2 group
drop if exists table sysmt_usr2bgrp;
create table sysmt_usr2bgrp(uid int not null,
       bgid int not null);

create primary index on sysmt_usr2bgrp(uid,bgid);
create index sysmt_usr2bgrp_i1 on sysmt_usr2bgrp(bgid);


-- user search
drop if exists table sysmt_usersearch;
create table sysmt_usersearch(usid int not null, usname string(20), usspec string(1000), uid int);


-- vip 2 host
drop if exists table sysmt_vip2host;
create table sysmt_vip2host(vip string(30) not null,
       hid int not null, 
       status string(15));

-- resource
drop if exists table sysmt_resource;
create table sysmt_resource(resid int not null,
       resname  string(30),
       resdesc string(1000));

create primary index on sysmt_resource(resid);

-- skill
drop if exists table sysmt_skill;
create table sysmt_skill(skid int not null,
       skname  string(30),
       skdesc string(1000));

create primary index on sysmt_skill(skid);

-- resource 2 prj
drop if exists table sysmt_res2prj;
create table sysmt_res2prj(resid int not null,
       pid int not null);

create primary index on sysmt_res2prj(resid, pid);

-- resource 2 skill
drop if exists table sysmt_res2skill;
create table sysmt_res2skill(resid int not null,
       skid int not null);

create primary index on sysmt_res2skill(resid, skid);


-- resource plan
drop if exists table sysmt_resourceplan;
create table sysmt_resourceplan(
       rpeid int not null,
       activity string(200),
       resfrom datetime,
       resto datetime,
       resid int not null,
       mid int not null);

create primary index on sysmt_resourceplan(rpeid);
