--
-- SysMT cego view definitions
--

drop if exists view sysmt_mtview;
create view sysmt_mtview as
select
 mt.mid as mid,
 mt.lockby as lockby,
 prj.prjname as prjname,
 prj.pid as pid,
 sys.sysid as sysid,
 sys.sid as sid,
 sys.category as category,
 sys.saptype as saptype,
 sys.mtinfo as mtinfo,
 mt.shortdesc as shortdesc,
 mt.description as description,
 mt.mtfrom as mtfrom,
 mt.mtto as mtto,
 mt.downfrom as downfrom,
 mt.downto as downto,
 mt.status as status,
 mt.ticketnr as ticketnr,
 mt.mttype as mttype,
 mt.repcomment as repcomment,
 mt.repappcheck as repappcheck,
 mt.thrid as thrid,
 (select tg.tgname as tgname from sysmt_threadgroup@sysmt tg, sysmt_thread@sysmt t 
  where ( t.thrid = mt.thrid and t.tgid = tg.tgid )) as tgname,
 (select t.shortdesc as shortdesc from sysmt_thread@sysmt t where t.thrid = mt.thrid ) as tshortdesc,
 (select count(*) from sysmt_mt@sysmt mt2 
  where ( ( ( mt2.mtfrom > mt.mtfrom and mt2.mtfrom < mt.mtto ) 
  and mt2.mid != mt.mid ) and mt.sysid = mt2.sysid )) as conflicts
from
 sysmt_mt@sysmt mt,
 sysmt_project@sysmt prj,
 sysmt_system@sysmt sys
where
 ( sys.pid = prj.pid
  and
 mt.sysid = sys.sysid );

drop if exists view sysmt_usrview;
create view sysmt_usrview as
select
 u.uid as uid,
 u.dbuser as dbuser,
 u.username as username,
 u.userright as userright,
 (select
 count( distinct s.sid)
from
 sysmt_system@sysmt s,
 sysmt_prj2bgrp@sysmt p2g,
 sysmt_usr2bgrp@sysmt u2g
where
 ( ( p2g.pid = s.pid
 and
u2g.bgid = p2g.bgid )
  and
 u2g.uid = u.uid )
order by
 s.sid) as numsys,
 (select
 count( distinct p.pid)
from
 sysmt_project@sysmt p,
 sysmt_prj2bgrp@sysmt p2g,
 sysmt_usr2bgrp@sysmt u2g
where
 ( ( p2g.pid = p.pid
 and
u2g.bgid = p2g.bgid )
  and
 u2g.uid = u.uid )
order by
 p.pid) as numprj
from
 sysmt_user@sysmt u;


drop if exists view sysmt_systemview;
create view sysmt_systemview as
select
 sys.sysid as sysid,
 sys.sid as sid,
 sys.saptype as saptype,
 sys.dbtype as dbtype,
 sys.dbversion as dbversion,
 sys.sapversion as sapversion,
 sys.arch as arch,
 sys.category as category,
 sys.platform as platform,
 sys.status as status,
 sys.vip as vip,
 sys.nfsvip as nfsvip,
 sys.vipip as vipip,
 sys.vipif as vipif,
 sys.sysnr as sysnr,
 sys.scs as scs,
 sys.javaport as javaport,
 sys.smdid as smdid,
 sys.zoneA as zoneA,
 sys.zoneB as zoneB,
 sys.partA as partA,
 sys.partB as partB,
 sys.partC as partC,
 sys.partD as partD,
 sys.restartzones as restartzones,
 sys.sharedfs as sharedfs,
 sys.parthalog as parthalog,
 sys.sdbtype as sdbtype,
 sys.dbvip as dbvip,
 sys.dbvA as dbvA,
 sys.dbvB as dbvB,
 sys.slaid as slaid,
 prj.prjname as prjname,
 prj.pid as pid,
 sys.sysdesc as description,
 sys.mtinfo as mtinfo,
 sys.scansapversion as scansapversion,
 sys.scandbversion as scandbversion,
 (select
 count(*)
from
 sysmt_instance@sysmt i
where
 i.sysid = sys.sysid
) as numinst
from
 sysmt_system@sysmt sys,
 sysmt_project@sysmt prj
where
 sys.pid = prj.pid;


drop if exists view sysmt_mtmonthprj;
create view sysmt_mtmonthprj as
select
 mt.mid as mid,
 mt.status as status,
 p.prjname as prjname,
 p.pid as pid,
 s.sid as sid,
 date2str(mt.mtfrom,'%m') as month,
 date2str(mt.mtfrom,'%Y') as year
from
 sysmt_mt@sysmt mt,
 sysmt_system@sysmt s,
 sysmt_project@sysmt p
where
 ( mt.sysid = s.sysid
  and
 s.pid = p.pid );


drop if exists view sysmt_mtmonthset;
create view sysmt_mtmonthset as
select
 mt.mid as mid,
 mt.status as status,
 ss.setname as setname,
 ss.setid as setid,
 sys.sid as sid,
 date2str(mt.mtfrom,'%m') as month,
 date2str(mt.mtfrom,'%Y') as year
from
 sysmt_mt mt,
 sysmt_system sys,
 sysmt_sys2set s2s,
 sysmt_systemset ss
where  mt.sysid = s2s.sysid and s2s.sysid = sys.sysid and s2s.setid = ss.setid;


drop if exists view sysmt_sysfwview;
create view sysmt_sysfwview as
select
 sfw.fwrid as fwrid,
 sfw.sysid as sysid,
 (select
 sysmt_system.sid as sid
from
 sysmt_system@sysmt sysmt_system
where
 sysmt_system.sysid = sfw.sysid
) as sid,
 (select
 sysmt_fwsg.sgname as sgname
from
 sysmt_fwsg@sysmt sysmt_fwsg
where
 sysmt_fwsg.sgid = sfw.sgidfrom
) as sgfrom,
 (select
 sysmt_fwsg.sgname as sgname
from
 sysmt_fwsg@sysmt sysmt_fwsg
where
 sysmt_fwsg.sgid = sfw.sgidto
) as sgto,
 (select
 sysmt_fwps.psname as psname
from
 sysmt_fwps@sysmt sysmt_fwps
where
 sysmt_fwps.psid = sfw.psid
) as portset,
sfw.fwrdesc as fwrdesc
from
 sysmt_sysfw@sysmt sfw;


drop if exists view sysmt_threadview;
create view sysmt_threadview as
select
 t.thrid as thrid,
 tg.tgname as tgname,
 tg.tgid as tgid,
 t.created as created,
 t.shortdesc as shortdesc,
 t.description as description,
 t.remind as remind,
 bg.bgname as bgname,
 t.status as status,
 u.uid as uid,
 t.lastedit as lastedit,
 t.lasteditby as lasteditby,
case when rs.readstat = null then 'UNREAD' else 'READ' end as readstat,
rs.uid as rsuid,
 case when t.remind < sysdate then 'EXPIRED' else 'INTIME' end as remstat
from
 sysmt_thread t inner join  sysmt_threadgroup tg on t.tgid = tg.tgid
 inner join sysmt_bgroup bg on bg.bgid = t.bgid inner join sysmt_user u on u.uid = u.uid
left outer join sysmt_threadstat rs on rs.uid = u.uid and rs.thrid = t.thrid;

drop if exists view sysmt_masterhostview;
create view sysmt_masterhostview as
select
 h.hostname as masterhost,
 v2h.vip as vip,
 v2h.status as status
from
 sysmt_vip2host@sysmt v2h,
 sysmt_host@sysmt h
where
 v2h.hid = h.hid;

drop if exists view sysmt_mtbyday;
create view sysmt_mtbyday as
select
 sysmt_mt.mid as mid,
 date2str(sysmt_mt.mtfrom,'%d') as day
from
 sysmt_mt@sysmt sysmt_mt;
drop if exists view sysmt_prj2uid;
create view sysmt_prj2uid as
select
 p.prjname as prjname,
 u2g.uid as uid
from
 sysmt_project@sysmt p,
 sysmt_prj2bgrp@sysmt p2g,
 sysmt_usr2bgrp@sysmt u2g
where
 ( p2g.pid = p.pid
  and
 u2g.bgid = p2g.bgid );

drop if exists view sysmt_diskview;
create view sysmt_diskview as
select
 d.did as did,
 d.diskname as diskname,
 d.status as status,
 d.scandate as scandate,
 d.disksize as disksize,
 d.diskusage as diskusage,
 d.diskvg as diskvg,
 h.hostname as hostname
from
 sysmt_disk@sysmt d,
 sysmt_disk2host@sysmt d2h,
 sysmt_host@sysmt h
where
 ( d.did = d2h.did
  and
 d2h.hid = h.hid );

drop if exists view sysmt_sid2uid;
create view sysmt_sid2uid as
select
 s.sid as sid,
 u2g.uid as uid
from
 sysmt_system@sysmt s,
 sysmt_prj2bgrp@sysmt p2g,
 sysmt_usr2bgrp@sysmt u2g
where
 ( p2g.pid = s.pid
  and
 u2g.bgid = p2g.bgid );

drop if exists view sysmt_resplanview;
create view sysmt_resplanview as
select
 p.rpeid as rpeid,
 r.resid as resid,
 r.resname as resname,
 p.activity as activity,
 p.resfrom as resfrom,
 p.resto as resto,
 p.mid as mid 
from
 sysmt_resource r,
 sysmt_resourceplan p
where r.resid = p.resid;

drop if exists view sysmt_mtrepview;
create view sysmt_mtrepview as
select
 mt.mid as mid,
 mt.shortdesc as shortdesc,
 p.prjname as prjname,
 s.sid as sid,
 ss.setname as setname,
 mt.shortdesc as shortdesc,
 mt.mtfrom as mtfrom,
 mt.mtto as mtto,
 mt.downfrom as downfrom,
 mt.downto as downto,
 mt.status as status,
 mt.repcomment as repcomment,
 mt.repappcheck as repappcheck,
 date2str(mt.mtfrom,'%m') as month,
 date2str(mt.mtfrom,'%Y') as year
from
 sysmt_mt mt,
 sysmt_system s,
 sysmt_project p,
 sysmt_sys2set s2s,
 sysmt_systemset ss
where
  mt.sysid = s.sysid and s.pid = p.pid and mt.sysid = s2s.sysid and s2s.setid = ss.setid;
