#!/bin/sh

if [ ! -f ./param_${1}.sh ]
then
    echo "Param file for '${1}' does not exist"
    exit 1
fi

. ./param_${1}.sh

. ./tooltips.sh

echo "Patching and copying static html templates .."
for f in htdocs/*.tmpl
do
    TARGET=`echo $f | sed 's/tmpl/html/'`
    echo Patching $f ...
    cat $f | sed "s/@HTTPHOST@/$HTTPHOST/" \
	| sed "s/@HEADERTEXT@/$HEADERTEXT/" \
	| sed "s/@FOOTERTEXT@/$FOOTERTEXT/" > $TARGET

done

echo "Patching and copying dynamic html templates .."
for f in templates/*.tmpl
do
    TARGET=`echo $f | sed 's/tmpl/html/'`
    echo Patching $f ...
    cat $f | sed "s/@HTTPHOST@/$HTTPHOST/" \
	| sed "s/@HEADERTEXT@/$HEADERTEXT/" \
	| sed "s/@TT_CATEGORY@/$TT_CATEGORY/" \
	| sed "s/@TT_PROJECT@/$TT_PROJECT/" \
	| sed "s/@TT_PLATFORM@/$TT_PLATFORM/" \
	| sed "s/@TT_STATUS@/$TT_STATUS/" \
	| sed "s/@TT_SAPTYPE@/$TT_SAPTYPE/" \
	| sed "s/@TT_SCS@/$TT_SCS/" \
	| sed "s/@TT_SYSNR@/$TT_SYSNR/" \
	| sed "s/@TT_JAVAPORT@/$TT_JAVAPORT/" \
	| sed "s/@TT_MTINFO@/$TT_MTINFO/" \
	| sed "s/@TT_DB@/$TT_DB/" \
	| sed "s/@TT_DBVERSION@/$TT_DBVERSION/" \
	| sed "s/@TT_VIP@/$TT_VIP/" \
	| sed "s/@TT_SMDID@/$TT_SMDID/" \
	| sed "s/@TT_DESC@/$TT_DESC/" \
	| sed "s/@TT_ZONE@/$TT_ZONE/" \
	| sed "s/@TT_PART@/$TT_PART/" \
	| sed "s/@TT_ARCH@/$TT_ARCH/" \
	| sed "s/@TT_HALOG@/$TT_HALOG/" \
	| sed "s/@TT_MZONE@/$TT_MZONE/" \
	| sed "s/@TT_RZONE@/$TT_RZONE/" \
	| sed "s/@TT_SHAREDFS@/$TT_SHAREDFS/" \
	| sed "s/@TT_VIPIP@/$TT_VIPIP/" \
	| sed "s/@TT_VIPIF@/$TT_VIPIF/" \
	| sed "s/@TT_RFTS@/$TT_RFTS/" \
	| sed "s/@TT_WILY@/$TT_WILY/" \
	| sed "s/@TT_WEBDISP@/$TT_WEBDISP/" \
	| sed "s/@TT_CWAY@/$TT_CWAY/" \
	| sed "s/@TT_VERTEX@/$TT_VERTEX/" \
	| sed "s/@FOOTERTEXT@/$FOOTERTEXT/" > $TARGET
done

echo "Patching and copying perl db master .."
cat PerlSpace/SysMtExecuter.tmpl \
    | sed "s/@HEADERTEXT@/$HEADERTEXT/" \
    | sed "s/@DATABASE@/$DATABASE/" \
    | sed "s/@HTTPHOST@/$HTTPHOST/" \
    | sed "s/@DBNAME@/$DBNAME/" \
    | sed "s/@DBHOST@/$DBHOST/" \
    | sed "s/@DBPORT@/$DBPORT/" \
    | sed "s/@DBUSER@/$DBUSER/" \
    | sed "s/@DBPWD@/$DBPWD/" \
    | sed "s/@SUPMAIL@/$SUPPORTMAIL/" \
    | sed "s/@SUPSUBJECT@/$SUPPORTSUBJECT/" \
    | sed "s/@SUPPREBODY@/$SUPPORTPREBODY/" \
    | sed "s/@SUPPOSTBODY@/$SUPPORTPOSTBODY/" \
    | sed "s#@PERLSPACEPATH@#$PERLSPACEPATH#" \
    | sed "s#@TEMPLATEPATH@#$TEMPLATEPATH#" \
    | sed "s#@DOCUMENTPATH@#$DOCUMENTPATH#" \
    | sed "s#@HTTPPASSWD@#$HTTPPASSWD#" \
    | sed "s#@MAILX@#$MAILX#" \
    | sed "s#@PASSWDFILE@#$PASSWDFILE#" >  $PERLSPACEPATH/SysMtExecuter.pm

echo "Copying perl programs .."
for f in PerlSpace/*.pm
do
    TARGET=`basename $f`
    cp $f $PERLSPACEPATH/$TARGET
done

echo "Copying static html .."
for f in htdocs/*.html 
do
    TARGET=`basename $f`
    cp $f $HTDOCPATH/$TARGET
done

echo "Copying css file .."
cp htdocs/sysmt-$CSS.css $HTDOCPATH/sysmt.css

echo "Copying favicon .."
cp htdocs/sysmt-logo.gif $HTDOCPATH/sysmt-logo.gif
cp htdocs/sysmt-logo.png $HTDOCPATH/sysmt-logo.png
cp htdocs/lit-logo.gif $HTDOCPATH/lit-logo.gif

echo "Copying html templates .."
for f in templates/*.html
do
    TARGET=`basename $f`
    cp $f $TEMPLATEPATH/$TARGET
done

echo "Copying Calendar files .."
( cd htdocs; cp -r jscalendar-1.0 $HTDOCPATH; cd .. )

echo "Setting admin passwd .."
$HTTPPASSWD -b $PASSWDFILE admin admin 



