--
-- SysMT db2 procedures
--

create function ts_fmt(TS timestamp, fmt varchar(20))
returns varchar(50)
return
with tmp (dd,mm,yyyy,hh,mi,ss,nnnnnn) as
(
    select
    substr( digits (day(TS)),9),
    substr( digits (month(TS)),9) ,
    rtrim(char(year(TS))) ,
    substr( digits (hour(TS)),9),
    substr( digits (minute(TS)),9),
    substr( digits (second(TS)),9),
    rtrim(char(microsecond(TS)))
    from sysibm.sysdummy1
    )
select
case fmt
    when 'dd.mm.yyyy'
        then dd || '.' || mm || '.' || yyyy 
    when 'mm/dd/yyyy'
        then mm || '/' || dd || '/' || yyyy
    when 'dd.mm.yyyy hh:mi:ss'
        then dd || '.' || mm || '.' || yyyy || ' ' ||
               hh || ':' || mi || ':' || ss
    when 'yyyy-mm-dd-hh.mi.ss'
        then yyyy || '-' || mm || '-' || dd || '-' ||
               hh || '.' || mi || '.' || ss
    when 'nnnnnn'
        then nnnnnn
    else
        'date format ' || coalesce(fmt,' <null> ') ||
        ' not recognized.'
    end
from tmp;

create procedure nextId(l_id varchar(20), out l_idval int)
language sql
modifies SQL data
begin atomic
   select idval into l_idval from new table ( update sysmt_id set idval=idval+1 where id = l_id ) where id = l_id;--
end;

create procedure getPid(l_prjname varchar(100),
       out l_pid int)
language sql
begin atomic

   set l_pid = ( select pid as pid
      from sysmt_project
      where prjname = l_prjname );--

   if ( l_pid is null )
   then
       set l_pid = 0;--
   end if;--

end;

create procedure getUid(l_dbuser varchar(20),
       out l_uid int)

language sql
begin atomic

   set l_uid = ( select uid as uid
      from sysmt_user
      where dbuser = l_dbuser );--

   if ( l_uid is null )
   then
       set l_uid = 0;--
   end if;--

end;

create procedure getSysId(l_sid varchar(20),
       out l_sysid int)

language sql
modifies SQL data
begin atomic

   set l_sysid = ( select sysid from sysmt_system where sid = l_sid fetch first 1 rows only );--

   if ( l_sysid is null )
   then
       set l_sysid = 0;--
   end if;--

end;

create procedure getHostId(l_hostname varchar(20),
       out l_hid int)
begin

   set l_hid = ( select hid from sysmt_host where hostname = l_hostname fetch first 1 rows only );--

   if ( l_hid is null )
   then
       set l_hid = 0;--
   end if;--

end;

create procedure getDiskId(l_diskname varchar(100),
       out l_did int)
language sql
modifies SQL data
begin atomic

   set l_did = ( select did from sysmt_disk where diskname = l_diskname fetch first 1 rows only );--

   if ( l_did is null )
   then
       set l_did = 0;--
   end if;--

end;

create procedure newSystem(l_sid varchar(30),
     l_prjname varchar(100),
     l_category varchar(10),
     l_platform varchar(10),
     l_status varchar(10),
     out l_sysid int )
language sql
modifies SQL data
begin atomic

   declare SQLSTATE char(5) default '00000';--

   declare l_pid int;--

   declare l_wfgid int;--
   declare l_seqnr int;--
   declare l_wfstatus varchar(10);--
   declare l_startdate timestamp;--

   declare agCur cursor for
      select bgid as bgid,
            seqnr as seqnr
      from sysmt_prj2workflow sysmt_prj2workflow
      where pid = l_pid
      order by seqnr;--

   call nextId('SYSID', l_sysid);--
   call getPid(l_prjname, l_pid);--

   insert into sysmt_system ( sysid, sid, category, platform, status, pid ) values (l_sysid, l_sid, l_category, l_platform, l_status, l_pid);--

   set l_wfstatus = 'Requested';--
   set l_startdate = current timestamp;--

   open agCur;--

   fetch agCur into l_wfgid, l_seqnr;--
   
   while ( SQLSTATE = '00000' ) 
   do
      insert into sysmt_sysworkflow ( sysid, bgid, seqnr, assigned, status ) values (l_sysid, l_wfgid, l_seqnr, l_startdate, l_wfstatus);--
      set l_wfstatus = 'Waiting';--
      set l_startdate = null;--

      fetch agCur into l_wfgid, l_seqnr;--

   end while;--
   close agCur;--
end;

create procedure newSystemSet(l_setname varchar(10),
     l_description varchar(100),
     out l_setid int)
     language sql
     modifies SQL data
begin atomic
   call nextId('SETID', l_setid);--
   insert into sysmt_systemset ( setid, setname, description ) values (l_setid, l_setname, l_description);--
end;

create procedure newGroup(l_bgname varchar(20),
     l_bgdesc varchar(100),
     out l_bgid int)
language sql
modifies SQL data
begin atomic
   call nextId('BGID', l_bgid);--
   insert into sysmt_bgroup ( bgid, bgname, bgdesc ) values (l_bgid, l_bgname, l_bgdesc);--
end;

create procedure sysWfFire(l_sysid int,
     l_bgname varchar(20),
     l_dbuser varchar(20),
     l_comment varchar(500),
     out l_seqnr int )
language sql
modifies SQL data
begin atomic

      set l_seqnr = (select sysmt_sysworkflow.seqnr as seqnr
   	     	     from sysmt_sysworkflow sysmt_sysworkflow
		     	  where  ( sysmt_sysworkflow.sysid = l_sysid
 			  	 and 
				   sysmt_sysworkflow.bgid = 
				   (select sysmt_bgroup.bgid as bgid
				   	   from sysmt_bgroup sysmt_bgroup
					   	where sysmt_bgroup.bgname = l_bgname) ) );--
   update sysmt_sysworkflow set status='Done',
   	  		    	released = current timestamp, 
   				comment = l_comment,
				dbuser = l_dbuser 
				where  ( sysid = l_sysid
   		      		and  seqnr = l_seqnr );--
   update sysmt_sysworkflow set status='Requested',
   	  		    	assigned = current timestamp
				where  ( sysid = l_sysid
   	  		    	and seqnr = l_seqnr + 1 ) ;--

   set l_seqnr = l_seqnr + 1;--
end;

create procedure impSys( l_sid varchar(20), l_sysdesc varchar(1000), l_dbvers varchar(100), l_sapvers varchar(100))
language sql
modifies SQL data
begin atomic

   declare l_sysid int;

   call getSysId(l_sid, l_sysid);
   if l_sysid = 0
   then
      call newSystem(l_sid,'Unassigned','NA','NA','NA', l_sysid);
      update sysmt_system set sysdesc=l_sysdesc, scandbversion=l_dbvers, scansapversion=l_sapvers where sysid = l_sysi
d;
   else
   update sysmt_system set status='Xandria', scandbversion=l_dbvers, scansapversion=l_sapvers where sid = l_sid;
   end if;
end;

create procedure impDisk(l_diskname varchar(100),
     l_scandate timestamp,
     l_disksize  bigint,
     l_diskusage  varchar(100),
     l_diskvg  varchar(100),
     l_hostname varchar(30))
language sql
modifies SQL data
begin atomic

   declare l_did int;--
   declare l_hid int;--
   declare l_d2h int;--

   call getDiskId(l_diskname, l_did);--
   call getHostId(l_hostname, l_hid);--

   if l_did = 0
   then
      call nextId('DID', l_did);--
      insert into sysmt_disk ( did, scandate, status, diskname, disksize, diskusage, diskvg )
      	     values (l_did, l_scandate, 'new', l_diskname, l_disksize, l_diskusage, l_diskvg);--
      if l_hid != 0
      then
            insert into sysmt_disk2host ( did, hid ) values (l_did, l_hid);--
      end if;--
   else
      update sysmt_disk set scandate=l_scandate, status='valid', diskusage=l_diskusage, diskvg=l_diskvg where did = l_did;--
      set l_d2h = (select count(*)
       	     from sysmt_disk2host sysmt_disk2host
	     	  where ( sysmt_disk2host.hid = l_hid
		  	 and 
			 sysmt_disk2host.did = l_did ) );--
      if l_d2h = 0 and l_hid != 0
      then
	insert into sysmt_disk2host ( did, hid ) values (l_did, l_hid);--
      end if;--
   end if;--
end;

create procedure getPidForSid(l_sid varchar(20),
       out l_pid int)

language sql
modifies SQL data
begin atomic

   set l_pid = ( select pid from sysmt_system where sid = l_sid fetch first 1 rows only );--

   if ( l_pid is null )
   then
       set l_pid = 0;--
   end if;--

end;

create procedure resetApproval(l_mid int)
language sql
modifies SQL data
begin atomic

   declare SQLSTATE char(5) default '00000';--

   declare l_sid varchar(20);--
   declare l_sysid int;--
   declare l_pid int;--
   declare l_status varchar(20);--
   declare l_bgid int;--

   declare aCur cursor for
           select bgid as bgid
           from  sysmt_prj2approval
           where pid = l_pid;--

   declare vCur cursor for
           select bgid as bgid
           from  sysmt_prj2verification
           where pid = l_pid;--



   delete from sysmt_mtapproval where mid = l_mid;--
   delete from sysmt_mtverification where mid = l_mid;--

   set l_status = ( select status
       		  from sysmt_mtview
		  where mid = l_mid );--

   if l_status != 'Claimed'
   then

      set l_sid = ( select sid
      	  	  from sysmt_mtview 
		  where mid = l_mid );--
      set l_sysid = ( select sysid as sysid
      	  	  from sysmt_mt
		  where mid = l_mid );--

      call getPidForSid(l_sid, l_pid);--

      open aCur;--

      fetch aCur into l_bgid;--

      while ( SQLSTATE = '00000' ) 
      do
            insert into sysmt_mtapproval ( mid, bgid, status ) 
	    	   values (l_mid, l_bgid, 'Requested');--

	    fetch aCur into l_bgid;--
      end while;--
      close aCur;--

      open vCur;--

      fetch vCur into l_bgid;--

      while ( SQLSTATE = '00000' ) 
      do
            insert into sysmt_mtverification ( mid, bgid, status ) 
	    	   values (l_mid, l_bgid, 'Requested');--

	    fetch vCur into l_bgid;--
      end while;--
      close vCur;--

      update sysmt_mt set status='Requested' where mid = l_mid;--
   end if;--
end;

create procedure getBgid( l_bgname varchar(20),
       out l_bgid int)
language sql
modifies SQL data
begin atomic

   set l_bgid = ( select bgid as bgid from sysmt_bgroup
      where bgname = l_bgname fetch first 1 rows only );--

end;

create procedure deleteProject(l_pid int)
language sql
modifies SQL data
begin atomic

   declare SQLSTATE char(5) default '00000';--

   declare l_sysid int;--

   declare sysCur cursor for
      select sysid as sysid
      from sysmt_system
      where pid = l_pid;--

   open sysCur;--

   fetch sysCur into l_sysid;--
 
   while ( SQLSTATE = '00000' ) 
   do
      call deleteSystem(l_sysid);--
      fetch sysCur into l_sysid;--
   end while;--

   close sysCur;--

   delete from sysmt_prj2approval where pid = l_pid;--
   delete from sysmt_prj2bgrp where pid = l_pid;--
   delete from sysmt_project where pid = l_pid;--
end;

create procedure sysWfReset(l_sysid int)
language sql
modifies SQL data
begin atomic

   declare SQLSTATE char(5) default '00000';--

   declare l_pid int;--
   declare l_seqnr int;--
   declare l_wfgid int;--
   declare l_wfstatus varchar(10);--
   declare l_startdate timestamp;--

   declare agCur cursor for
      select bgid as bgid,
            seqnr as seqnr
      from sysmt_prj2workflow
      where pid = l_pid
      order by seqnr;--

   delete from sysmt_sysworkflow where sysid = l_sysid;--

   set l_pid = ( select pid
       	       from sysmt_system
	       where sysid = l_sysid);--


   set l_wfstatus = 'Requested';--
   set l_startdate = current timestamp;--

   open agCur;--

   fetch agCur into l_wfgid, l_seqnr;--

   while ( SQLSTATE = '00000' ) 
   do
      insert into sysmt_sysworkflow ( sysid, bgid, seqnr, assigned, status ) 
      values (l_sysid, l_wfgid, l_seqnr, l_startdate, l_wfstatus);--
      set l_wfstatus = 'Waiting';--
      set l_startdate = null;--

      fetch agCur into l_wfgid, l_seqnr;--
   end while;--

   close agCur;--

end;

create procedure impHost(l_hostname varchar(30),
     l_scandate timestamp,
     l_hostinfo varchar(100),
     l_osinfo varchar(100),
     l_cpuinfo varchar(100),
     l_meminfo varchar(100))

language sql
modifies SQL data
begin atomic

   declare l_hid int;--

   call getHostId(l_hostname, l_hid);--

   if l_hid = 0
   then
      call nextId('HID', l_hid);--
      insert into sysmt_host ( hid, scandate, status, hostname, hostinfo, osinfo, cpuinfo, meminfo ) values (l_hid, l_scandate, 'valid', l_hostname, l_hostinfo, l_osinfo, l_cpuinfo, l_meminfo);--
   else
      update sysmt_host set scandate= l_scandate, status='valid', hostinfo=l_hostinfo, osinfo=l_osinfo, cpuinfo=l_cpuinfo, meminfo=l_meminfo where hid = l_hid;--
   end if;--

end;

create procedure newFileSysTmpl(l_fstmplname varchar(50),
     l_fstmpltype varchar(10),
     l_fstmplrule varchar(200),
     l_fstmpldesc varchar(500),
     out l_tmplid int)
language sql
modifies SQL data
begin atomic

   call nextId('TMPLID', l_tmplid);--

   insert into sysmt_filesystmpl ( tmplid, fstmplname, fstmpltype, fstmplrule, fstmpldesc ) values (l_tmplid, l_fstmplname, l_fstmpltype, l_fstmplrule, l_fstmpldesc);--

end;

create procedure newUserSearch(l_usname varchar(30),
     l_usspec varchar(500),
     l_dbuser varchar(20),
     out l_usid int)
language sql
modifies SQL data
begin atomic

   declare l_uid int;--
   call nextId('USID', l_usid);--
   call getUid(l_dbuser, l_uid);--
   insert into sysmt_usersearch ( usid, usname, usspec, uid ) values ( l_usid, l_usname, l_usspec, l_uid);--

end;

create procedure newInstance(l_sysid int,
     l_instnr varchar(10),
     l_instvip varchar(50),
     l_instsmd varchar(10),
     l_instsaptype varchar(10),
     l_instjavaport varchar(10),
     l_instzone varchar(50),
     l_instarch varchar(10),
     l_instdisp varchar(10),
     out l_instid int)

language sql
modifies SQL data
begin atomic

   call nextId('INSTID', l_instid);--

   insert into sysmt_instance ( instid, instnr, instvip, instsmd, instsaptype, instjavaport, instzone, instarch, instdisp, sysid ) 
   values (l_instid, l_instnr, l_instvip, l_instsmd, l_instsaptype, l_instjavaport, l_instzone, l_instarch, l_instdisp, l_sysid);--

end;

create procedure newFileSysTmplEntry(l_tmplid int,
     l_fstype varchar(50),
     l_fspath varchar(100),
     l_fsvg varchar(100),
     l_fslv varchar(100),
     l_fsopt varchar(100),
     l_fssizesmall bigint,
     l_fssizebig bigint,
     out l_fsid int )
language sql
modifies SQL data
begin atomic

   call nextId('FSID', l_fsid);--
   insert into sysmt_filesystmplentry ( fsid, tmplid, fstype, fspath, fsvg, fslv, fsopt, fssizesmall, fssizebig ) 
   values (l_fsid, l_tmplid, l_fstype, l_fspath, l_fsvg, l_fslv, l_fsopt, l_fssizesmall, l_fssizebig);--

end;

create procedure getSetId(l_setname varchar(20),
       out l_setid int)

language sql
begin atomic

   set l_setid = ( select setid as setid
      from sysmt_systemset
      where setname = l_setname fetch first 1 rows only );--

   if ( l_setid is null )
   then
       set l_setid = 0;--
   end if;--

end;

create procedure impVip2Host(l_vip varchar(30),
     l_hostname varchar(30),
     l_status varchar(10))
language sql
modifies SQL data
begin atomic

   declare l_hid int;--

   call getHostId(l_hostname, l_hid);--

   if l_hid != 0
   then
      delete from sysmt_vip2host where  ( vip = l_vip and hid = l_hid ) ;--
      insert into sysmt_vip2host ( vip, hid, status ) values ( l_vip, l_hid, l_status);--
   end if;--
end;

create procedure newGroupSearch(l_gsname varchar(30),
     l_gsspec varchar(100),
     out l_gsid int)
language sql
modifies SQL data
begin atomic

   call nextId('GSID', l_gsid);--
   insert into sysmt_groupsearch ( gsid, gsname, gsspec ) values (l_gsid, l_gsname, l_gsspec);--
end;

create procedure newSLA(l_slanr varchar(30),
     l_shortdesc varchar(100),
     out l_slaid int)
language sql
modifies SQL data
begin atomic

   call nextId('SLAID', l_slaid);--
   insert into sysmt_sla ( slaid, slanr, shortdesc ) values (l_slaid, l_slanr, l_shortdesc);--
end;

create procedure impFS(l_sid varchar(20),
     l_fspath varchar(100),
     l_fssize int)
language sql
modifies SQL data
begin atomic

   declare l_sysid int;--

   call getSysId(l_sid, l_sysid);--

   update sysmt_filesys set fssize= l_fssize where sysid = l_sysid and fspath = l_fspath;--

end;

create procedure newNFS(l_sysid int,
     l_nfspath varchar(100),
     l_nfsnode varchar(100),
     l_nfsmount varchar(100),
     out l_nfsid int)
language sql
modifies SQL data
begin atomic
   call nextId('NFSID', l_nfsid);--
   insert into sysmt_nfs ( nfsid, nfspath, nfsnode, nfsmount, sysid ) values (l_nfsid, l_nfspath, l_nfsnode, l_nfsmount, l_sysid);--
end;

create procedure newAddon(l_sysid int,
     l_aotype varchar(20),
     l_aoname varchar(20),
     out l_aoid int)
     language sql
     modifies SQL data
begin atomic
   call nextId('AOID', l_aoid);--
   insert into sysmt_addon ( aoid, aotype, aoname, sysid ) values (l_aoid, l_aotype, l_aoname, l_sysid);--
end;

create procedure newUser(l_dbuser varchar(20),
     l_username varchar(20),
     l_userdesc varchar(200),
     l_userright varchar(10),
     l_usermail varchar(100),
     out l_uid int)

language sql
modifies SQL data
begin atomic

   call nextId('UID', l_uid);--
   insert into sysmt_user ( uid, dbuser, username, userdesc, userright, usermail )
          values (l_uid, l_dbuser, l_username, l_userdesc, l_userright, l_usermail);--

end;

create procedure newProject(l_prjname varchar(100),
     l_prjdesc varchar(1000),
     out l_pid int)
language sql
modifies SQL data
begin atomic

   call nextId('PID', l_pid);--
   insert into sysmt_project ( pid, prjname, prjdesc ) values ( l_pid, l_prjname, l_prjdesc);--

end;

create procedure newMt(l_sid varchar(20),
     l_shortdesc varchar(100),
     l_description varchar(500),
     l_mtfrom timestamp,
     l_mtto timestamp,
     l_downfrom timestamp,
     l_downto timestamp,
     l_status varchar(10),
     l_ticketnr bigint,
     l_mttype varchar(10),
     l_thrid int,
     out l_mid int)

language sql
modifies SQL data
begin atomic

   declare SQLSTATE char(5) default '00000';--

   declare l_sysid int;--
   declare l_pid int;--
   declare l_agid int;--

   declare agCur cursor for select bgid
                 from sysmt_prj2approval
                 where pid = l_pid;--


   call nextId('MID', l_mid);--
   call getSysId(l_sid, l_sysid);--

   insert into sysmt_mt ( mid, sysid, shortdesc, description, mtfrom, mtto, downfrom, downto, status, ticketnr, mttype, thrid ) values ( l_mid, l_sysid, l_shortdesc, l_description, l_mtfrom, l_mtto, l_downfrom, l_downto, l_status, l_ticketnr, l_mttype, l_thrid);--

   call getPidForSid(l_sid, l_pid);--

   open agCur;--

   fetch agCur into l_agid;--

   while ( SQLSTATE = '00000' )
   do
      insert into sysmt_mtapproval ( mid, bgid, status ) values ( l_mid, l_agid, 'Requested');--

      fetch agCur into l_agid;--

   end while;--
   close agCur;--

end ;

create procedure deleteSystem(l_sysid int)

language sql
modifies SQL data
begin atomic

   declare SQLSTATE char(5) default '00000';--

   declare l_mid int;--
   declare midCur cursor for
      select mid as mid
      from sysmt_mt
      where sysid = l_sysid;--

   open midCur;--

   fetch midCur into l_mid;--

   while ( SQLSTATE = '00000' )
   do
      delete from sysmt_mtapproval where mid = l_mid;--
      delete from sysmt_mtlog where mid = l_mid;--
      delete from sysmt_mt where mid = l_mid;--

      fetch midCur into l_mid;--
   end while;--
   close midCur;--

   delete from sysmt_sys2set where sysid = l_sysid;--
   delete from sysmt_system where sysid = l_sysid;--
   delete from sysmt_instance where sysid = l_sysid;--
end;

create procedure newThreadGroup(l_tgname varchar(30),
     l_tgdesc varchar(1000),
     out l_tgid int)
language sql
modifies SQL data
begin atomic
   call nextId('TGID', l_tgid);--
   insert into sysmt_threadgroup ( tgid, tgname, tgdesc ) values (l_tgid, l_tgname, l_tgdesc );--
end;

create procedure newThread(l_tgname varchar(30),
     l_shortdesc varchar(100),
     l_bgname varchar(20), 
     l_remind timestamp,
     out l_thrid int)
language sql
modifies SQL data
begin atomic

      declare l_tgid int;--

      set l_tgid = ( select tgid from sysmt_threadgroup where tgname = l_tgname );--

      call nextId('THRID', l_thrid);

      insert into sysmt_thread ( thrid, tgid, shortdesc, created, remind, bgid, status )
      values (l_thrid, l_tgid, l_shortdesc, current timestamp, l_remind, (select bgid as bgid from sysmt_bgroup where bgname = l_bgname), 'OPEN');
      
end;

create procedure newDocument(l_doctype varchar(10),
      l_docname varchar(200),
      out l_docid int)
language sql
modifies SQL data
begin atomic
      call nextId('DOCID', l_docid);--
      insert into sysmt_document ( docid, doctype, docname )
             values (l_docid, l_doctype, l_docname);--
end;

create procedure newFWSG(l_sgname varchar(30),
       l_sgdesc varchar(500),
       out l_sgid int)
language sql
modifies SQL data
begin atomic
   call nextId('SGID', l_sgid);--
   insert into sysmt_fwsg ( sgid, sgname, sgdesc )
    values ( l_sgid, l_sgname, l_sgdesc);--
end;

create procedure newFWPS(l_psname varchar(30),
        l_psdesc varchar(500),
       out l_psid int)
language sql
modifies SQL data
begin atomic
   call nextId('PSID', l_psid);--
   insert into sysmt_fwps ( psid, psname, psdesc )
    values ( l_psid, l_psname, l_psdesc);--
end;

create procedure newSysFW(l_sgfrom varchar(30),
        l_sgto varchar(30),
        l_portset varchar(30),
        l_sid varchar(20),
        out l_fwrid int)
language sql
modifies SQL data
begin atomic
   call nextId('FWRID', l_fwrid);--
   insert into sysmt_sysfw ( fwrid, sgidfrom, sgidto, psid, sysid ) values (
   l_fwrid,
   ( select sgid from sysmt_fwsg where sgname = l_sgfrom ),
   ( select sgid from sysmt_fwsg where sgname = l_sgto ),
   ( select psid from sysmt_fwps where psname = l_portset ),
   ( select sysid from sysmt_system where sid = l_sid ) );--
end;
