--
-- SysT db2 table definitions
--


-- sysmtem parameters
create table sysmt_sysparam(pname varchar(20) not null,
       pval varchar(200));
alter table sysmt_sysparam add primary key (pname);


-- sysmt_systemset
CREATE TABLE SYSMT_SYSTEMSET  (
		  SETID INTEGER NOT NULL , 
		  SETNAME VARCHAR(20) , 
		  DESCRIPTION VARCHAR(100) );

ALTER TABLE SYSMT_SYSTEMSET ADD PRIMARY KEY ( SETID );
CREATE UNIQUE INDEX SYSMT_SYSTEMSET_I1 ON SYSMT_SYSTEMSET ( SETNAME ASC) ALLOW REVERSE SCANS;
 

-- sysmt_filesys
CREATE TABLE SYSMT_FILESYS  (
		  FSTYPE VARCHAR(50), 
		  FSPATH VARCHAR(100) NOT NULL, 
		  FSVG VARCHAR(100) NOT NULL, 
		  FSSIZE BIGINT NOT NULL, 
		  FSOPT VARCHAR(100), 
		  FSLV VARCHAR(100), 
		  SYSID INTEGER );

-- sysmt_filesystmpl
CREATE TABLE SYSMT_FILESYSTMPL  (
		  TMPLID INTEGER NOT NULL , 
		  FSTMPLNAME VARCHAR(50) , 
		  FSTMPLDESC VARCHAR(500) , 
		  FSTMPLRULE VARCHAR(200) , 
		  FSTMPLTYPE VARCHAR(10) , 
		  FSLV VARCHAR(100) );
ALTER TABLE SYSMT_FILESYSTMPL ADD PRIMARY KEY ( TMPLID );


CREATE UNIQUE INDEX SYSMT_FILESYSTMPL_I1 ON SYSMT_FILESYSTMPL ( FSTMPLNAME ASC) ALLOW REVERSE SCANS;
 

-- sysmt_filesystmplentry
CREATE TABLE SYSMT_FILESYSTMPLENTRY  (
		  FSID INTEGER NOT NULL , 
		  TMPLID INTEGER NOT NULL , 
		  FSTYPE VARCHAR(50) , 
		  FSPATH VARCHAR(100) NOT NULL , 
		  FSVG VARCHAR(100) NOT NULL , 
		  FSSIZESMALL BIGINT NOT NULL , 
		  FSOPT VARCHAR(100) , 
		  FSSIZEBIG BIGINT , 
		  FSLV VARCHAR(100) );

ALTER TABLE SYSMT_FILESYSTMPLENTRY ADD PRIMARY KEY (FSID);

-- sysmt_gs2bgrp
CREATE TABLE SYSMT_GS2BGRP  (
		  GSID INTEGER NOT NULL , 
		  BGID INTEGER NOT NULL );

ALTER TABLE SYSMT_GS2BGRP ADD PRIMARY KEY (GSID, BGID);

-- sysmt_sla
CREATE TABLE SYSMT_SLA  (
		  SLAID INTEGER NOT NULL , 
		  SLANR VARCHAR(30) , 
		  SHORTDESC VARCHAR(100) );

ALTER TABLE SYSMT_SLA ADD PRIMARY KEY (SLAID);


CREATE INDEX SYSMT_SLA_I1 ON SYSMT_SLA 
		(SLANR ASC)
		ALLOW REVERSE SCANS;
 
-- sysmt_prj2approval
CREATE TABLE SYSMT_PRJ2APPROVAL  (
		  PID INTEGER NOT NULL , 
		  BGID INTEGER NOT NULL );

ALTER TABLE SYSMT_PRJ2APPROVAL 
	ADD PRIMARY KEY
		(PID,
		 BGID);


-- sysmt_vip2host
CREATE TABLE SYSMT_VIP2HOST  (
		  VIP VARCHAR(30) NOT NULL , 
		  HID INTEGER NOT NULL , 
		  STATUS VARCHAR(10) );

ALTER TABLE SYSMT_VIP2HOST ADD PRIMARY KEY (VIP, HID);


-- sysmt_mtlog
CREATE TABLE SYSMT_MTLOG  (
		  LOGTS TIMESTAMP , 
		  MID INTEGER , 
		  LOGENTRY VARCHAR(100) );
 
-- sysmt_disk
CREATE TABLE SYSMT_DISK  (
		  DID INTEGER NOT NULL , 
		  SCANDATE TIMESTAMP , 
		  STATUS VARCHAR(20) , 
		  DISKNAME VARCHAR(100) , 
		  DISKSIZE BIGINT , 
		  DISKUSAGE VARCHAR(30) , 
		  DISKVG VARCHAR(30) , 
		  SLAID INTEGER );

ALTER TABLE SYSMT_DISK 	ADD PRIMARY KEY	(DID);

CREATE INDEX SYSMT_DISK_I1 ON SYSMT_DISK 
		(DISKNAME ASC)
		ALLOW REVERSE SCANS;
 

-- sysmt_disk2host
CREATE TABLE SYSMT_DISK2HOST  (
		  DID INTEGER NOT NULL , 
		  HID INTEGER NOT NULL );

ALTER TABLE SYSMT_DISK2HOST ADD PRIMARY KEY (DID, HID);

CREATE INDEX SYSMT_DISK2HOST_I1 ON SYSMT_DISK2HOST 
		(DID ASC)
		ALLOW REVERSE SCANS;

CREATE INDEX SYSMT_DISK2HOST_I2 ON SYSMT_DISK2HOST 
		(HID ASC)
		ALLOW REVERSE SCANS;
 
-- sysmt_bgright
CREATE TABLE SYSMT_BGRIGHT  (
		  BGID INTEGER NOT NULL , 
		  BGRIGHT VARCHAR(20) NOT NULL );

ALTER TABLE SYSMT_BGRIGHT ADD PRIMARY KEY (BGID, BGRIGHT);


-- sysmt_project
CREATE TABLE SYSMT_PROJECT  (
		  PID INTEGER NOT NULL , 
		  PRJNAME VARCHAR(100) , 
		  PRJDESC VARCHAR(1000) , 
		  PRJMAIL VARCHAR(100) );

ALTER TABLE SYSMT_PROJECT ADD PRIMARY KEY (PID);

CREATE UNIQUE INDEX SYSMT_PROJECT_I1 ON SYSMT_PROJECT 
		(PRJNAME ASC)
		ALLOW REVERSE SCANS;

-- sysmt_id 
CREATE TABLE SYSMT_ID  (
		  ID VARCHAR(10) NOT NULL , 
		  IDVAL INTEGER );

ALTER TABLE SYSMT_ID ADD PRIMARY KEY (ID);

-- sysmt_bgroup
CREATE TABLE SYSMT_BGROUP  (
		  BGID INTEGER NOT NULL , 
		  BGNAME VARCHAR(20) , 
		  BGDESC VARCHAR(2000) );

ALTER TABLE SYSMT_BGROUP ADD PRIMARY KEY (BGID);

CREATE UNIQUE INDEX SYSMT_BGROUP_I1 ON SYSMT_BGROUP 
		(BGNAME ASC)
		ALLOW REVERSE SCANS;

-- sysmt_host
CREATE TABLE SYSMT_HOST  (
		  HID INTEGER NOT NULL , 
		  SCANDATE TIMESTAMP , 
		  STATUS VARCHAR(20) , 
		  HOSTNAME VARCHAR(30) , 
		  HOSTINFO VARCHAR(100) , 
		  OSINFO VARCHAR(100) , 
		  CPUINFO VARCHAR(100) , 
		  MEMINFO VARCHAR(100) );

ALTER TABLE SYSMT_HOST ADD PRIMARY KEY (HID);

CREATE INDEX SYSMT_HOST_I1 ON SYSMT_HOST 
		(HOSTNAME ASC)
		ALLOW REVERSE SCANS;

-- sysmt_user
CREATE TABLE SYSMT_USER  (
		  UID INTEGER NOT NULL , 
		  DBUSER VARCHAR(20) , 
		  USERNAME VARCHAR(20) , 
		  USERDESC VARCHAR(200) , 
		  USERRIGHT VARCHAR(10) , 
		  USERMAIL VARCHAR(100) );

ALTER TABLE SYSMT_USER ADD PRIMARY KEY (UID);

CREATE UNIQUE INDEX SYSMT_USER_I1 ON SYSMT_USER 
		(DBUSER ASC)
		ALLOW REVERSE SCANS;

-- sysmt_usersearch
CREATE TABLE SYSMT_USERSEARCH  (
		  USID INTEGER NOT NULL , 
		  USNAME VARCHAR(20) , 
		  USSPEC VARCHAR(500) , 
		  UID INTEGER );

ALTER TABLE SYSMT_USERSEARCH ADD PRIMARY KEY (USID);

-- sysmt_custcond
CREATE TABLE SYSMT_CUSTCOND  (
		  CCID INTEGER NOT NULL , 
		  CCNAME VARCHAR(20) , 
		  CCSPEC VARCHAR(100) , 
		  UID INTEGER , 
		  CCTYPE VARCHAR(20) );

ALTER TABLE SYSMT_CUSTCOND ADD PRIMARY KEY (CCID);


-- sysmt_sysworkflow
CREATE TABLE SYSMT_SYSWORKFLOW  (
		  SYSID INTEGER NOT NULL , 
		  BGID INTEGER NOT NULL , 
		  SEQNR INTEGER , 
		  ASSIGNED TIMESTAMP , 
		  RELEASED TIMESTAMP , 
		  DBUSER VARCHAR(20) , 
		  COMMENT VARCHAR(500) , 
		  STATUS VARCHAR(10) );

ALTER TABLE SYSMT_SYSWORKFLOW ADD PRIMARY KEY (SYSID, BGID);


-- sysmt_sla2prj
CREATE TABLE SYSMT_SLA2PRJ  (
		  SLAID INTEGER NOT NULL , 
		  PID INTEGER NOT NULL );

ALTER TABLE SYSMT_SLA2PRJ ADD PRIMARY KEY (SLAID, PID);


-- sysmt_sys2set
CREATE TABLE SYSMT_SYS2SET  (
		  SYSID INTEGER NOT NULL , 
		  SETID INTEGER NOT NULL );

ALTER TABLE SYSMT_SYS2SET ADD PRIMARY KEY (SYSID, SETID);


-- sysmt_usr2bgrp
CREATE TABLE SYSMT_USR2BGRP  (
		  UID INTEGER NOT NULL , 
		  BGID INTEGER NOT NULL );

ALTER TABLE SYSMT_USR2BGRP ADD PRIMARY KEY (UID, BGID);


CREATE INDEX SYSMT_USR2BGRP_I1 ON SYSMT_USR2BGRP 
		(UID ASC)
		ALLOW REVERSE SCANS;

CREATE INDEX SYSMT_USR2BGRP_I2 ON SYSMT_USR2BGRP 
		(BGID ASC)
		ALLOW REVERSE SCANS;

-- sysmt_prj2workflow 
CREATE TABLE SYSMT_PRJ2WORKFLOW  (
		  PID INTEGER NOT NULL , 
		  BGID INTEGER NOT NULL , 
		  SEQNR INTEGER );

ALTER TABLE SYSMT_PRJ2WORKFLOW ADD PRIMARY KEY (PID, BGID);


-- sysmt_instance
CREATE TABLE SYSMT_INSTANCE  (
		  INSTID INTEGER NOT NULL , 
		  INSTNR VARCHAR(10) NOT NULL , 
		  INSTVIP VARCHAR(50) NOT NULL , 
		  INSTSMD VARCHAR(10) NOT NULL , 
		  INSTZONE VARCHAR(50) , 
		  INSTARCH VARCHAR(10) , 
		  SYSID INTEGER NOT NULL , 
		  CREATED TIMESTAMP , 
		  INSTSAPTYPE VARCHAR(10) , 
		  INSTJAVAPORT VARCHAR(10) , 
		  INSTDISP VARCHAR(10) );

ALTER TABLE SYSMT_INSTANCE ADD PRIMARY KEY (INSTID);

CREATE INDEX SYSMT_INSTANCE_I1 ON SYSMT_INSTANCE 
		(SYSID ASC)
		ALLOW REVERSE SCANS;
 
-- sysmt_prj2bgrp
CREATE TABLE SYSMT_PRJ2BGRP  (
		  PID INTEGER NOT NULL , 
		  BGID INTEGER NOT NULL );

ALTER TABLE SYSMT_PRJ2BGRP ADD PRIMARY KEY (PID, BGID);

CREATE INDEX SYSMT_PRJ2BGRP_I1 ON SYSMT_PRJ2BGRP 
		(BGID ASC)
		ALLOW REVERSE SCANS;

-- sysmt_set2bgrp
CREATE TABLE SYSMT_SET2BGRP  (
		  SETID INTEGER NOT NULL , 
		  BGID INTEGER NOT NULL );

ALTER TABLE SYSMT_SET2BGRP ADD PRIMARY KEY (SETID, BGID);


-- sysmt_mtapproval 
CREATE TABLE SYSMT_MTAPPROVAL  (
		  MID INTEGER NOT NULL , 
		  BGID INTEGER NOT NULL , 
		  STATUS VARCHAR(10) );

ALTER TABLE SYSMT_MTAPPROVAL ADD PRIMARY KEY (MID, BGID);


CREATE INDEX SYSMT_MTAPPROVAL_I1 ON SYSMT_MTAPPROVAL 
		(MID ASC)
		ALLOW REVERSE SCANS;

-- sysmt_mt 
CREATE TABLE SYSMT_MT  (
		  MID INTEGER NOT NULL , 
		  SHORTDESC VARCHAR(100) , 
		  DESCRIPTION VARCHAR(500) , 
		  MTFROM TIMESTAMP , 
		  MTTO TIMESTAMP , 
		  STATUS VARCHAR(10) , 
		  TICKETNR BIGINT , 
		  SYSID INTEGER , 
		  LOCKBY VARCHAR(20) , 
		  MTTYPE VARCHAR(10) , 
		  DOWNFROM TIMESTAMP , 
		  DOWNTO TIMESTAMP , 
		  REPCOMMENT VARCHAR(50) , 
		  REPAPPCHECK VARCHAR(20) , 
		  THRID INTEGER );

ALTER TABLE SYSMT_MT ADD PRIMARY KEY (MID);

CREATE INDEX SYSMT_MT_I1 ON SYSMT_MT 
		(SYSID ASC)
		ALLOW REVERSE SCANS;

CREATE INDEX SYSMT_MT_I2 ON SYSMT_MT 
		(STATUS ASC)
		ALLOW REVERSE SCANS;

CREATE INDEX SYSMT_MT_I3 ON SYSMT_MT 
		(MTFROM ASC)
		ALLOW REVERSE SCANS;

-- sysmt_groupsearch 
CREATE TABLE SYSMT_GROUPSEARCH  (
		  GSID INTEGER NOT NULL , 
		  GSNAME VARCHAR(20) , 
		  GSSPEC VARCHAR(100) );

ALTER TABLE SYSMT_GROUPSEARCH ADD PRIMARY KEY (GSID);

-- sysmt_system
CREATE TABLE SYSMT_SYSTEM  (
		  SYSID INTEGER NOT NULL , 
		  SID VARCHAR(20) , 
		  CATEGORY VARCHAR(10) , 
		  SYSDESC VARCHAR(1000) , 
		  PID INTEGER , 
		  SYSTYPE VARCHAR(10) , 
		  MTINFO VARCHAR(300) , 
		  PLATFORM VARCHAR(10) , 
		  STATUS VARCHAR(10) , 
		  SAPTYPE VARCHAR(10) , 
		  VIP VARCHAR(20) , 
		  SYSNR VARCHAR(10) , 
		  SCS VARCHAR(10) , 
		  JAVAPORT VARCHAR(10) , 
		  SMDID VARCHAR(10) , 
		  ZONEA VARCHAR(20) , 
		  ZONEB VARCHAR(20) , 
		  PARTA VARCHAR(20) , 
		  PARTB VARCHAR(20) , 
		  PARTC VARCHAR(20) , 
		  PARTD VARCHAR(20) , 
		  RESTARTZONES VARCHAR(100) , 
		  CREATED TIMESTAMP , 
		  DBTYPE VARCHAR(10) , 
		  ARCH VARCHAR(10) , 
		  NFSVIP VARCHAR(30) , 
		  VIPIP VARCHAR(20) , 
		  VIPIF VARCHAR(20) , 
		  DBVERSION VARCHAR(20) , 
		  SHAREDFS VARCHAR(300) , 
		  PARTHALOG VARCHAR(300) , 
		  SLAID INTEGER , 
		  SAPVERSION VARCHAR(20) , 
		  SDBTYPE VARCHAR(10) , 
		  DBVIP VARCHAR(20) , 
		  DBVA VARCHAR(20) , 
		  DBVB VARCHAR(20),
                  SCANDBVERSION varchar(100),
                  SCANSAPVERSION varchar(100) );

ALTER TABLE SYSMT_SYSTEM ADD PRIMARY KEY (SYSID);

CREATE UNIQUE INDEX SYSMT_SYSTEM_I1 ON SYSMT_SYSTEM 
		(SID ASC)
		ALLOW REVERSE SCANS;

CREATE INDEX SYSMT_SYSTEM_I2 ON SYSMT_SYSTEM 
		(PID ASC)
		ALLOW REVERSE SCANS;

-- sysmt_dispsys
CREATE TABLE SYSMT_DISPSYS  (
		  SYSID INTEGER NOT NULL , 
		  DISPSYSID INTEGER NOT NULL );

ALTER TABLE SYSMT_DISPSYS ADD PRIMARY KEY (SYSID, DISPSYSID);


-- sysmt_addon
CREATE TABLE SYSMT_ADDON  (
		  AOID INTEGER NOT NULL , 
		  AOTYPE VARCHAR(20) , 
		  AONAME VARCHAR(20) , 
		  AOHOME VARCHAR(100) , 
		  AOUSER VARCHAR(100) , 
		  AOGROUP VARCHAR(100) , 
		  AOEXEPATH VARCHAR(100) , 
		  AOLOGPATH VARCHAR(100) , 
		  SYSID INTEGER );

ALTER TABLE SYSMT_ADDON ADD PRIMARY KEY	(AOID);

-- sysmt_mtverification
CREATE TABLE SYSMT_MTVERIFICATION  (
		  MID INTEGER NOT NULL , 
		  BGID INTEGER NOT NULL , 
		  STATUS VARCHAR(10) );

ALTER TABLE SYSMT_MTVERIFICATION ADD PRIMARY KEY (MID, BGID);

-- sysmt_prjnotification
CREATE TABLE SYSMT_PRJNOTIFICATION  (
		  PID INTEGER NOT NULL , 
		  BGID INTEGER NOT NULL );

ALTER TABLE SYSMT_PRJNOTIFICATION ADD PRIMARY KEY (PID, BGID);

-- sysmt_nfs
CREATE TABLE SYSMT_NFS  (
		  NFSID INTEGER NOT NULL , 
		  NFSPATH VARCHAR(100) , 
		  NFSNODE VARCHAR(100) , 
		  NFSMOUNT VARCHAR(100) , 
		  SYSID INTEGER );

ALTER TABLE SYSMT_NFS ADD PRIMARY KEY (NFSID);

-- sysmt_prj2notification
CREATE TABLE SYSMT_PRJ2NOTIFICATION  (
		  PID INTEGER NOT NULL , 
		  BGID INTEGER NOT NULL );

ALTER TABLE SYSMT_PRJ2NOTIFICATION ADD PRIMARY KEY (PID, BGID);


-- sysmt_prj2verification
CREATE TABLE SYSMT_PRJ2VERIFICATION  (
		  PID INTEGER NOT NULL , 
		  BGID INTEGER NOT NULL );

ALTER TABLE SYSMT_PRJ2VERIFICATION ADD PRIMARY KEY (PID, BGID);


-- sysmt_threadgroup
CREATE TABLE SYSMT_THREADGROUP  (
		  TGID INTEGER NOT NULL , 
		  TGNAME VARCHAR(30) , 
		  TGDESC VARCHAR(500) );

ALTER TABLE SYSMT_THREADGROUP ADD PRIMARY KEY (TGID);

CREATE UNIQUE INDEX SYSMT_THREADGROUP_I1 ON SYSMT_THREADGROUP 
		(TGNAME ASC)
		ALLOW REVERSE SCANS;

-- sysmt_thread 
CREATE TABLE SYSMT_THREAD  (
		  THRID INTEGER NOT NULL , 
		  SHORTDESC VARCHAR(100) , 
		  DESCRIPTION VARCHAR(1000) , 
		  CREATED TIMESTAMP , 
		  REMIND TIMESTAMP , 
		  LASTEDIT TIMESTAMP , 
		  LASTEDITBY VARCHAR(20) , 
		  STATUS VARCHAR(15) , 
		  TGID INTEGER , 
		  BGID INTEGER );


ALTER TABLE SYSMT_THREAD ADD PRIMARY KEY (THRID);

-- sysmt_threadstat
CREATE TABLE SYSMT_THREADSTAT  (
		  THRID INTEGER NOT NULL , 
		  UID INTEGER NOT NULL , 
		  READSTAT VARCHAR(15) );


ALTER TABLE SYSMT_THREADSTAT ADD PRIMARY KEY (THRID, UID);

-- sysmt_thr2bgrp
CREATE TABLE SYSMT_THR2BGRP  (
		  THRID INTEGER NOT NULL , 
		  BGID INTEGER NOT NULL );

ALTER TABLE SYSMT_THR2BGRP ADD PRIMARY KEY (THRID, BGID);

-- sysmt_doc2thread
CREATE TABLE SYSMT_DOC2THREAD  (
		  DOCID INTEGER NOT NULL , 
		  THRID INTEGER NOT NULL );

ALTER TABLE SYSMT_DOC2THREAD ADD PRIMARY KEY (DOCID, THRID);


-- sysmt_document
CREATE TABLE SYSMT_DOCUMENT  (
		  DOCID INTEGER NOT NULL , 
		  DOCTYPE VARCHAR(10) , 
		  DOCNAME VARCHAR(200) );

ALTER TABLE SYSMT_DOCUMENT ADD PRIMARY KEY (DOCID);

-- sysmt_tg2bgrp
CREATE TABLE SYSMT_TG2BGRP  (
		  TGID INTEGER NOT NULL , 
		  BGID INTEGER NOT NULL );

ALTER TABLE SYSMT_TG2BGRP ADD PRIMARY KEY (TGID, BGID);


-- sysmt_threadlog
CREATE TABLE SYSMT_THREADLOG  (
		  LOGTS TIMESTAMP , 
		  LOGENTRY VARCHAR(3000) , 
		  THRID INTEGER , 
		  DBUSER VARCHAR(20) );
 
-- sysmt_fwsg
CREATE TABLE SYSMT_FWSG  (
		  SGID INTEGER NOT NULL , 
		  SGNAME VARCHAR(30) , 
		  SGDESC VARCHAR(500) );

ALTER TABLE SYSMT_FWSG ADD PRIMARY KEY (SGID);

-- sysmt_fwsgentry
CREATE TABLE SYSMT_FWSGENTRY  (
		  SGID INTEGER NOT NULL , 
		  IPVAL VARCHAR(30) NOT NULL , 
		  IPDESC VARCHAR(100) )   
		 IN USERSPACE1 ; 

ALTER TABLE SYSMT_FWSGENTRY ADD PRIMARY KEY (SGID, IPVAL);


-- sysmt_fwps
CREATE TABLE SYSMT_FWPS  (
		  PSID INTEGER NOT NULL , 
		  PSNAME VARCHAR(30) , 
		  PSDESC VARCHAR(500) );

ALTER TABLE SYSMT_FWPS ADD PRIMARY KEY (PSID);

-- sysmt_fwpsentry
CREATE TABLE SYSMT_FWPSENTRY  (
		  PSID INTEGER NOT NULL , 
		  PORTVAL VARCHAR(30) NOT NULL , 
		  PORTDESC VARCHAR(100) );

ALTER TABLE SYSMT_FWPSENTRY ADD PRIMARY KEY (PSID, PORTVAL);


CREATE TABLE SYSMT_SYSFW  (
		  FWRID INTEGER NOT NULL , 
		  SGIDFROM INTEGER , 
		  SGIDTO INTEGER , 
		  PSID INTEGER , 
		  SYSID INTEGER );

ALTER TABLE SYSMT_SYSFW ADD PRIMARY KEY	(FWRID);


-- DDL Statements for foreign keys on Table SYSMT_SYSTEM

ALTER TABLE SYSMT_SYSTEM 
	ADD CONSTRAINT SQL110829134719780 FOREIGN KEY
		(PID)
	REFERENCES SYSMT_PROJECT
		(PID)
	ON DELETE NO ACTION
	ON UPDATE NO ACTION
	ENFORCED
	ENABLE QUERY OPTIMIZATION;
