--
-- SysMT db2 views
--

create view sysmt_mtmonthprj as 
select mt.mid as mid, 
       mt.status as status,
       p.prjname as prjname, 
       p.pid as pid,
       s.sid as sid, 
       month(mt.mtfrom) as month,
       year(mt.mtfrom) as year 
from sysmt_mt mt, 
     sysmt_system s, 
     sysmt_project p 
where  ( mt.sysid = s.sysid and s.pid = p.pid );


create view sysmt_mtmonthset as
select
 mt.mid as mid,
 mt.status as status,
 ss.setname as setname,
 ss.setid as setid,
 sys.sid as sid,
 month(mt.mtfrom) as month,
 year(mt.mtfrom) as year
from
 sysmt_mt mt,
 sysmt_system sys,
 sysmt_sys2set s2s,
 sysmt_systemset ss
where  mt.sysid = s2s.sysid and s2s.sysid = sys.sysid and s2s.setid = ss.setid;


create view sysmt_masterhostview as
select h.hostname as masterhost,
       v2h.vip as vip, 
       v2h.status as status 
from sysmt_vip2host v2h,
     sysmt_host h 
where v2h.hid = h.hid;

create view sysmt_mtbyday as
select sysmt_mt.mid as mid, 
       day(sysmt_mt.mtfrom) as day 
from sysmt_mt sysmt_mt;

create view sysmt_diskview as
select d.did as did,
       d.diskname as diskname,
       d.status as status, 
       d.scandate as scandate,
       d.disksize as disksize,
       d.diskusage as diskusage,
       d.diskvg as diskvg,
       h.hostname as hostname
from sysmt_disk d,
     sysmt_disk2host d2h,
     sysmt_host h
where  ( d.did = d2h.did and d2h.hid = h.hid );

create view sysmt_systemview as
select sys.sysid as sysid,
       sys.sid as sid,
       sys.saptype as saptype,
       sys.dbtype as dbtype,
       sys.dbversion as dbversion,
       sys.sapversion as sapversion,
       sys.scandbversion as scandbversion,
       sys.scansapversion as scansapversion,
       sys.arch as arch,
       sys.category as category,
       sys.platform as platform,
       sys.status as status,
       sys.vip as vip,
       sys.nfsvip as nfsvip,
       sys.vipip as vipip,
       sys.vipif as vipif,
       sys.sysnr as sysnr,
       sys.scs as scs,
       sys.javaport as javaport,
       sys.smdid as smdid,
       sys.zoneA as zoneA,
       sys.zoneB as zoneB,
       sys.partA as partA,
       sys.partB as partB,
       sys.partC as partC,
       sys.partD as partD,
       sys.restartzones as restartzones,
       sys.sharedfs as sharedfs,
       sys.parthalog as parthalog,
       sys.sdbtype as sdbtype,
       sys.dbvip as dbvip,
       sys.dbvA as dbvA,
       sys.dbvB as dbvB,
       sys.slaid as slaid,
       prj.prjname as prjname,
       prj.pid as pid,
       sys.sysdesc as description,
       sys.mtinfo as mtinfo,
       (select count(*) from sysmt_instance i where i.sysid = sys.sysid) as numinst
from sysmt_system sys,
     sysmt_project prj
where sys.pid = prj.pid;

create view sysmt_prj2uid as
select distinct p.prjname as prjname,
       u2g.uid as uid
from sysmt_project p,
     sysmt_prj2bgrp p2g,
     sysmt_usr2bgrp u2g
where ( p2g.pid = p.pid and u2g.bgid = p2g.bgid );

create view sysmt_sid2uid as
select distinct s.sid as sid,
       u2g.uid as uid
from sysmt_system s,
     sysmt_prj2bgrp p2g,
     sysmt_usr2bgrp u2g
where ( p2g.pid = s.pid and u2g.bgid = p2g.bgid );

create view sysmt_usrview as
select u.uid as uid,
       u.dbuser as dbuser,
       u.username as username,
       u.userright as userright,
       (select count(*) from sysmt_prj2uid sysmt_prj2uid where sysmt_prj2uid.uid = u.uid ) as numprj,
       (select count(*) from sysmt_sid2uid sysmt_sid2uid where sysmt_sid2uid.uid = u.uid ) as numsys
from sysmt_user u;


create view sysmt_mtview as
select mt.mid as mid,
       mt.lockby as lockby,
       prj.prjname as prjname,
       prj.pid as pid,
       sys.sysid as sysid,
       sys.sid as sid,
       sys.category as category,
       sys.saptype as saptype,
       sys.mtinfo as mtinfo,
       mt.shortdesc as shortdesc,
       mt.description as description,
       mt.mtfrom as mtfrom,
       mt.mtto as mtto,
       mt.downfrom as downfrom,
       mt.downto as downto,
       mt.status as status,
       mt.ticketnr as ticketnr,
       mt.mttype as mttype,
       mt.repcomment as repcomment,
       mt.repappcheck as repappcheck,
       mt.thrid as thrid, 
       (select tg.tgname as tgname from sysmt_threadgroup tg, sysmt_thread t where ( t.thrid = mt.thrid and t.tgid = tg.tgid ) ) as tgname,
       (select t.shortdesc from sysmt_thread t where t.thrid = mt.thrid ) as tshortdesc,
       (select count(*) from sysmt_mt mt2
       	       where ( ( (mt.mtfrom > mt2.mtfrom and mt.mtfrom < mt2.mtto)
	       	       	 or (mt.mtfrom < mt2.mtfrom and mt.mtto> mt2.mtfrom)
		       	 and mt2.mid != mt.mid )
		       and mt.sysid = mt2.sysid ) ) as conflicts
from sysmt_mt mt,
     sysmt_project prj,
     sysmt_system sys
where ( sys.pid = prj.pid and mt.sysid = sys.sysid );

drop view sysmt_threadview;
create view sysmt_threadview as
select
 t.thrid as thrid,
 tg.tgname as tgname,
 tg.tgid as tgid,
 t.created as created,
 t.shortdesc as shortdesc,
 t.description as description,
 t.lastedit as lastedit,
 t.lasteditby as lasteditby,
 t.remind as remind,
 bg.bgname as bgname,
 t.status as status,
u.uid as uid,
case when rs.readstat is null then 'UNREAD' else 'READ' end as readstat,
 rs.uid as rsuid,
 case when t.remind < current timestamp then 'EXPIRED' else 'INTIME' end as remstat
from
 sysmt_thread t inner join sysmt_threadgroup tg on t.tgid = tg.tgid
 inner join sysmt_bgroup bg on bg.bgid = t.bgid inner join sysmt_user u on 1 = 1 left outer join sysmt_threadstat rs on rs.uid = u.uid
 and rs.thrid = t.thrid;


create view sysmt_sysfwview as 
select sfw.fwrid as fwrid,
       sfw.sysid as sysid,
       (select sysmt_system.sid as sid from sysmt_system where sysmt_system.sysid = sfw.sysid) as sid, 
       (select sysmt_fwsg.sgname as sgname from sysmt_fwsg where sysmt_fwsg.sgid = sfw.sgidfrom) as sgfrom,
       (select sysmt_fwsg.sgname as sgname from sysmt_fwsg where sysmt_fwsg.sgid = sfw.sgidto) as sgto,
       (select sysmt_fwps.psname as psname from sysmt_fwps where sysmt_fwps.psid = sfw.psid) as portset,
       sfw.fwrdesc as fwrdesc 
from sysmt_sysfw sfw;

create view sysmt_threadview as 
select t.thrid as thrid, 
       tg.tgname as tgname,
       tg.tgid as tgid, 
       t.created as created,
       t.shortdesc as shortdesc,
       t.description as description,
       t.remind as remind,
       bg.bgname as bgname,
       t.status as status
       rs.status as readstat,
       rs.uid as uid,
       case when t.remind < current timestamp then 'EXPIRED' else 'INTIME' end as remstat
from sysmt_thread t, 
     sysmt_threadgroup tg, 
     sysmt_bgroup bg,
     sysmt_threadstat rs
where t.tgid = tg.tgid 
      and bg.bgid = t.bgid
      and rs.thrid = t.thrid;



