--
-- SysMT mysql procedure definitions
--

delimiter //

drop function if exists getSysId
//
CREATE FUNCTION getSysId (l_sid VARCHAR(20)) RETURNS INT DETERMINISTIC
BEGIN
	DECLARE l_sysid int;
	SELECT sysid INTO l_sysid FROM sysmt_system where sid = l_sid;
	RETURN l_sysid;
END;
//

drop function if exists getSetId
//
CREATE FUNCTION getSetId (l_setname VARCHAR(20)) RETURNS INT DETERMINISTIC
BEGIN
	DECLARE l_setid int;
	SELECT setid INTO l_setid FROM sysmt_systemset where setname = l_setname;
	RETURN l_setid;
END;
//

drop function if exists getPid
//
CREATE FUNCTION getPid (l_prjname VARCHAR(100)) RETURNS INT DETERMINISTIC
BEGIN
	DECLARE l_pid int;
	SELECT pid INTO l_pid FROM sysmt_project where prjname = l_prjname;
	RETURN l_pid;
END;
//

drop function if exists getPidForSid
//
CREATE FUNCTION getPidForSid (l_sid VARCHAR(20)) RETURNS INT DETERMINISTIC
BEGIN
	DECLARE l_pid int;
	SELECT pid INTO l_pid FROM sysmt_system where sid = l_sid;
	RETURN l_pid;
END;
//

drop function if exists getUid
//
CREATE FUNCTION getUid (l_dbuser VARCHAR(20)) RETURNS INT DETERMINISTIC
BEGIN
	DECLARE l_uid int;
	SELECT uid INTO l_uid FROM sysmt_user where dbuser = l_dbuser;
	RETURN l_uid;
END;
//

drop function if exists getBgid
//
CREATE FUNCTION getBgid (l_bgname VARCHAR(20)) RETURNS INT DETERMINISTIC
BEGIN
	DECLARE l_bgid int;
	SELECT bgid INTO l_bgid FROM sysmt_bgroup where bgname = l_bgname;
	RETURN l_bgid;
END;
//


drop function if exists getDiskId
//
create function getDiskId(l_diskname VARCHAR(20)) returns int deterministic
begin
   declare l_actId int;
   set l_actId = (select sysmt_disk.did as did 
             from sysmt_disk where sysmt_disk.diskname = l_diskname);
   return l_actId;
end;
//


drop function if exists newThreadGroup
//
create function newThreadGroup(l_tgname VARCHAR(30),
     l_tgdesc VARCHAR(1000)) returns int DETERMINISTIC
begin
   declare l_tgid int;

   SET l_tgid = nextId('TGID');
   insert into sysmt_threadgroup ( tgid, tgname, tgdesc )
    values (l_tgid, l_tgname, l_tgdesc);
   return l_tgid;
end;
//


drop function if exists newSystemSet
//
CREATE FUNCTION newSystemSet (l_setname VARCHAR(20),
       		 	      l_description VARCHAR(100)) RETURNS INT DETERMINISTIC
BEGIN

	DECLARE l_setid INT;
	SET l_setid = nextId('SETID');
	insert into sysmt_systemset ( setid, setname, description ) values ( l_setid, l_setname, l_description);	
	RETURN l_setid;
END;
//

drop function if exists newGroup
//
CREATE FUNCTION newGroup (l_bgname VARCHAR(20),
       		 	  l_bgdesc VARCHAR(100)) RETURNS INT DETERMINISTIC
BEGIN

	DECLARE l_bgid INT;
	SET l_bgid = nextId('BGID');
	insert into sysmt_bgroup values ( l_bgid, l_bgname, l_bgdesc);	
	RETURN l_bgid;
END;
//


drop function if exists sysWfFire
//
create function sysWfFire(l_sysid int,
     l_bgname VARCHAR(20),
     l_dbuser VARCHAR(20),
     l_comment VARCHAR(500)) RETURNS INT DETERMINISTIC
begin
   declare l_seqnr int;
   set l_seqnr = (select sysmt_sysworkflow.seqnr as seqnr
       	       	  from sysmt_sysworkflow
		  where ( sysid = l_sysid and bgid = (select sysmt_bgroup.bgid as bgid 
                                                      from sysmt_bgroup where bgname = l_bgname)));

   update sysmt_sysworkflow set status='Done', released=now(), comment=l_comment, dbuser=l_dbuser 
   where ( sysid = l_sysid and seqnr = l_seqnr );
   update sysmt_sysworkflow set status='Requested', assigned=sysdate where ( sysid = l_sysid and seqnr = l_seqnr + 1 );
   return l_seqnr + 1;
end;
//



drop function if exists impSys
//
create function impSys(l_sid VARCHAR(10),
     l_sysdesc VARCHAR(1000)) RETURNS INT DETERMINISTIC
begin
   declare l_sysid int;
   set l_sysid = getSysId(l_sid);
   if l_sysid = 0
   then
      set l_sysid = newSystem(l_sid,'Unassigned','NA','NA','NA');
      update sysmt_system set sysdesc=l_sysdesc where sysid = l_sysid;
   else
      update sysmt_system set status='Xandria' where sid = l_sid;
   end if;
   return l_sysid;
end;
//


drop function if exists newSystem
//
CREATE FUNCTION newSystem (l_sid VARCHAR(30),
       		 	   l_prjname VARCHAR(20),
			   l_category VARCHAR(10),
			   l_platform VARCHAR(10),
			   l_status VARCHAR(10)) RETURNS INT DETERMINISTIC
BEGIN
	DECLARE l_pid INT;
	DECLARE l_sysid INT;
	
	SET l_sysid = nextId('SYSID');
	SET l_pid = getPid(l_prjname);

	insert into sysmt_system ( sysid, 
	       	    	       sid,
			       category,
			       platform,
			       status,
			       pid ) 
			       values 
			       (l_sysid,
			       l_sid,
			       l_category,
			       l_platform,
			       l_status,
			       l_pid); 
	RETURN l_sysid;	
END;
//


drop function if exists newThread
//
create function newThread(l_tgname VARCHAR(30),
     l_shortdesc VARCHAR(100),
     l_bgname VARCHAR(20),
     l_remind datetime) returns int deterministic
begin
   declare l_tgid int;
   declare l_thrid int;
   set l_tgid = (select sysmt_threadgroup.tgid as tgid
                 from sysmt_threadgroup
		 where sysmt_threadgroup.tgname = l_tgname);
   set l_thrid = nextId('THRID');
   insert into sysmt_thread ( thrid, tgid, shortdesc, created, remind, bgid, status )
   values (l_thrid, l_tgid, l_shortdesc, now(), l_remind, 
          (select bgid as bgid from sysmt_bgroup where bgname = l_bgname), 'OPEN');
   return l_thrid;

end;
//


drop function if exists impDisk
//
create function impDisk(l_diskname VARCHAR(100),
     l_scandate datetime,
     l_disksize long,
     l_diskusage VARCHAR(100),
     l_diskvg VARCHAR(100),
     l_hostname VARCHAR(30)) returns int deterministic
begin
   declare l_did int;
   declare l_hid int;
   declare l_d2h int;
   set l_did = getDiskId(l_diskname);
   set l_hid = getHostId(l_hostname);
   if l_did = null
   then
      set l_did = nextId('DID');
      insert into sysmt_disk ( did, scandate, status, diskname, disksize, diskusage, diskvg )
       values (l_did, l_scandate, 'new', l_diskname, l_disksize, l_diskusage, l_diskvg);
      if l_hid != null
      then
            insert into sysmt_disk2host ( did, hid )
             values (l_did, l_hid);
      end if;
   else
      update sysmt_disk set scandate=l_scandate, status='valid', diskusage=l_diskusage, diskvg=l_diskvg
      where did = l_did;
      set l_d2h = (select count(*) from  sysmt_disk2host
                   where ( sysmt_disk2host.hid = l_hid and sysmt_disk2host.did = l_did ));
      if l_d2h = 0 and l_hid != null
      then
         insert into sysmt_disk2host ( did, hid )
         values (l_did, l_hid);
      end if;
   end if;
   return l_did;
end;
//



drop function if exists resetApproval
//

create function resetApproval(l_mid int) returns int deterministic
begin
   declare l_sid VARCHAR(20);
   declare l_pid int;
   declare l_status VARCHAR(20);
   declare l_bgid int;

   DECLARE done INT DEFAULT 0; 

   declare aCur cursor for select bgid from sysmt_prj2approval
                            where pid = l_pid;

   declare vCur cursor for select bgid from sysmt_prj2verification
                            where pid = l_pid;


   DECLARE CONTINUE HANDLER FOR NOT FOUND SET done = 1; 

   delete from sysmt_mtapproval where mid = l_mid;
   delete from sysmt_mtverification where mid = l_mid;

   set l_status = (select status as status
       		   from sysmt_mtview
                   where mid = l_mid );
   if l_status != 'Claimed'
   then

      set l_sid = (select sid as sid
                   from sysmt_mtview
                   where mid = l_mid);
      set l_pid = getPidForSid(l_sid);

      open aCur;

      REPEAT

            fetch aCur into l_bgid;
            if NOT done
	    then
               insert into sysmt_mtapproval ( mid, bgid, status )  values (l_mid, l_bgid, 'Requested');
	    end if;
      
      UNTIL done END REPEAT;

      close aCur;

      open vCur;

      REPEAT

            fetch vCur into l_bgid;
            if NOT done
	    then
               insert into sysmt_mtverification ( mid, bgid, status )  values (l_mid, l_bgid, 'Requested');
	    end if;
      
      UNTIL done END REPEAT;

      close vCur;

      update sysmt_mt set status='Requested' where mid = l_mid;
   end if;

   return 0;
end;
//

drop function if exists deleteProject
//
CREATE FUNCTION deleteProject (l_pid INT) RETURNS INT DETERMINISTIC
BEGIN

	DECLARE l_sysid INT;
	DECLARE ret INT;

	DECLARE done INT DEFAULT 0; 

	DECLARE cur1 CURSOR FOR SELECT sysid from sysmt_system where pid = l_pid;

        DECLARE CONTINUE HANDLER FOR NOT FOUND SET done = 1; 

	OPEN cur1;

	REPEAT 
	       
	       FETCH cur1 INTO l_sysid;

	       if NOT done
	       then
	          SET ret = deleteSystem(l_sysid);
               end if;
 	       
  	UNTIL done END REPEAT;

	close cur1;

	delete from sysmt_prj2approval where pid = l_pid;
        delete from sysmt_prj2bgrp where pid = l_pid;
        delete from sysmt_project where pid = l_pid;

	RETURN 0;
END;
//


drop function if exists sysWfReset
//

create function sysWfReset(l_sysid int) returns int deterministic
begin
   declare l_pid int;
   declare l_seqnr int;
   declare l_wfgid int;
   declare l_wfstatus VARCHAR(10);
   declare l_startdate datetime;

   DECLARE done INT DEFAULT 0; 

   DECLARE cur1 CURSOR FOR 
      select bgid, seqnr
      from sysmt_prj2workflow where pid = l_pid
      order by seqnr;


   DECLARE CONTINUE HANDLER FOR NOT FOUND SET done = 1; 


   delete from sysmt_sysworkflow where sysid = l_sysid;


   set l_pid = (select pid from sysmt_system
                where sysid = l_sysid);


   OPEN cur1;

   set l_wfstatus = 'Requested';
   set l_startdate = now();

   REPEAT 
	       
	FETCH cur1 INTO l_wfgid, l_seqnr;

        if not done
        then
           insert into sysmt_sysworkflow ( sysid, bgid, seqnr, assigned, status )
               values (l_sysid, l_wfgid, l_seqnr, l_startdate, l_wfstatus);

           set l_wfstatus = 'Waiting';
           set l_startdate = null;
        end if;
    
   UNTIL done END REPEAT;

   CLOSE cur1;

   return 0;
end;
//


drop function if exists nextId
//
CREATE FUNCTION nextId (l_id VARCHAR(30)) RETURNS INT DETERMINISTIC
BEGIN
	DECLARE l_val INT;

	UPDATE sysmt_id SET idval = LAST_INSERT_ID(idval + 1) where id = l_id;
	
	SELECT LAST_INSERT_ID() INTO l_val;

	RETURN l_val;
	
END;
//


drop function if exists impHost
//
create function impHost(l_hostname VARCHAR(30),
     l_scandate datetime,
     l_hostinfo VARCHAR(100),
     l_osinfo VARCHAR(100),
     l_cpuinfo VARCHAR(100),
     l_meminfo VARCHAR(100)) returns int deterministic
begin
   declare l_hid int;
   set l_hid = getHostId(l_hostname);
   if l_hid = null
   then
      set l_hid = nextId('HID');
      insert into sysmt_host ( hid, scandate, status, hostname, hostinfo, osinfo, cpuinfo, meminfo )
       values (l_hid, l_scandate, 'valid', l_hostname, l_hostinfo, l_osinfo, l_cpuinfo, l_meminfo);
   else
      update sysmt_host set scandate=l_scandate, status='valid', hostinfo=l_hostinfo, osinfo=l_osinfo, cpuinfo=l_cpuinfo, meminfo=l_meminfo where hid = l_hid;
   end if;
   return l_hid;
end;
//

drop function if exists newFWPS
//

create function newFWPS(l_psname varchar(30), l_psdesc varchar(500)) returns int deterministic
begin
   declare l_psid int;
   set l_psid = nextId('PSID');
   insert into sysmt_fwps ( psid, psname, psdesc )
    values (l_psid, l_psname, l_psdesc);
   return l_psid;
end;
//

drop function if exists newFileSysTmpl
//

create function newFileSysTmpl(l_fstmplname VARCHAR(50),
     l_fstmpltype VARCHAR(10),
     l_fstmplrule VARCHAR(200),
     l_fstmpldesc VARCHAR(500)) returns int deterministic
begin
   declare l_tmplid int;
   set l_tmplid = nextId('TMPLID');
   insert into sysmt_filesystmpl ( tmplid, fstmplname, fstmpltype, fstmplrule, fstmpldesc )
    values (l_tmplid, l_fstmplname, l_fstmpltype, l_fstmplrule, l_fstmpldesc);
   return l_tmplid;
end;
//

drop function if exists newAddon
//
create function newAddon(l_sysid int,
     l_aotype VARCHAR(20),
     l_aoname VARCHAR(20)) returns int deterministic
begin
   declare l_aoid int;
   set l_aoid = nextId('AOID');
   insert into sysmt_addon ( aoid, aotype, aoname, sysid )
    values (l_aoid, l_aotype, l_aoname, l_sysid);
   return l_aoid;
end;
//

drop function if exists newNFS
//

create function newNFS(l_sysid int,
     l_nfspath VARCHAR(100),
     l_nfsnode VARCHAR(100),
     l_nfsmount VARCHAR(100)) returns int deterministic
begin
   declare l_nfsid int;
   set l_nfsid = nextId('NFSID');
   insert into sysmt_nfs ( nfsid, nfspath, nfsnode, nfsmount, sysid )
    values (l_nfsid, l_nfspath, l_nfsnode, l_nfsmount, l_sysid);
   return l_nfsid;
end;
//

drop function if exists newFWSG
//
create function newFWSG(l_sgname VARCHAR(30),
     l_sgdesc VARCHAR(500)) returns int deterministic
begin
   declare l_sgid int;
   set l_sgid = nextId('SGID');
   insert into sysmt_fwsg ( sgid, sgname, sgdesc )
    values (l_sgid, l_sgname, l_sgdesc);
   return l_sgid;
end;
//


drop function if exists newSysFW
//
create function newSysFW(l_sgfrom VARCHAR(30),
     l_sgto VARCHAR(30),
     l_portset VARCHAR(30),
     l_fwrdesc VARCHAR(500),
     l_sid VARCHAR(20)) returns int deterministic
begin
   declare l_fwrid int;
   set l_fwrid = nextId('FWRID');
   insert into sysmt_sysfw ( fwrid, sgidfrom, sgidto, psid, fwrdesc, sysid )
    values (l_fwrid, 
           (select sgid from sysmt_fwsg where sgname = l_sgfrom),
           (select sgid from sysmt_fwsg where sgname = l_sgto),
	   (select psid from sysmt_fwps where psname = l_portset),
	   l_fwrdesc,
	   (select sysid from sysmt_system where sid = l_sid));
   return l_fwrid;
end;
//

drop function if exists newDocument
//
create function newDocument(l_doctype VARCHAR(10),
     l_docname VARCHAR(200)) returns int deterministic
begin
   declare l_docid int;
   set  l_docid = nextId('DOCID');
   insert into sysmt_document ( docid, doctype, docname )
    values (l_docid, l_doctype, l_docname);
   return l_docid;
end;
//

drop function if exists newInstance
//
CREATE FUNCTION newInstance (l_sysid INT,
       		 	   l_instnr VARCHAR(10),
			   l_instvip VARCHAR(20),
			   l_instsmd VARCHAR(10),
			   l_instsaptype VARCHAR(10),
                           l_instjavaport VARCHAR(10),
                           l_instzone VARCHAR(50),
                           l_instarch VARCHAR(10),
                           l_instdisp VARCHAR(10)) RETURNS INT DETERMINISTIC
BEGIN
	DECLARE l_instid INT;
	
	SET l_instid = nextId('INSTID');
	
   	insert into sysmt_instance ( instid, instnr, instvip, instsmd, instsaptype, instjavaport, 
                                     instzone, instarch, instdisp, sysid )
			       values 
			           (l_instid, l_instnr, l_instvip, l_instsmd, l_instsaptype, l_instjavaport,
			            l_instzone, l_instarch, l_instdisp, l_sysid); 
	RETURN l_instid;	
END;
//

drop function if exists newUser
//
CREATE FUNCTION newUser (l_dbuser VARCHAR(20),
       		 	  l_username VARCHAR(20),
			  l_userdesc VARCHAR(50),
			  l_userright VARCHAR(10)) RETURNS INT DETERMINISTIC
BEGIN

	DECLARE l_uid INT;
	SET l_uid = nextId('UID');
	insert into sysmt_user ( uid, dbuser, username, userdesc, userright ) values ( l_uid, l_dbuser, l_username, l_userdesc, l_userright );	
	RETURN l_uid;
END;
//

drop function if exists newProject
//
CREATE FUNCTION newProject (l_prjname VARCHAR(100),
       		 	  l_prjdesc VARCHAR(100)) RETURNS INT DETERMINISTIC
BEGIN
	DECLARE l_pid INT;
	SET l_pid = nextId('PID');
	insert into sysmt_project values ( l_pid, l_prjname, l_prjdesc);	
	RETURN l_pid;

END;
//

drop function if exists newMt
//
CREATE FUNCTION newMt (l_sid VARCHAR(20),
		l_shortdesc VARCHAR(50),
		l_description VARCHAR(500),
		l_mtfrom DATETIME,
		l_mtto DATETIME,
		l_downfrom DATETIME,
		l_downto DATETIME,
		l_status VARCHAR(10),	
		l_ticketnr BIGINT,
		l_mttype VARCHAR(10),
		l_thrid int) RETURNS INT DETERMINISTIC
BEGIN
	DECLARE l_mid INT;
	DECLARE l_sysid INT;
	DECLARE l_pid INT;
	
	SET l_mid = nextId('MID');
	SET l_sysid = getSysId(l_sid);
	SET l_pid = getPidForSid(l_sid);

	insert into sysmt_mt ( mid,
	       	    	   sysid,
			   shortdesc,
			   description,
			   mtfrom,
			   mtto,
			   downfrom,
			   downto,
			   status,
			   ticketnr,
			   mttype,
			   thrid) 
			   values ( l_mid,
	       	    	   l_sysid,
			   l_shortdesc,
			   l_description,
			   l_mtfrom,
			   l_mtto,
			   l_downfrom,
			   l_downto,
			   l_status,
			   l_ticketnr,
			   l_mttype,
			   l_thrid);
	RETURN l_mid;

	insert into sysmt_mtapproval select l_mid, bgid, 'Requested' from sysmt_prj2approval where pid = l_pid;	

END;
//



drop function if exists deleteSystem
//
CREATE FUNCTION deleteSystem (l_sysid INT) RETURNS INT DETERMINISTIC
BEGIN

	delete from sysmt_mtapproval where mid in ( select mid from sysmt_mt where sysid = l_sysid);
	delete from sysmt_mtlog where mid in ( select mid from sysmt_mt where sysid = l_sysid);
	delete from sysmt_mt where mid in ( select mid from sysmt_mt where sysid = l_sysid);

	delete from sysmt_sys2set where sysid = l_sysid;
   	delete from sysmt_system where sysid = l_sysid;
        delete from sysmt_instance where sysid = l_sysid;

	RETURN 0;	
END;
//

drop function if exists newUserSearch
//
CREATE FUNCTION newUserSearch (l_usname VARCHAR(20), l_usspec VARCHAR(20), l_dbuser VARCHAR(20)) RETURNS INT DETERMINISTIC
BEGIN

	DECLARE l_usid INT;
	DECLARE l_uid INT;
	
	SET l_usid = nextId('USID');
	SET l_uid = getUid(l_dbuser);

	insert into sysmt_usersearch ( usid, usname, usspec, uid ) values (l_usid, l_usname, l_usspec, l_uid);
	RETURN l_usid;
END;
//

drop function if exists newGroupSearch
//
CREATE FUNCTION newGroupSearch (l_gsname VARCHAR(20), l_gsspec VARCHAR(20)) RETURNS INT DETERMINISTIC
BEGIN

	DECLARE l_gsid INT;
	
	SET l_gsid = nextId('GSID');
	insert into sysmt_groupsearch ( gsid, gsname, gsspec ) values (l_gsid, l_gsname, l_gsspec);

	RETURN l_gsid;
END;
//

drop function if exists impFS
//
create function impFS(l_sid VARCHAR(20),
     l_fspath VARCHAR(100),
     l_fssize long)  RETURNS INT DETERMINISTIC
begin
   declare l_sysid int;
   set l_sysid = getSysId(l_sid);
   if l_sysid != null
   then
      update sysmt_filesys set fssize=l_fssize where ( sysid = l_sysid and fspath = l_fspath );
   end if;
   return 0;
end;
//

drop function if exists impVip2Host
//
create function impVip2Host(l_vip VARCHAR(30),
     l_hostname VARCHAR(30),
     l_status VARCHAR(15))   RETURNS INT DETERMINISTIC
begin
   declare l_hid int;
   set l_hid = getHostId(l_hostname);
   if l_hid != null
   then
      delete from sysmt_vip2host where ( vip = l_vip and hid = l_hid );
      insert into sysmt_vip2host ( vip, hid, status )
       values ( l_vip, l_hid, l_status);
   end if;

   return 0;
end;
//

drop function if exists newResource
//

create function newResource(l_resname varchar(100),
     l_resdesc varchar(1000)) returns int deterministic
begin
   declare l_resid int;
   set l_resid = nextId('RESID');
   insert into sysmt_resource ( resid, resname, resdesc )
    values (l_resid, l_resname, l_resdesc);
   return l_resid;
end;
//

drop function if exists newSkill
//

create function newSkill(l_skname varchar(100),
     l_skdesc varchar(1000)) returns int deterministic
begin
   declare l_skid int;
   set l_skid = nextId('SKID');
   insert into sysmt_skill ( skid, skname, skdesc )
    values (l_skid, l_skname, l_skdesc);
   return l_skid;
end;
//


drop function if exists newResourcePlanEntry
//
create function newResourcePlanEntry(l_activity varchar(200),
     l_resfrom datetime,
     l_resto datetime,
     l_resid int,
     l_mid int) returns int deterministic
begin
   declare l_rpeid int;
   set l_rpeid = nextId('RPEID');
   insert into sysmt_resourceplan ( rpeid, activity, resfrom, resto, resid, mid )
    values (l_rpeid, l_activity, l_resfrom, l_resto, l_resid, l_mid);
   return l_rpeid;
end;
//

drop function if exists newResourceEntry;
//
create function newResourceEntry(l_activity varchar(200),
     l_resfrom datetime,
     l_resto datetime,
     l_resid int,
     l_mid int) returns int deterministic
begin
   declare l_rpeid int;
   set l_rpeid = nextId('RPEID');
   insert into sysmt_resourceplan ( rpeid, activity, resfrom, resto, resid, mid )
    values (l_rpeid, l_activity, l_resfrom, l_resto, l_resid, l_mid);
   return l_rpeid;
end;
//


