--
-- SysMt mysql definitions
--


-- sysmt parameters
drop table if exists sysmt_sysparam;
create table sysmt_sysparam(pname varchar(20) not null,
       pval varchar(200),
       primary key(pname)) ENGINE=InnoDB;

-- system addon
drop table if exists sysmt_addon;
create table sysmt_addon(aoid int not null, 
       aotype VARCHAR(20), 
       aoname VARCHAR(20),
       aohome VARCHAR(100),
       aouser VARCHAR(100),
       aogroup VARCHAR(100),
       aoexepath VARCHAR(100),
       aologpath VARCHAR(100), 
       sysid int,
       PRIMARY KEY(aoid)) ENGINE=InnoDB;

-- business group
drop table if exists sysmt_bgroup;
create table sysmt_bgroup ( bgid INT,
       	     	    bgname VARCHAR(20),
		    bgdesc VARCHAR(10000),
		    PRIMARY KEY(bgid)) ENGINE=InnoDB;

create index sysmt_bgroup_i1 on sysmt_bgroup(bgname);

-- business group right
drop table if exists sysmt_bgright;
create table sysmt_bgright(bgid int not null,
       bgright VARCHAR(20) not null);

-- custom search condition
drop table if exists sysmt_custcond;
create table sysmt_custcond(ccid int not null,
       ccname VARCHAR(20),
       ccspec VARCHAR(100),
       uid int,
       cctype VARCHAR(20),
       PRIMARY KEY(ccid)) ENGINE=InnoDB;

-- displacement system
drop table if exists sysmt_dispsys;
create table sysmt_dispsys(sysid int not null, 
       dispsysid int not null,
       PRIMARY KEY(sysid,dispsysid)) ENGINE=InnoDB;

-- disk
drop table if exists sysmt_disk;
create table sysmt_disk(did int not null, 
       scandate datetime,
       status VARCHAR(20),
       diskname VARCHAR(100),
       disksize long,
       diskusage VARCHAR(100),
       diskvg VARCHAR(100),
       slaid int,
       PRIMARY KEY(did)) ENGINE=InnoDB;


-- disk 2 host
drop table if exists sysmt_disk2host;
create table sysmt_disk2host(did int not null, 
       hid int not null,
       PRIMARY KEY(did, hid)) ENGINE=InnoDB;

-- document
drop table if exists sysmt_document;
create table sysmt_document(docid int not null,
       doctype VARCHAR(10),
       docname VARCHAR(200),
       PRIMARY KEY(docid)) ENGINE=InnoDB;

-- document 2 thread
drop table if exists sysmt_doc2thread;
create table sysmt_doc2thread(docid int, 
       thrid int,
       PRIMARY KEY(docid, thrid)) ENGINE=InnoDB;

-- filesystem
drop table if exists sysmt_filesys;
create table sysmt_filesys(fstype VARCHAR(50),
       fspath VARCHAR(100) not null,
       fsvg VARCHAR(100) not null,
       fssize long not null,
       sysid int not null,
       fsopt VARCHAR(100),
       fslv VARCHAR(100));

-- file system template
drop table if exists sysmt_filesystmpl;
create table sysmt_filesystmpl(tmplid int not null, 
       fstmplname VARCHAR(50),
       fstmpldesc VARCHAR(500),
       fstmplrule VARCHAR(200),
       fstmpltype VARCHAR(10),
       PRIMARY KEY(tmplid)) ENGINE=InnoDB;


-- file system template entry
drop table if exists sysmt_filesystmplentry;
create table sysmt_filesystmplentry(tmplid int not null, 
       fstype VARCHAR(50), 
       fspath VARCHAR(100) not null, 
       fsvg VARCHAR(100) not null, 
       fssizesmall long not null, 
       fsopt VARCHAR(100), 
       fsid int, 
       fssizebig long, 
       fslv VARCHAR(100));

-- firewall port set
drop table if exists sysmt_fwps;
create table sysmt_fwps(psid int not null,
       psname VARCHAR(30),
       psdesc VARCHAR(500),
       PRIMARY KEY(psid)) ENGINE=InnoDB;

create unique index sysmt_fwps_i1 on sysmt_fwps(psname);

-- firewall port set entry
drop table if exists sysmt_fwpsentry;
create table sysmt_fwpsentry(psid int, 
       portval VARCHAR(30),
       porttype VARCHAR(10), 
       portdesc VARCHAR(500),
       PRIMARY KEY(psid, portval)) ENGINE=InnoDB;

-- firewall server group
drop table if exists sysmt_fwsg;
create table sysmt_fwsg(sgid int not null, 
       sgname VARCHAR(30),
       sgdesc VARCHAR(500),
       PRIMARY KEY(sgid)) ENGINE=InnoDB;

create unique index sysmt_fwsg_i1 on sysmt_fwsg(sgname);

-- firewall server group entry
drop table if exists sysmt_fwsgentry;
create table sysmt_fwsgentry(sgid int,
       ipval VARCHAR(30),
       ipdesc VARCHAR(500),
       PRIMARY KEY(sgid, ipval)) ENGINE=InnoDB;

-- group search
drop table if exists sysmt_groupsearch;
create table sysmt_groupsearch(gsid int not null, 
       gsname VARCHAR(20), 
       gsspec VARCHAR(100),
       PRIMARY KEY(gsid)) ENGINE=InnoDB;

-- group search 2 group
drop table if exists sysmt_gs2bgrp;
create table sysmt_gs2bgrp(gsid int not null, 
       bgid int not null,
       PRIMARY KEY(gsid, bgid)) ENGINE=InnoDB;

-- host
drop table if exists sysmt_host;
create table sysmt_host(hid int not null, 
       scandate datetime,
       status VARCHAR(20),
       hostname VARCHAR(30),
       hostinfo VARCHAR(100),
       osinfo VARCHAR(30),
       cpuinfo VARCHAR(30),
       meminfo VARCHAR(30),
       PRIMARY KEY(hid)) ENGINE=InnoDB;


-- identificator
drop table if exists sysmt_id;
create table sysmt_id(id VARCHAR(10) not null, 
       idval int,
       PRIMARY KEY(id)) ENGINE=InnoDB;

-- system instance
drop table if exists sysmt_instance;
create table sysmt_instance(instid int not null,
       instnr VARCHAR(10) not null,
       instvip VARCHAR(50) not null,
       instsmd VARCHAR(10) not null,
       instzone VARCHAR(50),
       instarch VARCHAR(10),
       sysid int not null,
       created datetime not null,
       instsaptype VARCHAR(10),
       instjavaport VARCHAR(10),
       instdisp VARCHAR(10),
       PRIMARY KEY(instid)) ENGINE=InnoDB;


-- maintain
drop table if exists sysmt_mt;
create table sysmt_mt(mid int not null,
       shortdesc VARCHAR(100),
       description VARCHAR(500),
       mtfrom datetime,
       mtto datetime,
       status VARCHAR(10),
       ticketnr bigint(10),
       sysid int,
       lockby VARCHAR(20),
       mttype VARCHAR(10),
       downfrom datetime,
       downto datetime,
       repcomment VARCHAR(50),
       repappcheck VARCHAR(10),
       thrid int,
       PRIMARY KEY(mid)) ENGINE=InnoDB;

create index sysmt_mt_i1 on sysmt_mt(status);
create index sysmt_mt_i2 on sysmt_mt(mtfrom);
create index sysmt_mt_i3 on sysmt_mt(sysid);
create index sysmt_mt_i4 on sysmt_mt(mtto);



-- maintain approval
drop table if exists sysmt_mtapproval;
create table sysmt_mtapproval(mid int not null,
       bgid int not null,
       status VARCHAR(10),
       PRIMARY KEY(mid,bgid)) ENGINE=InnoDB;

-- maintain log
drop table if exists sysmt_mtlog;
create table sysmt_mtlog(logts datetime, 
       mid int,
       logentry VARCHAR(100));

-- maintain verification
drop table if exists sysmt_mtverification;
create table sysmt_mtverification(mid int not null,
       bgid int not null,
       status VARCHAR(10),
       PRIMARY KEY(mid, bgid)) ENGINE=InnoDB;

-- project
drop table if exists sysmt_project;
create table sysmt_project(pid int not null,
       prjname VARCHAR(100),
       prjdesc VARCHAR(1000),
       prjmail VARCHAR(100),
       PRIMARY KEY(pid)) ENGINE=InnoDB;

create unique index sysmt_project_i1 on sysmt_project(prjname);


-- project 2 approval
drop table if exists sysmt_prj2approval;
create table sysmt_prj2approval(pid int not null, 
       bgid int not null,
       PRIMARY KEY(pid, bgid)) ENGINE=InnoDB;


-- project 2 group
drop table if exists sysmt_prj2bgrp;
create table sysmt_prj2bgrp(pid int not null,
       bgid int not null,
       PRIMARY KEY(pid, bgid)) ENGINE=InnoDB;

create index sysmt_prj2bgrp_i1 on sysmt_prj2bgrp(bgid);
create index sysmt_prj2bgrp_i2 on sysmt_prj2bgrp(pid);


-- project 2 notification
drop table if exists sysmt_prj2notification;
create table sysmt_prj2notification(pid int not null,
       bgid int not null,
       PRIMARY KEY(pid, bgid)) ENGINE=InnoDB;


-- project 2 workflow
drop table if exists sysmt_prj2workflow;
create table sysmt_prj2workflow(pid int not null,
       bgid int not null,
       seqnr int,
       PRIMARY KEY(pid, bgid)) ENGINE=InnoDB;

-- project 2 verification
drop table if exists sysmt_prj2verification;
create table sysmt_prj2verification(pid int not null,
       bgid int not null,
       PRIMARY KEY(pid, bgid)) ENGINE=InnoDB;

-- SLA
drop table if exists sysmt_sla;
create table sysmt_sla(slaid int not null,
       slanr VARCHAR(30),
       shortdesc VARCHAR(100),
       PRIMARY KEY(slaid)) ENGINE=InnoDB;


-- SLA 2 project
drop table if exists sysmt_sla2prj;
create table sysmt_sla2prj(slaid int not null,
       pid int not null,
       PRIMARY KEY(slaid, pid)) ENGINE=InnoDB;

-- system firewall entry
drop table if exists sysmt_sysfw;
create table sysmt_sysfw(fwrid int not null,
       sgidfrom int,
       sgidto int,
       psid int,
       sysid int,
       fwrdesc VARCHAR(500),
       PRIMARY KEY(fwrid)) ENGINE=InnoDB;


-- system
drop table if exists sysmt_system;
create table sysmt_system(sysid int not null, 
       sid VARCHAR(20), 
       category VARCHAR(10),
       sysdesc VARCHAR(1000),
       pid int,
       systype VARCHAR(10),
       mtinfo VARCHAR(300),
       platform VARCHAR(10),
       status VARCHAR(10),
       saptype VARCHAR(10),
       vip VARCHAR(20),
       sysnr VARCHAR(10),
       scs VARCHAR(10),
       javaport VARCHAR(10),
       smdid VARCHAR(10),
       zoneA VARCHAR(20),
       zoneB VARCHAR(20),
       partA VARCHAR(20),
       partB VARCHAR(20),
       partC VARCHAR(20),
       partD VARCHAR(20),
       restartzones VARCHAR(100),
       created datetime,
       dbtype VARCHAR(10), 
       arch VARCHAR(10),
       nfsvip VARCHAR(30),
       vipip VARCHAR(20),
       vipif VARCHAR(20),
       dbversion VARCHAR(20),
       sharedfs VARCHAR(300),
       parthalog VARCHAR(300),
       slaid int,
       sapversion VARCHAR(20),
       sdbtype VARCHAR(10),
       dbvip VARCHAR(20),
       dbvA VARCHAR(20),
       dbvB VARCHAR(20),
       PRIMARY KEY(sysid)) ENGINE=InnoDB;

create index sysmt_system_i1 on sysmt_system(pid);

-- system 2 set
drop table if exists sysmt_sys2set;
create table sysmt_sys2set(sysid int not null,
       setid int not null,
       PRIMARY KEY(sysid,setid)) ENGINE=InnoDB;


-- system set
drop table if exists sysmt_systemset;
create table sysmt_systemset(setid int not null, 
       setname VARCHAR(20),
       description VARCHAR(1000),
       PRIMARY KEY(setid)) ENGINE=InnoDB;


-- system set 2 group
drop table if exists sysmt_set2bgrp;
create table sysmt_set2bgrp(setid int not null,
       bgid int not null,
       PRIMARY KEY(setid, bgid)) ENGINE=InnoDB;

-- system workflow
drop table if exists sysmt_sysworkflow;
create table sysmt_sysworkflow(sysid int not null,
       bgid int not null,
       seqnr int,
       assigned datetime,
       released datetime,
       dbuser VARCHAR(20),
       comment VARCHAR(500),
       status VARCHAR(10),
       PRIMARY KEY(sysid,bgid,seqnr)) ENGINE=InnoDB;

-- system nfs
drop table if exists sysmt_nfs;
create table sysmt_nfs(nfsid int not null,
       nfspath VARCHAR(100),
       nfsnode VARCHAR(100),
       nfsmount VARCHAR(100),
       sysid int,
       PRIMARY KEY(nfsid)) ENGINE=InnoDB;

-- thread group 2 business group
drop table if exists sysmt_tg2bgrp;
create table sysmt_tg2bgrp(tgid int not null,
       bgid int not null,
       PRIMARY KEY(tgid, bgid)) ENGINE=InnoDB;

-- thread
drop table if exists sysmt_thread;
create table sysmt_thread(thrid int not null,
       shortdesc VARCHAR(100),
       description VARCHAR(1000),
       created datetime,
       remind datetime,
       lastedit datetime,
       lasteditby VARCHAR(20),
       status VARCHAR(15),
       tgid int,
       bgid int,
       PRIMARY KEY(thrid)) ENGINE=InnoDB;

create index sysmt_thread_i1 on sysmt_thread(tgid);

-- thread stat
drop table if exists sysmt_threadstat;
create table sysmt_threadstat(thrid int not null,
       uid int not null,
       status VARCHAR(15),
       PRIMARY KEY(thrid, uid)) ENGINE=InnoDB;

-- thread 2 group
drop table if exists sysmt_thr2bgrp;
create table sysmt_thr2bgrp(thrid int not null,
       bgid int not null,
       PRIMARY KEY(thrid, bgid)) ENGINE=InnoDB;

-- thread group
drop table if exists sysmt_threadgroup;
create table sysmt_threadgroup(tgid int not null,
       tgname VARCHAR(30),
       tgdesc VARCHAR(500),
       PRIMARY KEY(tgid)) ENGINE=InnoDB;

-- thread log
drop table if exists sysmt_threadlog;
create table sysmt_threadlog(logts datetime,
       logentry VARCHAR(1000),
       thrid int,
       dbuser VARCHAR(20));

-- user
drop table if exists sysmt_user;
create table sysmt_user(uid int not null,
       dbuser VARCHAR(20),
       username VARCHAR(20),
       userdesc VARCHAR(1000),
       userright VARCHAR(10),
       usermail VARCHAR(100),
       PRIMARY KEY(uid)) ENGINE=InnoDB;

create unique index sysmt_user_i1 on sysmt_user(dbuser);



-- user 2 group
drop table if exists sysmt_usr2bgrp;
create table sysmt_usr2bgrp(uid int not null,
       bgid int not null,
       PRIMARY KEY(uid,bgid)) ENGINE=InnoDB;

create index sysmt_usr2bgrp_i1 on sysmt_usr2bgrp(bgid);

-- user search
drop table if exists sysmt_usersearch;
create table sysmt_usersearch(usid int not null,
       usname VARCHAR(20),
       usspec VARCHAR(1000),
       uid int,
       PRIMARY KEY(usid)) ENGINE=InnoDB;

-- vip 2 host
drop table if exists sysmt_vip2host;
create table sysmt_vip2host(vip VARCHAR(30) not null,
       hid int not null, 
       status VARCHAR(15),
       PRIMARY KEY(vip, hid)) ENGINE=InnoDB;


-- resource
drop table if exists sysmt_resource;
create table sysmt_resource(resid int not null,
       resname varchar(30),
       resdesc varchar(1000),
       PRIMARY KEY(resid)) ENGINE=InnoDB;

-- skill
drop table if exists sysmt_skill;
create table sysmt_skill(skid int not null,
       skname varchar(30),
       skdesc varchar(1000),
       PRIMARY KEY(skid)) ENGINE=InnoDB;

-- resource 2 prj
drop table if exists sysmt_res2prj;
create table sysmt_res2prj(resid int not null,
       pid int not null,
       PRIMARY KEY(resid, pid)) ENGINE=InnoDB;

-- resource 2 skill
drop table if exists sysmt_res2skill;
create table sysmt_res2skill(resid int not null,
       skid int not null,
       PRIMARY KEY(resid, skid)) ENGINE=InnoDB;

-- resource plan
drop table if exists sysmt_resourceplan;
create table sysmt_resourceplan(
       rpeid int not null,
       activity varchar(200),
       resfrom datetime,
       resto datetime,
       resid int not null,
       mid int not null,
       PRIMARY KEY(rpeid)) ENGINE=InnoDB;