#!/usr/bin/perl

use DBI;
use DBI qw(:sql_types);
use Getopt::Long;

my $db;
my $dbname="sysmt";
my $dbhost="localhost";
my $dbport="2200";
my $dbuser="sysmt";
my $dbpwd="sysmt";
my $expfile="exp.out";
my $adulterate;

my $db="db2";
my $dbname="zv4xap01";
my $dbhost="localhost";
my $dbport="2200";
my $dbuser="catxadm";
my $dbpwd="admXcat01";


usage() if ( ! GetOptions ("db=s" => \$db,
	      "name=s" => \$dbname,
	      "port=i" => \$dbport,
	      "host=s" => \$dbhost,
	      "user=s" => \$dbuser,
	      "pwd=s" => \$dbpwd,
	      "expfile=s" => \$expfile,
	     "adulterate" => \$adulterate)
	     or defined $help );

sub usage
{
    print "Unknown option: @_\n" if ( @_ );
    print "usage: sysmtexp.pl [--db=[db2|cego|mysql]] [--name=<name>] [--port=<port>] [--host=<host>]  [--user=<user>] [--pwd=<pwd>] [--expfile=<expfile>] [ --adulterate ]\n";
    exit;
}

# cego url
my $url;
my $DTFORMAT;
my $DTFUNC;

if ( $db eq "cego" )
{
    $url="dbi:Cego:tableset=$dbname;hostname=$dbhost;port=$dbport;protocol=serial;logfile=;logmode=notice";
    $DTFORMAT="%Y-%m-%d-%H.%M.%S";
    $DTFUNC="date2str";
}
elsif ( $db eq "mysql" )
{
    $url="DBI:mysql:database=$dbname:host=$dbhost";
    $DTFORMAT="%Y-%m-%d-%H.%M.%S";
    $DTFUNC="date2str";
}
elsif ( $db eq "db2" )
{
    $url="DBI:DB2:$dbname";
    $DTFORMAT="yyyy-mm-dd-hh.mi.ss";
    $DTFUNC="ts_fmt";
}
else
{
    print "Unknown database, choose either cego, db2 or mysql\n";
    exit;
}

if ( $adulterate )
{
    print "!!!!!!!!!!!!!!!!!!!!!!!!\n";
    print "Adulterating export ...\n";
    print "!!!!!!!!!!!!!!!!!!!!!!!!\n";
}

eval
{

    my $dbh = DBI->connect ($url,
			    $dbuser,
			    $dbpwd,
			    {
				RaiseError => 1,
				AutoCommit => 1
			    } ) or die "Can't connect to database: $DBI::errstr\n";
    


    
    open EXPOUT, "> $expfile"
	or die "Can't open export file $expfile\n";
    
    exportId($dbh);
    exportBGroup($dbh);
    exportUser($dbh);
    exportProject($dbh);
    exportDisk($dbh);
    exportAddOn($dbh);
    exportFileSys($dbh);
    exportHost($dbh);
    exportSystem($dbh);
    exportInstance($dbh);
    exportSysSet($dbh);
    exportSLA($dbh);
    exportFileSysTmpl($dbh);
    exportFileSysTmplEntry($dbh);
    exportSystemWorkFlow($dbh);
    exportBGroupRight($dbh);
    exportCustCond($dbh);
    exportDisk2Host($dbh);
    exportDispSys($dbh);
    exportGroupSearch($dbh);
    exportGroupSearch2BGroup($dbh);
    exportMt($dbh);
    exportMtApproval($dbh);
    exportMtLog($dbh);
    exportMtVerification($dbh);
    exportNFS($dbh);
    exportPrj2Approval($dbh);
    exportPrj2BGroup($dbh);
    exportPrj2Notification($dbh);
    exportPrj2Verification($dbh);
    exportPrj2Workflow($dbh);
    exportSet2BGroup($dbh);
    exportSLA2Prj($dbh);
    exportSys2Set($dbh);
    exportUserSearch($dbh);
    exportUser2BGroup($dbh);
    exportVip2Host($dbh);
    exportThread($dbh);
    exportThreadLog($dbh);
    exportThreadGroup($dbh);
    exportThreadGroup2BGroup($dbh);
    exportThreadStat($dbh);
    exportDocument($dbh);
    exportDoc2Thread($dbh);
    exportFirewallPortSet($dbh);
    exportFirewallPortSetEntry($dbh);
    exportFirewallServerGroup($dbh);
    exportFirewallServerGroupEntry($dbh);
    exportSystemFirewall($dbh);   

    $dbh->disconnect or warn "Disconnection error: $DBI::errstr\n";


    close EXPOUT;


};
if ( $@ )
{    
    print "Export error : " .  $@ . "\n";
    exit 1;
}    

exit 0; 


sub exportAddOn
{
    my ( $dbh ) = @_;

    print "Exporting addon  ...\n";

    $sth = $dbh->prepare("select aoid, aotype, aoname, aohome, aouser, aogroup, aoexepath, aologpath, sysid from sysmt_addon;");

    $sth->execute;
    
    while ( ( $aoid,
	      $aotype,
	      $aoname,
	      $aohome,
	      $aouser,
	      $aogroup,
	      $aoexepath,
	      $aologpath,
	      $sysid ) = $sth->fetchrow_array )
    {
	
	print EXPOUT "table=sysmt_addon,aoid=" . $aoid
	    . ",aotype=" . $aotype
	    . ",aoname=" . $aoname
	    . ",aohome=" . $aohome
	    . ",aouser=" . $aouser
	    . ",aogroup=" . $aogroup
	    . ",aoexepath=" . $aoexepath
	    . ",aologpath=" . $aologpath
	    . ",sysid=" . $sysid
	    . "\n";
    }
    
    $sth->finish;
}

sub exportBGroupRight
{
    my ($dbh) = @_;

    print "Exporting bgright  ...\n";

    $sth = $dbh->prepare("select bgid, bgright from sysmt_bgright;");
    
    $sth->execute;
    
    while ( ( $bgid, $bgright ) = $sth->fetchrow_array )
    {
	print EXPOUT "table=sysmt_bgright,bgid=" . $bgid . ",bgright=" . $bgright . "\n";
    }
    
    $sth->finish;

}


sub exportBGroup
{
    my ( $dbh ) = @_;

    print "Exporting bgroup  ...\n";

    $sth = $dbh->prepare("select bgid, bgname, bgdesc from sysmt_bgroup;");
    
    $sth->execute;

    while ( ( $bgid, $bgname, $bgdesc ) = $sth->fetchrow_array )
    {

	$bgdesc =~ s/\r//g;
	$bgdesc =~ s/\n/\\n/g;
	$bgdesc =~ s/,/%SEP%/g;

	if ( $adulterate )
	{
	    $bgname =~ s/A/I/g;
	    $bgname =~ s/R/X/g;
	    $bgname =~ s/E/O/g;
	    $bgname =~ s/U/A/g;
	    $bgname =~ s/O/E/g;
	    $bgname =~ s/F/G/g;
	    $bgname =~ s/T/X/g;
	    $bgname =~ s/i/o/g;
	    $bgname =~ s/e/i/g;
	    
	    $bgdesc = "XXXXX BG DESC XXXX";
	}
	       
	print EXPOUT "table=sysmt_bgroup,bgid=" . $bgid . ",bgname=" . $bgname . ",bgdesc=" . $bgdesc ."\n";
    }
    
    $sth->finish;

}

sub exportProject
{
    my ( $dbh ) = @_;

    print "Exporting project ...\n";
    
    $sth = $dbh->prepare("select pid, prjname, prjdesc, prjmail from sysmt_project;");
    
    $sth->execute;
    
    while ( ( my $pid, $prjname, $prjdesc, $prjmail ) = $sth->fetchrow_array )
    {
	$prjdesc =~ s/\r//g;
	$prjdesc =~ s/\n/\\n/g;
	$prjdesc =~ s/,/%SEP%/g;


	if ( $adulterate )
	{
	    $prjname =~ s/A/I/g;
	    $prjname =~ s/R/X/g;
	    $prjname =~ s/E/O/g;
	    $prjname =~ s/U/A/g;
	    $prjname =~ s/O/E/g;
	    $prjname =~ s/F/G/g;
	    $prjname =~ s/T/X/g;
	    $prjname =~ s/M/B/g;
	    $prjname =~ s/i/o/g;
	    $prjname =~ s/e/i/g;
	    $prjname =~ s/a/o/g;
	    
	    $prjdesc = "XXXXX PRJ DESC XXXX";
	    $prjmail = "project@mail.com";
	}

	
	print EXPOUT "table=sysmt_project,pid=" . $pid 
	    . ",prjname=" . $prjname 
	    . ",prjdesc=" . $prjdesc
	    . ",prjmail=" . $prjmail ."\n";
    }
    
    $sth->finish;
}

sub exportMt
{
    my ( $dbh ) = @_;


    print "Exporting mt ...\n";

    $sth = $dbh->prepare("select mid,shortdesc,description,". $DTFUNC . "(mtfrom, '" . $DTFORMAT . "'), ". $DTFUNC . "(mtto, '" . $DTFORMAT . "'), ". $DTFUNC . "(downfrom, '" . $DTFORMAT . "'), ". $DTFUNC . "(downto, '" . $DTFORMAT . "'),status,ticketnr,sysid,lockby,mttype,repcomment,repappcheck from sysmt_mt;");
    
    $sth->execute;
    
    while ( ( $mid, $shortdesc, $description, $mtfrom, $mtto, $downfrom, $downto, $status,$ticketnr,$sysid, $lockby, $mttype,$repcomment,$repappcheck  ) = $sth->fetchrow_array )
    {
	$description =~ s/\r//g;
	$description =~ s/\n/\\n/g;
	$description =~ s/,/%SEP%/g;
	
	print EXPOUT "table=sysmt_mt,mid=" . $mid 
	    . ",shortdesc=" . $shortdesc 
	    . ",description=" . $description
	    . ",mtfrom=" . $mtfrom
	    . ",mtto=" . $mtto
	    . ",downfrom=" . $downfrom
	    . ",downto=" . $downto
	    . ",status=" . $status
	    . ",ticketnr=" . $ticketnr
	    . ",sysid=" . $sysid
	    . ",lockby=" . $lockby
	    . ",mttype=" . $mttype
	    . ",repcomment=" . $repcomment
	    . ",repappcheck=" . $repappcheck
	    ."\n";
    }
    
    $sth->finish;

}

sub exportUser
{
    my ( $dbh ) = @_;


    print "Exporting user ...\n";

    $sth = $dbh->prepare("select uid, dbuser, username, userdesc, userright, usermail from sysmt_user;");
    
    $sth->execute;
    
    while ( ( my $uid, $dbuser, $username, $userdesc, $userright, $usermail ) = $sth->fetchrow_array )
    {
	$userdesc =~ s/\r//g;
	$userdesc =~ s/\n/\\n/g;
	$userdesc =~ s/,/%SEP%/g;

	if ( $adulterate )
	{
	    $dbuser =~ s/i/o/g;
	    $dbuser =~ s/e/i/g;
	    $dbuser =~ s/a/o/g;
	    $dbuser =~ s/u/e/g;
	    $dbuser =~ s/o/k/g;

	    $username =~ s/A/B/g;
	    $username =~ s/T/F/g;
	    $username =~ s/K/L/g;
	    $username =~ s/I/P/g;

	    
	    $userdesc = "XXXXX USER DESC XXXX";
	    $usermail = "user@mail.com";
	}

	print EXPOUT "table=sysmt_user,uid=" . $uid
	    . ",dbuser=" . $dbuser 
	    . ",username=" . $username 
	    . ",userdesc=" . $userdesc
	    . ",userright=" . $userright
	    . ",usermail=" . $usermail ."\n";
    }
    
    $sth->finish;

}

sub exportSystem
{
    my ( $dbh ) = @_;


    print "Exporting system  ...\n";

    $sth = $dbh->prepare("select sysid, sid, category, sysdesc, pid, systype, mtinfo, platform, status, saptype, vip, sysnr, scs, javaport, smdid, zoneA, zoneB, partA, partB, partC, partD, restartzones, ". $DTFUNC . "(created, '" . $DTFORMAT . "'), dbtype, arch, nfsvip, vipip, vipif, dbversion, sharedfs, parthalog, slaid, sapversion, sdbtype, dbvip, dbvA, dbvB, scandbversion, scansapversion from sysmt_system;");

    $sth->execute;
    
    while ( ( $sysid,
	      $sid,
	      $category,
	      $sysdesc,
	      $pid,
	      $systype, 
	      $mtinfo,
	      $platform,
	      $status,
	      $saptype,
	      $vip,
	      $sysnr,
	      $scs,
	      $javaport,
	      $smdid,
	      $zoneA,
	      $zoneB,
	      $partA,
	      $partB,
	      $partC,
	      $partD,
	      $restartzones,
	      $created, 
	      $dbtype, 
	      $arch, 
	      $nfsvip, 
	      $vipip, 
	      $vipif, 
	      $dbversion, 
	      $sharedfs, 
	      $parthalog,
	      $slaid,
	      $sapversion,
	      $sdbtype,
	      $dbvip,
	      $dbvA,
	      $dbvB,
              $scandbversion,
              $scansapversion ) = $sth->fetchrow_array )
    {

	if ( $adulterate )
	{
	    # change A with B
	    $sid =~ s/A/#/g;
	    $sid =~ s/B/A/g;
	    $sid =~ s/#/B/g;

	    # change P with U
	    $sid =~ s/P/#/g;
	    $sid =~ s/U/P/g;
	    $sid =~ s/#/U/g;

	    # change Z with R
	    $sid =~ s/Z/#/g;
	    $sid =~ s/R/Z/g;
	    $sid =~ s/#/R/g;
	    
	}

	$sysdesc =~ s/\r//g;
	$sysdesc =~ s/\n/\\n/g;
	$sysdesc =~ s/,/%SEP%/g;

	$mtinfo =~ s/\r//g;
	$mtinfo =~ s/\n/\\n/g;
	$mtinfo =~ s/,/%SEP%/g;
	
	print EXPOUT "table=sysmt_system,sysid=" . $sysid
	    . ",sid=" . $sid
	    . ",category=" . $category
	    . ",sysdesc=" .  $sysdesc
	    . ",pid=" . $pid
	    . ",systype=" . $systype
	    . ",mtinfo=" . $mtinfo
	    . ",platform=" . $platform
	    . ",status=" . $status
	    . ",saptype=" . $saptype
	    . ",vip=" . $vip
	    . ",sysnr=" . $sysnr
	    . ",scs=" . $scs
	    . ",javaport=" . $javaport
	    . ",smdid=" . $smdid
	    . ",zoneA=" . $zoneA
	    . ",zoneB=" . $zoneB
	    . ",partA=" . $partA
	    . ",partB=" . $partB
	    . ",partC=" . $partC
	    . ",partD=" . $partD
	    . ",restartzone=" . $restartzones
	    . ",created=" . $created
	    . ",dbtype=" . $dbtype
	    . ",arch=" . $arch
	    . ",nfsvip=" . $nfsvip
	    . ",vipip=" . $vipip
	    . ",vipif=" . $vipif
	    . ",dbversion=" . $dbversion 
	    . ",sharedfs=" . $sharedfs
	    . ",parthalog=" . $parthalog
	    . ",slaid=" . $slaid
	    . ",sapversion=" . $sapversion
	    . ",sdbtype=" . $sdbtype
	    . ",dbvip=" . $dbvip
	    . ",dbvA=" . $dbvA
	    . ",dbvB=" . $dbvB
	    . ",scandbversion=" . $scandbversion
	    . ",scansapversion=" . $scansapversion
	    . "\n";
    }
    
    $sth->finish;

}

sub exportSysSet
{
    my ( $dbh ) = @_;

    print "Exporting set  ...\n";

    $sth = $dbh->prepare("select setid, setname, description from sysmt_systemset;");

    $sth->execute;
    
    while ( ( $setid, $setname, $setdesc ) = $sth->fetchrow_array )
    {

	$setdesc =~ s/\r//g;
	$setdesc =~ s/\n/\\n/g;
	$setdesc =~ s/,/%SEP%/g;
	
	print EXPOUT "table=sysmt_systemset,setid=" . $setid . ",setname=" . $setname . ",description=" . $setdesc ."\n";
    }
    
    $sth->finish;

}

sub exportSys2Set
{
    my ( $dbh ) = @_;

    print "Exporting sys2set  ...\n";

    $sth = $dbh->prepare("select sysid, setid from sysmt_sys2set;");
    
    $sth->execute;
    
    while ( ( $sysid, $setid ) = $sth->fetchrow_array )
    {
	print EXPOUT "table=sysmt_sys2set,sysid=" . $sysid . ",setid=" . $setid ."\n";
    }
    
    $sth->finish;
    
}

sub exportUser2BGroup
{

    my ( $dbh ) = @_;

    print "Exporting user2bgroup  ...\n";

    $sth = $dbh->prepare("select uid, bgid from sysmt_usr2bgrp;");

    $sth->execute;
    
    while ( ( $uid, $bgid ) = $sth->fetchrow_array )
    {
	print EXPOUT "table=sysmt_usr2bgrp,uid=" . $uid . ",bgid=" . $bgid ."\n";
    }
    
    $sth->finish;
    
}

sub exportPrj2BGroup
{

    my ( $dbh ) = @_;

    print "Exporting prj2bgroup  ...\n";

    $sth = $dbh->prepare("select pid, bgid from sysmt_prj2bgrp;");

    $sth->execute;
    
    while ( ( $pid, $bgid ) = $sth->fetchrow_array )
    {
	print EXPOUT "table=sysmt_prj2bgrp,pid=" . $pid . ",bgid=" . $bgid ."\n";
    }
    
    $sth->finish;
    
}

sub exportSet2BGroup
{

    my ( $dbh ) = @_;

    print "Exporting set2bgroup  ...\n";

    $sth = $dbh->prepare("select setid, bgid from sysmt_set2bgrp;");
    
    $sth->execute;
    
    while ( ( $setid, $bgid ) = $sth->fetchrow_array )
    {
	print EXPOUT "table=sysmt_set2bgrp,setid=" . $setid . ",bgid=" . $bgid ."\n";
    }
    
    $sth->finish;
    
}


sub exportFileSysTmpl
{
    my ($dbh) = @_;

    print "Exporting filesystmpl  ...\n";

    $sth = $dbh->prepare("select tmplid, fstmplname, fstmpldesc, fstmplrule, fstmpltype from sysmt_filesystmpl;");
    
    $sth->execute;
    
    while ( ( $tmplid, $fstmplname, $fstmpldesc, $fstmplrule, $fstmpltype) = $sth->fetchrow_array )
    {

        $fstmplrule =~ s/=/%ESEP%/g;
	$fstmplrule =~ s/'/''/g;

	print EXPOUT "table=sysmt_filesystmpl,tmplid=" . $tmplid . ",fstmplname=" . $fstmplname . ",fstmpldesc=" . $fstmpldesc . ",fstmplrule=" . $fstmplrule . ",fstmpltype=" . $fstmpltype . "\n";
    }
    
    $sth->finish;

}

sub exportFileSysTmplEntry
{
    my ($dbh) = @_;

    print "Exporting filesystmplentry  ...\n";

    $sth = $dbh->prepare("select fsid, tmplid, fstype, fspath, fsvg, fssizesmall, fssizebig, fsopt, fslv from sysmt_filesystmplentry;");
    
    $sth->execute;
    
    while ( ( $fsid, $tmplid, $fstype, $fspath, $fsvg, $fssizesmall, $fssizebig, $fsopt, $fslv ) = $sth->fetchrow_array )
    {

	$fsopt =~ s/,/%SEP%/g;
	$fsopt =~ s/=/%ESEP%/g;
	$fsopt =~ s/'/''/g;

	print EXPOUT "table=sysmt_filesystmplentry,fsid=" . $fsid . ",tmplid=" . $tmplid . ",fstype=" . $fstype . ",fspath=" . $fspath . ",fsvg=" . $fsvg . ",fssizesmall=" . $fssizesmall . ",fssizebig=" . ",fsopt=" . $fsopt . ",fslv=" . $fslv . "\n";
    }
    
    $sth->finish;

}

sub exportGroupSearch2BGroup
{
    my ($dbh) = @_;

    print "Exporting groupsearch2bgroup  ...\n";

    $sth = $dbh->prepare("select gsid, bgid from sysmt_gs2bgrp;");

    $sth->execute;
        
    while ( ( $gsid, $bgid ) = $sth->fetchrow_array )
    {
	print EXPOUT "table=sysmt_gs2bgrp,gsid=" . $gsid . ",bgid=" . $bgid . "\n";
    }
    
    $sth->finish;
}

sub exportPrj2Approval
{
    my ($dbh) = @_;

    print "Exporting prj2approval  ...\n";

    $sth = $dbh->prepare("select pid, bgid from sysmt_prj2approval;");
    
    $sth->execute;
    
    while ( ( $pid, $bgid ) = $sth->fetchrow_array )
    {
	print EXPOUT "table=sysmt_prj2approval,pid=" . $pid . ",bgid=" . $bgid . "\n";
    }
    
    $sth->finish;
}

sub exportVip2Host
{
    my ($dbh) = @_;

    print "Exporting vip2host  ...\n";

    $sth = $dbh->prepare("select vip, hid, status from sysmt_vip2host;");
    
    $sth->execute;
    
    while ( ( $vip, $hid, $status ) = $sth->fetchrow_array )
    {
	print EXPOUT "table=sysmt_vip2host,vip=" . $vip . ",hid=" . $hid . ",status=" . $status . "\n";
    }
    
    $sth->finish;
}

sub exportMtLog
{
    my ($dbh) = @_;

    print "Exporting mtlog  ...\n";

    $sth = $dbh->prepare("select ". $DTFUNC . "(logts, '" . $DTFORMAT . "'), mid, logentry from sysmt_mtlog;");
    
    $sth->execute;
    
    while ( ( my $logts, $mid, $logentry ) = $sth->fetchrow_array )
    {

	if ( $adulterate )
	{
	    # change A with B
	    $logentry =~ s/by ..../by XXXX/g;	    
	}

	
	print EXPOUT "table=sysmt_mtlog,logts=" . $logts . ",mid=" . $mid . ",logentry=" . $logentry . "\n";
    }
   
    $sth->finish;
}

sub exportDisk
{
    my ($dbh) = @_;

    print "Exporting disk  ...\n";

    $sth = $dbh->prepare("select did, ". $DTFUNC . "(scandate, '" . $DTFORMAT . "'), status, diskname, disksize, diskusage, diskvg, slaid from sysmt_disk;");
    
    $sth->execute;

    while ( ( $did, $scandate, $status, $diskname, $disksize, $diskusage, $diskvg, $slaid ) = $sth->fetchrow_array )
    {
	print EXPOUT "table=sysmt_disk,did=" . $did . ",scandate=" . $scandate . ",status=" . $status . ",diskname=" . $diskname . ",disksize=" . $disksize . ",diskusage=" . $diskusage . ",diskvg=" . $diskvg . ",slaid=" . $slaid . "\n";
    }
    
    $sth->finish;

}

sub exportDisk2Host
{
    my ($dbh) = @_;

    print "Exporting disk2host  ...\n";

    $sth = $dbh->prepare("select did, hid from sysmt_disk2host;");

    $sth->execute;
        
    while ( ( $did, $hid ) = $sth->fetchrow_array )
    {
	print EXPOUT "table=sysmt_disk2host,did=" . $did . ",hid=" . $hid . "\n";
    }
    
    $sth->finish;
}

sub exportId
{
    my ($dbh) = @_;

    print "Exporting id  ...\n";

    $sth = $dbh->prepare("select id, idval from sysmt_id;");
    
    $sth->execute;
    
    while ( ( $id, $idval ) = $sth->fetchrow_array )
    {
	print EXPOUT "table=sysmt_id,id=" . $id . ",idval=" . $idval . "\n";
    }
    
    $sth->finish;

}

sub exportHost
{
    my ($dbh) = @_;

    print "Exporting host  ...\n";

    $sth = $dbh->prepare("select hid, ". $DTFUNC . "(scandate, '" .$DTFORMAT . "'), status, hostname, hostinfo, osinfo, cpuinfo, meminfo from sysmt_host;");
    
    $sth->execute;
    
    while ( ( $hid, $scandate, $status, $hostname, $hostinfo, $osinfo, $cpuinfo, $meminfo ) = $sth->fetchrow_array )
    {
	print EXPOUT "table=sysmt_host,hid=" . $hid . ",scandate=" . $scandate . ",status=" . $status . ",hostname=" . $hostname . ",hostinfo=" . $hostinfo . ",osinfo=" . $osinfo . ",cpuinfo=" . $cpuinfo . ",meminfo=" . $meminfo . "\n";
    }
    
    $sth->finish;

}

sub exportUserSearch
{
    my ($dbh) = @_;

    print "Exporting usersearch  ...\n";

    $sth = $dbh->prepare("select usid, usname, usspec, uid from sysmt_usersearch;");
    
    $sth->execute;
    
    while ( ( $usid, $usname, $usspec, $uid) = $sth->fetchrow_array )
    {
	$usspec =~ s/=/%ESEP%/g;
	$usspec =~ s/'/''/g;
	print EXPOUT "table=sysmt_usersearch,usid=" . $usid . ",usname=" . $usname . ",usspec=" . $usspec . ",uid=" . $uid . "\n";
    }
    
    $sth->finish;

}

sub exportCustCond
{
    my ($dbh) = @_;

    print "Exporting custcond  ...\n";

    $sth = $dbh->prepare("select ccid, ccname, ccspec, uid, cctype from sysmt_custcond;");
    
    $sth->execute;

    while ( ( $ccid, $ccname, $ccspec, $uid, $cctype ) = $sth->fetchrow_array )
    {
	$ccspec =~ s/=/%ESEP%/g;
	$ccspec =~ s/'/''/g;
	print EXPOUT "table=sysmt_custcond,ccid=" . $ccid . ",ccname=" . $ccname . ",ccspec=" . $ccspec . ",uid=" . $uid . ",cctype=" . $cctype . "\n";
    }
    
    $sth->finish;

}

sub exportSystemWorkFlow
{
    my ($dbh) = @_;

    print "Exporting sysworkflow  ...\n";

    $sth = $dbh->prepare("select sysid, bgid, seqnr, ". $DTFUNC . "(assigned, '" . $DTFORMAT . "'), ". $DTFUNC . "(released, '" . $DTFORMAT . "'), dbuser, comment, status from sysmt_sysworkflow;");
    
    $sth->execute;
    
    while ( ( $sysid, $bgid, $seqnr, $assigned, $released, $dbuser, $comment, $status ) = $sth->fetchrow_array )
    {
	print EXPOUT "table=sysmt_sysworkflow,sysid=" . $sysid . ",bgid=" . $bgid . ",seqnr=" . $seqnr . ",assigned=" . $assigned . ",released=" . $released . ",dbuser=" . $dbuser . ",comment=" . $comment . ",status=" . $status . "\n";
    }
    
    $sth->finish;
}

sub exportPrj2Workflow
{
    my ($dbh) = @_;

    print "Exporting prj2workflow  ...\n";

    $sth = $dbh->prepare("select pid, bgid, seqnr from sysmt_prj2workflow;");
    
    $sth->execute;
    
    while ( ( $pid, $bgid, $seqnr ) = $sth->fetchrow_array )
    {
	print EXPOUT "table=sysmt_prj2workflow,pid=" . $pid . ",bgid=" . $bgid . ",seqnr=" . $seqnr . "\n";
    }
    
    $sth->finish;
}

sub exportInstance
{
    my ($dbh) = @_;
    # sysmt_instance

    print "Exporting instance  ...\n";

    $sth = $dbh->prepare("select instid, instnr, instvip, instsmd, instzone, instarch, sysid, ". $DTFUNC . "(created, '" . $DTFORMAT . "'), instsaptype, instjavaport, instdisp from sysmt_instance;");
    
    $sth->execute;
    
    while ( ( $instid, $instnr, $instvip, $instsmd, $instzone, $instarch, $sysid, $created, $instsaptype, $instjavaport, $instdisp ) = $sth->fetchrow_array )
    {
	print EXPOUT "table=sysmt_instance,instid=" . $instid . ",instnr=" . $instnr . ",instvip=" . $instvip . ",instsmd=" . $instsmd . ",instzone=" . $instzone . ",instarch=" . $instarch . ",sysid=" . $sysid . ",created=" . $created . ",instsaptype=" . $instsaptype . ",instjavaport=" . $instjavaport . ",instdisp=" . $instdisp . "\n";
    }
    
    $sth->finish;
}

sub exportMtApproval
{
    my ($dbh) = @_;

    print "Exporting mtapproval  ...\n";

    $sth = $dbh->prepare("select mid, bgid, status from sysmt_mtapproval;");

    $sth->execute;
        
    while ( ( $mid, $bgid, $status ) = $sth->fetchrow_array )
    {
	print EXPOUT "table=sysmt_mtapproval,mid=" . $mid . ",bgid=" . $bgid . ",status=" . $status . "\n";
    }
    
    $sth->finish;
}

sub exportFileSys
{
    my ($dbh) = @_;

    print "Exporting filesys  ...\n";

    $sth = $dbh->prepare("select fstype, fspath, fsvg, fssize, sysid, fsopt, fslv from sysmt_filesys;");

    $sth->execute;
    
    while ( ( $fstype, $fspath, $fsvg, $fssize, $sysid, $fsopt, $fslv ) = $sth->fetchrow_array )
    {
	$fsopt =~ s/,/%SEP%/g;
	print EXPOUT "table=sysmt_filesys,fstype=" . $fstype . ",fspath=" . $fspath . ",fsvg=" . $fsvg . ",fssize=" . $fssize . ",sysid=" . $sysid . ",fsopt=" . $fsopt . ",fslv=" . $fslv . "\n";
    }
    
    $sth->finish;
}

sub exportGroupSearch
{
    my ($dbh) = @_;

    print "Exporting groupsearch  ...\n";

    $sth = $dbh->prepare("select gsid, gsname, gsspec from sysmt_groupsearch;");

    $sth->execute;
    
    while ( ( $gsid, $gsname, $gsspec ) = $sth->fetchrow_array )
    {
	print EXPOUT "table=sysmt_groupsearch,gsid=" . $gsid . ",gsname=" . $gsname . ",gsspec=" . $gsspec . "\n";
    }
    
    $sth->finish;
}

sub exportDispSys
{
    my ($dbh) = @_;

    print "Exporting dispsys  ...\n";

    $sth = $dbh->prepare("select sysid, dispsysid from sysmt_dispsys;");
    
    $sth->execute;
    
    while ( ( $sysid, $dispsysid ) = $sth->fetchrow_array )
    {
	print EXPOUT "table=sysmt_dispsys,sysid=" . $sysid . ",dispsysid=" . $dispsysid . "\n";
    }
    
    $sth->finish;
}

sub exportMtVerification
{
    my ($dbh) = @_;

    print "Exporting mtverification  ...\n";

    $sth = $dbh->prepare("select mid, bgid, status from sysmt_mtverification;");
    
    $sth->execute;

    while ( ( $mid, $bgid, $status ) = $sth->fetchrow_array )
    {
	print EXPOUT "table=sysmt_mtverification,mid=" . $mid . ",bgid=" . $bgid . ",status=" . $status . "\n";
    }
    
    $sth->finish;
}

sub exportNFS
{
    my ($dbh) = @_;

    print "Exporting nfs  ...\n";

    $sth = $dbh->prepare("select nfsid, nfspath, nfsnode, nfsmount, sysid from sysmt_nfs;");
    
    $sth->execute;
    
    while ( ( $nfsid, $nfspath, $nfsnode, $nfsmount, $sysid ) = $sth->fetchrow_array )
    {
	print EXPOUT "table=sysmt_nfs,nfsid=" . $nfsid . ",nfspath=" . $nfspath . ",nfsnode=" . $nfsnode . ",nfsmount=" . $nfsmount . ",sysid=" . $sysid . "\n";
    }
    
    $sth->finish;
}

sub exportPrj2Notification
{
    my ($dbh) = @_;

    print "Exporting prj2notification  ...\n";

    $sth = $dbh->prepare("select pid, bgid from sysmt_prj2notification;");
    
    $sth->execute;
    
    while ( ( $pid, $bgid ) = $sth->fetchrow_array )
    {
	print EXPOUT "table=sysmt_prj2notification,pid=" . $pid . ",bgid=" . $bgid . "\n";
    }
    
    $sth->finish;
}

sub exportPrj2Verification
{
    my ($dbh) = @_;

    print "Exporting prj2verification  ...\n";

    $sth = $dbh->prepare("select pid, bgid from sysmt_prj2verification;");
    
    $sth->execute;
    
    while ( ( $pid, $bgid ) = $sth->fetchrow_array )
    {
	print EXPOUT "table=sysmt_prj2verification,pid=" . $pid . ",bgid=" . $bgid . "\n";
    }
    
    $sth->finish;

}

sub exportSLA
{
    my ($dbh) = @_;

    print "Exporting sla  ...\n";

    $sth = $dbh->prepare("select slaid, slanr, shortdesc from sysmt_sla;");
    
    $sth->execute;
    
    while ( ( $slaid, $slanr, $shortdesc ) = $sth->fetchrow_array )
    {
	print EXPOUT "table=sysmt_sla,slaid=" . $slaid . ",slanr=" . $slanr . ",shortdesc=" . $shortdesc . "\n";
    }
    
    $sth->finish;
}

sub exportSLA2Prj
{
    my ($dbh) = @_;

    print "Exporting sla2prj  ...\n";

    $sth = $dbh->prepare("select slaid, pid from sysmt_sla2prj;");
    
    $sth->execute;
    
    while ( ( $slaid, $pid ) = $sth->fetchrow_array )
    {
	print EXPOUT "table=sysmt_sla2prj,slaid=" . $slaid . ",pid=" . $pid . "\n";
    }
    
    $sth->finish;

}

sub exportThread
{
    my ($dbh) = @_;

    print "Exporting thread  ...\n";

    $sth = $dbh->prepare("select thrid, shortdesc, description, ". $DTFUNC . "(created, '" . $DTFORMAT . "'), ". $DTFUNC . "(remind, '" . $DTFORMAT . "'), " . $DTFUNC . "(lastedit, '" . $DTFORMAT . "'), lasteditby, status, tgid, bgid from sysmt_thread;");
    
    $sth->execute;

    while ( ( $thrid, $shortdesc, $desc, $created, $remind, $lastedit, $lasteditby, $status, $tgid, $bgid ) = $sth->fetchrow_array )
    {
	print EXPOUT "table=sysmt_thread,thrid=" . $thrid . ",shortdesc=" . $shortdesc . ",description=" . $desc . ",created=" . $created . ",remind=" . $remind . ",status=" . $status . ",lastedit=" . $lastedit . ",lasteditby=" . $lasteditby . ",tgid=" . $tgid . ",bgid=" . $bgid . "\n";
    }
    
    $sth->finish;
}

sub exportThreadLog
{
    my ($dbh) = @_;

    print "Exporting threadlog  ...\n";

    $sth = $dbh->prepare("select " . $DTFUNC . "(logts, '" . $DTFORMAT . "'), logentry, thrid, dbuser from sysmt_threadlog;");

    $sth->execute;
    
    while ( ( $logts, $logentry, $thrid, $dbuser) = $sth->fetchrow_array )
    {
	$logentry =~ s/\r//g;
	$logentry =~ s/\n/\\n/g;
	print EXPOUT "table=sysmt_threadlog,logts=" . $logts . ",logentry=" . $logentry . ",thrid=" . $thrid . ",dbuser=" . $dbuser . "\n";
    }
    
    $sth->finish;
}

sub exportThreadGroup
{
    my ($dbh) = @_;

    print "Exporting threadgroup  ...\n";

    $sth = $dbh->prepare("select tgid, tgname, tgdesc from sysmt_threadgroup;");

    $sth->execute;
    
    while ( ( $tgid, $tgname, $tgdesc) = $sth->fetchrow_array )
    {

	$tgdesc =~ s/\r//g;
	$tgdesc =~ s/\n/\\n/g;

	print EXPOUT "table=sysmt_threadgroup,tgid=" . $tgid . ",tgname=" . $tgname . ",tgdesc=" . $tgdesc . "\n";
    }
    
    $sth->finish;
}

sub exportThreadGroup2BGroup
{
    my ($dbh) = @_;

    print "Exporting tg2bgrp  ...\n";

    $sth = $dbh->prepare("select tgid, bgid from sysmt_tg2bgrp;");

    $sth->execute;

    while ( ( $tgid, $bgid) = $sth->fetchrow_array )
    {
	print EXPOUT "table=sysmt_tg2bgrp,tgid=" . $tgid . ",bgid=" . $bgid . "\n";
    }
    
    $sth->finish;

}

sub exportThreadStat
{
    my ($dbh) = @_;

    print "Exporting threadstat  ...\n";

    $sth = $dbh->prepare("select thrid, uid, readstat from sysmt_threadstat;");

    $sth->execute;
    
    while ( ( $thrid, $uid, $readstat) = $sth->fetchrow_array )
    {
	print EXPOUT "table=sysmt_threadstat,thrid=" . $thrid . ",uid=" . $uid . ",readstat=" . $readstat . "\n";
    }
    
    $sth->finish;
}

sub exportDocument
{
    my ($dbh) = @_;

    print "Exporting document  ...\n";

    $sth = $dbh->prepare("select docid, doctype, docname from sysmt_document;");

    $sth->execute;
    
    while ( ( $docid, $doctype, $docname) = $sth->fetchrow_array )
    {
	print EXPOUT "table=sysmt_document,docid=" . $docid . ",doctype=" . $doctype . ",docname=" . $docname . "\n";
    }
    
    $sth->finish;

}

sub exportDoc2Thread
{
    my ($dbh) = @_;

    print "Exporting doc2thread  ...\n";

    $sth = $dbh->prepare("select docid, thrid from sysmt_doc2thread;");

    $sth->execute;
    
    while ( ( $docid, $thrid) = $sth->fetchrow_array )
    {
	print EXPOUT "table=sysmt_doc2thread,docid=" . $docid . ",thrid=" . $thrid . "\n";
    }
    
    $sth->finish;

}

sub exportFirewallPortSet
{
    my ($dbh) = @_;

    print "Exporting fwps  ...\n";

    $sth = $dbh->prepare("select psid, psname, psdesc from sysmt_fwps;");

    $sth->execute;
    
    while ( ( $psid, $psname, $psdesc ) = $sth->fetchrow_array )
    {
	$psdesc =~ s/\r//g;
	$psdesc =~ s/\n/\\n/g;
	print EXPOUT "table=sysmt_fwps,psid=" . $psid . ",psname=" . $psname . ",psdesc=" . $psdesc . "\n";
    }
    
    $sth->finish;

}

sub exportFirewallPortSetEntry
{
    my ($dbh) = @_;

    print "Exporting fwpsenrtry  ...\n";

    $sth = $dbh->prepare("select psid, portval, portdesc from sysmt_fwpsentry;");

    $sth->execute;
    
    while ( ( $psid, $portval, $portdesc) = $sth->fetchrow_array )
    {
	$portdesc =~ s/\r//g;
	$portdesc =~ s/\n/\\n/g;
	print EXPOUT "table=sysmt_fwpsentry,psid=" . $psid . ",portval=" . $portval . ",portdesc=" . $portdesc .  "\n";
    }
    
    $sth->finish;

}


sub exportFirewallServerGroup
{
    my ($dbh) = @_;

    print "Exporting fwsg  ...\n";

    $sth = $dbh->prepare("select sgid, sgname, sgdesc from sysmt_fwsg;");

    $sth->execute;
    
    while ( ( $sgid, $sgname, $sgdesc, $sgtype ) = $sth->fetchrow_array )
    {
	$sgdesc =~ s/\r//g;
	$sgdesc =~ s/\n/\\n/g;
	print EXPOUT "table=sysmt_fwsg,sgid=" . $sgid . ",sgname=" . $sgname . ",sgdesc=" . $sgdesc . "\n";
    }
    
    $sth->finish;

}

sub exportFirewallServerGroupEntry
{
    my ($dbh) = @_;

    print "Exporting fwsgenrtry  ...\n";

    $sth = $dbh->prepare("select sgid, ipval, ipdesc from sysmt_fwsgentry;");

    $sth->execute;
    
    while ( ( $sgid, $ipval, $ipdesc) = $sth->fetchrow_array )
    {
	$ipdesc =~ s/\r//g;
	$ipdesc =~ s/\n/\\n/g;
	print EXPOUT "table=sysmt_fwsgentry,sgid=" . $sgid . ",ipval=" . $ipval . ",ipdesc=" . $ipdesc .  "\n";
    }
    
    $sth->finish;

}


sub exportSystemFirewall
{
    my ($dbh) = @_;

    print "Exporting sysfw  ...\n";

    $sth = $dbh->prepare("select fwrid, sgidfrom, sgidto, psid, sysid from sysmt_sysfw;");

    $sth->execute;
    
    while ( ( $fwrid, $sgidfrom, $sgidto, $psid, $sysid) = $sth->fetchrow_array )
    {
	print EXPOUT "table=sysmt_sysfw,fwrid=" . $fwrid . ",sgidfrom=" . $sgidfrom . ",sgidto=" . $sgidto . ",psid=" . $psid . ",sysid=" . $sysid .  "\n";
    }   
    $sth->finish;
}
