#!/usr/bin/perl

use DBI;
use DBI qw(:sql_types);
use Getopt::Long;


# $db="db2";
# my $dbname="zv4xap01";
# my $dbhost="localhost";
# my $dbport="2200";
# my $dbuser="catxadm";
# my $dbpwd="admXcat01";

my $db;
my $dbname="sysmt";
my $dbhost="localhost";
my $dbport="2200";
my $dbuser="sysmt";
my $dbpwd="sysmt";

my $impfile="exp.out";
my $dberrorcode;
my $force=0;

my @tablelist = qw(sysmt_mt
sysmt_addon
sysmt_usr2bgrp
sysmt_vip2host
sysmt_bgright
sysmt_custcond
sysmt_disk2host
sysmt_dispsys
sysmt_filesys
sysmt_filesystmpl
sysmt_filesystmplentry
sysmt_groupsearch
sysmt_gs2bgrp
sysmt_id
sysmt_instance
sysmt_mtlog
sysmt_mtapproval
sysmt_mtverification
sysmt_usersearch
sysmt_nfs
sysmt_prj2approval
sysmt_prj2bgrp
sysmt_prj2notification
sysmt_prj2verification
sysmt_prj2workflow
sysmt_set2bgrp
sysmt_sla
sysmt_sla2prj
sysmt_sys2set
sysmt_sysworkflow
sysmt_host
sysmt_disk
sysmt_system
sysmt_systemset
sysmt_bgroup
sysmt_user
sysmt_project
sysmt_thread
sysmt_threadlog
sysmt_threadgroup
sysmt_threadstat
sysmt_tg2bgrp
sysmt_document
sysmt_doc2thread
sysmt_fwsg
sysmt_fwsgentry
sysmt_fwps
sysmt_fwpsentry
sysmt_sysfw
);

usage() if ( ! GetOptions ("db=s" => \$db,
			   "name=s" => \$dbname,
			   "port=i" => \$dbport,
			   "host=s" => \$dbhost,
			   "user=s" => \$dbuser,
			   "pwd=s" => \$dbpwd,
			   "impfile=s" => \$impfile,
			   "force" => \$force)
	     or defined $help );

sub usage
{
    print "Unknown option: @_\n" if ( @_ );
    print "usage: sysmtimp.pl [--db=[db2|cego|mysql]] [--name=<name>] [--port=<port>] [--host=<host>]  [--user=<user>] [--pwd=<pwd>] [--impfile=<expfile>] [--force]\n";
    exit;
}

# cego url
my $url;

if ( $db eq "cego" )
{
    $url="dbi:Cego:tableset=$dbname;hostname=$dbhost;port=$dbport;protocol=serial;logfile=;logmode=notice";
    $dberrorcode=-1;
}
elsif ( $db eq "mysql" )
{
    $url="DBI:mysql:database=$dbname:host=$dbhost";
    $dberrorcode=-1;
}
elsif ( $db eq "db2" )
{
    $url="DBI:DB2:$dbname";
    $dberrorcode=0;
}
else
{
    print "Unknown database, choose either cego, db2 or mysql\n";
    exit;
}

#connect to MySQL database
my $dbh = DBI->connect ($url,
			$dbuser,
			$dbpwd,
			{
			    RaiseError => 1,
			    AutoCommit => 1
                        } ) or die "Can't connect to database: $DBI::errstr\n";


# first step : clean tables

cleanTables($dbh);

open IMPFILE, "cat $impfile |" or die "Can't open impfile $impfile\n";

my $data;
my $prevtable;

while ( <IMPFILE> )
{

    chop $_;

    # print "Line = " . $_ . "\n";

    @line = split (/,/, $_);


    for ( $i=0; $i<=$#line; $i++ )
    {
	( $attr, $value ) = split (/=/, $line[$i]);
	$$data{$attr} = $value;

    }

    if ( $prevtable ne $$data{'table'} )
    {
	print "Importing table " . $$data{'table'} . "...\n";
    }

    eval 
    {

	my $sth;

	if ( $$data{'table'} eq 'sysmt_project' )
	{
	    
	    $sth = $dbh->prepare("insert into sysmt_project ( pid, prjname, prjdesc, prjmail ) values ( ?, ?, ?, ? );");
	    
	    $sth->bind_param(1, $$data{'pid'}, SQL_INTEGER);
	    $sth->bind_param(2, $$data{'prjname'}, SQL_VARCHAR);
	    $sth->bind_param(3, $$data{'prjdesc'}, SQL_VARCHAR);
	    $sth->bind_param(4, $$data{'prjmail'}, SQL_VARCHAR);
	    
	}
	elsif ( $$data{'table'} eq 'sysmt_system' )
	{	
	    
	    $sysdesc = $$data{'sysdesc'};
	    $sysdesc =~ s/\\n/\n/g;
	    $sysdesc =~ s/%SEP%/,/g;
	    
	    $mtinfo = $$data{'mtinfo'};
	    $mtinfo =~ s/\\n/\n/g;
	    $mtinfo =~ s/%SEP%/,/g;
	    
	    $slaid = $$data{'slaid'};
	    if ( ! $slaid )
	    {
		$slaid = 0;
	    }
	    
		
	    $sth = $dbh->prepare("insert into sysmt_system ( sysid, sid, category, sysdesc, pid, systype, mtinfo, platform, status, saptype, vip, sysnr, scs, javaport, smdid, zoneA, zoneB, partA, partB, partC, partD, restartzones, dbtype, arch, nfsvip, vipip, vipif, dbversion, sharedfs, parthalog, slaid, sapversion, sdbtype, dbvip, dbvA, dbvB, scandbversion, scansapversion ) values ( ?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?);");
		
	    
	    $sth->bind_param(1, $$data{'sysid'}, SQL_INTEGER);
	    $sth->bind_param(2, $$data{'sid'}, SQL_VARCHAR);
	    $sth->bind_param(3, $$data{'category'}, SQL_VARCHAR);
	    $sth->bind_param(4, $sysdesc, SQL_VARCHAR);
	    $sth->bind_param(5, $$data{'pid'}, SQL_INTEGER);
	    $sth->bind_param(6, $$data{'systype'}, SQL_VARCHAR);
	    $sth->bind_param(7, $mtinfo, SQL_VARCHAR);
	    $sth->bind_param(8, $$data{'platform'}, SQL_VARCHAR);
	    $sth->bind_param(9, $$data{'status'}, SQL_VARCHAR);
	    $sth->bind_param(10, $$data{'saptype'}, SQL_VARCHAR);
	    $sth->bind_param(11, $$data{'vip'}, SQL_VARCHAR);
	    $sth->bind_param(12, $$data{'sysnr'}, SQL_VARCHAR);
	    $sth->bind_param(13, $$data{'scs'}, SQL_VARCHAR);
	    $sth->bind_param(14, $$data{'javaport'}, SQL_VARCHAR);
	    $sth->bind_param(15, $$data{'smdid'}, SQL_VARCHAR);
	    $sth->bind_param(16, $$data{'zoneA'}, SQL_VARCHAR);
	    $sth->bind_param(17, $$data{'zoneB'}, SQL_VARCHAR);
	    $sth->bind_param(18, $$data{'partA'}, SQL_VARCHAR);
	    $sth->bind_param(19, $$data{'partB'}, SQL_VARCHAR);
	    $sth->bind_param(20, $$data{'partC'}, SQL_VARCHAR);
	    $sth->bind_param(21, $$data{'partD'}, SQL_VARCHAR);
	    $sth->bind_param(22, $$data{'restartzones'}, SQL_VARCHAR);
	    # $sth->bind_param(23, $$data{'created'}, SQL_VARCHAR);
	    $sth->bind_param(23, $$data{'dbtype'}, SQL_VARCHAR);
	    $sth->bind_param(24, $$data{'arch'}, SQL_VARCHAR);
	    $sth->bind_param(25, $$data{'nfsvip'}, SQL_VARCHAR);
	    $sth->bind_param(26, $$data{'vipip'}, SQL_VARCHAR);
	    $sth->bind_param(27, $$data{'vipif'}, SQL_VARCHAR);
	    $sth->bind_param(28, $$data{'dbversion'}, SQL_VARCHAR);
	    $sth->bind_param(29, $$data{'sharedfs'}, SQL_VARCHAR);
	    $sth->bind_param(30, $$data{'parthalog'}, SQL_VARCHAR);
	    $sth->bind_param(31, $slaid, SQL_INTEGER);
	    $sth->bind_param(32, $$data{'sapversion'}, SQL_VARCHAR);
	    $sth->bind_param(33, $$data{'sdbtype'}, SQL_VARCHAR);
	    $sth->bind_param(34, $$data{'dbvip'}, SQL_VARCHAR);
	    $sth->bind_param(35, $$data{'dbvA'}, SQL_VARCHAR);
	    $sth->bind_param(36, $$data{'dbvB'}, SQL_VARCHAR);
	    $sth->bind_param(37, $$data{'scandbversion'}, SQL_VARCHAR);
	    $sth->bind_param(38, $$data{'scansapversion'}, SQL_VARCHAR);
	    
	}       
	elsif ( $$data{'table'} eq 'sysmt_mt' )
	{	
	    
	    $mtdesc = $$data{'description'};
	    $mtdesc =~ s/\\n/\n/g;
	    $mtdesc =~ s/%SEP%/,/g;
	    	    
	    if ( $db eq "cego" )
	    {
		$DTFORMAT="%Y-%m-%d-%H.%M.%S";
		
		if ( $$data{'mtfrom'} && $$data{'mtto'} )
		{
		    $d1="date('" . $DTFORMAT . "', '" . $$data{'mtfrom'} . "')";
		    $d2="date('" . $DTFORMAT . "', '" . $$data{'mtto'} . "')";	    
		}
		else
		{
		    $d1="null";
		    $d1="null";
		}
		if ( $$data{'downfrom'} && $$data{'downto'} )
		{
		    $d3="date('" . $DTFORMAT . "', '" . $$data{'downfrom'} . "')";
		    $d4="date('" . $DTFORMAT . "', '" . $$data{'downto'} . "')";	    
		}
		else
		{
		    $d3="null";
		    $d4="null";
		}
		
		$sth = $dbh->prepare("insert into sysmt_mt ( mid, shortdesc, description,mtfrom,mtto, status, ticketnr, sysid, lockby, mttype, downfrom,downto,repcomment,repappcheck) values ( ?,?,?," . $d1 . "," . $d2 . ",?,?,?,?,?," . $d3 . "," . $d4 .",?,? );");
		
		
		$sth->bind_param(1, $$data{'mid'}, SQL_INTEGER);
		$sth->bind_param(2, $$data{'shortdesc'}, SQL_VARCHAR);
		$sth->bind_param(3, $mtdesc, SQL_VARCHAR);	    	    
		$sth->bind_param(4, $$data{'status'}, SQL_VARCHAR);
		$sth->bind_param(5, $$data{'ticketnr'}, SQL_INTEGER);
		$sth->bind_param(6, $$data{'sysid'}, SQL_INTEGER);
		$sth->bind_param(7, $$data{'lockby'}, SQL_VARCHAR);
		$sth->bind_param(8, $$data{'mttype'}, SQL_VARCHAR);
		$sth->bind_param(9, $$data{'repcomment'}, SQL_VARCHAR);
		$sth->bind_param(10, $$data{'repappcheck'}, SQL_VARCHAR);
		
	    }
	    elsif ( $db eq "mysql" )
	    {
		
		$sth = $dbh->prepare("insert into sysmt_mt ( mid, shortdesc, description,mtfrom,mtto,downfrom,downto,status,ticketnr,sysid,lockby,mttype,repcomment,repappcheck) values ( ?,?,?,?,?,?,?,?,?,?,?,?,?,? );");
		
		$sth->bind_param(1, $$data{'mid'}, SQL_INTEGER);
		$sth->bind_param(2, $$data{'shortdesc'}, SQL_VARCHAR);
		$sth->bind_param(3, $mtdesc, SQL_VARCHAR);
		
		$sth->bind_param(4, $$data{'mtfrom'}, SQL_VARCHAR);
		$sth->bind_param(5, $$data{'mtto'}, SQL_VARCHAR);
		$sth->bind_param(6, $$data{'downfrom'}, SQL_VARCHAR);
		$sth->bind_param(7, $$data{'downto'}, SQL_VARCHAR);
		
		$sth->bind_param(8, $$data{'status'}, SQL_VARCHAR);
		$sth->bind_param(9, $$data{'ticketnr'}, SQL_INTEGER);
		$sth->bind_param(10, $$data{'sysid'}, SQL_INTEGER);
		$sth->bind_param(11, $$data{'lockby'}, SQL_VARCHAR);
		$sth->bind_param(12, $$data{'mttype'}, SQL_VARCHAR);
		$sth->bind_param(13, $$data{'repcomment'}, SQL_VARCHAR);
		$sth->bind_param(14, $$data{'repappcheck'}, SQL_VARCHAR);
		
		
	    }
	    elsif ( $db eq "db2" )
	    {
		
		$sth = $dbh->prepare("insert into sysmt_mt ( mid, shortdesc, description,mtfrom,mtto,downfrom,downto,status,ticketnr,sysid,lockby,mttype,repcomment,repappcheck) values ( ?,?,?,?,?,?,?,?,?,?,?,?,?,? );");
		
		$sth->bind_param(1, $$data{'mid'}, SQL_INTEGER);
		$sth->bind_param(2, $$data{'shortdesc'}, SQL_VARCHAR);
		$sth->bind_param(3, $mtdesc, SQL_VARCHAR);
		
		$sth->bind_param(4, $$data{'mtfrom'}, SQL_VARCHAR);
		$sth->bind_param(5, $$data{'mtto'}, SQL_VARCHAR);
		$sth->bind_param(6, $$data{'downfrom'}, SQL_VARCHAR);
		$sth->bind_param(7, $$data{'downto'}, SQL_VARCHAR);
		
		$sth->bind_param(8, $$data{'status'}, SQL_VARCHAR);
		$sth->bind_param(9, $$data{'ticketnr'}, SQL_INTEGER);
		$sth->bind_param(10, $$data{'sysid'}, SQL_INTEGER);
		$sth->bind_param(11, $$data{'lockby'}, SQL_VARCHAR);
		$sth->bind_param(12, $$data{'mttype'}, SQL_VARCHAR);
		$sth->bind_param(13, $$data{'repcomment'}, SQL_VARCHAR);
		$sth->bind_param(14, $$data{'repappcheck'}, SQL_VARCHAR);
		
	    }	    	   	    
	}
	elsif ( $$data{'table'} eq 'sysmt_user' )
	{
	    $userdesc = $$data{'userdesc'};
	    $userdesc =~ s/\\n/\n/g;
	    $userdesc =~ s/%SEP%/,/g;
	    
	    $sth = $dbh->prepare("insert into sysmt_user ( uid, dbuser, username, userdesc, userright, usermail ) values ( ?, ?, ?, ?, ?, ? );");
	    
	    $sth->bind_param(1, $$data{'uid'}, SQL_INTEGER);
	    $sth->bind_param(2, $$data{'dbuser'}, SQL_VARCHAR);
	    $sth->bind_param(3, $$data{'username'}, SQL_VARCHAR);
	    $sth->bind_param(4, $userdesc, SQL_VARCHAR);
	    $sth->bind_param(5, $$data{'userright'}, SQL_VARCHAR);
	    $sth->bind_param(6, $$data{'usermail'}, SQL_VARCHAR);
	    
	}
	elsif ( $$data{'table'} eq 'sysmt_bgroup' )
	{
	    $bgdesc = $$data{'bgdesc'};
	    $bgdesc =~ s/\\n/\n/g;
	    $bgdesc =~ s/%SEP%/,/g;
	    
	    $sth = $dbh->prepare("insert into sysmt_bgroup ( bgid, bgname, bgdesc ) values ( ?, ?, ? );");
	    
	    $sth->bind_param(1, $$data{'bgid'}, SQL_INTEGER);
	    $sth->bind_param(2, $$data{'bgname'}, SQL_VARCHAR);
	    $sth->bind_param(3, $bgdesc, SQL_VARCHAR);	    	    
	}
	elsif ( $$data{'table'} eq 'sysmt_systemset' )
	{
	    
	    $description = $$data{'description'};
	    $description =~ s/\\n/\n/g;
	    $description =~ s/%SEP%/,/g;
	    
	    $sth = $dbh->prepare("insert into sysmt_systemset ( setid, setname, description ) values ( ?, ?, ? );");
	    
	    $sth->bind_param(1, $$data{'setid'}, SQL_INTEGER);
	    $sth->bind_param(2, $$data{'setname'}, SQL_VARCHAR);
	    $sth->bind_param(3, $description, SQL_VARCHAR);
	}
	elsif ( $$data{'table'} eq 'sysmt_sys2set' )
	{
	    
	    $sth = $dbh->prepare("insert into sysmt_sys2set ( sysid, setid ) values ( ?, ? );");
	    
	    $sth->bind_param(1, $$data{'sysid'}, SQL_INTEGER);
	    $sth->bind_param(2, $$data{'setid'}, SQL_INTEGER);
	}
	elsif ( $$data{'table'} eq 'sysmt_usr2bgrp' )
	{
	    
	    $sth = $dbh->prepare("insert into sysmt_usr2bgrp ( uid, bgid ) values ( ?, ? );");
	    
	    $sth->bind_param(1, $$data{'uid'}, SQL_INTEGER);
	    $sth->bind_param(2, $$data{'bgid'}, SQL_INTEGER);
	}
	elsif ( $$data{'table'} eq 'sysmt_prj2bgrp' )
	{
	    
	    $sth = $dbh->prepare("insert into sysmt_prj2bgrp ( pid, bgid ) values ( ?, ? );");
	    
	    $sth->bind_param(1, $$data{'pid'}, SQL_INTEGER);
	    $sth->bind_param(2, $$data{'bgid'}, SQL_INTEGER);
	}
	elsif ( $$data{'table'} eq 'sysmt_set2bgrp' )
	{
	    
	    $sth = $dbh->prepare("insert into sysmt_set2bgrp ( setid, bgid ) values ( ?, ? );");
	    
	    $sth->bind_param(1, $$data{'setid'}, SQL_INTEGER);
	    $sth->bind_param(2, $$data{'bgid'}, SQL_INTEGER);
	}
	elsif ( $$data{'table'} eq 'sysmt_filesystmpl' )
	{
	    
	    $fstmplrule = $$data{'fstmplrule'};
	    $fstmplrule =~ s/%ESEP%/=/g;
	    
	    $sth = $dbh->prepare("insert into sysmt_filesystmpl (  tmplid, fstmplname, fstmpldesc, fstmplrule, fstmpltype ) values ( ?, ?, ?, ?, ? );");
	    
	    $sth->bind_param(1, $$data{'tmplid'}, SQL_INTEGER);
	    $sth->bind_param(2, $$data{'fstmplname'}, SQL_VARCHAR);
	    $sth->bind_param(3, $$data{'fstmpldesc'}, SQL_VARCHAR);
	    $sth->bind_param(4, $fstmplrule, SQL_VARCHAR);
	    $sth->bind_param(5, $$data{'fstmpltype'}, SQL_VARCHAR);
	}
	elsif ( $$data{'table'} eq 'sysmt_filesystmplentry' )
	{
	    
	    $fsopt = $$data{'fsopt'};
	    $fsopt =~ s/%SEP%/,/g;
	    $fsopt =~ s/%ESEP%/=/g;
	    
	    $sth = $dbh->prepare("insert into sysmt_filesystmplentry ( fsid, tmplid, fstype, fspath, fsvg, fssizesmall, fssizebig, fsopt, fslv ) values ( ?, ?, ?, ?, ?, ?, ?, ?, ? );");
	    
	    $fssizesmall = $$data{'fssizesmall'};
	    if ( ! $fssizesmall  )
	    {
		$fssizesmall=0;
	    }
	    
	    $fssizebig = $$data{'fssizebig'};
	    if ( ! $fssizebig  )
	    {
		$fssizebig=0;
	    }
	    
	    $sth->bind_param(1, $$data{'fsid'}, SQL_INTEGER);
	    $sth->bind_param(2, $$data{'tmplid'}, SQL_INTEGER);
	    $sth->bind_param(3, $$data{'fstype'}, SQL_VARCHAR);
	    $sth->bind_param(4, $$data{'fspath'}, SQL_VARCHAR);
	    $sth->bind_param(5, $$data{'fsvg'}, SQL_VARCHAR);
	    $sth->bind_param(6, $fssizesmall, SQL_INTEGER);
	    $sth->bind_param(7, $fssizebig, SQL_INTEGER);
	    $sth->bind_param(8, $fsopt, SQL_VARCHAR);
	    $sth->bind_param(9, $$data{'fslv'}, SQL_VARCHAR);
	}
	elsif ( $$data{'table'} eq 'sysmt_groupsearch2bgroup' )
	{
	    
	    $sth = $dbh->prepare("insert into sysmt_groupsearch2bgroup ( gsid, bgid ) values ( ?, ? );");
	    
	    $sth->bind_param(1, $$data{'gsid'}, SQL_INTEGER);
	    $sth->bind_param(2, $$data{'bgid'}, SQL_INTEGER);

	}
	elsif ( $$data{'table'} eq 'sysmt_prj2approval' )
	{
	    
	    $sth = $dbh->prepare("insert into sysmt_prj2approval ( pid, bgid ) values ( ?, ? );");
	    
	    $sth->bind_param(1, $$data{'pid'}, SQL_INTEGER);
	    $sth->bind_param(2, $$data{'bgid'}, SQL_INTEGER);
	}
	elsif ( $$data{'table'} eq 'sysmt_vip2host' )
	{
	    
	    $sth = $dbh->prepare("insert into sysmt_vip2host ( vip, hid ) values ( ?, ? );");
	    
	    $sth->bind_param(1, $$data{'vip'}, SQL_VARCHAR);
	    $sth->bind_param(2, $$data{'hid'}, SQL_INTEGER);

	}
	elsif ( $$data{'table'} eq 'sysmt_mtlog' )
	{
	    
	    if ( $db eq "cego" )
	    {
		$DTFORMAT="%Y-%m-%d-%H.%M.%S";
		$sth = $dbh->prepare("insert into sysmt_mtlog ( logts, mid, logentry ) values ( date('" . $DTFORMAT . "', ?), ?, ? );");
		
	    }
	    elsif ( $db eq "mysql" )
	    {
		$sth = $dbh->prepare("insert into sysmt_mtlog ( logts, mid, logentry ) values ( ?, ?, ? );");
	    }
	    elsif ( $db eq "db2" )
	    {
		$sth = $dbh->prepare("insert into sysmt_mtlog ( logts, mid, logentry ) values ( ?, ?, ? );");
	    }
	    
	    $sth->bind_param(1, $$data{'logts'}, SQL_VARCHAR);
	    $sth->bind_param(2, $$data{'mid'}, SQL_INTEGER);
	    $sth->bind_param(3, $$data{'logentry'}, SQL_VARCHAR);
	    
	}
	
	elsif ( $$data{'table'} eq 'sysmt_disk' )
	{
	    if ( $db eq "cego" )
	    {
		$DTFORMAT="%Y-%m-%d-%H.%M.%S";
		$sth = $dbh->prepare("insert into sysmt_disk ( did, scandate, status, diskname, disksize, diskusage, diskvg, slaid ) values ( ?, date('" . $DTFORMAT . "', ?), ?, ?, ?, ?, ?, ? );");
		
	    }
	    elsif ( $db eq "mysql" )
	    {
		$sth = $dbh->prepare("insert into sysmt_disk ( did, scandate, status, diskname, disksize, diskusage, diskvg, slaid ) values ( ?, ?, ?, ?, ?, ?, ?, ? );");
	    }
	    elsif ( $db eq "db2" )
	    {
		$sth = $dbh->prepare("insert into sysmt_disk ( did, scandate, status, diskname, disksize, diskusage, diskvg, slaid ) values ( ?, ?, ?, ?, ?, ?, ?, ? );");
	    }
	    
	    $slaid = $$data{'slaid'};
	    
	    if ( ! $slaid )
	    {
		$slaid = 0;
	    }
	    
	    $sth->bind_param(1, $$data{'did'}, SQL_INTEGER);
	    $sth->bind_param(2, $$data{'scandate'}, SQL_VARCHAR);
	    $sth->bind_param(3, $$data{'status'}, SQL_VARCHAR);
	    $sth->bind_param(4, $$data{'diskname'}, SQL_VARCHAR);
	    $sth->bind_param(5, $$data{'disksize'}, SQL_INTEGER);
	    $sth->bind_param(6, $$data{'diskusage'}, SQL_VARCHAR);
	    $sth->bind_param(7, $$data{'diskvg'}, SQL_VARCHAR);
	    $sth->bind_param(8, $slaid, SQL_INTEGER);
	    
	}
	elsif ( $$data{'table'} eq 'sysmt_disk2host' )
	{
	    
	    $sth = $dbh->prepare("insert into sysmt_disk2host ( did, hid ) values ( ?, ? );");
	    
	    $sth->bind_param(1, $$data{'did'}, SQL_INTEGER);
	    $sth->bind_param(2, $$data{'hid'}, SQL_INTEGER);	    
	}
	elsif ( $$data{'table'} eq 'sysmt_bgright' )
	{
	    
	    $sth = $dbh->prepare("insert into sysmt_bgright ( bgid, bgright ) values ( ?, ? );");
	    
	    $sth->bind_param(1, $$data{'bgid'}, SQL_INTEGER);
	    $sth->bind_param(2, $$data{'bgright'}, SQL_VARCHAR);
	}
	elsif ( $$data{'table'} eq 'sysmt_id' )
	{
	    
	    $sth = $dbh->prepare("insert into sysmt_id ( id, idval ) values ( ?, ? );");
	    
	    $sth->bind_param(1, $$data{'id'}, SQL_VARCHAR);
	    $sth->bind_param(2, $$data{'idval'}, SQL_INTEGER);
	}
	elsif ( $$data{'table'} eq 'sysmt_host' )
	{
	    
	    if ( $db eq "cego" )
	    {
		$DTFORMAT="%Y-%m-%d-%H.%M.%S";
		$sth = $dbh->prepare("insert into sysmt_host ( hid, scandate, status, hostname, hostinfo, osinfo, cpuinfo, meminfo) values ( ?, date('" . $DTFORMAT . "', ?), ?, ? ,?, ? ,?, ? );");
		
	    }
	    elsif ( $db eq "mysql" )
	    {
		$sth = $dbh->prepare("insert into sysmt_host ( hid, scandate, status, hostname, hostinfo, osinfo, cpuinfo, meminfo) values ( ?, ?, ?, ? ,?, ? ,?, ? );");
	    }
	    elsif ( $db eq "db2" )
	    {
		$sth = $dbh->prepare("insert into sysmt_host ( hid, scandate, status, hostname, hostinfo, osinfo, cpuinfo, meminfo) values ( ?, ?, ?, ? ,?, ? ,?, ? );");
		
	    }
	    
	    $sth->bind_param(1, $$data{'hid'}, SQL_INTEGER);      
	    $sth->bind_param(2, $$data{'scandate'}, SQL_VARCHAR);
	    $sth->bind_param(3, $$data{'status'}, SQL_VARCHAR);
	    $sth->bind_param(4, $$data{'hostname'}, SQL_VARCHAR);
	    $sth->bind_param(5, $$data{'hostinfo'}, SQL_VARCHAR);
	    $sth->bind_param(6, $$data{'osinfo'}, SQL_VARCHAR);
	    $sth->bind_param(7, $$data{'cpuinfo'}, SQL_VARCHAR);
	    $sth->bind_param(8, $$data{'meminfo'}, SQL_VARCHAR);
	    
	}
	elsif ( $$data{'table'} eq 'sysmt_usersearch' )
	{
	    
	    $sth = $dbh->prepare("insert into sysmt_usersearch ( usid, usname, usspec, uid ) values ( ?, ?, ?, ? );");
	    
	    $usspec= $$data{'usspec'};
	    $usspec =~ s/%ESEP%/=/g;
	    
	    $sth->bind_param(1, $$data{'usid'}, SQL_INTEGER);      
	    $sth->bind_param(2, $$data{'usname'}, SQL_VARCHAR);
	    $sth->bind_param(3, $usspec, SQL_VARCHAR);
	    $sth->bind_param(4, $$data{'uid'}, SQL_INTEGER);	    
	}
	elsif ( $$data{'table'} eq 'sysmt_custcond' )
	{
	    
	    $sth = $dbh->prepare("insert into sysmt_custcond ( ccid, ccname, ccspec, uid, cctype ) values ( ?, ?, ?, ?, ? );");
	    
	    $ccspec= $$data{'ccspec'};
	    $ccspec =~ s/%ESEP%/=/g;
	    
	    $sth->bind_param(1, $$data{'ccid'}, SQL_INTEGER);
	    $sth->bind_param(2, $$data{'ccname'}, SQL_VARCHAR);
	    $sth->bind_param(3, $ccspec, SQL_VARCHAR);
	    $sth->bind_param(4, $$data{'uid'}, SQL_INTEGER);
	    $sth->bind_param(5, $$data{'cctype'}, SQL_VARCHAR);
	}
	elsif ( $$data{'table'} eq 'sysmt_sysworkflow' )
	{
	    
	    if ( $db eq "cego" )
	    {
		$DTFORMAT="%Y-%m-%d-%H.%M.%S";
		$sth = $dbh->prepare("insert into sysmt_sysworkflow ( sysid, bgid, seqnr, assigned, released, dbuser, comment, status ) values ( ?, ?, ?, date('" . $DTFORMAT . "', ?), date('" . $DTFORMAT . "', ?), ? , ?, ? );");
		
	    }
	    elsif ( $db eq "mysql" )
	    {
		$sth = $dbh->prepare("insert into sysmt_sysworkflow ( sysid, bgid, seqnr, assigned, released, dbuser, comment, status ) values ( ?, ?, ?, ?, ?, ? , ?, ? );");
	    }
	    elsif ( $db eq "db2" )
	    {
		$sth = $dbh->prepare("insert into sysmt_sysworkflow ( sysid, bgid, seqnr, assigned, released, dbuser, comment, status ) values ( ?, ?, ?, ?, ?, ? , ?, ? );");
		
	    }
	    
	    $sth->bind_param(1, $$data{'sysid'}, SQL_INTEGER);
	    $sth->bind_param(2, $$data{'bgid'}, SQL_INTEGER);
	    $sth->bind_param(3, $$data{'seqnr'}, SQL_INTEGER);
	    $sth->bind_param(4, $$data{'assigned'}, SQL_VARCHAR);
	    $sth->bind_param(5, $$data{'released'}, SQL_VARCHAR);
	    $sth->bind_param(6, $$data{'dbuser'}, SQL_VARCHAR);
	    $sth->bind_param(7, $$data{'comment'}, SQL_VARCHAR);
	    $sth->bind_param(8, $$data{'status'}, SQL_VARCHAR);
	}
	elsif ( $$data{'table'} eq 'sysmt_prj2workflow' )
	{
	    
	    $sth = $dbh->prepare("insert into sysmt_prj2workflow ( pid, bgid, seqnr ) values ( ?, ?, ? );");
	    
	    $sth->bind_param(1, $$data{'pid'}, SQL_INTEGER);
	    $sth->bind_param(2, $$data{'bgid'}, SQL_INTEGER);
	    $sth->bind_param(3, $$data{'seqnr'}, SQL_INTEGER);
	}
	elsif ( $$data{'table'} eq 'sysmt_instance' )
	{
	    
	    if ( $db eq "cego" )
	    {
		$DTFORMAT="%Y-%m-%d-%H.%M.%S";
		$sth = $dbh->prepare("insert into sysmt_instance( instid, instnr, instvip, instsmd, instzone, instarch, sysid, instsaptype, instjavaport, instdisp ) values ( ?, ?, ?, ? ,?, ?, ?, ?, ?, ? );");
		
	    }
	    elsif ( $db eq "mysql" )
	    {
		$sth = $dbh->prepare("insert into sysmt_instance( instid, instnr, instvip, instsmd, instzone, instarch, sysid, instsaptype, instjavaport, instdisp ) values ( ?, ?, ?, ? ,?, ?, ?, ?, ?, ? );");
	    }
	    elsif ( $db eq "db2" )
	    {
		$sth = $dbh->prepare("insert into sysmt_instance( instid, instnr, instvip, instsmd, instzone, instarch, sysid, instsaptype, instjavaport, instdisp ) values ( ?, ?, ?, ? ,?, ?, ?, ?, ?, ? );");
		
	    }
	    	    
	    $sth->bind_param(1, $$data{'instid'}, SQL_INTEGER);
	    $sth->bind_param(2, $$data{'instnr'}, SQL_VARCHAR);
	    $sth->bind_param(3, $$data{'instvip'}, SQL_VARCHAR);
	    $sth->bind_param(4, $$data{'instsmd'}, SQL_VARCHAR);
	    $sth->bind_param(5, $$data{'instzone'}, SQL_VARCHAR);
	    $sth->bind_param(6, $$data{'instarch'}, SQL_VARCHAR);
	    $sth->bind_param(7, $$data{'sysid'}, SQL_INTEGER);
	    $sth->bind_param(8, $$data{'instsaptype'}, SQL_VARCHAR);
	    $sth->bind_param(9, $$data{'instjavaport'}, SQL_VARCHAR);
	    $sth->bind_param(10, $$data{'instdisp'}, SQL_VARCHAR);
	    
	}
	elsif ( $$data{'table'} eq 'sysmt_mtapproval' )
	{
	    
	    $sth = $dbh->prepare("insert into sysmt_mtapproval ( mid, bgid, status ) values ( ?, ?, ? );");
	    
	    $sth->bind_param(1, $$data{'mid'}, SQL_INTEGER);
	    $sth->bind_param(2, $$data{'bgid'}, SQL_INTEGER);
	    $sth->bind_param(3, $$data{'status'}, SQL_VARCHAR);
	    
	}
	elsif ( $$data{'table'} eq 'sysmt_filesys' )
	{
	    
	    $fsopt = $$data{'fsopt'};
	    $fsopt =~ s/%SEP%/,/g;	
	    $fsopt =~ s/%ESEP%/=/g;	
	    
	    $sth = $dbh->prepare("insert into sysmt_filesys ( fstype, fspath, fsvg, fssize, fsopt, fslv, sysid ) values  ( ?, ?, ?, ?, ?, ?, ? );");
	    
	    $sth->bind_param(1, $$data{'fstype'}, SQL_VARCHAR);
	    $sth->bind_param(2, $$data{'fspath'}, SQL_VARCHAR);
	    $sth->bind_param(3, $$data{'fsvg'}, SQL_VARCHAR);
	    $sth->bind_param(4, $$data{'fssize'}, SQL_INTEGER);
	    $sth->bind_param(5, $fsopt, SQL_VARCHAR);
	    $sth->bind_param(6, $$data{'fslv'}, SQL_VARCHAR);
	    $sth->bind_param(7, $$data{'sysid'}, SQL_INTEGER);
	    	    
	}
	elsif ( $$data{'table'} eq 'sysmt_groupsearch' )
	{
	    
	    $sth = $dbh->prepare("insert into sysmt_groupsearch ( gsid, gsname, gsspec ) values  ( ?, ?, ? );");
	    
	    $sth->bind_param(1, $$data{'gsid'}, SQL_INTEGER);
	    $sth->bind_param(2, $$data{'gsname'}, SQL_VARCHAR);
	    $sth->bind_param(3, $$data{'gsspec'}, SQL_VARCHAR);
	}
	elsif ( $$data{'table'} eq 'sysmt_dispsys' )
	{	
	    
	    $sth = $dbh->prepare("insert into sysmt_dispsys ( sysid, dispsysid ) values ( ?, ? );");
	    
	    $sth->bind_param(1, $$data{'sysid'}, SQL_INTEGER);
	    $sth->bind_param(2, $$data{'dispsysid'}, SQL_INTEGER);
	    	    
	}
	elsif ( $$data{'table'} eq 'sysmt_prj2notification' )
	{
	    
	    $sth = $dbh->prepare("insert into sysmt_prj2notification ( pid, bgid ) values ( ?, ? );");
	    
	    $sth->bind_param(1, $$data{'pid'}, SQL_INTEGER);
	    $sth->bind_param(2, $$data{'bgid'}, SQL_INTEGER);
	}
	elsif ( $$data{'table'} eq 'sysmt_prj2verification' )
	{	
	    $sth = $dbh->prepare("insert into sysmt_prj2verification ( pid, bgid ) values ( ?, ? );");
	    
	    $sth->bind_param(1, $$data{'pid'}, SQL_INTEGER);
	    $sth->bind_param(2, $$data{'bgid'}, SQL_INTEGER);
	    
	}
	elsif ( $$data{'table'} eq 'sysmt_addon' )
	{
	    
	    $sth = $dbh->prepare("insert into sysmt_addon ( aoid, aotype, aoname, aohome, aouser, aogroup, aoexepath, aologpath, sysid ) values ( ?,?,?,?,?,?,?,?,? );");
	    
	    $sth->bind_param(1, $$data{'aoid'}, SQL_INTEGER);
	    $sth->bind_param(2, $$data{'aotype'}, SQL_VARCHAR);
	    $sth->bind_param(3, $$data{'aoname'}, SQL_VARCHAR);
	    $sth->bind_param(4, $$data{'aohome'}, SQL_VARCHAR);
	    $sth->bind_param(5, $$data{'aouser'}, SQL_VARCHAR);
	    $sth->bind_param(6, $$data{'aogroup'}, SQL_VARCHAR);
	    $sth->bind_param(7, $$data{'aoexepath'}, SQL_VARCHAR);
	    $sth->bind_param(8, $$data{'aologpath'}, SQL_VARCHAR);
	    $sth->bind_param(9, $$data{'sysid'}, SQL_INTEGER);
	    
	}
	elsif ( $$data{'table'} eq 'sysmt_mtverification' )
	{
	    
	    $sth = $dbh->prepare("insert into sysmt_mtverification ( mid, bgid, status ) values ( ?, ?, ? );");
	    
	    $sth->bind_param(1, $$data{'mid'}, SQL_INTEGER);
	    $sth->bind_param(2, $$data{'bgid'}, SQL_INTEGER);
	    $sth->bind_param(3, $$data{'status'}, SQL_VARCHAR);
	}
	elsif ( $$data{'table'} eq 'sysmt_nfs' )
	{
	    
	    $sth = $dbh->prepare("insert into sysmt_nfs ( nfsid, nfspath, nfsnode, nfsmount, sysid ) values ( ?, ?, ?, ?,? );");
	    
	    $sth->bind_param(1, $$data{'nfsid'}, SQL_INTEGER);
	    $sth->bind_param(2, $$data{'nfspath'}, SQL_VARCHAR);
	    $sth->bind_param(3, $$data{'nfsnode'}, SQL_VARCHAR);
	    $sth->bind_param(4, $$data{'nfsmount'}, SQL_VARCHAR);
	    $sth->bind_param(5, $$data{'sysid'}, SQL_INTEGER);
	}
	elsif ( $$data{'table'} eq 'sysmt_sla' )
	{
	    
	    $sth = $dbh->prepare("insert into sysmt_sla ( slaid, slanr, shortdesc ) values ( ?,?,? );");
	    
	    $sth->bind_param(1, $$data{'slaid'}, SQL_INTEGER);
	    $sth->bind_param(2, $$data{'slanr'}, SQL_VARCHAR);
	    $sth->bind_param(3, $$data{'shortdesc'}, SQL_VARCHAR);
	    
	}
	elsif ( $$data{'table'} eq 'sysmt_sla2prj' )
	{
	    
	    $sth = $dbh->prepare("insert into sysmt_sla2prj ( slaid, pid ) values ( ?,? );");
	    
	    $sth->bind_param(1, $$data{'slaid'}, SQL_INTEGER);
	    $sth->bind_param(2, $$data{'pid'}, SQL_INTEGER);
	}
	elsif ( $$data{'table'} eq 'sysmt_gs2bgrp' )
	{
	    
	    $sth = $dbh->prepare("insert into sysmt_gs2bgrp ( gsid, bgid ) values ( ?,? );");
	    
	    $sth->bind_param(1, $$data{'gsid'}, SQL_INTEGER);
	    $sth->bind_param(2, $$data{'bgid'}, SQL_INTEGER);	    
	}
	elsif ( $$data{'table'} eq 'sysmt_thread' )
	{
	    
	    
	    if ( $db eq "cego" )
	    {
		$DTFORMAT="%Y-%m-%d-%H.%M.%S";
		$sth = $dbh->prepare("insert into sysmt_thread ( thrid, shortdesc, description, created, remind, lastedit, lasteditby, status, tgid, bgid ) values ( ?,?,?,date('" . $DTFORMAT . "', ?), date('" . $DTFORMAT . "', ?),date('" . $DTFORMAT . "', ?),?,?,?,?);");
		
	    }
	    elsif ( $db eq "mysql" )
	    {
		$sth = $dbh->prepare("insert into sysmt_thread ( thrid, shortdesc, description, created, remind, lastedit, lasteditby, status, tgid, bgid ) values ( ?,?,?,?,?,?,?,?,?,?);");	   
	    }
	    elsif ( $db eq "db2" )
	    {
		$sth = $dbh->prepare("insert into sysmt_thread ( thrid, shortdesc, description, created, remind, lastedit, lasteditby, status, tgid, bgid ) values ( ?,?,?,?,?,?,?,?,?,?);");	   
	    }
	    
	    $sth->bind_param(1, $$data{'thrid'}, SQL_INTEGER);
	    $sth->bind_param(2, $$data{'shortdesc'}, SQL_VARCHAR);
	    $sth->bind_param(3, $$data{'description'}, SQL_VARCHAR);
	    $sth->bind_param(4, $$data{'created'}, SQL_VARCHAR);
	    $sth->bind_param(5, $$data{'remind'}, SQL_VARCHAR);
	    $sth->bind_param(6, $$data{'lastedit'}, SQL_VARCHAR);
	    $sth->bind_param(7, $$data{'lasteditby'}, SQL_VARCHAR);
	    $sth->bind_param(8, $$data{'status'}, SQL_VARCHAR);
	    $sth->bind_param(9, $$data{'tgid'}, SQL_INTEGER);
	    $sth->bind_param(10, $$data{'bgid'}, SQL_INTEGER);
	}
	elsif ( $$data{'table'} eq 'sysmt_threadlog' )
	{
	    
	    if ( $db eq "cego" )
	    {
		$DTFORMAT="%Y-%m-%d-%H.%M.%S";
		$sth = $dbh->prepare("insert into sysmt_threadlog ( logts, logentry, thrid, dbuser ) values ( date('" . $DTFORMAT . "', ?),?,?,?);");
		
	    }
	    elsif ( $db eq "mysql" )
	    {
		$sth = $dbh->prepare("insert into sysmt_threadlog ( logts, logentry, thrid, dbuser ) values ( ?,?,?,?);");	   
	    }
	    elsif ( $db eq "db2" )
	    {
		$sth = $dbh->prepare("insert into sysmt_threadlog ( logts, logentry, thrid, dbuser ) values ( ?,?,?,?);");	   
	    }
	    
	    $sth->bind_param(1, $$data{'logts'}, SQL_VARCHAR);
	    $sth->bind_param(2, $$data{'logentry'}, SQL_VARCHAR);
	    $sth->bind_param(3, $$data{'thrid'}, SQL_INTEGER);
	    $sth->bind_param(4, $$data{'dbuser'}, SQL_VARCHAR);
	}
	elsif ( $$data{'table'} eq 'sysmt_threadgroup' )
	{
	    
	    $tgdesc = $$data{'tgdesc'};
	    $tgdesc =~ s/\\n/\n/g;
	    $tgdesc =~ s/%SEP%/,/g;
	    
	    $sth = $dbh->prepare("insert into sysmt_threadgroup ( tgid, tgname, tgdesc ) values ( ?,?,? );");
	    
	    $sth->bind_param(1, $$data{'tgid'}, SQL_INTEGER);
	    $sth->bind_param(2, $$data{'tgname'}, SQL_VARCHAR);
	    $sth->bind_param(3, $tgdesc, SQL_VARCHAR);	    
	}
	elsif ( $$data{'table'} eq 'sysmt_tg2bgrp' )
	{
	    
	    $sth = $dbh->prepare("insert into sysmt_tg2bgrp ( tgid, bgid ) values ( ?,? );");
	    
	    $sth->bind_param(1, $$data{'tgid'}, SQL_INTEGER);
	    $sth->bind_param(2, $$data{'bgid'}, SQL_INTEGER);
	}
	elsif ( $$data{'table'} eq 'sysmt_threadstat' )
	{
	    
	    $sth = $dbh->prepare("insert into sysmt_threadstat ( thrid, uid, readstat ) values ( ?,?,? );");
	    
	    $sth->bind_param(1, $$data{'thrid'}, SQL_INTEGER);
	    $sth->bind_param(2, $$data{'uid'}, SQL_INTEGER);
	    $sth->bind_param(3, $$data{'readstat'}, SQL_VARCHAR);
	}

	elsif ( $$data{'table'} eq 'sysmt_document' )
	{	    
	    $sth = $dbh->prepare("insert into sysmt_document ( docid, doctype, docname ) values ( ?,?,? );");	    
	    $sth->bind_param(1, $$data{'docid'}, SQL_INTEGER);
	    $sth->bind_param(2, $$data{'doctype'}, SQL_VARCHAR);
	    $sth->bind_param(3, $$data{'docname'}, SQL_VARCHAR);
	}
	elsif ( $$data{'table'} eq 'sysmt_doc2thread' )
	{	    
	    $sth = $dbh->prepare("insert into sysmt_doc2thread ( docid, thrid ) values ( ?,? );");
	    
	    $sth->bind_param(1, $$data{'docid'}, SQL_INTEGER);
	    $sth->bind_param(2, $$data{'thrid'}, SQL_INTEGER);
	}
	elsif ( $$data{'table'} eq 'sysmt_fwsg' )
	{
	    $sgdesc = $$data{'sgdesc'};
	    $sgdesc =~ s/\\n/\n/g;
	    $sgdesc =~ s/%SEP%/,/g;
	    
	    $sth = $dbh->prepare("insert into sysmt_fwsg ( sgid, sgname, sgdesc) values ( ?,?,? );");
	    
	    $sth->bind_param(1, $$data{'sgid'}, SQL_INTEGER);
	    $sth->bind_param(2, $$data{'sgname'}, SQL_VARCHAR);
	    $sth->bind_param(3, $sgdesc, SQL_VARCHAR);	    
	}
	elsif ( $$data{'table'} eq 'sysmt_fwsgentry' )
	{	    
	    $sth = $dbh->prepare("insert into sysmt_fwsgentry ( sgid, ipval, ipdesc ) values ( ?,?,? );");
	    
	    $sth->bind_param(1, $$data{'sgid'}, SQL_INTEGER);
	    $sth->bind_param(2, $$data{'ipval'}, SQL_VARCHAR);
	    $sth->bind_param(3, $$data{'ipdesc'}, SQL_VARCHAR);
	}
	elsif ( $$data{'table'} eq 'sysmt_fwps' )
	{	    
	    $psdesc = $$data{'psdesc'};
	    $psdesc =~ s/\\n/\n/g;
	    $psdesc =~ s/%SEP%/,/g;
	    
	    $sth = $dbh->prepare("insert into sysmt_fwps ( psid, psname, psdesc ) values ( ?,?,? );");
	    
	    $sth->bind_param(1, $$data{'psid'}, SQL_INTEGER);
	    $sth->bind_param(2, $$data{'psname'}, SQL_VARCHAR);
	    $sth->bind_param(3, $psdesc, SQL_VARCHAR);
	}
	elsif ( $$data{'table'} eq 'sysmt_fwpsentry' )
	{
	    $sth = $dbh->prepare("insert into sysmt_fwpsentry ( psid, portval, portdesc ) values ( ?,?,? );");
	    
	    $sth->bind_param(1, $$data{'psid'}, SQL_INTEGER);
	    $sth->bind_param(2, $$data{'portval'}, SQL_VARCHAR);
	    $sth->bind_param(3, $$data{'portdesc'}, SQL_VARCHAR);
	    
	}
	elsif ( $$data{'table'} eq 'sysmt_sysfw' )
	{
	    
	    $sth = $dbh->prepare("insert into sysmt_sysfw ( fwrid, sgidfrom, sgidto, psid, sysid ) values ( ?,?,?,?,? );");
	    
	    $sth->bind_param(1, $$data{'fwrid'}, SQL_INTEGER);
	    $sth->bind_param(2, $$data{'sgidfrom'}, SQL_INTEGER);
	    $sth->bind_param(3, $$data{'sgidto'}, SQL_INTEGER);
	    $sth->bind_param(4, $$data{'psid'}, SQL_INTEGER);
	    $sth->bind_param(5, $$data{'sysid'}, SQL_INTEGER);	    
	}

	$sth->execute;
	$sth->finish;
       
    };
    
    if ( $@ )
    {
	if ( $force )
	{
	    print "Ignoring error : " . $@ . "\n";
	}
        else
	{
	    print "Import error : " .  $@ . "\n";
	    exit 1;
	}
    }    
    
    $prevtable=$$data{'table'};
    
}

#disconnect from database
$dbh->disconnect or warn "Disconnection error: $DBI::errstr\n";

close IMPFILE;

exit; 


sub cleanTables
{
    my ( $dbh ) = @_;


    for ( $i=0; $i< @tablelist; $i++)
    {

	print "Cleaning table " . $tablelist[$i] . " ...\n";

	$sth = $dbh->prepare("delete from " . $tablelist[$i] . ";");
	
	if ( $sth->execute == -1 )
	{	
	    $errmsg = $sth->errstr;
	    exit;
	}
	$sth->finish;
    }

}
